/* Generated by Cython 0.29.21 */

/* BEGIN: Cython Metadata
{
    "distutils": {
        "name": "MorphologicalAnalysis.FsmMorphologicalAnalyzer",
        "sources": [
            "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx"
        ]
    },
    "module_name": "MorphologicalAnalysis.FsmMorphologicalAnalyzer"
}
END: Cython Metadata */

#define PY_SSIZE_T_CLEAN
#include "Python.h"
#ifndef Py_PYTHON_H
    #error Python headers needed to compile C extensions, please install development version of Python.
#elif PY_VERSION_HEX < 0x02060000 || (0x03000000 <= PY_VERSION_HEX && PY_VERSION_HEX < 0x03030000)
    #error Cython requires Python 2.6+ or Python 3.3+.
#else
#define CYTHON_ABI "0_29_21"
#define CYTHON_HEX_VERSION 0x001D15F0
#define CYTHON_FUTURE_DIVISION 1
#include <stddef.h>
#ifndef offsetof
  #define offsetof(type, member) ( (size_t) & ((type*)0) -> member )
#endif
#if !defined(WIN32) && !defined(MS_WINDOWS)
  #ifndef __stdcall
    #define __stdcall
  #endif
  #ifndef __cdecl
    #define __cdecl
  #endif
  #ifndef __fastcall
    #define __fastcall
  #endif
#endif
#ifndef DL_IMPORT
  #define DL_IMPORT(t) t
#endif
#ifndef DL_EXPORT
  #define DL_EXPORT(t) t
#endif
#define __PYX_COMMA ,
#ifndef HAVE_LONG_LONG
  #if PY_VERSION_HEX >= 0x02070000
    #define HAVE_LONG_LONG
  #endif
#endif
#ifndef PY_LONG_LONG
  #define PY_LONG_LONG LONG_LONG
#endif
#ifndef Py_HUGE_VAL
  #define Py_HUGE_VAL HUGE_VAL
#endif
#ifdef PYPY_VERSION
  #define CYTHON_COMPILING_IN_PYPY 1
  #define CYTHON_COMPILING_IN_PYSTON 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #if PY_VERSION_HEX < 0x03050000
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #undef CYTHON_AVOID_BORROWED_REFS
  #define CYTHON_AVOID_BORROWED_REFS 1
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE 0
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
#elif defined(PYSTON_VERSION)
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_PYSTON 1
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #undef CYTHON_USE_ASYNC_SLOTS
  #define CYTHON_USE_ASYNC_SLOTS 0
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE 0
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
#else
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_PYSTON 0
  #define CYTHON_COMPILING_IN_CPYTHON 1
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #if PY_VERSION_HEX < 0x02070000
    #undef CYTHON_USE_PYTYPE_LOOKUP
    #define CYTHON_USE_PYTYPE_LOOKUP 0
  #elif !defined(CYTHON_USE_PYTYPE_LOOKUP)
    #define CYTHON_USE_PYTYPE_LOOKUP 1
  #endif
  #if PY_MAJOR_VERSION < 3
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #if PY_VERSION_HEX < 0x02070000
    #undef CYTHON_USE_PYLONG_INTERNALS
    #define CYTHON_USE_PYLONG_INTERNALS 0
  #elif !defined(CYTHON_USE_PYLONG_INTERNALS)
    #define CYTHON_USE_PYLONG_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_PYLIST_INTERNALS
    #define CYTHON_USE_PYLIST_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #if PY_VERSION_HEX < 0x030300F0
    #undef CYTHON_USE_UNICODE_WRITER
    #define CYTHON_USE_UNICODE_WRITER 0
  #elif !defined(CYTHON_USE_UNICODE_WRITER)
    #define CYTHON_USE_UNICODE_WRITER 1
  #endif
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #ifndef CYTHON_FAST_THREAD_STATE
    #define CYTHON_FAST_THREAD_STATE 1
  #endif
  #ifndef CYTHON_FAST_PYCALL
    #define CYTHON_FAST_PYCALL 1
  #endif
  #ifndef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT (PY_VERSION_HEX >= 0x03050000)
  #endif
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE (PY_VERSION_HEX >= 0x030400a1)
  #endif
  #ifndef CYTHON_USE_DICT_VERSIONS
    #define CYTHON_USE_DICT_VERSIONS (PY_VERSION_HEX >= 0x030600B1)
  #endif
  #ifndef CYTHON_USE_EXC_INFO_STACK
    #define CYTHON_USE_EXC_INFO_STACK (PY_VERSION_HEX >= 0x030700A3)
  #endif
#endif
#if !defined(CYTHON_FAST_PYCCALL)
#define CYTHON_FAST_PYCCALL  (CYTHON_FAST_PYCALL && PY_VERSION_HEX >= 0x030600B1)
#endif
#if CYTHON_USE_PYLONG_INTERNALS
  #include "longintrepr.h"
  #undef SHIFT
  #undef BASE
  #undef MASK
  #ifdef SIZEOF_VOID_P
    enum { __pyx_check_sizeof_voidp = 1 / (int)(SIZEOF_VOID_P == sizeof(void*)) };
  #endif
#endif
#ifndef __has_attribute
  #define __has_attribute(x) 0
#endif
#ifndef __has_cpp_attribute
  #define __has_cpp_attribute(x) 0
#endif
#ifndef CYTHON_RESTRICT
  #if defined(__GNUC__)
    #define CYTHON_RESTRICT __restrict__
  #elif defined(_MSC_VER) && _MSC_VER >= 1400
    #define CYTHON_RESTRICT __restrict
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_RESTRICT restrict
  #else
    #define CYTHON_RESTRICT
  #endif
#endif
#ifndef CYTHON_UNUSED
# if defined(__GNUC__)
#   if !(defined(__cplusplus)) || (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4))
#     define CYTHON_UNUSED __attribute__ ((__unused__))
#   else
#     define CYTHON_UNUSED
#   endif
# elif defined(__ICC) || (defined(__INTEL_COMPILER) && !defined(_MSC_VER))
#   define CYTHON_UNUSED __attribute__ ((__unused__))
# else
#   define CYTHON_UNUSED
# endif
#endif
#ifndef CYTHON_MAYBE_UNUSED_VAR
#  if defined(__cplusplus)
     template<class T> void CYTHON_MAYBE_UNUSED_VAR( const T& ) { }
#  else
#    define CYTHON_MAYBE_UNUSED_VAR(x) (void)(x)
#  endif
#endif
#ifndef CYTHON_NCP_UNUSED
# if CYTHON_COMPILING_IN_CPYTHON
#  define CYTHON_NCP_UNUSED
# else
#  define CYTHON_NCP_UNUSED CYTHON_UNUSED
# endif
#endif
#define __Pyx_void_to_None(void_result) ((void)(void_result), Py_INCREF(Py_None), Py_None)
#ifdef _MSC_VER
    #ifndef _MSC_STDINT_H_
        #if _MSC_VER < 1300
           typedef unsigned char     uint8_t;
           typedef unsigned int      uint32_t;
        #else
           typedef unsigned __int8   uint8_t;
           typedef unsigned __int32  uint32_t;
        #endif
    #endif
#else
   #include <stdint.h>
#endif
#ifndef CYTHON_FALLTHROUGH
  #if defined(__cplusplus) && __cplusplus >= 201103L
    #if __has_cpp_attribute(fallthrough)
      #define CYTHON_FALLTHROUGH [[fallthrough]]
    #elif __has_cpp_attribute(clang::fallthrough)
      #define CYTHON_FALLTHROUGH [[clang::fallthrough]]
    #elif __has_cpp_attribute(gnu::fallthrough)
      #define CYTHON_FALLTHROUGH [[gnu::fallthrough]]
    #endif
  #endif
  #ifndef CYTHON_FALLTHROUGH
    #if __has_attribute(fallthrough)
      #define CYTHON_FALLTHROUGH __attribute__((fallthrough))
    #else
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
  #if defined(__clang__ ) && defined(__apple_build_version__)
    #if __apple_build_version__ < 7000000
      #undef  CYTHON_FALLTHROUGH
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
#endif

#ifndef CYTHON_INLINE
  #if defined(__clang__)
    #define CYTHON_INLINE __inline__ __attribute__ ((__unused__))
  #elif defined(__GNUC__)
    #define CYTHON_INLINE __inline__
  #elif defined(_MSC_VER)
    #define CYTHON_INLINE __inline
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_INLINE inline
  #else
    #define CYTHON_INLINE
  #endif
#endif

#if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX < 0x02070600 && !defined(Py_OptimizeFlag)
  #define Py_OptimizeFlag 0
#endif
#define __PYX_BUILD_PY_SSIZE_T "n"
#define CYTHON_FORMAT_SSIZE_T "z"
#if PY_MAJOR_VERSION < 3
  #define __Pyx_BUILTIN_MODULE_NAME "__builtin__"
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a+k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
  #define __Pyx_DefaultClassType PyClass_Type
#else
  #define __Pyx_BUILTIN_MODULE_NAME "builtins"
#if PY_VERSION_HEX >= 0x030800A4 && PY_VERSION_HEX < 0x030800B2
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a, 0, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#else
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#endif
  #define __Pyx_DefaultClassType PyType_Type
#endif
#ifndef Py_TPFLAGS_CHECKTYPES
  #define Py_TPFLAGS_CHECKTYPES 0
#endif
#ifndef Py_TPFLAGS_HAVE_INDEX
  #define Py_TPFLAGS_HAVE_INDEX 0
#endif
#ifndef Py_TPFLAGS_HAVE_NEWBUFFER
  #define Py_TPFLAGS_HAVE_NEWBUFFER 0
#endif
#ifndef Py_TPFLAGS_HAVE_FINALIZE
  #define Py_TPFLAGS_HAVE_FINALIZE 0
#endif
#ifndef METH_STACKLESS
  #define METH_STACKLESS 0
#endif
#if PY_VERSION_HEX <= 0x030700A3 || !defined(METH_FASTCALL)
  #ifndef METH_FASTCALL
     #define METH_FASTCALL 0x80
  #endif
  typedef PyObject *(*__Pyx_PyCFunctionFast) (PyObject *self, PyObject *const *args, Py_ssize_t nargs);
  typedef PyObject *(*__Pyx_PyCFunctionFastWithKeywords) (PyObject *self, PyObject *const *args,
                                                          Py_ssize_t nargs, PyObject *kwnames);
#else
  #define __Pyx_PyCFunctionFast _PyCFunctionFast
  #define __Pyx_PyCFunctionFastWithKeywords _PyCFunctionFastWithKeywords
#endif
#if CYTHON_FAST_PYCCALL
#define __Pyx_PyFastCFunction_Check(func)\
    ((PyCFunction_Check(func) && (METH_FASTCALL == (PyCFunction_GET_FLAGS(func) & ~(METH_CLASS | METH_STATIC | METH_COEXIST | METH_KEYWORDS | METH_STACKLESS)))))
#else
#define __Pyx_PyFastCFunction_Check(func) 0
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Malloc)
  #define PyObject_Malloc(s)   PyMem_Malloc(s)
  #define PyObject_Free(p)     PyMem_Free(p)
  #define PyObject_Realloc(p)  PyMem_Realloc(p)
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030400A1
  #define PyMem_RawMalloc(n)           PyMem_Malloc(n)
  #define PyMem_RawRealloc(p, n)       PyMem_Realloc(p, n)
  #define PyMem_RawFree(p)             PyMem_Free(p)
#endif
#if CYTHON_COMPILING_IN_PYSTON
  #define __Pyx_PyCode_HasFreeVars(co)  PyCode_HasFreeVars(co)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno) PyFrame_SetLineNumber(frame, lineno)
#else
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno)  (frame)->f_lineno = (lineno)
#endif
#if !CYTHON_FAST_THREAD_STATE || PY_VERSION_HEX < 0x02070000
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#elif PY_VERSION_HEX >= 0x03060000
  #define __Pyx_PyThreadState_Current _PyThreadState_UncheckedGet()
#elif PY_VERSION_HEX >= 0x03000000
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#else
  #define __Pyx_PyThreadState_Current _PyThreadState_Current
#endif
#if PY_VERSION_HEX < 0x030700A2 && !defined(PyThread_tss_create) && !defined(Py_tss_NEEDS_INIT)
#include "pythread.h"
#define Py_tss_NEEDS_INIT 0
typedef int Py_tss_t;
static CYTHON_INLINE int PyThread_tss_create(Py_tss_t *key) {
  *key = PyThread_create_key();
  return 0;
}
static CYTHON_INLINE Py_tss_t * PyThread_tss_alloc(void) {
  Py_tss_t *key = (Py_tss_t *)PyObject_Malloc(sizeof(Py_tss_t));
  *key = Py_tss_NEEDS_INIT;
  return key;
}
static CYTHON_INLINE void PyThread_tss_free(Py_tss_t *key) {
  PyObject_Free(key);
}
static CYTHON_INLINE int PyThread_tss_is_created(Py_tss_t *key) {
  return *key != Py_tss_NEEDS_INIT;
}
static CYTHON_INLINE void PyThread_tss_delete(Py_tss_t *key) {
  PyThread_delete_key(*key);
  *key = Py_tss_NEEDS_INIT;
}
static CYTHON_INLINE int PyThread_tss_set(Py_tss_t *key, void *value) {
  return PyThread_set_key_value(*key, value);
}
static CYTHON_INLINE void * PyThread_tss_get(Py_tss_t *key) {
  return PyThread_get_key_value(*key);
}
#endif
#if CYTHON_COMPILING_IN_CPYTHON || defined(_PyDict_NewPresized)
#define __Pyx_PyDict_NewPresized(n)  ((n <= 8) ? PyDict_New() : _PyDict_NewPresized(n))
#else
#define __Pyx_PyDict_NewPresized(n)  PyDict_New()
#endif
#if PY_MAJOR_VERSION >= 3 || CYTHON_FUTURE_DIVISION
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_TrueDivide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceTrueDivide(x,y)
#else
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_Divide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceDivide(x,y)
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030500A1 && CYTHON_USE_UNICODE_INTERNALS
#define __Pyx_PyDict_GetItemStr(dict, name)  _PyDict_GetItem_KnownHash(dict, name, ((PyASCIIObject *) name)->hash)
#else
#define __Pyx_PyDict_GetItemStr(dict, name)  PyDict_GetItem(dict, name)
#endif
#if PY_VERSION_HEX > 0x03030000 && defined(PyUnicode_KIND)
  #define CYTHON_PEP393_ENABLED 1
  #define __Pyx_PyUnicode_READY(op)       (likely(PyUnicode_IS_READY(op)) ?\
                                              0 : _PyUnicode_Ready((PyObject *)(op)))
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_LENGTH(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_READ_CHAR(u, i)
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   PyUnicode_MAX_CHAR_VALUE(u)
  #define __Pyx_PyUnicode_KIND(u)         PyUnicode_KIND(u)
  #define __Pyx_PyUnicode_DATA(u)         PyUnicode_DATA(u)
  #define __Pyx_PyUnicode_READ(k, d, i)   PyUnicode_READ(k, d, i)
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  PyUnicode_WRITE(k, d, i, ch)
  #if defined(PyUnicode_IS_READY) && defined(PyUnicode_GET_SIZE)
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : PyUnicode_GET_SIZE(u)))
  #else
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_LENGTH(u))
  #endif
#else
  #define CYTHON_PEP393_ENABLED 0
  #define PyUnicode_1BYTE_KIND  1
  #define PyUnicode_2BYTE_KIND  2
  #define PyUnicode_4BYTE_KIND  4
  #define __Pyx_PyUnicode_READY(op)       (0)
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_SIZE(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) ((Py_UCS4)(PyUnicode_AS_UNICODE(u)[i]))
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   ((sizeof(Py_UNICODE) == 2) ? 65535 : 1114111)
  #define __Pyx_PyUnicode_KIND(u)         (sizeof(Py_UNICODE))
  #define __Pyx_PyUnicode_DATA(u)         ((void*)PyUnicode_AS_UNICODE(u))
  #define __Pyx_PyUnicode_READ(k, d, i)   ((void)(k), (Py_UCS4)(((Py_UNICODE*)d)[i]))
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  (((void)(k)), ((Py_UNICODE*)d)[i] = ch)
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_SIZE(u))
#endif
#if CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyUnicode_Concat(a, b)      PyNumber_Add(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  PyNumber_Add(a, b)
#else
  #define __Pyx_PyUnicode_Concat(a, b)      PyUnicode_Concat(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  ((unlikely((a) == Py_None) || unlikely((b) == Py_None)) ?\
      PyNumber_Add(a, b) : __Pyx_PyUnicode_Concat(a, b))
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyUnicode_Contains)
  #define PyUnicode_Contains(u, s)  PySequence_Contains(u, s)
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyByteArray_Check)
  #define PyByteArray_Check(obj)  PyObject_TypeCheck(obj, &PyByteArray_Type)
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Format)
  #define PyObject_Format(obj, fmt)  PyObject_CallMethod(obj, "__format__", "O", fmt)
#endif
#define __Pyx_PyString_FormatSafe(a, b)   ((unlikely((a) == Py_None || (PyString_Check(b) && !PyString_CheckExact(b)))) ? PyNumber_Remainder(a, b) : __Pyx_PyString_Format(a, b))
#define __Pyx_PyUnicode_FormatSafe(a, b)  ((unlikely((a) == Py_None || (PyUnicode_Check(b) && !PyUnicode_CheckExact(b)))) ? PyNumber_Remainder(a, b) : PyUnicode_Format(a, b))
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyString_Format(a, b)  PyUnicode_Format(a, b)
#else
  #define __Pyx_PyString_Format(a, b)  PyString_Format(a, b)
#endif
#if PY_MAJOR_VERSION < 3 && !defined(PyObject_ASCII)
  #define PyObject_ASCII(o)            PyObject_Repr(o)
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBaseString_Type            PyUnicode_Type
  #define PyStringObject               PyUnicodeObject
  #define PyString_Type                PyUnicode_Type
  #define PyString_Check               PyUnicode_Check
  #define PyString_CheckExact          PyUnicode_CheckExact
#ifndef PyObject_Unicode
  #define PyObject_Unicode             PyObject_Str
#endif
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyBaseString_Check(obj) PyUnicode_Check(obj)
  #define __Pyx_PyBaseString_CheckExact(obj) PyUnicode_CheckExact(obj)
#else
  #define __Pyx_PyBaseString_Check(obj) (PyString_Check(obj) || PyUnicode_Check(obj))
  #define __Pyx_PyBaseString_CheckExact(obj) (PyString_CheckExact(obj) || PyUnicode_CheckExact(obj))
#endif
#ifndef PySet_CheckExact
  #define PySet_CheckExact(obj)        (Py_TYPE(obj) == &PySet_Type)
#endif
#if PY_VERSION_HEX >= 0x030900A4
  #define __Pyx_SET_REFCNT(obj, refcnt) Py_SET_REFCNT(obj, refcnt)
  #define __Pyx_SET_SIZE(obj, size) Py_SET_SIZE(obj, size)
#else
  #define __Pyx_SET_REFCNT(obj, refcnt) Py_REFCNT(obj) = (refcnt)
  #define __Pyx_SET_SIZE(obj, size) Py_SIZE(obj) = (size)
#endif
#if CYTHON_ASSUME_SAFE_MACROS
  #define __Pyx_PySequence_SIZE(seq)  Py_SIZE(seq)
#else
  #define __Pyx_PySequence_SIZE(seq)  PySequence_Size(seq)
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyIntObject                  PyLongObject
  #define PyInt_Type                   PyLong_Type
  #define PyInt_Check(op)              PyLong_Check(op)
  #define PyInt_CheckExact(op)         PyLong_CheckExact(op)
  #define PyInt_FromString             PyLong_FromString
  #define PyInt_FromUnicode            PyLong_FromUnicode
  #define PyInt_FromLong               PyLong_FromLong
  #define PyInt_FromSize_t             PyLong_FromSize_t
  #define PyInt_FromSsize_t            PyLong_FromSsize_t
  #define PyInt_AsLong                 PyLong_AsLong
  #define PyInt_AS_LONG                PyLong_AS_LONG
  #define PyInt_AsSsize_t              PyLong_AsSsize_t
  #define PyInt_AsUnsignedLongMask     PyLong_AsUnsignedLongMask
  #define PyInt_AsUnsignedLongLongMask PyLong_AsUnsignedLongLongMask
  #define PyNumber_Int                 PyNumber_Long
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBoolObject                 PyLongObject
#endif
#if PY_MAJOR_VERSION >= 3 && CYTHON_COMPILING_IN_PYPY
  #ifndef PyUnicode_InternFromString
    #define PyUnicode_InternFromString(s) PyUnicode_FromString(s)
  #endif
#endif
#if PY_VERSION_HEX < 0x030200A4
  typedef long Py_hash_t;
  #define __Pyx_PyInt_FromHash_t PyInt_FromLong
  #define __Pyx_PyInt_AsHash_t   PyInt_AsLong
#else
  #define __Pyx_PyInt_FromHash_t PyInt_FromSsize_t
  #define __Pyx_PyInt_AsHash_t   PyInt_AsSsize_t
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyMethod_New(func, self, klass) ((self) ? ((void)(klass), PyMethod_New(func, self)) : __Pyx_NewRef(func))
#else
  #define __Pyx_PyMethod_New(func, self, klass) PyMethod_New(func, self, klass)
#endif
#if CYTHON_USE_ASYNC_SLOTS
  #if PY_VERSION_HEX >= 0x030500B1
    #define __Pyx_PyAsyncMethodsStruct PyAsyncMethods
    #define __Pyx_PyType_AsAsync(obj) (Py_TYPE(obj)->tp_as_async)
  #else
    #define __Pyx_PyType_AsAsync(obj) ((__Pyx_PyAsyncMethodsStruct*) (Py_TYPE(obj)->tp_reserved))
  #endif
#else
  #define __Pyx_PyType_AsAsync(obj) NULL
#endif
#ifndef __Pyx_PyAsyncMethodsStruct
    typedef struct {
        unaryfunc am_await;
        unaryfunc am_aiter;
        unaryfunc am_anext;
    } __Pyx_PyAsyncMethodsStruct;
#endif

#if defined(WIN32) || defined(MS_WINDOWS)
  #define _USE_MATH_DEFINES
#endif
#include <math.h>
#ifdef NAN
#define __PYX_NAN() ((float) NAN)
#else
static CYTHON_INLINE float __PYX_NAN() {
  float value;
  memset(&value, 0xFF, sizeof(value));
  return value;
}
#endif
#if defined(__CYGWIN__) && defined(_LDBL_EQ_DBL)
#define __Pyx_truncl trunc
#else
#define __Pyx_truncl truncl
#endif

#define __PYX_MARK_ERR_POS(f_index, lineno) \
    { __pyx_filename = __pyx_f[f_index]; (void)__pyx_filename; __pyx_lineno = lineno; (void)__pyx_lineno; __pyx_clineno = __LINE__; (void)__pyx_clineno; }
#define __PYX_ERR(f_index, lineno, Ln_error) \
    { __PYX_MARK_ERR_POS(f_index, lineno) goto Ln_error; }

#ifndef __PYX_EXTERN_C
  #ifdef __cplusplus
    #define __PYX_EXTERN_C extern "C"
  #else
    #define __PYX_EXTERN_C extern
  #endif
#endif

#define __PYX_HAVE__MorphologicalAnalysis__FsmMorphologicalAnalyzer
#define __PYX_HAVE_API__MorphologicalAnalysis__FsmMorphologicalAnalyzer
/* Early includes */
#ifdef _OPENMP
#include <omp.h>
#endif /* _OPENMP */

#if defined(PYREX_WITHOUT_ASSERTIONS) && !defined(CYTHON_WITHOUT_ASSERTIONS)
#define CYTHON_WITHOUT_ASSERTIONS
#endif

typedef struct {PyObject **p; const char *s; const Py_ssize_t n; const char* encoding;
                const char is_unicode; const char is_str; const char intern; } __Pyx_StringTabEntry;

#define __PYX_DEFAULT_STRING_ENCODING_IS_ASCII 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_UTF8 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT (PY_MAJOR_VERSION >= 3 && __PYX_DEFAULT_STRING_ENCODING_IS_UTF8)
#define __PYX_DEFAULT_STRING_ENCODING ""
#define __Pyx_PyObject_FromString __Pyx_PyBytes_FromString
#define __Pyx_PyObject_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#define __Pyx_uchar_cast(c) ((unsigned char)c)
#define __Pyx_long_cast(x) ((long)x)
#define __Pyx_fits_Py_ssize_t(v, type, is_signed)  (\
    (sizeof(type) < sizeof(Py_ssize_t))  ||\
    (sizeof(type) > sizeof(Py_ssize_t) &&\
          likely(v < (type)PY_SSIZE_T_MAX ||\
                 v == (type)PY_SSIZE_T_MAX)  &&\
          (!is_signed || likely(v > (type)PY_SSIZE_T_MIN ||\
                                v == (type)PY_SSIZE_T_MIN)))  ||\
    (sizeof(type) == sizeof(Py_ssize_t) &&\
          (is_signed || likely(v < (type)PY_SSIZE_T_MAX ||\
                               v == (type)PY_SSIZE_T_MAX)))  )
static CYTHON_INLINE int __Pyx_is_valid_index(Py_ssize_t i, Py_ssize_t limit) {
    return (size_t) i < (size_t) limit;
}
#if defined (__cplusplus) && __cplusplus >= 201103L
    #include <cstdlib>
    #define __Pyx_sst_abs(value) std::abs(value)
#elif SIZEOF_INT >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) abs(value)
#elif SIZEOF_LONG >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) labs(value)
#elif defined (_MSC_VER)
    #define __Pyx_sst_abs(value) ((Py_ssize_t)_abs64(value))
#elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define __Pyx_sst_abs(value) llabs(value)
#elif defined (__GNUC__)
    #define __Pyx_sst_abs(value) __builtin_llabs(value)
#else
    #define __Pyx_sst_abs(value) ((value<0) ? -value : value)
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject*);
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject*, Py_ssize_t* length);
#define __Pyx_PyByteArray_FromString(s) PyByteArray_FromStringAndSize((const char*)s, strlen((const char*)s))
#define __Pyx_PyByteArray_FromStringAndSize(s, l) PyByteArray_FromStringAndSize((const char*)s, l)
#define __Pyx_PyBytes_FromString        PyBytes_FromString
#define __Pyx_PyBytes_FromStringAndSize PyBytes_FromStringAndSize
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char*);
#if PY_MAJOR_VERSION < 3
    #define __Pyx_PyStr_FromString        __Pyx_PyBytes_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#else
    #define __Pyx_PyStr_FromString        __Pyx_PyUnicode_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyUnicode_FromStringAndSize
#endif
#define __Pyx_PyBytes_AsWritableString(s)     ((char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsWritableSString(s)    ((signed char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsWritableUString(s)    ((unsigned char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsString(s)     ((const char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsSString(s)    ((const signed char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsUString(s)    ((const unsigned char*) PyBytes_AS_STRING(s))
#define __Pyx_PyObject_AsWritableString(s)    ((char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableSString(s)    ((signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableUString(s)    ((unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsSString(s)    ((const signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsUString(s)    ((const unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_FromCString(s)  __Pyx_PyObject_FromString((const char*)s)
#define __Pyx_PyBytes_FromCString(s)   __Pyx_PyBytes_FromString((const char*)s)
#define __Pyx_PyByteArray_FromCString(s)   __Pyx_PyByteArray_FromString((const char*)s)
#define __Pyx_PyStr_FromCString(s)     __Pyx_PyStr_FromString((const char*)s)
#define __Pyx_PyUnicode_FromCString(s) __Pyx_PyUnicode_FromString((const char*)s)
static CYTHON_INLINE size_t __Pyx_Py_UNICODE_strlen(const Py_UNICODE *u) {
    const Py_UNICODE *u_end = u;
    while (*u_end++) ;
    return (size_t)(u_end - u - 1);
}
#define __Pyx_PyUnicode_FromUnicode(u)       PyUnicode_FromUnicode(u, __Pyx_Py_UNICODE_strlen(u))
#define __Pyx_PyUnicode_FromUnicodeAndLength PyUnicode_FromUnicode
#define __Pyx_PyUnicode_AsUnicode            PyUnicode_AsUnicode
#define __Pyx_NewRef(obj) (Py_INCREF(obj), obj)
#define __Pyx_Owned_Py_None(b) __Pyx_NewRef(Py_None)
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b);
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject*);
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject*);
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x);
#define __Pyx_PySequence_Tuple(obj)\
    (likely(PyTuple_CheckExact(obj)) ? __Pyx_NewRef(obj) : PySequence_Tuple(obj))
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject*);
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t);
#if CYTHON_ASSUME_SAFE_MACROS
#define __pyx_PyFloat_AsDouble(x) (PyFloat_CheckExact(x) ? PyFloat_AS_DOUBLE(x) : PyFloat_AsDouble(x))
#else
#define __pyx_PyFloat_AsDouble(x) PyFloat_AsDouble(x)
#endif
#define __pyx_PyFloat_AsFloat(x) ((float) __pyx_PyFloat_AsDouble(x))
#if PY_MAJOR_VERSION >= 3
#define __Pyx_PyNumber_Int(x) (PyLong_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Long(x))
#else
#define __Pyx_PyNumber_Int(x) (PyInt_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Int(x))
#endif
#define __Pyx_PyNumber_Float(x) (PyFloat_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Float(x))
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
static int __Pyx_sys_getdefaultencoding_not_ascii;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    PyObject* ascii_chars_u = NULL;
    PyObject* ascii_chars_b = NULL;
    const char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    if (strcmp(default_encoding_c, "ascii") == 0) {
        __Pyx_sys_getdefaultencoding_not_ascii = 0;
    } else {
        char ascii_chars[128];
        int c;
        for (c = 0; c < 128; c++) {
            ascii_chars[c] = c;
        }
        __Pyx_sys_getdefaultencoding_not_ascii = 1;
        ascii_chars_u = PyUnicode_DecodeASCII(ascii_chars, 128, NULL);
        if (!ascii_chars_u) goto bad;
        ascii_chars_b = PyUnicode_AsEncodedString(ascii_chars_u, default_encoding_c, NULL);
        if (!ascii_chars_b || !PyBytes_Check(ascii_chars_b) || memcmp(ascii_chars, PyBytes_AS_STRING(ascii_chars_b), 128) != 0) {
            PyErr_Format(
                PyExc_ValueError,
                "This module compiled with c_string_encoding=ascii, but default encoding '%.200s' is not a superset of ascii.",
                default_encoding_c);
            goto bad;
        }
        Py_DECREF(ascii_chars_u);
        Py_DECREF(ascii_chars_b);
    }
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    Py_XDECREF(ascii_chars_u);
    Py_XDECREF(ascii_chars_b);
    return -1;
}
#endif
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT && PY_MAJOR_VERSION >= 3
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeUTF8(c_str, size, NULL)
#else
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_Decode(c_str, size, __PYX_DEFAULT_STRING_ENCODING, NULL)
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
static char* __PYX_DEFAULT_STRING_ENCODING;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) (const char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    __PYX_DEFAULT_STRING_ENCODING = (char*) malloc(strlen(default_encoding_c) + 1);
    if (!__PYX_DEFAULT_STRING_ENCODING) goto bad;
    strcpy(__PYX_DEFAULT_STRING_ENCODING, default_encoding_c);
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    return -1;
}
#endif
#endif


/* Test for GCC > 2.95 */
#if defined(__GNUC__)     && (__GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95)))
  #define likely(x)   __builtin_expect(!!(x), 1)
  #define unlikely(x) __builtin_expect(!!(x), 0)
#else /* !__GNUC__ or GCC < 2.95 */
  #define likely(x)   (x)
  #define unlikely(x) (x)
#endif /* __GNUC__ */
static CYTHON_INLINE void __Pyx_pretend_to_initialize(void* ptr) { (void)ptr; }

static PyObject *__pyx_m = NULL;
static PyObject *__pyx_d;
static PyObject *__pyx_b;
static PyObject *__pyx_cython_runtime = NULL;
static PyObject *__pyx_empty_tuple;
static PyObject *__pyx_empty_bytes;
static PyObject *__pyx_empty_unicode;
static int __pyx_lineno;
static int __pyx_clineno = 0;
static const char * __pyx_cfilenm= __FILE__;
static const char *__pyx_filename;


static const char *__pyx_f[] = {
  "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx",
  "stringsource",
  "Word.pxd",
  "TrieNode.pxd",
  "TxtWord.pxd",
  "Trie.pxd",
  "Dictionary.pxd",
  "TxtDictionary.pxd",
  "LRUCache.pxd",
  "MorphologicalAnalysis/InflectionalGroup.pxd",
  "MorphologicalAnalysis/MorphologicalParse.pxd",
  "MorphologicalAnalysis/State.pxd",
  "MorphologicalAnalysis/FsmParse.pxd",
  "MorphologicalAnalysis/FiniteStateMachine.pxd",
  "MorphologicalAnalysis/MetamorphicParse.pxd",
  "Sentence.pxd",
  "MorphologicalAnalysis/FsmParseList.pxd",
  "MorphologicalAnalysis/Transition.pxd",
};

/*--- Type declarations ---*/
struct __pyx_obj_10Dictionary_4Word_Word;
struct __pyx_obj_10Dictionary_4Trie_8TrieNode_TrieNode;
struct __pyx_obj_10Dictionary_7TxtWord_TxtWord;
struct __pyx_obj_10Dictionary_4Trie_4Trie_Trie;
struct __pyx_obj_10Dictionary_10Dictionary_Dictionary;
struct __pyx_obj_10Dictionary_13TxtDictionary_TxtDictionary;
struct __pyx_obj_13DataStructure_5Cache_8LRUCache_LRUCache;
struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup;
struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse;
struct __pyx_obj_21MorphologicalAnalysis_5State_State;
struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse;
struct __pyx_obj_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine;
struct __pyx_obj_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse;
struct __pyx_obj_6Corpus_8Sentence_Sentence;
struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList;
struct __pyx_obj_21MorphologicalAnalysis_10Transition_Transition;
struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer;
struct __pyx_opt_args_10Dictionary_4Trie_8TrieNode_8TrieNode_addWord;

/* "Dictionary/Trie/TrieNode.pxd":9
 *     cdef set __words
 * 
 *     cpdef addWord(self, str word, Word root, int index=*)             # <<<<<<<<<<<<<<
 *     cpdef TrieNode getChild(self, char ch)
 *     cpdef set getWords(self)
 */
struct __pyx_opt_args_10Dictionary_4Trie_8TrieNode_8TrieNode_addWord {
  int __pyx_n;
  int index;
};
struct __pyx_opt_args_21MorphologicalAnalysis_18FiniteStateMachine_18FiniteStateMachine_addTransition;

/* "MorphologicalAnalysis/FiniteStateMachine.pxd":12
 *     cpdef list getStates(self)
 *     cpdef State getState(self, str name)
 *     cpdef addTransition(self, State fromState, State toState, str _with, str withName, toPos=*)             # <<<<<<<<<<<<<<
 *     cpdef list getTransitions(self, State state)
 */
struct __pyx_opt_args_21MorphologicalAnalysis_18FiniteStateMachine_18FiniteStateMachine_addTransition {
  int __pyx_n;
  PyObject *toPos;
};
struct __pyx_opt_args_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_morphologicalAnalysisRoot;

/* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pxd":33
 *     cpdef bint __parseExists(self, list fsmParse, str surfaceForm)
 *     cpdef list __parseWord(self, list fsmParse, maxLengthOrSurfaceForm)
 *     cpdef list morphologicalAnalysisRoot(self, str surfaceForm, TxtWord root, state=*)             # <<<<<<<<<<<<<<
 *     cpdef list generateAllParses(self, TxtWord root, int maxLength)
 *     cpdef bint __analysisExists(self, TxtWord rootWord, str surfaceForm, bint isProper)
 */
struct __pyx_opt_args_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_morphologicalAnalysisRoot {
  int __pyx_n;
  PyObject *state;
};

/* "Dictionary/Word.pxd":1
 * cdef class Word:             # <<<<<<<<<<<<<<
 * 
 *     cdef str name
 */
struct __pyx_obj_10Dictionary_4Word_Word {
  PyObject_HEAD
  struct __pyx_vtabstruct_10Dictionary_4Word_Word *__pyx_vtab;
  PyObject *name;
};


/* "Dictionary/Trie/TrieNode.pxd":4
 * 
 * 
 * cdef class TrieNode:             # <<<<<<<<<<<<<<
 * 
 *     cdef dict __children
 */
struct __pyx_obj_10Dictionary_4Trie_8TrieNode_TrieNode {
  PyObject_HEAD
  struct __pyx_vtabstruct_10Dictionary_4Trie_8TrieNode_TrieNode *__pyx_vtab;
  PyObject *__pyx___children;
  PyObject *__pyx___words;
};


/* "Dictionary/TxtWord.pxd":4
 * 
 * 
 * cdef class TxtWord(Word):             # <<<<<<<<<<<<<<
 * 
 *     cdef list __flags
 */
struct __pyx_obj_10Dictionary_7TxtWord_TxtWord {
  struct __pyx_obj_10Dictionary_4Word_Word __pyx_base;
  PyObject *__pyx___flags;
};


/* "Dictionary/Trie/Trie.pxd":6
 * 
 * 
 * cdef class Trie:             # <<<<<<<<<<<<<<
 * 
 *     cdef TrieNode __rootNode
 */
struct __pyx_obj_10Dictionary_4Trie_4Trie_Trie {
  PyObject_HEAD
  struct __pyx_vtabstruct_10Dictionary_4Trie_4Trie_Trie *__pyx_vtab;
  struct __pyx_obj_10Dictionary_4Trie_8TrieNode_TrieNode *__pyx___rootNode;
};


/* "Dictionary/Dictionary.pxd":4
 * 
 * 
 * cdef class Dictionary:             # <<<<<<<<<<<<<<
 * 
 *     cdef list words
 */
struct __pyx_obj_10Dictionary_10Dictionary_Dictionary {
  PyObject_HEAD
  struct __pyx_vtabstruct_10Dictionary_10Dictionary_Dictionary *__pyx_vtab;
  PyObject *words;
  PyObject *filename;
  PyObject *comparator;
};


/* "Dictionary/TxtDictionary.pxd":7
 * 
 * 
 * cdef class TxtDictionary(Dictionary):             # <<<<<<<<<<<<<<
 * 
 *     cdef dict __misspelledWords
 */
struct __pyx_obj_10Dictionary_13TxtDictionary_TxtDictionary {
  struct __pyx_obj_10Dictionary_10Dictionary_Dictionary __pyx_base;
  PyObject *__pyx___misspelledWords;
};


/* "DataStructure/Cache/LRUCache.pxd":1
 * cdef class LRUCache(object):             # <<<<<<<<<<<<<<
 * 
 *     cdef int __cacheSize
 */
struct __pyx_obj_13DataStructure_5Cache_8LRUCache_LRUCache {
  PyObject_HEAD
  struct __pyx_vtabstruct_13DataStructure_5Cache_8LRUCache_LRUCache *__pyx_vtab;
  int __pyx___cacheSize;
  PyObject *__pyx___map;
};


/* "MorphologicalAnalysis/InflectionalGroup.pxd":1
 * cdef class InflectionalGroup:             # <<<<<<<<<<<<<<
 * 
 *     cdef list __IG
 */
struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup {
  PyObject_HEAD
  struct __pyx_vtabstruct_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *__pyx_vtab;
  PyObject *__pyx___IG;
};


/* "MorphologicalAnalysis/MorphologicalParse.pxd":7
 * 
 * 
 * cdef class MorphologicalParse:             # <<<<<<<<<<<<<<
 * 
 *     cdef list inflectionalGroups
 */
struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse {
  PyObject_HEAD
  struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_vtab;
  PyObject *inflectionalGroups;
  struct __pyx_obj_10Dictionary_4Word_Word *root;
};


/* "MorphologicalAnalysis/State.pxd":1
 * cdef class State:             # <<<<<<<<<<<<<<
 * 
 *     cdef bint __startState, __endState
 */
struct __pyx_obj_21MorphologicalAnalysis_5State_State {
  PyObject_HEAD
  struct __pyx_vtabstruct_21MorphologicalAnalysis_5State_State *__pyx_vtab;
  int __pyx___startState;
  int __pyx___endState;
  PyObject *__pyx___name;
  PyObject *__pyx___pos;
};


/* "MorphologicalAnalysis/FsmParse.pxd":5
 * 
 * 
 * cdef class FsmParse(MorphologicalParse):             # <<<<<<<<<<<<<<
 * 
 *     cdef list __suffixList
 */
struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse {
  struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse __pyx_base;
  PyObject *__pyx___suffixList;
  PyObject *__pyx___formList;
  PyObject *__pyx___transitionList;
  PyObject *__pyx___withList;
  PyObject *__pyx___initialPos;
  PyObject *__pyx___pos;
  PyObject *__pyx___form;
  PyObject *__pyx___verbAgreement;
  PyObject *__pyx___possesiveAgreement;
};


/* "MorphologicalAnalysis/FiniteStateMachine.pxd":4
 * 
 * 
 * cdef class FiniteStateMachine:             # <<<<<<<<<<<<<<
 * 
 *     cdef list __states
 */
struct __pyx_obj_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine {
  PyObject_HEAD
  struct __pyx_vtabstruct_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine *__pyx_vtab;
  PyObject *__pyx___states;
  PyObject *__pyx___transitions;
};


/* "MorphologicalAnalysis/MetamorphicParse.pxd":6
 * 
 * 
 * cdef class MetamorphicParse:             # <<<<<<<<<<<<<<
 * 
 *     cdef list __metaMorphemeList
 */
struct __pyx_obj_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse {
  PyObject_HEAD
  struct __pyx_vtabstruct_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse *__pyx_vtab;
  PyObject *__pyx___metaMorphemeList;
  struct __pyx_obj_10Dictionary_4Word_Word *__pyx___root;
};


/* "Corpus/Sentence.pxd":4
 * 
 * 
 * cdef class Sentence:             # <<<<<<<<<<<<<<
 * 
 *     cdef list words
 */
struct __pyx_obj_6Corpus_8Sentence_Sentence {
  PyObject_HEAD
  struct __pyx_vtabstruct_6Corpus_8Sentence_Sentence *__pyx_vtab;
  PyObject *words;
};


/* "MorphologicalAnalysis/FsmParseList.pxd":4
 * from MorphologicalAnalysis.FsmParse cimport FsmParse
 * 
 * cdef class FsmParseList:             # <<<<<<<<<<<<<<
 * 
 *     cdef list __fsmParses
 */
struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList {
  PyObject_HEAD
  struct __pyx_vtabstruct_21MorphologicalAnalysis_12FsmParseList_FsmParseList *__pyx_vtab;
  PyObject *__pyx___fsmParses;
};


/* "MorphologicalAnalysis/Transition.pxd":6
 * 
 * 
 * cdef class Transition:             # <<<<<<<<<<<<<<
 * 
 *     cdef State __toState
 */
struct __pyx_obj_21MorphologicalAnalysis_10Transition_Transition {
  PyObject_HEAD
  struct __pyx_vtabstruct_21MorphologicalAnalysis_10Transition_Transition *__pyx_vtab;
  struct __pyx_obj_21MorphologicalAnalysis_5State_State *__pyx___toState;
  PyObject *__pyx___with;
  PyObject *__pyx___withName;
  PyObject *__pyx___formationToCheck;
  PyObject *__pyx___toPos;
};


/* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pxd":12
 * 
 * 
 * cdef class FsmMorphologicalAnalyzer:             # <<<<<<<<<<<<<<
 * 
 *     cdef Trie __dictionaryTrie
 */
struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer {
  PyObject_HEAD
  struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_vtab;
  struct __pyx_obj_10Dictionary_4Trie_4Trie_Trie *__pyx___dictionaryTrie;
  struct __pyx_obj_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine *__pyx___finiteStateMachine;
  struct __pyx_obj_10Dictionary_13TxtDictionary_TxtDictionary *__pyx___dictionary;
  struct __pyx_obj_13DataStructure_5Cache_8LRUCache_LRUCache *__pyx___cache;
  PyObject *__pyx___mostUsedPatterns;
  PyObject *__pyx___parsedSurfaceForms;
};



/* "Dictionary/Word.pxd":1
 * cdef class Word:             # <<<<<<<<<<<<<<
 * 
 *     cdef str name
 */

struct __pyx_vtabstruct_10Dictionary_4Word_Word {
  int (*charCount)(struct __pyx_obj_10Dictionary_4Word_Word *, int __pyx_skip_dispatch);
  PyObject *(*getName)(struct __pyx_obj_10Dictionary_4Word_Word *, int __pyx_skip_dispatch);
  PyObject *(*setName)(struct __pyx_obj_10Dictionary_4Word_Word *, PyObject *, int __pyx_skip_dispatch);
  int (*isPunctuation)(struct __pyx_obj_10Dictionary_4Word_Word *, int __pyx_skip_dispatch);
  PyObject *(*toCharacters)(struct __pyx_obj_10Dictionary_4Word_Word *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_10Dictionary_4Word_Word *__pyx_vtabptr_10Dictionary_4Word_Word;


/* "Dictionary/Trie/TrieNode.pxd":4
 * 
 * 
 * cdef class TrieNode:             # <<<<<<<<<<<<<<
 * 
 *     cdef dict __children
 */

struct __pyx_vtabstruct_10Dictionary_4Trie_8TrieNode_TrieNode {
  PyObject *(*addWord)(struct __pyx_obj_10Dictionary_4Trie_8TrieNode_TrieNode *, PyObject *, struct __pyx_obj_10Dictionary_4Word_Word *, int __pyx_skip_dispatch, struct __pyx_opt_args_10Dictionary_4Trie_8TrieNode_8TrieNode_addWord *__pyx_optional_args);
  struct __pyx_obj_10Dictionary_4Trie_8TrieNode_TrieNode *(*getChild)(struct __pyx_obj_10Dictionary_4Trie_8TrieNode_TrieNode *, char, int __pyx_skip_dispatch);
  PyObject *(*getWords)(struct __pyx_obj_10Dictionary_4Trie_8TrieNode_TrieNode *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_10Dictionary_4Trie_8TrieNode_TrieNode *__pyx_vtabptr_10Dictionary_4Trie_8TrieNode_TrieNode;


/* "Dictionary/TxtWord.pxd":4
 * 
 * 
 * cdef class TxtWord(Word):             # <<<<<<<<<<<<<<
 * 
 *     cdef list __flags
 */

struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord {
  struct __pyx_vtabstruct_10Dictionary_4Word_Word __pyx_base;
  PyObject *(*addFlag)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*removeFlag)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*verbType)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*samePos)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isNominal)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isPassive)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isAbbreviation)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isInterjection)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isDuplicate)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isHeader)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isAdjective)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isPureAdjective)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isPronoun)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isQuestion)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isVerb)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isPortmanteau)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isDeterminer)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isConjunction)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isAdverb)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isPostP)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isPortmanteauEndingWithSI)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isPortmanteauFacedVowelEllipsis)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isPortmanteauFacedSoftening)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isSuffix)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isProperNoun)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isPlural)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isNumeral)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isReal)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isFraction)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isTime)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isDate)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isPercent)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isRange)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isOrdinal)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*notObeysVowelHarmonyDuringAgglutination)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*obeysAndNotObeysVowelHarmonyDuringAgglutination)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*rootSoftenDuringSuffixation)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*rootSoftenAndNotSoftenDuringSuffixation)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*verbSoftenDuringSuffixation)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*nounSoftenDuringSuffixation)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*endingKChangesIntoG)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isExceptional)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*duplicatesDuringSuffixation)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*duplicatesAndNotDuplicatesDuringSuffixation)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*lastIdropsDuringSuffixation)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*lastIDropsAndNotDropDuringSuffixation)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*takesRelativeSuffixKi)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*takesRelativeSuffixKu)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*consonantSMayInsertedDuringPossesiveSuffixation)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*lastIdropsDuringPassiveSuffixation)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*vowelAChangesToIDuringYSuffixation)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*vowelEChangesToIDuringYSuffixation)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*takesSuffixIRAsAorist)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*takesSuffixDIRAsFactitive)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*showsSuRegularities)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*containsFlag)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, PyObject *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *__pyx_vtabptr_10Dictionary_7TxtWord_TxtWord;


/* "Dictionary/Trie/Trie.pxd":6
 * 
 * 
 * cdef class Trie:             # <<<<<<<<<<<<<<
 * 
 *     cdef TrieNode __rootNode
 */

struct __pyx_vtabstruct_10Dictionary_4Trie_4Trie_Trie {
  PyObject *(*addWord)(struct __pyx_obj_10Dictionary_4Trie_4Trie_Trie *, PyObject *, struct __pyx_obj_10Dictionary_4Word_Word *, int __pyx_skip_dispatch);
  PyObject *(*getWordsWithPrefix)(struct __pyx_obj_10Dictionary_4Trie_4Trie_Trie *, PyObject *, int __pyx_skip_dispatch);
  struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *(*getCompundWordStartingWith)(struct __pyx_obj_10Dictionary_4Trie_4Trie_Trie *, PyObject *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_10Dictionary_4Trie_4Trie_Trie *__pyx_vtabptr_10Dictionary_4Trie_4Trie_Trie;


/* "Dictionary/Dictionary.pxd":4
 * 
 * 
 * cdef class Dictionary:             # <<<<<<<<<<<<<<
 * 
 *     cdef list words
 */

struct __pyx_vtabstruct_10Dictionary_10Dictionary_Dictionary {
  struct __pyx_obj_10Dictionary_4Word_Word *(*getWord)(struct __pyx_obj_10Dictionary_10Dictionary_Dictionary *, PyObject *, int __pyx_skip_dispatch);
  int (*getWordIndex)(struct __pyx_obj_10Dictionary_10Dictionary_Dictionary *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*removeWord)(struct __pyx_obj_10Dictionary_10Dictionary_Dictionary *, PyObject *, int __pyx_skip_dispatch);
  int (*size)(struct __pyx_obj_10Dictionary_10Dictionary_Dictionary *, int __pyx_skip_dispatch);
  struct __pyx_obj_10Dictionary_4Word_Word *(*getWordWithIndex)(struct __pyx_obj_10Dictionary_10Dictionary_Dictionary *, int, int __pyx_skip_dispatch);
  int (*longestWordSize)(struct __pyx_obj_10Dictionary_10Dictionary_Dictionary *, int __pyx_skip_dispatch);
  int (*__pyx___getPosition)(struct __pyx_obj_10Dictionary_10Dictionary_Dictionary *, struct __pyx_obj_10Dictionary_4Word_Word *, int __pyx_skip_dispatch);
  int (*getWordStartingWith)(struct __pyx_obj_10Dictionary_10Dictionary_Dictionary *, PyObject *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_10Dictionary_10Dictionary_Dictionary *__pyx_vtabptr_10Dictionary_10Dictionary_Dictionary;


/* "Dictionary/TxtDictionary.pxd":7
 * 
 * 
 * cdef class TxtDictionary(Dictionary):             # <<<<<<<<<<<<<<
 * 
 *     cdef dict __misspelledWords
 */

struct __pyx_vtabstruct_10Dictionary_13TxtDictionary_TxtDictionary {
  struct __pyx_vtabstruct_10Dictionary_10Dictionary_Dictionary __pyx_base;
  PyObject *(*addNumber)(struct __pyx_obj_10Dictionary_13TxtDictionary_TxtDictionary *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*addRealNumber)(struct __pyx_obj_10Dictionary_13TxtDictionary_TxtDictionary *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*addFraction)(struct __pyx_obj_10Dictionary_13TxtDictionary_TxtDictionary *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*addTime)(struct __pyx_obj_10Dictionary_13TxtDictionary_TxtDictionary *, PyObject *, int __pyx_skip_dispatch);
  int (*addProperNoun)(struct __pyx_obj_10Dictionary_13TxtDictionary_TxtDictionary *, PyObject *, int __pyx_skip_dispatch);
  int (*addNoun)(struct __pyx_obj_10Dictionary_13TxtDictionary_TxtDictionary *, PyObject *, int __pyx_skip_dispatch);
  int (*addVerb)(struct __pyx_obj_10Dictionary_13TxtDictionary_TxtDictionary *, PyObject *, int __pyx_skip_dispatch);
  int (*addAdjective)(struct __pyx_obj_10Dictionary_13TxtDictionary_TxtDictionary *, PyObject *, int __pyx_skip_dispatch);
  int (*addAdverb)(struct __pyx_obj_10Dictionary_13TxtDictionary_TxtDictionary *, PyObject *, int __pyx_skip_dispatch);
  int (*addPronoun)(struct __pyx_obj_10Dictionary_13TxtDictionary_TxtDictionary *, PyObject *, int __pyx_skip_dispatch);
  int (*addWithFlag)(struct __pyx_obj_10Dictionary_13TxtDictionary_TxtDictionary *, PyObject *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*mergeDictionary)(struct __pyx_obj_10Dictionary_13TxtDictionary_TxtDictionary *, PyObject *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*__pyx___loadFromText)(struct __pyx_obj_10Dictionary_13TxtDictionary_TxtDictionary *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*__pyx___loadMisspelledWords)(struct __pyx_obj_10Dictionary_13TxtDictionary_TxtDictionary *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*getCorrectForm)(struct __pyx_obj_10Dictionary_13TxtDictionary_TxtDictionary *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*saveAsTxt)(struct __pyx_obj_10Dictionary_13TxtDictionary_TxtDictionary *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*__pyx___addWordWhenRootSoften)(struct __pyx_obj_10Dictionary_13TxtDictionary_TxtDictionary *, struct __pyx_obj_10Dictionary_4Trie_4Trie_Trie *, Py_UNICODE, PyObject *, struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  struct __pyx_obj_10Dictionary_4Trie_4Trie_Trie *(*prepareTrie)(struct __pyx_obj_10Dictionary_13TxtDictionary_TxtDictionary *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_10Dictionary_13TxtDictionary_TxtDictionary *__pyx_vtabptr_10Dictionary_13TxtDictionary_TxtDictionary;


/* "DataStructure/Cache/LRUCache.pxd":1
 * cdef class LRUCache(object):             # <<<<<<<<<<<<<<
 * 
 *     cdef int __cacheSize
 */

struct __pyx_vtabstruct_13DataStructure_5Cache_8LRUCache_LRUCache {
  int (*contains)(struct __pyx_obj_13DataStructure_5Cache_8LRUCache_LRUCache *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*get)(struct __pyx_obj_13DataStructure_5Cache_8LRUCache_LRUCache *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*add)(struct __pyx_obj_13DataStructure_5Cache_8LRUCache_LRUCache *, PyObject *, PyObject *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_13DataStructure_5Cache_8LRUCache_LRUCache *__pyx_vtabptr_13DataStructure_5Cache_8LRUCache_LRUCache;


/* "MorphologicalAnalysis/InflectionalGroup.pxd":1
 * cdef class InflectionalGroup:             # <<<<<<<<<<<<<<
 * 
 *     cdef list __IG
 */

struct __pyx_vtabstruct_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup {
  PyObject *(*getTag)(struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *, int, int __pyx_skip_dispatch);
  int (*size)(struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *, int __pyx_skip_dispatch);
  PyObject *(*containsCase)(struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *, int __pyx_skip_dispatch);
  int (*containsPlural)(struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *, int __pyx_skip_dispatch);
  int (*containsTag)(struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *, PyObject *, int __pyx_skip_dispatch);
  int (*containsPossessive)(struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *__pyx_vtabptr_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup;


/* "MorphologicalAnalysis/MorphologicalParse.pxd":7
 * 
 * 
 * cdef class MorphologicalParse:             # <<<<<<<<<<<<<<
 * 
 *     cdef list inflectionalGroups
 */

struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse {
  struct __pyx_obj_10Dictionary_4Word_Word *(*getWord)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getTransitionList)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getInflectionalGroupString)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int, int __pyx_skip_dispatch);
  struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *(*getInflectionalGroup)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int, int __pyx_skip_dispatch);
  struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *(*getLastInflectionalGroup)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getTag)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int, int __pyx_skip_dispatch);
  int (*tagSize)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*size)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *(*firstInflectionalGroup)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *(*lastInflectionalGroup)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  struct __pyx_obj_10Dictionary_4Word_Word *(*getWordWithPos)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getPos)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getRootPos)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*lastIGContainsCase)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*lastIGContainsTag)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, PyObject *, int __pyx_skip_dispatch);
  int (*lastIGContainsPossessive)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isCapitalWord)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isNoun)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isVerb)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isRootVerb)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isAdjective)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isProperNoun)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isPunctuation)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isCardinal)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isOrdinal)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isReal)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isNumber)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isTime)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isDate)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isHashTag)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isEmail)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isPercent)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isFraction)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isRange)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isPlural)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isAuxiliary)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*containsTag)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*getTreePos)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getPronType)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getNumType)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getReflex)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getNumber)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getCase)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getDefinite)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getDegree)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getPolarity)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getPerson)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getVoice)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getAspect)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getTense)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getMood)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getVerbForm)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getUniversalDependencyFeatures)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getUniversalDependencyPos)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_vtabptr_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse;


/* "MorphologicalAnalysis/State.pxd":1
 * cdef class State:             # <<<<<<<<<<<<<<
 * 
 *     cdef bint __startState, __endState
 */

struct __pyx_vtabstruct_21MorphologicalAnalysis_5State_State {
  PyObject *(*getName)(struct __pyx_obj_21MorphologicalAnalysis_5State_State *, int __pyx_skip_dispatch);
  PyObject *(*getPos)(struct __pyx_obj_21MorphologicalAnalysis_5State_State *, int __pyx_skip_dispatch);
  int (*isEndState)(struct __pyx_obj_21MorphologicalAnalysis_5State_State *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_21MorphologicalAnalysis_5State_State *__pyx_vtabptr_21MorphologicalAnalysis_5State_State;


/* "MorphologicalAnalysis/FsmParse.pxd":5
 * 
 * 
 * cdef class FsmParse(MorphologicalParse):             # <<<<<<<<<<<<<<
 * 
 *     cdef list __suffixList
 */

struct __pyx_vtabstruct_21MorphologicalAnalysis_8FsmParse_FsmParse {
  struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse __pyx_base;
  PyObject *(*constructInflectionalGroups)(struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, int __pyx_skip_dispatch);
  PyObject *(*getVerbAgreement)(struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, int __pyx_skip_dispatch);
  PyObject *(*getPossesiveAgreement)(struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, int __pyx_skip_dispatch);
  PyObject *(*setAgreement)(struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*getLastLemmaWithTag)(struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*getLastLemma)(struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, int __pyx_skip_dispatch);
  PyObject *(*addSuffix)(struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, struct __pyx_obj_21MorphologicalAnalysis_5State_State *, PyObject *, PyObject *, PyObject *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*getSurfaceForm)(struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, int __pyx_skip_dispatch);
  struct __pyx_obj_21MorphologicalAnalysis_5State_State *(*getStartState)(struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, int __pyx_skip_dispatch);
  PyObject *(*getFinalPos)(struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, int __pyx_skip_dispatch);
  PyObject *(*getInitialPos)(struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, int __pyx_skip_dispatch);
  PyObject *(*setForm)(struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, PyObject *, int __pyx_skip_dispatch);
  struct __pyx_obj_21MorphologicalAnalysis_5State_State *(*getFinalSuffix)(struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, int __pyx_skip_dispatch);
  PyObject *(*headerTransition)(struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, int __pyx_skip_dispatch);
  PyObject *(*pronounTransition)(struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, int __pyx_skip_dispatch);
  PyObject *(*transitionList)(struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, int __pyx_skip_dispatch);
  PyObject *(*suffixList)(struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, int __pyx_skip_dispatch);
  PyObject *(*withList)(struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_21MorphologicalAnalysis_8FsmParse_FsmParse *__pyx_vtabptr_21MorphologicalAnalysis_8FsmParse_FsmParse;


/* "MorphologicalAnalysis/FiniteStateMachine.pxd":4
 * 
 * 
 * cdef class FiniteStateMachine:             # <<<<<<<<<<<<<<
 * 
 *     cdef list __states
 */

struct __pyx_vtabstruct_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine {
  int (*isValidTransition)(struct __pyx_obj_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*getStates)(struct __pyx_obj_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine *, int __pyx_skip_dispatch);
  struct __pyx_obj_21MorphologicalAnalysis_5State_State *(*getState)(struct __pyx_obj_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*addTransition)(struct __pyx_obj_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine *, struct __pyx_obj_21MorphologicalAnalysis_5State_State *, struct __pyx_obj_21MorphologicalAnalysis_5State_State *, PyObject *, PyObject *, int __pyx_skip_dispatch, struct __pyx_opt_args_21MorphologicalAnalysis_18FiniteStateMachine_18FiniteStateMachine_addTransition *__pyx_optional_args);
  PyObject *(*getTransitions)(struct __pyx_obj_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine *, struct __pyx_obj_21MorphologicalAnalysis_5State_State *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine *__pyx_vtabptr_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine;


/* "MorphologicalAnalysis/MetamorphicParse.pxd":6
 * 
 * 
 * cdef class MetamorphicParse:             # <<<<<<<<<<<<<<
 * 
 *     cdef list __metaMorphemeList
 */

struct __pyx_vtabstruct_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse {
  PyObject *(*getMetaMorphemeTag)(struct __pyx_obj_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse *, PyObject *, int __pyx_skip_dispatch);
  struct __pyx_obj_10Dictionary_4Word_Word *(*getWord)(struct __pyx_obj_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse *, int __pyx_skip_dispatch);
  PyObject *(*getMetaMorphemeTagForParse)(struct __pyx_obj_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse *, struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, PyObject *, int __pyx_skip_dispatch);
  int (*size)(struct __pyx_obj_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse *, int __pyx_skip_dispatch);
  PyObject *(*addMetaMorphemeList)(struct __pyx_obj_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*removeMetaMorphemeFromIndex)(struct __pyx_obj_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse *, int, int __pyx_skip_dispatch);
  PyObject *(*getMetaMorpheme)(struct __pyx_obj_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse *, int, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse *__pyx_vtabptr_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse;


/* "Corpus/Sentence.pxd":4
 * 
 * 
 * cdef class Sentence:             # <<<<<<<<<<<<<<
 * 
 *     cdef list words
 */

struct __pyx_vtabstruct_6Corpus_8Sentence_Sentence {
  struct __pyx_obj_10Dictionary_4Word_Word *(*getWord)(struct __pyx_obj_6Corpus_8Sentence_Sentence *, int, int __pyx_skip_dispatch);
  PyObject *(*getWords)(struct __pyx_obj_6Corpus_8Sentence_Sentence *, int __pyx_skip_dispatch);
  PyObject *(*getStrings)(struct __pyx_obj_6Corpus_8Sentence_Sentence *, int __pyx_skip_dispatch);
  int (*getIndex)(struct __pyx_obj_6Corpus_8Sentence_Sentence *, struct __pyx_obj_10Dictionary_4Word_Word *, int __pyx_skip_dispatch);
  int (*wordCount)(struct __pyx_obj_6Corpus_8Sentence_Sentence *, int __pyx_skip_dispatch);
  PyObject *(*addWord)(struct __pyx_obj_6Corpus_8Sentence_Sentence *, struct __pyx_obj_10Dictionary_4Word_Word *, int __pyx_skip_dispatch);
  int (*charCount)(struct __pyx_obj_6Corpus_8Sentence_Sentence *, int __pyx_skip_dispatch);
  PyObject *(*replaceWord)(struct __pyx_obj_6Corpus_8Sentence_Sentence *, int, struct __pyx_obj_10Dictionary_4Word_Word *, int __pyx_skip_dispatch);
  int (*safeIndex)(struct __pyx_obj_6Corpus_8Sentence_Sentence *, int, int __pyx_skip_dispatch);
  PyObject *(*toString)(struct __pyx_obj_6Corpus_8Sentence_Sentence *, int __pyx_skip_dispatch);
  PyObject *(*writeToFile)(struct __pyx_obj_6Corpus_8Sentence_Sentence *, PyObject *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_6Corpus_8Sentence_Sentence *__pyx_vtabptr_6Corpus_8Sentence_Sentence;


/* "MorphologicalAnalysis/FsmParseList.pxd":4
 * from MorphologicalAnalysis.FsmParse cimport FsmParse
 * 
 * cdef class FsmParseList:             # <<<<<<<<<<<<<<
 * 
 *     cdef list __fsmParses
 */

struct __pyx_vtabstruct_21MorphologicalAnalysis_12FsmParseList_FsmParseList {
  int (*size)(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *, int __pyx_skip_dispatch);
  PyObject *(*addFsmParse)(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *, struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, int __pyx_skip_dispatch);
  struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *(*getFsmParse)(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *, int, int __pyx_skip_dispatch);
  PyObject *(*rootWords)(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *, int __pyx_skip_dispatch);
  PyObject *(*reduceToParsesWithSameRootAndPos)(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *, struct __pyx_obj_10Dictionary_4Word_Word *, int __pyx_skip_dispatch);
  struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *(*getParseWithLongestRootWord)(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *, int __pyx_skip_dispatch);
  PyObject *(*reduceToParsesWithSameRoot)(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*constructParseListForDifferentRootWithPos)(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *, int __pyx_skip_dispatch);
  PyObject *(*parsesWithoutPrefixAndSuffix)(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_21MorphologicalAnalysis_12FsmParseList_FsmParseList *__pyx_vtabptr_21MorphologicalAnalysis_12FsmParseList_FsmParseList;


/* "MorphologicalAnalysis/Transition.pxd":6
 * 
 * 
 * cdef class Transition:             # <<<<<<<<<<<<<<
 * 
 *     cdef State __toState
 */

struct __pyx_vtabstruct_21MorphologicalAnalysis_10Transition_Transition {
  struct __pyx_obj_21MorphologicalAnalysis_5State_State *(*toState)(struct __pyx_obj_21MorphologicalAnalysis_10Transition_Transition *, int __pyx_skip_dispatch);
  PyObject *(*toPos)(struct __pyx_obj_21MorphologicalAnalysis_10Transition_Transition *, int __pyx_skip_dispatch);
  int (*transitionPossibleForString)(struct __pyx_obj_21MorphologicalAnalysis_10Transition_Transition *, PyObject *, PyObject *, int __pyx_skip_dispatch);
  int (*transitionPossibleForParse)(struct __pyx_obj_21MorphologicalAnalysis_10Transition_Transition *, struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, int __pyx_skip_dispatch);
  int (*transitionPossibleForWord)(struct __pyx_obj_21MorphologicalAnalysis_10Transition_Transition *, struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, struct __pyx_obj_21MorphologicalAnalysis_5State_State *, int __pyx_skip_dispatch);
  PyObject *(*__pyx___beforeLastVowel)(struct __pyx_obj_21MorphologicalAnalysis_10Transition_Transition *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*__pyx___lastVowel)(struct __pyx_obj_21MorphologicalAnalysis_10Transition_Transition *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*__pyx___lastPhoneme)(struct __pyx_obj_21MorphologicalAnalysis_10Transition_Transition *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*__pyx___withFirstChar)(struct __pyx_obj_21MorphologicalAnalysis_10Transition_Transition *, int __pyx_skip_dispatch);
  int (*__pyx___startWithVowelorConsonantDrops)(struct __pyx_obj_21MorphologicalAnalysis_10Transition_Transition *, int __pyx_skip_dispatch);
  int (*softenDuringSuffixation)(struct __pyx_obj_21MorphologicalAnalysis_10Transition_Transition *, struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  PyObject *(*makeTransitionNoStartState)(struct __pyx_obj_21MorphologicalAnalysis_10Transition_Transition *, struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*makeTransition)(struct __pyx_obj_21MorphologicalAnalysis_10Transition_Transition *, struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, PyObject *, struct __pyx_obj_21MorphologicalAnalysis_5State_State *, int __pyx_skip_dispatch);
  PyObject *(*__pyx___resolveD)(struct __pyx_obj_21MorphologicalAnalysis_10Transition_Transition *, struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*__pyx___resolveA)(struct __pyx_obj_21MorphologicalAnalysis_10Transition_Transition *, struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, PyObject *, int, int __pyx_skip_dispatch);
  PyObject *(*__pyx___resolveH)(struct __pyx_obj_21MorphologicalAnalysis_10Transition_Transition *, struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, PyObject *, int, int, int, int __pyx_skip_dispatch);
  PyObject *(*__pyx___resolveC)(struct __pyx_obj_21MorphologicalAnalysis_10Transition_Transition *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*__pyx___resolveS)(struct __pyx_obj_21MorphologicalAnalysis_10Transition_Transition *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*__pyx___resolveSh)(struct __pyx_obj_21MorphologicalAnalysis_10Transition_Transition *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*withName)(struct __pyx_obj_21MorphologicalAnalysis_10Transition_Transition *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_21MorphologicalAnalysis_10Transition_Transition *__pyx_vtabptr_21MorphologicalAnalysis_10Transition_Transition;


/* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":13
 * 
 * 
 * cdef class FsmMorphologicalAnalyzer:             # <<<<<<<<<<<<<<
 * 
 *     MAX_DISTANCE = 2
 */

struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer {
  PyObject *(*addParsedSurfaceForms)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*getPossibleWords)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, struct __pyx_obj_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse *, int __pyx_skip_dispatch);
  struct __pyx_obj_10Dictionary_13TxtDictionary_TxtDictionary *(*getDictionary)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, int __pyx_skip_dispatch);
  struct __pyx_obj_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine *(*getFiniteStateMachine)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, int __pyx_skip_dispatch);
  int (*__pyx___isPossibleSubstring)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, PyObject *, PyObject *, struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  PyObject *(*__pyx___initializeParseList)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, PyObject *, struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int, int __pyx_skip_dispatch);
  PyObject *(*__pyx___initializeParseListFromRoot)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, PyObject *, struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int, int __pyx_skip_dispatch);
  PyObject *(*__pyx___initializeParseListFromSurfaceForm)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, PyObject *, int, int __pyx_skip_dispatch);
  PyObject *(*__pyx___addNewParsesFromCurrentParse)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, PyObject *, PyObject *, struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*__pyx___parseExists)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, PyObject *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*__pyx___parseWord)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, PyObject *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*morphologicalAnalysisRoot)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, PyObject *, struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch, struct __pyx_opt_args_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_morphologicalAnalysisRoot *__pyx_optional_args);
  PyObject *(*generateAllParses)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int, int __pyx_skip_dispatch);
  int (*__pyx___analysisExists)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, PyObject *, int, int __pyx_skip_dispatch);
  PyObject *(*__pyx___analysis)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, PyObject *, int, int __pyx_skip_dispatch);
  int (*patternMatches)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, PyObject *, PyObject *, int __pyx_skip_dispatch);
  int (*isProperNoun)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*morphologicalAnalysis)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*robustMorphologicalAnalysis)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, PyObject *, int __pyx_skip_dispatch);
  int (*__pyx___isInteger)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, PyObject *, int __pyx_skip_dispatch);
  int (*__pyx___isDouble)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, PyObject *, int __pyx_skip_dispatch);
  int (*__pyx___isNumber)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, PyObject *, int __pyx_skip_dispatch);
  int (*__pyx___isPercent)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, PyObject *, int __pyx_skip_dispatch);
  int (*__pyx___isTime)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, PyObject *, int __pyx_skip_dispatch);
  int (*__pyx___isRange)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, PyObject *, int __pyx_skip_dispatch);
  int (*__pyx___isDate)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*__pyx___toLower)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, PyObject *, int __pyx_skip_dispatch);
  int (*morphologicalAnalysisExists)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, PyObject *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_vtabptr_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer;

/* --- Runtime support code (head) --- */
/* Refnanny.proto */
#ifndef CYTHON_REFNANNY
  #define CYTHON_REFNANNY 0
#endif
#if CYTHON_REFNANNY
  typedef struct {
    void (*INCREF)(void*, PyObject*, int);
    void (*DECREF)(void*, PyObject*, int);
    void (*GOTREF)(void*, PyObject*, int);
    void (*GIVEREF)(void*, PyObject*, int);
    void* (*SetupContext)(const char*, int, const char*);
    void (*FinishContext)(void**);
  } __Pyx_RefNannyAPIStruct;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNanny = NULL;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname);
  #define __Pyx_RefNannyDeclarations void *__pyx_refnanny = NULL;
#ifdef WITH_THREAD
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          if (acquire_gil) {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__);\
              PyGILState_Release(__pyx_gilstate_save);\
          } else {\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__);\
          }
#else
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__)
#endif
  #define __Pyx_RefNannyFinishContext()\
          __Pyx_RefNanny->FinishContext(&__pyx_refnanny)
  #define __Pyx_INCREF(r)  __Pyx_RefNanny->INCREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_DECREF(r)  __Pyx_RefNanny->DECREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GOTREF(r)  __Pyx_RefNanny->GOTREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GIVEREF(r) __Pyx_RefNanny->GIVEREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_XINCREF(r)  do { if((r) != NULL) {__Pyx_INCREF(r); }} while(0)
  #define __Pyx_XDECREF(r)  do { if((r) != NULL) {__Pyx_DECREF(r); }} while(0)
  #define __Pyx_XGOTREF(r)  do { if((r) != NULL) {__Pyx_GOTREF(r); }} while(0)
  #define __Pyx_XGIVEREF(r) do { if((r) != NULL) {__Pyx_GIVEREF(r);}} while(0)
#else
  #define __Pyx_RefNannyDeclarations
  #define __Pyx_RefNannySetupContext(name, acquire_gil)
  #define __Pyx_RefNannyFinishContext()
  #define __Pyx_INCREF(r) Py_INCREF(r)
  #define __Pyx_DECREF(r) Py_DECREF(r)
  #define __Pyx_GOTREF(r)
  #define __Pyx_GIVEREF(r)
  #define __Pyx_XINCREF(r) Py_XINCREF(r)
  #define __Pyx_XDECREF(r) Py_XDECREF(r)
  #define __Pyx_XGOTREF(r)
  #define __Pyx_XGIVEREF(r)
#endif
#define __Pyx_XDECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_XDECREF(tmp);\
    } while (0)
#define __Pyx_DECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_DECREF(tmp);\
    } while (0)
#define __Pyx_CLEAR(r)    do { PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);} while(0)
#define __Pyx_XCLEAR(r)   do { if((r) != NULL) {PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);}} while(0)

/* PyObjectGetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GetAttrStr(o,n) PyObject_GetAttr(o,n)
#endif

/* GetBuiltinName.proto */
static PyObject *__Pyx_GetBuiltinName(PyObject *name);

/* RaiseDoubleKeywords.proto */
static void __Pyx_RaiseDoubleKeywordsError(const char* func_name, PyObject* kw_name);

/* ParseKeywords.proto */
static int __Pyx_ParseOptionalKeywords(PyObject *kwds, PyObject **argnames[],\
    PyObject *kwds2, PyObject *values[], Py_ssize_t num_pos_args,\
    const char* function_name);

/* RaiseArgTupleInvalid.proto */
static void __Pyx_RaiseArgtupleInvalid(const char* func_name, int exact,
    Py_ssize_t num_min, Py_ssize_t num_max, Py_ssize_t num_found);

/* PyFunctionFastCall.proto */
#if CYTHON_FAST_PYCALL
#define __Pyx_PyFunction_FastCall(func, args, nargs)\
    __Pyx_PyFunction_FastCallDict((func), (args), (nargs), NULL)
#if 1 || PY_VERSION_HEX < 0x030600B1
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, Py_ssize_t nargs, PyObject *kwargs);
#else
#define __Pyx_PyFunction_FastCallDict(func, args, nargs, kwargs) _PyFunction_FastCallDict(func, args, nargs, kwargs)
#endif
#define __Pyx_BUILD_ASSERT_EXPR(cond)\
    (sizeof(char [1 - 2*!(cond)]) - 1)
#ifndef Py_MEMBER_SIZE
#define Py_MEMBER_SIZE(type, member) sizeof(((type *)0)->member)
#endif
  static size_t __pyx_pyframe_localsplus_offset = 0;
  #include "frameobject.h"
  #define __Pxy_PyFrame_Initialize_Offsets()\
    ((void)__Pyx_BUILD_ASSERT_EXPR(sizeof(PyFrameObject) == offsetof(PyFrameObject, f_localsplus) + Py_MEMBER_SIZE(PyFrameObject, f_localsplus)),\
     (void)(__pyx_pyframe_localsplus_offset = ((size_t)PyFrame_Type.tp_basicsize) - Py_MEMBER_SIZE(PyFrameObject, f_localsplus)))
  #define __Pyx_PyFrame_GetLocalsplus(frame)\
    (assert(__pyx_pyframe_localsplus_offset), (PyObject **)(((char *)(frame)) + __pyx_pyframe_localsplus_offset))
#endif

/* PyObjectCall.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw);
#else
#define __Pyx_PyObject_Call(func, arg, kw) PyObject_Call(func, arg, kw)
#endif

/* PyObjectCallMethO.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg);
#endif

/* PyObjectCallNoArg.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func);
#else
#define __Pyx_PyObject_CallNoArg(func) __Pyx_PyObject_Call(func, __pyx_empty_tuple, NULL)
#endif

/* PyCFunctionFastCall.proto */
#if CYTHON_FAST_PYCCALL
static CYTHON_INLINE PyObject *__Pyx_PyCFunction_FastCall(PyObject *func, PyObject **args, Py_ssize_t nargs);
#else
#define __Pyx_PyCFunction_FastCall(func, args, nargs)  (assert(0), NULL)
#endif

/* PyObjectCallOneArg.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg);

/* PyDictVersioning.proto */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
#define __PYX_DICT_VERSION_INIT  ((PY_UINT64_T) -1)
#define __PYX_GET_DICT_VERSION(dict)  (((PyDictObject*)(dict))->ma_version_tag)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)\
    (version_var) = __PYX_GET_DICT_VERSION(dict);\
    (cache_var) = (value);
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP) {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    if (likely(__PYX_GET_DICT_VERSION(DICT) == __pyx_dict_version)) {\
        (VAR) = __pyx_dict_cached_value;\
    } else {\
        (VAR) = __pyx_dict_cached_value = (LOOKUP);\
        __pyx_dict_version = __PYX_GET_DICT_VERSION(DICT);\
    }\
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj);
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj);
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version);
#else
#define __PYX_GET_DICT_VERSION(dict)  (0)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP)  (VAR) = (LOOKUP);
#endif

/* PyObjectCall2Args.proto */
static CYTHON_UNUSED PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2);

/* UnpackUnboundCMethod.proto */
typedef struct {
    PyObject *type;
    PyObject **method_name;
    PyCFunction func;
    PyObject *method;
    int flag;
} __Pyx_CachedCFunction;

/* CallUnboundCMethod0.proto */
static PyObject* __Pyx__CallUnboundCMethod0(__Pyx_CachedCFunction* cfunc, PyObject* self);
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_CallUnboundCMethod0(cfunc, self)\
    (likely((cfunc)->func) ?\
        (likely((cfunc)->flag == METH_NOARGS) ?  (*((cfunc)->func))(self, NULL) :\
         (PY_VERSION_HEX >= 0x030600B1 && likely((cfunc)->flag == METH_FASTCALL) ?\
            (PY_VERSION_HEX >= 0x030700A0 ?\
                (*(__Pyx_PyCFunctionFast)(void*)(PyCFunction)(cfunc)->func)(self, &__pyx_empty_tuple, 0) :\
                (*(__Pyx_PyCFunctionFastWithKeywords)(void*)(PyCFunction)(cfunc)->func)(self, &__pyx_empty_tuple, 0, NULL)) :\
          (PY_VERSION_HEX >= 0x030700A0 && (cfunc)->flag == (METH_FASTCALL | METH_KEYWORDS) ?\
            (*(__Pyx_PyCFunctionFastWithKeywords)(void*)(PyCFunction)(cfunc)->func)(self, &__pyx_empty_tuple, 0, NULL) :\
            (likely((cfunc)->flag == (METH_VARARGS | METH_KEYWORDS)) ?  ((*(PyCFunctionWithKeywords)(void*)(PyCFunction)(cfunc)->func)(self, __pyx_empty_tuple, NULL)) :\
               ((cfunc)->flag == METH_VARARGS ?  (*((cfunc)->func))(self, __pyx_empty_tuple) :\
               __Pyx__CallUnboundCMethod0(cfunc, self)))))) :\
        __Pyx__CallUnboundCMethod0(cfunc, self))
#else
#define __Pyx_CallUnboundCMethod0(cfunc, self)  __Pyx__CallUnboundCMethod0(cfunc, self)
#endif

/* ArgTypeTest.proto */
#define __Pyx_ArgTypeTest(obj, type, none_allowed, name, exact)\
    ((likely((Py_TYPE(obj) == type) | (none_allowed && (obj == Py_None)))) ? 1 :\
        __Pyx__ArgTypeTest(obj, type, name, exact))
static int __Pyx__ArgTypeTest(PyObject *obj, PyTypeObject *type, const char *name, int exact);

/* IncludeStringH.proto */
#include <string.h>

/* BytesEquals.proto */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals);

/* UnicodeEquals.proto */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals);

/* GetModuleGlobalName.proto */
#if CYTHON_USE_DICT_VERSIONS
#define __Pyx_GetModuleGlobalName(var, name)  {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    (var) = (likely(__pyx_dict_version == __PYX_GET_DICT_VERSION(__pyx_d))) ?\
        (likely(__pyx_dict_cached_value) ? __Pyx_NewRef(__pyx_dict_cached_value) : __Pyx_GetBuiltinName(name)) :\
        __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
}
#define __Pyx_GetModuleGlobalNameUncached(var, name)  {\
    PY_UINT64_T __pyx_dict_version;\
    PyObject *__pyx_dict_cached_value;\
    (var) = __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
}
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value);
#else
#define __Pyx_GetModuleGlobalName(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
#define __Pyx_GetModuleGlobalNameUncached(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name);
#endif

/* ExtTypeTest.proto */
static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type);

/* GetItemIntUnicode.proto */
#define __Pyx_GetItemInt_Unicode(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Unicode_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) :\
    (PyErr_SetString(PyExc_IndexError, "string index out of range"), (Py_UCS4)-1))
static CYTHON_INLINE Py_UCS4 __Pyx_GetItemInt_Unicode_Fast(PyObject* ustring, Py_ssize_t i,
                                                           int wraparound, int boundscheck);

/* unicode_tailmatch.proto */
static int __Pyx_PyUnicode_Tailmatch(
    PyObject* s, PyObject* substr, Py_ssize_t start, Py_ssize_t end, int direction);

/* PyIntBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_SubtractObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check);
#else
#define __Pyx_PyInt_SubtractObjC(op1, op2, intval, inplace, zerodivision_check)\
    (inplace ? PyNumber_InPlaceSubtract(op1, op2) : PyNumber_Subtract(op1, op2))
#endif

/* PyThreadStateGet.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyThreadState_declare  PyThreadState *__pyx_tstate;
#define __Pyx_PyThreadState_assign  __pyx_tstate = __Pyx_PyThreadState_Current;
#define __Pyx_PyErr_Occurred()  __pyx_tstate->curexc_type
#else
#define __Pyx_PyThreadState_declare
#define __Pyx_PyThreadState_assign
#define __Pyx_PyErr_Occurred()  PyErr_Occurred()
#endif

/* PyErrFetchRestore.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_Clear() __Pyx_ErrRestore(NULL, NULL, NULL)
#define __Pyx_ErrRestoreWithState(type, value, tb)  __Pyx_ErrRestoreInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)    __Pyx_ErrFetchInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  __Pyx_ErrRestoreInState(__pyx_tstate, type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)    __Pyx_ErrFetchInState(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_PyErr_SetNone(exc) (Py_INCREF(exc), __Pyx_ErrRestore((exc), NULL, NULL))
#else
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#endif
#else
#define __Pyx_PyErr_Clear() PyErr_Clear()
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#define __Pyx_ErrRestoreWithState(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestoreInState(tstate, type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchInState(tstate, type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)  PyErr_Fetch(type, value, tb)
#endif

/* WriteUnraisableException.proto */
static void __Pyx_WriteUnraisable(const char *name, int clineno,
                                  int lineno, const char *filename,
                                  int full_traceback, int nogil);

/* ListAppend.proto */
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE int __Pyx_PyList_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len) & likely(len > (L->allocated >> 1))) {
        Py_INCREF(x);
        PyList_SET_ITEM(list, len, x);
        __Pyx_SET_SIZE(list, len + 1);
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_PyList_Append(L,x) PyList_Append(L,x)
#endif

/* PyUnicode_Substring.proto */
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_Substring(
            PyObject* text, Py_ssize_t start, Py_ssize_t stop);

/* IterFinish.proto */
static CYTHON_INLINE int __Pyx_IterFinish(void);

/* set_iter.proto */
static CYTHON_INLINE PyObject* __Pyx_set_iterator(PyObject* iterable, int is_set,
                                                  Py_ssize_t* p_orig_length, int* p_source_is_set);
static CYTHON_INLINE int __Pyx_set_iter_next(
        PyObject* iter_obj, Py_ssize_t orig_length,
        Py_ssize_t* ppos, PyObject **value,
        int source_is_set);

/* PyObjectGetMethod.proto */
static int __Pyx_PyObject_GetMethod(PyObject *obj, PyObject *name, PyObject **method);

/* PyObjectCallMethod1.proto */
static PyObject* __Pyx_PyObject_CallMethod1(PyObject* obj, PyObject* method_name, PyObject* arg);

/* pop_index.proto */
static PyObject* __Pyx__PyObject_PopNewIndex(PyObject* L, PyObject* py_ix);
static PyObject* __Pyx__PyObject_PopIndex(PyObject* L, PyObject* py_ix);
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static PyObject* __Pyx__PyList_PopIndex(PyObject* L, PyObject* py_ix, Py_ssize_t ix);
#define __Pyx_PyObject_PopIndex(L, py_ix, ix, is_signed, type, to_py_func) (\
    (likely(PyList_CheckExact(L) && __Pyx_fits_Py_ssize_t(ix, type, is_signed))) ?\
        __Pyx__PyList_PopIndex(L, py_ix, ix) : (\
        (unlikely((py_ix) == Py_None)) ? __Pyx__PyObject_PopNewIndex(L, to_py_func(ix)) :\
            __Pyx__PyObject_PopIndex(L, py_ix)))
#define __Pyx_PyList_PopIndex(L, py_ix, ix, is_signed, type, to_py_func) (\
    __Pyx_fits_Py_ssize_t(ix, type, is_signed) ?\
        __Pyx__PyList_PopIndex(L, py_ix, ix) : (\
        (unlikely((py_ix) == Py_None)) ? __Pyx__PyObject_PopNewIndex(L, to_py_func(ix)) :\
            __Pyx__PyObject_PopIndex(L, py_ix)))
#else
#define __Pyx_PyList_PopIndex(L, py_ix, ix, is_signed, type, to_py_func)\
    __Pyx_PyObject_PopIndex(L, py_ix, ix, is_signed, type, to_py_func)
#define __Pyx_PyObject_PopIndex(L, py_ix, ix, is_signed, type, to_py_func) (\
    (unlikely((py_ix) == Py_None)) ? __Pyx__PyObject_PopNewIndex(L, to_py_func(ix)) :\
        __Pyx__PyObject_PopIndex(L, py_ix))
#endif

/* GetItemInt.proto */
#define __Pyx_GetItemInt(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Fast(o, (Py_ssize_t)i, is_list, wraparound, boundscheck) :\
    (is_list ? (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL) :\
               __Pyx_GetItemInt_Generic(o, to_py_func(i))))
#define __Pyx_GetItemInt_List(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_List_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) :\
    (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
#define __Pyx_GetItemInt_Tuple(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Tuple_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) :\
    (PyErr_SetString(PyExc_IndexError, "tuple index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j);
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i,
                                                     int is_list, int wraparound, int boundscheck);

/* PyUnicodeContains.proto */
static CYTHON_INLINE int __Pyx_PyUnicode_ContainsTF(PyObject* substring, PyObject* text, int eq) {
    int result = PyUnicode_Contains(text, substring);
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

/* PyDictContains.proto */
static CYTHON_INLINE int __Pyx_PyDict_ContainsTF(PyObject* item, PyObject* dict, int eq) {
    int result = PyDict_Contains(dict, item);
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

/* DictGetItem.proto */
#if PY_MAJOR_VERSION >= 3 && !CYTHON_COMPILING_IN_PYPY
static PyObject *__Pyx_PyDict_GetItem(PyObject *d, PyObject* key);
#define __Pyx_PyObject_Dict_GetItem(obj, name)\
    (likely(PyDict_CheckExact(obj)) ?\
     __Pyx_PyDict_GetItem(obj, name) : PyObject_GetItem(obj, name))
#else
#define __Pyx_PyDict_GetItem(d, key) PyObject_GetItem(d, key)
#define __Pyx_PyObject_Dict_GetItem(obj, name)  PyObject_GetItem(obj, name)
#endif

/* pyfrozenset_new.proto */
static CYTHON_INLINE PyObject* __Pyx_PyFrozenSet_New(PyObject* it);

/* PySetContains.proto */
static CYTHON_INLINE int __Pyx_PySet_ContainsTF(PyObject* key, PyObject* set, int eq);

/* CallUnboundCMethod1.proto */
static PyObject* __Pyx__CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg);
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg);
#else
#define __Pyx_CallUnboundCMethod1(cfunc, self, arg)  __Pyx__CallUnboundCMethod1(cfunc, self, arg)
#endif

/* PyErrExceptionMatches.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_ExceptionMatches(err) __Pyx_PyErr_ExceptionMatchesInState(__pyx_tstate, err)
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err);
#else
#define __Pyx_PyErr_ExceptionMatches(err)  PyErr_ExceptionMatches(err)
#endif

/* GetAttr.proto */
static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *, PyObject *);

/* GetAttr3.proto */
static CYTHON_INLINE PyObject *__Pyx_GetAttr3(PyObject *, PyObject *, PyObject *);

/* Import.proto */
static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level);

/* ImportFrom.proto */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name);

/* RaiseException.proto */
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause);

/* HasAttr.proto */
static CYTHON_INLINE int __Pyx_HasAttr(PyObject *, PyObject *);

/* PyObject_GenericGetAttrNoDict.proto */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static CYTHON_INLINE PyObject* __Pyx_PyObject_GenericGetAttrNoDict(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GenericGetAttrNoDict PyObject_GenericGetAttr
#endif

/* PyObject_GenericGetAttr.proto */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static PyObject* __Pyx_PyObject_GenericGetAttr(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GenericGetAttr PyObject_GenericGetAttr
#endif

/* SetVTable.proto */
static int __Pyx_SetVtable(PyObject *dict, void *vtable);

/* PyObjectGetAttrStrNoError.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStrNoError(PyObject* obj, PyObject* attr_name);

/* SetupReduce.proto */
static int __Pyx_setup_reduce(PyObject* type_obj);

/* TypeImport.proto */
#ifndef __PYX_HAVE_RT_ImportType_proto
#define __PYX_HAVE_RT_ImportType_proto
enum __Pyx_ImportType_CheckSize {
   __Pyx_ImportType_CheckSize_Error = 0,
   __Pyx_ImportType_CheckSize_Warn = 1,
   __Pyx_ImportType_CheckSize_Ignore = 2
};
static PyTypeObject *__Pyx_ImportType(PyObject* module, const char *module_name, const char *class_name, size_t size, enum __Pyx_ImportType_CheckSize check_size);
#endif

/* GetVTable.proto */
static void* __Pyx_GetVtable(PyObject *dict);

/* CLineInTraceback.proto */
#ifdef CYTHON_CLINE_IN_TRACEBACK
#define __Pyx_CLineForTraceback(tstate, c_line)  (((CYTHON_CLINE_IN_TRACEBACK)) ? c_line : 0)
#else
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line);
#endif

/* CodeObjectCache.proto */
typedef struct {
    PyCodeObject* code_object;
    int code_line;
} __Pyx_CodeObjectCacheEntry;
struct __Pyx_CodeObjectCache {
    int count;
    int max_count;
    __Pyx_CodeObjectCacheEntry* entries;
};
static struct __Pyx_CodeObjectCache __pyx_code_cache = {0,0,NULL};
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line);
static PyCodeObject *__pyx_find_code_object(int code_line);
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object);

/* AddTraceback.proto */
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_int(int value);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value);

/* CIntFromPy.proto */
static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *);

/* CIntFromPy.proto */
static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *);

/* FastTypeChecks.proto */
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_TypeCheck(obj, type) __Pyx_IsSubtype(Py_TYPE(obj), (PyTypeObject *)type)
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject *type);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *type1, PyObject *type2);
#else
#define __Pyx_TypeCheck(obj, type) PyObject_TypeCheck(obj, (PyTypeObject *)type)
#define __Pyx_PyErr_GivenExceptionMatches(err, type) PyErr_GivenExceptionMatches(err, type)
#define __Pyx_PyErr_GivenExceptionMatches2(err, type1, type2) (PyErr_GivenExceptionMatches(err, type1) || PyErr_GivenExceptionMatches(err, type2))
#endif
#define __Pyx_PyException_Check(obj) __Pyx_TypeCheck(obj, PyExc_Exception)

/* CheckBinaryVersion.proto */
static int __Pyx_check_binary_version(void);

/* InitStrings.proto */
static int __Pyx_InitStrings(__Pyx_StringTabEntry *t);

static PyObject *__pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_addParsedSurfaceForms(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_fileName, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_getPossibleWords(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_morphologicalParse, struct __pyx_obj_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse *__pyx_v_metamorphicParse, int __pyx_skip_dispatch); /* proto*/
static struct __pyx_obj_10Dictionary_13TxtDictionary_TxtDictionary *__pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_getDictionary(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static struct __pyx_obj_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine *__pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_getFiniteStateMachine(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer___isPossibleSubstring(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_shortString, PyObject *__pyx_v_longString, struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_root, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer___initializeParseList(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_fsmParse, struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_root, int __pyx_v_isProper, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer___initializeParseListFromRoot(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_parseList, struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_root, int __pyx_v_isProper, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer___initializeParseListFromSurfaceForm(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_surfaceForm, int __pyx_v_isProper, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer___addNewParsesFromCurrentParse(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *__pyx_v_currentFsmParse, PyObject *__pyx_v_fsmParse, PyObject *__pyx_v_maxLengthOrSurfaceForm, struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_root, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer___parseExists(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_fsmParse, PyObject *__pyx_v_surfaceForm, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer___parseWord(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_fsmParse, PyObject *__pyx_v_maxLengthOrSurfaceForm, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_morphologicalAnalysisRoot(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_surfaceForm, struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_root, int __pyx_skip_dispatch, struct __pyx_opt_args_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_morphologicalAnalysisRoot *__pyx_optional_args); /* proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_generateAllParses(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_root, int __pyx_v_maxLength, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer___analysisExists(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_rootWord, PyObject *__pyx_v_surfaceForm, int __pyx_v_isProper, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer___analysis(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_surfaceForm, int __pyx_v_isProper, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_patternMatches(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_expr, PyObject *__pyx_v_value, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_isProperNoun(CYTHON_UNUSED struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_surfaceForm, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer___isPercent(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_surfaceForm, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer___isTime(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_surfaceForm, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer___isRange(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_surfaceForm, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer___isDate(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_surfaceForm, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_morphologicalAnalysis(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_sentenceOrSurfaceForm, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_robustMorphologicalAnalysis(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_sentenceOrSurfaceForm, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer___isInteger(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_surfaceForm, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer___isDouble(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_surfaceForm, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer___isNumber(CYTHON_UNUSED struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_surfaceForm, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer___toLower(CYTHON_UNUSED struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_surfaceForm, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_morphologicalAnalysisExists(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_rootWord, PyObject *__pyx_v_surfaceForm, int __pyx_skip_dispatch); /* proto*/

/* Module declarations from 'Dictionary.Word' */
static PyTypeObject *__pyx_ptype_10Dictionary_4Word_Word = 0;

/* Module declarations from 'Dictionary.Trie.TrieNode' */
static PyTypeObject *__pyx_ptype_10Dictionary_4Trie_8TrieNode_TrieNode = 0;

/* Module declarations from 'Dictionary.TxtWord' */
static PyTypeObject *__pyx_ptype_10Dictionary_7TxtWord_TxtWord = 0;

/* Module declarations from 'Dictionary.Trie.Trie' */
static PyTypeObject *__pyx_ptype_10Dictionary_4Trie_4Trie_Trie = 0;

/* Module declarations from 'Dictionary.Dictionary' */
static PyTypeObject *__pyx_ptype_10Dictionary_10Dictionary_Dictionary = 0;

/* Module declarations from 'Dictionary.TxtDictionary' */
static PyTypeObject *__pyx_ptype_10Dictionary_13TxtDictionary_TxtDictionary = 0;

/* Module declarations from 'DataStructure.Cache.LRUCache' */
static PyTypeObject *__pyx_ptype_13DataStructure_5Cache_8LRUCache_LRUCache = 0;

/* Module declarations from 'MorphologicalAnalysis.InflectionalGroup' */
static PyTypeObject *__pyx_ptype_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup = 0;

/* Module declarations from 'MorphologicalAnalysis.MorphologicalParse' */
static PyTypeObject *__pyx_ptype_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse = 0;

/* Module declarations from 'MorphologicalAnalysis.State' */
static PyTypeObject *__pyx_ptype_21MorphologicalAnalysis_5State_State = 0;

/* Module declarations from 'MorphologicalAnalysis.FsmParse' */
static PyTypeObject *__pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse = 0;

/* Module declarations from 'MorphologicalAnalysis.FiniteStateMachine' */
static PyTypeObject *__pyx_ptype_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine = 0;

/* Module declarations from 'MorphologicalAnalysis.MetamorphicParse' */
static PyTypeObject *__pyx_ptype_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse = 0;

/* Module declarations from 'Corpus.Sentence' */
static PyTypeObject *__pyx_ptype_6Corpus_8Sentence_Sentence = 0;

/* Module declarations from 'MorphologicalAnalysis.FsmParseList' */
static PyTypeObject *__pyx_ptype_21MorphologicalAnalysis_12FsmParseList_FsmParseList = 0;

/* Module declarations from 'MorphologicalAnalysis.Transition' */
static PyTypeObject *__pyx_ptype_21MorphologicalAnalysis_10Transition_Transition = 0;

/* Module declarations from 'MorphologicalAnalysis.FsmMorphologicalAnalyzer' */
static PyTypeObject *__pyx_ptype_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer = 0;
static PyObject *__pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer___pyx_unpickle_FsmMorphologicalAnalyzer__set_state(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, PyObject *); /*proto*/
#define __Pyx_MODULE_NAME "MorphologicalAnalysis.FsmMorphologicalAnalyzer"
extern int __pyx_module_is_main_MorphologicalAnalysis__FsmMorphologicalAnalyzer;
int __pyx_module_is_main_MorphologicalAnalysis__FsmMorphologicalAnalyzer = 0;

/* Implementation of 'MorphologicalAnalysis.FsmMorphologicalAnalyzer' */
static PyObject *__pyx_builtin_open;
static PyObject *__pyx_builtin_range;
static const char __pyx_k_I[] = "I";
static const char __pyx_k_a[] = "a";
static const char __pyx_k_d[] = "\\+?\\d+";
static const char __pyx_k_e[] = "e";
static const char __pyx_k_i[] = "i";
static const char __pyx_k_k[] = "k";
static const char __pyx_k_o[] = "o";
static const char __pyx_k_p[] = "p";
static const char __pyx_k_r[] = "r";
static const char __pyx_k_t[] = "t";
static const char __pyx_k_u[] = "\305\237u";
static const char __pyx_k_w[] = "(\\w|\303\207|\305\236|\304\260|\303\234|\303\226)\\.";
static const char __pyx_k__2[] = "\303\247";
static const char __pyx_k__3[] = "";
static const char __pyx_k__4[] = ")";
static const char __pyx_k__5[] = "%";
static const char __pyx_k_be[] = "be\305\237";
static const char __pyx_k_br[] = "\303\266b\303\274r";
static const char __pyx_k_bu[] = "bu";
static const char __pyx_k_ka[] = "ka\303\247\304\261";
static const char __pyx_k_ne[] = "ne";
static const char __pyx_k_on[] = "on";
static const char __pyx_k_ou[] = "\303\247o\304\237u";
static const char __pyx_k_re[] = "re";
static const char __pyx_k_tm[] = "t\303\274m\303\274";
static const char __pyx_k_yz[] = "y\303\274z";
static const char __pyx_k__13[] = "#";
static const char __pyx_k__15[] = "@";
static const char __pyx_k__17[] = ".";
static const char __pyx_k__18[] = "'";
static const char __pyx_k__19[] = "/";
static const char __pyx_k__20[] = "\\/";
static const char __pyx_k__21[] = "\303\274\303\247";
static const char __pyx_k__22[] = "\304\260";
static const char __pyx_k__23[] = "\304\261";
static const char __pyx_k_alt[] = "alt\304\261";
static const char __pyx_k_baz[] = "baz\304\261";
static const char __pyx_k_ben[] = "ben";
static const char __pyx_k_bin[] = "bin";
static const char __pyx_k_bir[] = "bir";
static const char __pyx_k_biz[] = "biz";
static const char __pyx_k_d_d[] = "\\d+/\\d+";
static const char __pyx_k_drt[] = "d\303\266rt";
static const char __pyx_k_hep[] = "hep";
static const char __pyx_k_iki[] = "iki";
static const char __pyx_k_kim[] = "kim";
static const char __pyx_k_krk[] = "k\304\261rk";
static const char __pyx_k_lAr[] = "lAr";
static const char __pyx_k_mAk[] = "mAk";
static const char __pyx_k_new[] = "__new__";
static const char __pyx_k_pop[] = "pop";
static const char __pyx_k_sen[] = "sen";
static const char __pyx_k_siz[] = "siz";
static const char __pyx_k_str[] = "__str__";
static const char __pyx_k_VERB[] = "VERB";
static const char __pyx_k_altm[] = "altm\304\261\305\237";
static const char __pyx_k_biri[] = "biri";
static const char __pyx_k_copy[] = "copy";
static const char __pyx_k_dict[] = "__dict__";
static const char __pyx_k_elli[] = "elli";
static const char __pyx_k_expr[] = "expr";
static const char __pyx_k_kimi[] = "kimi";
static const char __pyx_k_main[] = "__main__";
static const char __pyx_k_name[] = "__name__";
static const char __pyx_k_nere[] = "nere";
static const char __pyx_k_open[] = "open";
static const char __pyx_k_otuz[] = "otuz";
static const char __pyx_k_root[] = "root";
static const char __pyx_k_teki[] = "\303\266teki";
static const char __pyx_k_test[] = "__test__";
static const char __pyx_k_topu[] = "topu";
static const char __pyx_k_yedi[] = "yedi";
static const char __pyx_k_Email[] = "Email";
static const char __pyx_k_IS_OA[] = "IS_OA";
static const char __pyx_k_IS_SD[] = "IS_SD";
static const char __pyx_k_IS_ST[] = "IS_ST";
static const char __pyx_k_IS_UD[] = "IS_UD";
static const char __pyx_k_IS_UU[] = "IS_UU";
static const char __pyx_k_PostP[] = "PostP";
static const char __pyx_k_bakas[] = "ba\305\237kas\304\261";
static const char __pyx_k_birka[] = "birka\303\247\304\261";
static const char __pyx_k_birou[] = "bir\303\247o\304\237u";
static const char __pyx_k_d_d_2[] = "\\d+\\\\/\\d+";
static const char __pyx_k_d_d_3[] = "\\d+-\\d+";
static const char __pyx_k_d_d_4[] = "\\+?(\\d+)?\\.\\d*";
static const char __pyx_k_d_d_d[] = "%(\\d\\d|\\d)";
static const char __pyx_k_dieri[] = "di\304\237eri";
static const char __pyx_k_dokuz[] = "dokuz";
static const char __pyx_k_hangi[] = "hangi";
static const char __pyx_k_hepsi[] = "hepsi";
static const char __pyx_k_index[] = "index";
static const char __pyx_k_kendi[] = "kendi";
static const char __pyx_k_kimse[] = "kimse";
static const char __pyx_k_lower[] = "lower";
static const char __pyx_k_onlar[] = "onlar";
static const char __pyx_k_range[] = "range";
static const char __pyx_k_sekiz[] = "sekiz";
static const char __pyx_k_state[] = "state";
static const char __pyx_k_strip[] = "strip";
static const char __pyx_k_value[] = "value";
static const char __pyx_k_yetmi[] = "yetmi\305\237";
static const char __pyx_k_yirmi[] = "yirmi";
static const char __pyx_k_IS_KIS[] = "IS_KIS";
static const char __pyx_k_IS_SDD[] = "IS_SDD";
static const char __pyx_k_IS_STT[] = "IS_STT";
static const char __pyx_k_IS_UDD[] = "IS_UDD";
static const char __pyx_k_IS_UUU[] = "IS_UUU";
static const char __pyx_k_bylesi[] = "b\303\266ylesi";
static const char __pyx_k_cmlesi[] = "c\303\274mlesi";
static const char __pyx_k_doksan[] = "doksan";
static const char __pyx_k_herkes[] = "herkes";
static const char __pyx_k_hibiri[] = "hi\303\247biri";
static const char __pyx_k_import[] = "__import__";
static const char __pyx_k_isDate[] = "__isDate";
static const char __pyx_k_isTime[] = "__isTime";
static const char __pyx_k_milyar[] = "milyar";
static const char __pyx_k_milyon[] = "milyon";
static const char __pyx_k_pickle[] = "pickle";
static const char __pyx_k_reduce[] = "__reduce__";
static const char __pyx_k_seksen[] = "seksen";
static const char __pyx_k_update[] = "update";
static const char __pyx_k_Hashtag[] = "Hashtag";
static const char __pyx_k_IS_DATE[] = "IS_DATE";
static const char __pyx_k_IS_SAYI[] = "IS_SAYI";
static const char __pyx_k_birbiri[] = "birbiri";
static const char __pyx_k_compile[] = "compile";
static const char __pyx_k_d_d_d_d[] = "%(\\d\\d|\\d)\\.\\d+";
static const char __pyx_k_isRange[] = "__isRange";
static const char __pyx_k_toLower[] = "__toLower";
static const char __pyx_k_trilyon[] = "trilyon";
static const char __pyx_k_DateRoot[] = "DateRoot";
static const char __pyx_k_IS_KESIR[] = "IS_KESIR";
static const char __pyx_k_IS_RANGE[] = "IS_RANGE";
static const char __pyx_k_IS_ZAMAN[] = "IS_ZAMAN";
static const char __pyx_k_RealRoot[] = "RealRoot";
static const char __pyx_k_TimeRoot[] = "TimeRoot";
static const char __pyx_k_analysis[] = "__analysis";
static const char __pyx_k_biroklar[] = "bir\303\247oklar\304\261";
static const char __pyx_k_deepcopy[] = "deepcopy";
static const char __pyx_k_fileName[] = "fileName";
static const char __pyx_k_fsmParse[] = "fsmParse";
static const char __pyx_k_getstate[] = "__getstate__";
static const char __pyx_k_isDouble[] = "__isDouble";
static const char __pyx_k_isNumber[] = "__isNumber";
static const char __pyx_k_isProper[] = "isProper";
static const char __pyx_k_pyx_type[] = "__pyx_type";
static const char __pyx_k_rootWord[] = "rootWord";
static const char __pyx_k_setstate[] = "__setstate__";
static const char __pyx_k_Adjective[] = "Adjective";
static const char __pyx_k_PassiveHn[] = "PassiveHn";
static const char __pyx_k_RangeRoot[] = "RangeRoot";
static const char __pyx_k_cacheSize[] = "cacheSize";
static const char __pyx_k_fullmatch[] = "fullmatch";
static const char __pyx_k_isCapital[] = "isCapital";
static const char __pyx_k_isInteger[] = "__isInteger";
static const char __pyx_k_isPercent[] = "__isPercent";
static const char __pyx_k_katrilyon[] = "katrilyon";
static const char __pyx_k_maxLength[] = "maxLength";
static const char __pyx_k_parseList[] = "parseList";
static const char __pyx_k_parseWord[] = "__parseWord";
static const char __pyx_k_pyx_state[] = "__pyx_state";
static const char __pyx_k_readlines[] = "readlines";
static const char __pyx_k_reduce_ex[] = "__reduce_ex__";
static const char __pyx_k_2147483647[] = "2147483647";
static const char __pyx_k_AdverbRoot[] = "AdverbRoot";
static const char __pyx_k_HeaderRoot[] = "HeaderRoot";
static const char __pyx_k_IS_PERCENT[] = "IS_PERCENT";
static const char __pyx_k_ProperRoot[] = "ProperRoot";
static const char __pyx_k_VerbalRoot[] = "VerbalRoot(";
static const char __pyx_k_birbirleri[] = "birbirleri";
static const char __pyx_k_longString[] = "longString";
static const char __pyx_k_pyx_result[] = "__pyx_result";
static const char __pyx_k_pyx_vtable[] = "__pyx_vtable__";
static const char __pyx_k_suffixList[] = "suffixList";
static const char __pyx_k_IS_REELSAYI[] = "IS_REELSAYI";
static const char __pyx_k_NominalRoot[] = "NominalRoot";
static const char __pyx_k_OrdinalRoot[] = "OrdinalRoot";
static const char __pyx_k_PercentRoot[] = "PercentRoot";
static const char __pyx_k_PickleError[] = "PickleError";
static const char __pyx_k_Punctuation[] = "Punctuation";
static const char __pyx_k_d_d_d_d_d_d[] = "(\\d\\d|\\d):(\\d\\d|\\d)";
static const char __pyx_k_parseExists[] = "__parseExists";
static const char __pyx_k_shortString[] = "shortString";
static const char __pyx_k_surfaceForm[] = "surfaceForm";
static const char __pyx_k_CardinalRoot[] = "CardinalRoot";
static const char __pyx_k_FractionRoot[] = "FractionRoot";
static const char __pyx_k_MAX_DISTANCE[] = "MAX_DISTANCE";
static const char __pyx_k_QuestionRoot[] = "QuestionRoot";
static const char __pyx_k_VerbalRoot_2[] = "VerbalRoot";
static const char __pyx_k_isProperNoun[] = "isProperNoun";
static const char __pyx_k_pyx_checksum[] = "__pyx_checksum";
static const char __pyx_k_stringsource[] = "stringsource";
static const char __pyx_k_AdjectiveRoot[] = "AdjectiveRoot";
static const char __pyx_k_DuplicateRoot[] = "DuplicateRoot";
static const char __pyx_k_d_d_d_d_d_d_d[] = "(\\d\\d|\\d)/(\\d\\d|\\d)/\\d+";
static const char __pyx_k_getDictionary[] = "getDictionary";
static const char __pyx_k_reduce_cython[] = "__reduce_cython__";
static const char __pyx_k_DeterminerRoot[] = "DeterminerRoot";
static const char __pyx_k_analysisExists[] = "__analysisExists";
static const char __pyx_k_patternMatches[] = "patternMatches";
static const char __pyx_k_ConjunctionRoot[] = "ConjunctionRoot";
static const char __pyx_k_currentFsmParse[] = "currentFsmParse";
static const char __pyx_k_d_d_d_d_d_d_d_2[] = "(\\d\\d|\\d)\\.(\\d\\d|\\d)\\.\\d+";
static const char __pyx_k_pyx_PickleError[] = "__pyx_PickleError";
static const char __pyx_k_setstate_cython[] = "__setstate_cython__";
static const char __pyx_k_CompoundNounRoot[] = "CompoundNounRoot";
static const char __pyx_k_InterjectionRoot[] = "InterjectionRoot";
static const char __pyx_k_MorphologicalTag[] = "MorphologicalTag";
static const char __pyx_k_PronounRoot_PERS[] = "PronounRoot(PERS)";
static const char __pyx_k_PronounRoot_QUES[] = "PronounRoot(QUES)";
static const char __pyx_k_getPossibleWords[] = "getPossibleWords";
static const char __pyx_k_metamorphicParse[] = "metamorphicParse";
static const char __pyx_k_NominalRootPlural[] = "NominalRootPlural";
static const char __pyx_k_PronounRoot_QUANT[] = "PronounRoot(QUANT)";
static const char __pyx_k_d_d_d_d_d_d_d_d_d[] = "(\\d\\d|\\d):(\\d\\d|\\d):(\\d\\d|\\d)";
static const char __pyx_k_generateAllParses[] = "generateAllParses";
static const char __pyx_k_PronounRoot_DEMONS[] = "PronounRoot(DEMONS)";
static const char __pyx_k_PronounRoot_REFLEX[] = "PronounRoot(REFLEX)";
static const char __pyx_k_cline_in_traceback[] = "cline_in_traceback";
static const char __pyx_k_dictionaryFileName[] = "dictionaryFileName";
static const char __pyx_k_misspelledFileName[] = "misspelledFileName";
static const char __pyx_k_morphologicalParse[] = "morphologicalParse";
static const char __pyx_k_initializeParseList[] = "__initializeParseList";
static const char __pyx_k_isPossibleSubstring[] = "__isPossibleSubstring";
static const char __pyx_k_isPunctuationSymbol[] = "isPunctuationSymbol";
static const char __pyx_k_addParsedSurfaceForms[] = "addParsedSurfaceForms";
static const char __pyx_k_getFiniteStateMachine[] = "getFiniteStateMachine";
static const char __pyx_k_morphologicalAnalysis[] = "morphologicalAnalysis";
static const char __pyx_k_NominalRootNoPossesive[] = "NominalRootNoPossesive";
static const char __pyx_k_maxLengthOrSurfaceForm[] = "maxLengthOrSurfaceForm";
static const char __pyx_k_transitionPossibleWord[] = "transitionPossibleWord";
static const char __pyx_k_PronounRoot_QUANTPLURAL[] = "PronounRoot(QUANTPLURAL)";
static const char __pyx_k_d_d_d_d_d_d_d_d_d_d_d_d[] = "(\\d\\d|\\d):(\\d\\d|\\d)-(\\d\\d|\\d):(\\d\\d|\\d)";
static const char __pyx_k_FsmMorphologicalAnalyzer[] = "FsmMorphologicalAnalyzer";
static const char __pyx_k_d_d_d_d_d_d_d_d_d_d_d_d_2[] = "(\\d\\d|\\d)\\.(\\d\\d|\\d)-(\\d\\d|\\d)\\.(\\d\\d|\\d)";
static const char __pyx_k_morphologicalAnalysisRoot[] = "morphologicalAnalysisRoot";
static const char __pyx_k_initializeParseListFromRoot[] = "__initializeParseListFromRoot";
static const char __pyx_k_morphologicalAnalysisExists[] = "morphologicalAnalysisExists";
static const char __pyx_k_robustMorphologicalAnalysis[] = "robustMorphologicalAnalysis";
static const char __pyx_k_addNewParsesFromCurrentParse[] = "__addNewParsesFromCurrentParse";
static const char __pyx_k_initializeParseListFromSurface[] = "__initializeParseListFromSurfaceForm";
static const char __pyx_k_pyx_unpickle_FsmMorphologicalA[] = "__pyx_unpickle_FsmMorphologicalAnalyzer";
static const char __pyx_k_Incompatible_checksums_s_vs_0xcb[] = "Incompatible checksums (%s vs 0xcbdb4c3 = (__cache, __dictionary, __dictionaryTrie, __finiteStateMachine, __mostUsedPatterns, __parsedSurfaceForms))";
static const char __pyx_k_MorphologicalAnalysis_FsmMorphol[] = "MorphologicalAnalysis.FsmMorphologicalAnalyzer";
static const char __pyx_k_MorphologicalAnalysis_Morphologi[] = "MorphologicalAnalysis.MorphologicalTag";
static const char __pyx_k_turkish_finite_state_machine_xml[] = "turkish_finite_state_machine.xml";
static PyObject *__pyx_kp_u_2147483647;
static PyObject *__pyx_n_u_Adjective;
static PyObject *__pyx_n_u_AdjectiveRoot;
static PyObject *__pyx_n_u_AdverbRoot;
static PyObject *__pyx_n_u_CardinalRoot;
static PyObject *__pyx_n_u_CompoundNounRoot;
static PyObject *__pyx_n_u_ConjunctionRoot;
static PyObject *__pyx_n_u_DateRoot;
static PyObject *__pyx_n_u_DeterminerRoot;
static PyObject *__pyx_n_u_DuplicateRoot;
static PyObject *__pyx_n_u_Email;
static PyObject *__pyx_n_u_FractionRoot;
static PyObject *__pyx_n_s_FsmMorphologicalAnalyzer;
static PyObject *__pyx_n_u_Hashtag;
static PyObject *__pyx_n_u_HeaderRoot;
static PyObject *__pyx_n_u_I;
static PyObject *__pyx_n_u_IS_DATE;
static PyObject *__pyx_n_u_IS_KESIR;
static PyObject *__pyx_n_u_IS_KIS;
static PyObject *__pyx_n_u_IS_OA;
static PyObject *__pyx_n_u_IS_PERCENT;
static PyObject *__pyx_n_u_IS_RANGE;
static PyObject *__pyx_n_u_IS_REELSAYI;
static PyObject *__pyx_n_u_IS_SAYI;
static PyObject *__pyx_n_u_IS_SD;
static PyObject *__pyx_n_u_IS_SDD;
static PyObject *__pyx_n_u_IS_ST;
static PyObject *__pyx_n_u_IS_STT;
static PyObject *__pyx_n_u_IS_UD;
static PyObject *__pyx_n_u_IS_UDD;
static PyObject *__pyx_n_u_IS_UU;
static PyObject *__pyx_n_u_IS_UUU;
static PyObject *__pyx_n_u_IS_ZAMAN;
static PyObject *__pyx_kp_s_Incompatible_checksums_s_vs_0xcb;
static PyObject *__pyx_n_u_InterjectionRoot;
static PyObject *__pyx_n_s_MAX_DISTANCE;
static PyObject *__pyx_n_s_MorphologicalAnalysis_FsmMorphol;
static PyObject *__pyx_n_s_MorphologicalAnalysis_Morphologi;
static PyObject *__pyx_n_s_MorphologicalTag;
static PyObject *__pyx_n_u_NominalRoot;
static PyObject *__pyx_n_u_NominalRootNoPossesive;
static PyObject *__pyx_n_u_NominalRootPlural;
static PyObject *__pyx_n_u_OrdinalRoot;
static PyObject *__pyx_n_u_PassiveHn;
static PyObject *__pyx_n_u_PercentRoot;
static PyObject *__pyx_n_s_PickleError;
static PyObject *__pyx_n_u_PostP;
static PyObject *__pyx_kp_u_PronounRoot_DEMONS;
static PyObject *__pyx_kp_u_PronounRoot_PERS;
static PyObject *__pyx_kp_u_PronounRoot_QUANT;
static PyObject *__pyx_kp_u_PronounRoot_QUANTPLURAL;
static PyObject *__pyx_kp_u_PronounRoot_QUES;
static PyObject *__pyx_kp_u_PronounRoot_REFLEX;
static PyObject *__pyx_n_u_ProperRoot;
static PyObject *__pyx_n_u_Punctuation;
static PyObject *__pyx_n_u_QuestionRoot;
static PyObject *__pyx_n_u_RangeRoot;
static PyObject *__pyx_n_u_RealRoot;
static PyObject *__pyx_n_u_TimeRoot;
static PyObject *__pyx_n_s_VERB;
static PyObject *__pyx_n_u_VERB;
static PyObject *__pyx_kp_u_VerbalRoot;
static PyObject *__pyx_n_u_VerbalRoot_2;
static PyObject *__pyx_kp_u__13;
static PyObject *__pyx_kp_u__15;
static PyObject *__pyx_kp_u__17;
static PyObject *__pyx_kp_u__18;
static PyObject *__pyx_kp_u__19;
static PyObject *__pyx_n_u__2;
static PyObject *__pyx_kp_u__20;
static PyObject *__pyx_n_u__21;
static PyObject *__pyx_n_u__22;
static PyObject *__pyx_n_u__23;
static PyObject *__pyx_kp_u__3;
static PyObject *__pyx_kp_u__4;
static PyObject *__pyx_kp_u__5;
static PyObject *__pyx_n_u_a;
static PyObject *__pyx_n_s_addNewParsesFromCurrentParse;
static PyObject *__pyx_n_s_addParsedSurfaceForms;
static PyObject *__pyx_n_u_alt;
static PyObject *__pyx_n_u_altm;
static PyObject *__pyx_n_s_analysis;
static PyObject *__pyx_n_s_analysisExists;
static PyObject *__pyx_n_u_bakas;
static PyObject *__pyx_n_u_baz;
static PyObject *__pyx_n_u_be;
static PyObject *__pyx_n_u_ben;
static PyObject *__pyx_n_u_bin;
static PyObject *__pyx_n_u_bir;
static PyObject *__pyx_n_u_birbiri;
static PyObject *__pyx_n_u_birbirleri;
static PyObject *__pyx_n_u_biri;
static PyObject *__pyx_n_u_birka;
static PyObject *__pyx_n_u_biroklar;
static PyObject *__pyx_n_u_birou;
static PyObject *__pyx_n_u_biz;
static PyObject *__pyx_n_u_br;
static PyObject *__pyx_n_u_bu;
static PyObject *__pyx_n_u_bylesi;
static PyObject *__pyx_n_s_cacheSize;
static PyObject *__pyx_n_s_cline_in_traceback;
static PyObject *__pyx_n_u_cmlesi;
static PyObject *__pyx_n_s_compile;
static PyObject *__pyx_n_s_copy;
static PyObject *__pyx_n_s_currentFsmParse;
static PyObject *__pyx_kp_u_d;
static PyObject *__pyx_kp_u_d_d;
static PyObject *__pyx_kp_u_d_d_2;
static PyObject *__pyx_kp_u_d_d_3;
static PyObject *__pyx_kp_u_d_d_4;
static PyObject *__pyx_kp_u_d_d_d;
static PyObject *__pyx_kp_u_d_d_d_d;
static PyObject *__pyx_kp_u_d_d_d_d_d_d;
static PyObject *__pyx_kp_u_d_d_d_d_d_d_d;
static PyObject *__pyx_kp_u_d_d_d_d_d_d_d_2;
static PyObject *__pyx_kp_u_d_d_d_d_d_d_d_d_d;
static PyObject *__pyx_kp_u_d_d_d_d_d_d_d_d_d_d_d_d;
static PyObject *__pyx_kp_u_d_d_d_d_d_d_d_d_d_d_d_d_2;
static PyObject *__pyx_n_s_deepcopy;
static PyObject *__pyx_n_s_dict;
static PyObject *__pyx_n_s_dictionaryFileName;
static PyObject *__pyx_n_u_dieri;
static PyObject *__pyx_n_u_doksan;
static PyObject *__pyx_n_u_dokuz;
static PyObject *__pyx_n_u_drt;
static PyObject *__pyx_n_u_e;
static PyObject *__pyx_n_u_elli;
static PyObject *__pyx_n_s_expr;
static PyObject *__pyx_n_s_fileName;
static PyObject *__pyx_n_s_fsmParse;
static PyObject *__pyx_n_s_fullmatch;
static PyObject *__pyx_n_s_generateAllParses;
static PyObject *__pyx_n_s_getDictionary;
static PyObject *__pyx_n_s_getFiniteStateMachine;
static PyObject *__pyx_n_s_getPossibleWords;
static PyObject *__pyx_n_s_getstate;
static PyObject *__pyx_n_u_hangi;
static PyObject *__pyx_n_u_hep;
static PyObject *__pyx_n_u_hepsi;
static PyObject *__pyx_n_u_herkes;
static PyObject *__pyx_n_u_hibiri;
static PyObject *__pyx_n_u_i;
static PyObject *__pyx_n_u_iki;
static PyObject *__pyx_n_s_import;
static PyObject *__pyx_n_s_index;
static PyObject *__pyx_n_s_initializeParseList;
static PyObject *__pyx_n_s_initializeParseListFromRoot;
static PyObject *__pyx_n_s_initializeParseListFromSurface;
static PyObject *__pyx_n_s_isCapital;
static PyObject *__pyx_n_s_isDate;
static PyObject *__pyx_n_s_isDouble;
static PyObject *__pyx_n_s_isInteger;
static PyObject *__pyx_n_s_isNumber;
static PyObject *__pyx_n_s_isPercent;
static PyObject *__pyx_n_s_isPossibleSubstring;
static PyObject *__pyx_n_s_isProper;
static PyObject *__pyx_n_s_isProperNoun;
static PyObject *__pyx_n_s_isPunctuationSymbol;
static PyObject *__pyx_n_s_isRange;
static PyObject *__pyx_n_s_isTime;
static PyObject *__pyx_n_u_k;
static PyObject *__pyx_n_u_ka;
static PyObject *__pyx_n_u_katrilyon;
static PyObject *__pyx_n_u_kendi;
static PyObject *__pyx_n_u_kim;
static PyObject *__pyx_n_u_kimi;
static PyObject *__pyx_n_u_kimse;
static PyObject *__pyx_n_u_krk;
static PyObject *__pyx_n_u_lAr;
static PyObject *__pyx_n_s_longString;
static PyObject *__pyx_n_s_lower;
static PyObject *__pyx_n_u_mAk;
static PyObject *__pyx_n_s_main;
static PyObject *__pyx_n_s_maxLength;
static PyObject *__pyx_n_s_maxLengthOrSurfaceForm;
static PyObject *__pyx_n_s_metamorphicParse;
static PyObject *__pyx_n_u_milyar;
static PyObject *__pyx_n_u_milyon;
static PyObject *__pyx_n_s_misspelledFileName;
static PyObject *__pyx_n_s_morphologicalAnalysis;
static PyObject *__pyx_n_s_morphologicalAnalysisExists;
static PyObject *__pyx_n_s_morphologicalAnalysisRoot;
static PyObject *__pyx_n_s_morphologicalParse;
static PyObject *__pyx_n_s_name;
static PyObject *__pyx_n_u_ne;
static PyObject *__pyx_n_u_nere;
static PyObject *__pyx_n_s_new;
static PyObject *__pyx_n_u_o;
static PyObject *__pyx_n_u_on;
static PyObject *__pyx_n_u_onlar;
static PyObject *__pyx_n_s_open;
static PyObject *__pyx_n_u_otuz;
static PyObject *__pyx_n_u_ou;
static PyObject *__pyx_n_u_p;
static PyObject *__pyx_n_s_parseExists;
static PyObject *__pyx_n_s_parseList;
static PyObject *__pyx_n_s_parseWord;
static PyObject *__pyx_n_s_patternMatches;
static PyObject *__pyx_n_s_pickle;
static PyObject *__pyx_n_s_pop;
static PyObject *__pyx_n_s_pyx_PickleError;
static PyObject *__pyx_n_s_pyx_checksum;
static PyObject *__pyx_n_s_pyx_result;
static PyObject *__pyx_n_s_pyx_state;
static PyObject *__pyx_n_s_pyx_type;
static PyObject *__pyx_n_s_pyx_unpickle_FsmMorphologicalA;
static PyObject *__pyx_n_s_pyx_vtable;
static PyObject *__pyx_n_u_r;
static PyObject *__pyx_n_s_range;
static PyObject *__pyx_n_s_re;
static PyObject *__pyx_n_s_readlines;
static PyObject *__pyx_n_s_reduce;
static PyObject *__pyx_n_s_reduce_cython;
static PyObject *__pyx_n_s_reduce_ex;
static PyObject *__pyx_n_s_robustMorphologicalAnalysis;
static PyObject *__pyx_n_s_root;
static PyObject *__pyx_n_s_rootWord;
static PyObject *__pyx_n_u_sekiz;
static PyObject *__pyx_n_u_seksen;
static PyObject *__pyx_n_u_sen;
static PyObject *__pyx_n_s_setstate;
static PyObject *__pyx_n_s_setstate_cython;
static PyObject *__pyx_n_s_shortString;
static PyObject *__pyx_n_u_siz;
static PyObject *__pyx_n_s_state;
static PyObject *__pyx_n_s_str;
static PyObject *__pyx_kp_s_stringsource;
static PyObject *__pyx_n_s_strip;
static PyObject *__pyx_n_s_suffixList;
static PyObject *__pyx_n_s_surfaceForm;
static PyObject *__pyx_n_u_t;
static PyObject *__pyx_n_u_teki;
static PyObject *__pyx_n_s_test;
static PyObject *__pyx_n_u_tm;
static PyObject *__pyx_n_s_toLower;
static PyObject *__pyx_n_u_topu;
static PyObject *__pyx_n_s_transitionPossibleWord;
static PyObject *__pyx_n_u_trilyon;
static PyObject *__pyx_kp_u_turkish_finite_state_machine_xml;
static PyObject *__pyx_n_u_u;
static PyObject *__pyx_n_s_update;
static PyObject *__pyx_n_s_value;
static PyObject *__pyx_kp_u_w;
static PyObject *__pyx_n_u_yedi;
static PyObject *__pyx_n_u_yetmi;
static PyObject *__pyx_n_u_yirmi;
static PyObject *__pyx_n_u_yz;
static int __pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer___init__(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_dictionaryFileName, PyObject *__pyx_v_misspelledFileName, PyObject *__pyx_v_fileName, PyObject *__pyx_v_cacheSize); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_2addParsedSurfaceForms(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_fileName); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_4getPossibleWords(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_morphologicalParse, struct __pyx_obj_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse *__pyx_v_metamorphicParse); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_6getDictionary(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_8getFiniteStateMachine(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_10__isPossibleSubstring(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_shortString, PyObject *__pyx_v_longString, struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_root); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_12__initializeParseList(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_fsmParse, struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_root, int __pyx_v_isProper); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_14__initializeParseListFromRoot(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_parseList, struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_root, int __pyx_v_isProper); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_16__initializeParseListFromSurfaceForm(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_surfaceForm, int __pyx_v_isProper); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_18__addNewParsesFromCurrentParse(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *__pyx_v_currentFsmParse, PyObject *__pyx_v_fsmParse, PyObject *__pyx_v_maxLengthOrSurfaceForm, struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_root); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_20__parseExists(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_fsmParse, PyObject *__pyx_v_surfaceForm); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_22__parseWord(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_fsmParse, PyObject *__pyx_v_maxLengthOrSurfaceForm); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_24morphologicalAnalysisRoot(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_surfaceForm, struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_root, PyObject *__pyx_v_state); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_26generateAllParses(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_root, int __pyx_v_maxLength); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_28__analysisExists(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_rootWord, PyObject *__pyx_v_surfaceForm, int __pyx_v_isProper); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_30__analysis(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_surfaceForm, int __pyx_v_isProper); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_32patternMatches(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_expr, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_34isProperNoun(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_surfaceForm); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_36__isPercent(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_surfaceForm); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_38__isTime(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_surfaceForm); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_40__isRange(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_surfaceForm); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_42__isDate(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_surfaceForm); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_44morphologicalAnalysis(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_sentenceOrSurfaceForm); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_46robustMorphologicalAnalysis(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_sentenceOrSurfaceForm); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_48__isInteger(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_surfaceForm); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_50__isDouble(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_surfaceForm); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_52__isNumber(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_surfaceForm); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_54__toLower(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_surfaceForm); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_56morphologicalAnalysisExists(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_rootWord, PyObject *__pyx_v_surfaceForm); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_58__reduce_cython__(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_60__setstate_cython__(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer___pyx_unpickle_FsmMorphologicalAnalyzer(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_tp_new_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static __Pyx_CachedCFunction __pyx_umethod_PyUnicode_Type_index = {0, &__pyx_n_s_index, 0, 0, 0};
static __Pyx_CachedCFunction __pyx_umethod_PyUnicode_Type_strip = {0, &__pyx_n_s_strip, 0, 0, 0};
static PyObject *__pyx_int_0;
static PyObject *__pyx_int_1;
static PyObject *__pyx_int_2;
static PyObject *__pyx_int_10000000;
static PyObject *__pyx_int_213759171;
static PyObject *__pyx_tuple_;
static PyObject *__pyx_tuple__6;
static PyObject *__pyx_tuple__7;
static PyObject *__pyx_tuple__8;
static PyObject *__pyx_tuple__9;
static PyObject *__pyx_tuple__10;
static PyObject *__pyx_tuple__11;
static PyObject *__pyx_tuple__12;
static PyObject *__pyx_tuple__14;
static PyObject *__pyx_tuple__16;
static PyObject *__pyx_tuple__24;
static PyObject *__pyx_codeobj__25;
/* Late includes */

/* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":17
 *     MAX_DISTANCE = 2
 * 
 *     def __init__(self, dictionaryFileName=None, misspelledFileName=None, fileName="turkish_finite_state_machine.xml",             # <<<<<<<<<<<<<<
 *                  cacheSize=10000000):
 *         """
 */

/* Python wrapper */
static int __pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer___init__[] = "\n        Constructor of FsmMorphologicalAnalyzer class. It generates a new TxtDictionary type dictionary from\n        given input dictionary file name and by using turkish_finite_state_machine.xml file.\n\n        PARAMETERS\n        ----------\n        fileName : str\n            the file to read the finite state machine.\n        cacheSize : int\n            the size of the LRUCache.\n        dictionaryFileName : str\n            the file to read the dictionary.\n        misspelledFileName: str\n            the file to read the misspelled file name.\n        ";
#if CYTHON_COMPILING_IN_CPYTHON
struct wrapperbase __pyx_wrapperbase_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer___init__;
#endif
static int __pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_dictionaryFileName = 0;
  PyObject *__pyx_v_misspelledFileName = 0;
  PyObject *__pyx_v_fileName = 0;
  PyObject *__pyx_v_cacheSize = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_dictionaryFileName,&__pyx_n_s_misspelledFileName,&__pyx_n_s_fileName,&__pyx_n_s_cacheSize,0};
    PyObject* values[4] = {0,0,0,0};
    values[0] = ((PyObject *)Py_None);
    values[1] = ((PyObject *)Py_None);
    values[2] = ((PyObject *)__pyx_kp_u_turkish_finite_state_machine_xml);
    values[3] = ((PyObject *)__pyx_int_10000000);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_dictionaryFileName);
          if (value) { values[0] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_misspelledFileName);
          if (value) { values[1] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_fileName);
          if (value) { values[2] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_cacheSize);
          if (value) { values[3] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) __PYX_ERR(0, 17, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_dictionaryFileName = values[0];
    __pyx_v_misspelledFileName = values[1];
    __pyx_v_fileName = values[2];
    __pyx_v_cacheSize = values[3];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 0, 4, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 17, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("MorphologicalAnalysis.FsmMorphologicalAnalyzer.FsmMorphologicalAnalyzer.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer___init__(((struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self), __pyx_v_dictionaryFileName, __pyx_v_misspelledFileName, __pyx_v_fileName, __pyx_v_cacheSize);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer___init__(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_dictionaryFileName, PyObject *__pyx_v_misspelledFileName, PyObject *__pyx_v_fileName, PyObject *__pyx_v_cacheSize) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":34
 *             the file to read the misspelled file name.
 *         """
 *         self.__mostUsedPatterns = {}             # <<<<<<<<<<<<<<
 *         self.__parsedSurfaceForms = None
 *         if dictionaryFileName is None:
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 34, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->__pyx___mostUsedPatterns);
  __Pyx_DECREF(__pyx_v_self->__pyx___mostUsedPatterns);
  __pyx_v_self->__pyx___mostUsedPatterns = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":35
 *         """
 *         self.__mostUsedPatterns = {}
 *         self.__parsedSurfaceForms = None             # <<<<<<<<<<<<<<
 *         if dictionaryFileName is None:
 *             self.__dictionary = TxtDictionary()
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->__pyx___parsedSurfaceForms);
  __Pyx_DECREF(__pyx_v_self->__pyx___parsedSurfaceForms);
  __pyx_v_self->__pyx___parsedSurfaceForms = ((PyObject*)Py_None);

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":36
 *         self.__mostUsedPatterns = {}
 *         self.__parsedSurfaceForms = None
 *         if dictionaryFileName is None:             # <<<<<<<<<<<<<<
 *             self.__dictionary = TxtDictionary()
 *         else:
 */
  __pyx_t_2 = (__pyx_v_dictionaryFileName == Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":37
 *         self.__parsedSurfaceForms = None
 *         if dictionaryFileName is None:
 *             self.__dictionary = TxtDictionary()             # <<<<<<<<<<<<<<
 *         else:
 *             self.__dictionary = TxtDictionary(dictionaryFileName, misspelledFileName)
 */
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_10Dictionary_13TxtDictionary_TxtDictionary)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 37, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_1);
    __Pyx_GOTREF(__pyx_v_self->__pyx___dictionary);
    __Pyx_DECREF(((PyObject *)__pyx_v_self->__pyx___dictionary));
    __pyx_v_self->__pyx___dictionary = ((struct __pyx_obj_10Dictionary_13TxtDictionary_TxtDictionary *)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":36
 *         self.__mostUsedPatterns = {}
 *         self.__parsedSurfaceForms = None
 *         if dictionaryFileName is None:             # <<<<<<<<<<<<<<
 *             self.__dictionary = TxtDictionary()
 *         else:
 */
    goto __pyx_L3;
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":39
 *             self.__dictionary = TxtDictionary()
 *         else:
 *             self.__dictionary = TxtDictionary(dictionaryFileName, misspelledFileName)             # <<<<<<<<<<<<<<
 *         self.__finiteStateMachine = FiniteStateMachine(fileName)
 *         self.__dictionaryTrie = self.__dictionary.prepareTrie()
 */
  /*else*/ {
    __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 39, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_dictionaryFileName);
    __Pyx_GIVEREF(__pyx_v_dictionaryFileName);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_dictionaryFileName);
    __Pyx_INCREF(__pyx_v_misspelledFileName);
    __Pyx_GIVEREF(__pyx_v_misspelledFileName);
    PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_misspelledFileName);
    __pyx_t_4 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_10Dictionary_13TxtDictionary_TxtDictionary), __pyx_t_1, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 39, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_GIVEREF(__pyx_t_4);
    __Pyx_GOTREF(__pyx_v_self->__pyx___dictionary);
    __Pyx_DECREF(((PyObject *)__pyx_v_self->__pyx___dictionary));
    __pyx_v_self->__pyx___dictionary = ((struct __pyx_obj_10Dictionary_13TxtDictionary_TxtDictionary *)__pyx_t_4);
    __pyx_t_4 = 0;
  }
  __pyx_L3:;

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":40
 *         else:
 *             self.__dictionary = TxtDictionary(dictionaryFileName, misspelledFileName)
 *         self.__finiteStateMachine = FiniteStateMachine(fileName)             # <<<<<<<<<<<<<<
 *         self.__dictionaryTrie = self.__dictionary.prepareTrie()
 *         self.__cache = LRUCache(cacheSize)
 */
  __pyx_t_4 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine), __pyx_v_fileName); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 40, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_4);
  __Pyx_GOTREF(__pyx_v_self->__pyx___finiteStateMachine);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->__pyx___finiteStateMachine));
  __pyx_v_self->__pyx___finiteStateMachine = ((struct __pyx_obj_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine *)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":41
 *             self.__dictionary = TxtDictionary(dictionaryFileName, misspelledFileName)
 *         self.__finiteStateMachine = FiniteStateMachine(fileName)
 *         self.__dictionaryTrie = self.__dictionary.prepareTrie()             # <<<<<<<<<<<<<<
 *         self.__cache = LRUCache(cacheSize)
 * 
 */
  __pyx_t_4 = ((PyObject *)((struct __pyx_vtabstruct_10Dictionary_13TxtDictionary_TxtDictionary *)__pyx_v_self->__pyx___dictionary->__pyx_base.__pyx_vtab)->prepareTrie(__pyx_v_self->__pyx___dictionary, 0)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 41, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_4);
  __Pyx_GOTREF(__pyx_v_self->__pyx___dictionaryTrie);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->__pyx___dictionaryTrie));
  __pyx_v_self->__pyx___dictionaryTrie = ((struct __pyx_obj_10Dictionary_4Trie_4Trie_Trie *)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":42
 *         self.__finiteStateMachine = FiniteStateMachine(fileName)
 *         self.__dictionaryTrie = self.__dictionary.prepareTrie()
 *         self.__cache = LRUCache(cacheSize)             # <<<<<<<<<<<<<<
 * 
 *     cpdef addParsedSurfaceForms(self, str fileName):
 */
  __pyx_t_4 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_13DataStructure_5Cache_8LRUCache_LRUCache), __pyx_v_cacheSize); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 42, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_4);
  __Pyx_GOTREF(__pyx_v_self->__pyx___cache);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->__pyx___cache));
  __pyx_v_self->__pyx___cache = ((struct __pyx_obj_13DataStructure_5Cache_8LRUCache_LRUCache *)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":17
 *     MAX_DISTANCE = 2
 * 
 *     def __init__(self, dictionaryFileName=None, misspelledFileName=None, fileName="turkish_finite_state_machine.xml",             # <<<<<<<<<<<<<<
 *                  cacheSize=10000000):
 *         """
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("MorphologicalAnalysis.FsmMorphologicalAnalyzer.FsmMorphologicalAnalyzer.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":44
 *         self.__cache = LRUCache(cacheSize)
 * 
 *     cpdef addParsedSurfaceForms(self, str fileName):             # <<<<<<<<<<<<<<
 *         cdef list lines
 *         cdef str line
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_3addParsedSurfaceForms(PyObject *__pyx_v_self, PyObject *__pyx_v_fileName); /*proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_addParsedSurfaceForms(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_fileName, int __pyx_skip_dispatch) {
  PyObject *__pyx_v_lines = 0;
  PyObject *__pyx_v_line = 0;
  PyObject *__pyx_v_file = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("addParsedSurfaceForms", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_addParsedSurfaceForms); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 44, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_3addParsedSurfaceForms)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_v_fileName) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_fileName);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 44, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":47
 *         cdef list lines
 *         cdef str line
 *         self.__parsedSurfaceForms = set()             # <<<<<<<<<<<<<<
 *         file = open(fileName, "r")
 *         lines = file.readlines()
 */
  __pyx_t_1 = PySet_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 47, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->__pyx___parsedSurfaceForms);
  __Pyx_DECREF(__pyx_v_self->__pyx___parsedSurfaceForms);
  __pyx_v_self->__pyx___parsedSurfaceForms = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":48
 *         cdef str line
 *         self.__parsedSurfaceForms = set()
 *         file = open(fileName, "r")             # <<<<<<<<<<<<<<
 *         lines = file.readlines()
 *         for line in lines:
 */
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 48, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_fileName);
  __Pyx_GIVEREF(__pyx_v_fileName);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_fileName);
  __Pyx_INCREF(__pyx_n_u_r);
  __Pyx_GIVEREF(__pyx_n_u_r);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_n_u_r);
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_open, __pyx_t_1, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 48, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_file = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":49
 *         self.__parsedSurfaceForms = set()
 *         file = open(fileName, "r")
 *         lines = file.readlines()             # <<<<<<<<<<<<<<
 *         for line in lines:
 *             self.__parsedSurfaceForms.add(line.strip())
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_file, __pyx_n_s_readlines); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 49, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
    }
  }
  __pyx_t_2 = (__pyx_t_3) ? __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_3) : __Pyx_PyObject_CallNoArg(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 49, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (!(likely(PyList_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "list", Py_TYPE(__pyx_t_2)->tp_name), 0))) __PYX_ERR(0, 49, __pyx_L1_error)
  __pyx_v_lines = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":50
 *         file = open(fileName, "r")
 *         lines = file.readlines()
 *         for line in lines:             # <<<<<<<<<<<<<<
 *             self.__parsedSurfaceForms.add(line.strip())
 * 
 */
  if (unlikely(__pyx_v_lines == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(0, 50, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_v_lines; __Pyx_INCREF(__pyx_t_2); __pyx_t_5 = 0;
  for (;;) {
    if (__pyx_t_5 >= PyList_GET_SIZE(__pyx_t_2)) break;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_1 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_5); __Pyx_INCREF(__pyx_t_1); __pyx_t_5++; if (unlikely(0 < 0)) __PYX_ERR(0, 50, __pyx_L1_error)
    #else
    __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 50, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    #endif
    if (!(likely(PyUnicode_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_1)->tp_name), 0))) __PYX_ERR(0, 50, __pyx_L1_error)
    __Pyx_XDECREF_SET(__pyx_v_line, ((PyObject*)__pyx_t_1));
    __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":51
 *         lines = file.readlines()
 *         for line in lines:
 *             self.__parsedSurfaceForms.add(line.strip())             # <<<<<<<<<<<<<<
 * 
 *     cpdef set getPossibleWords(self, MorphologicalParse morphologicalParse, MetamorphicParse metamorphicParse):
 */
    if (unlikely(__pyx_v_self->__pyx___parsedSurfaceForms == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "add");
      __PYX_ERR(0, 51, __pyx_L1_error)
    }
    __pyx_t_1 = __Pyx_CallUnboundCMethod0(&__pyx_umethod_PyUnicode_Type_strip, __pyx_v_line); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 51, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = PySet_Add(__pyx_v_self->__pyx___parsedSurfaceForms, __pyx_t_1); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 51, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":50
 *         file = open(fileName, "r")
 *         lines = file.readlines()
 *         for line in lines:             # <<<<<<<<<<<<<<
 *             self.__parsedSurfaceForms.add(line.strip())
 * 
 */
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":44
 *         self.__cache = LRUCache(cacheSize)
 * 
 *     cpdef addParsedSurfaceForms(self, str fileName):             # <<<<<<<<<<<<<<
 *         cdef list lines
 *         cdef str line
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("MorphologicalAnalysis.FsmMorphologicalAnalyzer.FsmMorphologicalAnalyzer.addParsedSurfaceForms", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_lines);
  __Pyx_XDECREF(__pyx_v_line);
  __Pyx_XDECREF(__pyx_v_file);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_3addParsedSurfaceForms(PyObject *__pyx_v_self, PyObject *__pyx_v_fileName); /*proto*/
static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_3addParsedSurfaceForms(PyObject *__pyx_v_self, PyObject *__pyx_v_fileName) {
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("addParsedSurfaceForms (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_fileName), (&PyUnicode_Type), 1, "fileName", 1))) __PYX_ERR(0, 44, __pyx_L1_error)
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_2addParsedSurfaceForms(((struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self), ((PyObject*)__pyx_v_fileName));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_2addParsedSurfaceForms(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_fileName) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("addParsedSurfaceForms", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_addParsedSurfaceForms(__pyx_v_self, __pyx_v_fileName, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 44, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.FsmMorphologicalAnalyzer.FsmMorphologicalAnalyzer.addParsedSurfaceForms", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":53
 *             self.__parsedSurfaceForms.add(line.strip())
 * 
 *     cpdef set getPossibleWords(self, MorphologicalParse morphologicalParse, MetamorphicParse metamorphicParse):             # <<<<<<<<<<<<<<
 *         """
 *         The getPossibleWords method takes MorphologicalParse and MetamorphicParse as input.
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_5getPossibleWords(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_getPossibleWords(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_morphologicalParse, struct __pyx_obj_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse *__pyx_v_metamorphicParse, int __pyx_skip_dispatch) {
  int __pyx_v_isRootVerb;
  int __pyx_v_containsVerb;
  struct __pyx_obj_21MorphologicalAnalysis_10Transition_Transition *__pyx_v_verbTransition = 0;
  struct __pyx_obj_21MorphologicalAnalysis_10Transition_Transition *__pyx_v_transition = 0;
  PyObject *__pyx_v_result = 0;
  PyObject *__pyx_v_currentWord = 0;
  PyObject *__pyx_v_verbWord = 0;
  PyObject *__pyx_v_pluralWord = 0;
  int __pyx_v_pluralIndex;
  int __pyx_v_i;
  struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_compoundWord = 0;
  struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_currentRoot = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_t_9;
  Py_ssize_t __pyx_t_10;
  Py_ssize_t __pyx_t_11;
  int __pyx_t_12;
  int __pyx_t_13;
  int __pyx_t_14;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getPossibleWords", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_getPossibleWords); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 53, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_5getPossibleWords)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        __pyx_t_5 = 0;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_5 = 1;
          }
        }
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_3)) {
          PyObject *__pyx_temp[3] = {__pyx_t_4, ((PyObject *)__pyx_v_morphologicalParse), ((PyObject *)__pyx_v_metamorphicParse)};
          __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 53, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_GOTREF(__pyx_t_2);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
          PyObject *__pyx_temp[3] = {__pyx_t_4, ((PyObject *)__pyx_v_morphologicalParse), ((PyObject *)__pyx_v_metamorphicParse)};
          __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 53, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_GOTREF(__pyx_t_2);
        } else
        #endif
        {
          __pyx_t_6 = PyTuple_New(2+__pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 53, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          if (__pyx_t_4) {
            __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4); __pyx_t_4 = NULL;
          }
          __Pyx_INCREF(((PyObject *)__pyx_v_morphologicalParse));
          __Pyx_GIVEREF(((PyObject *)__pyx_v_morphologicalParse));
          PyTuple_SET_ITEM(__pyx_t_6, 0+__pyx_t_5, ((PyObject *)__pyx_v_morphologicalParse));
          __Pyx_INCREF(((PyObject *)__pyx_v_metamorphicParse));
          __Pyx_GIVEREF(((PyObject *)__pyx_v_metamorphicParse));
          PyTuple_SET_ITEM(__pyx_t_6, 1+__pyx_t_5, ((PyObject *)__pyx_v_metamorphicParse));
          __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_6, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 53, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        }
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (!(likely(PySet_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "set", Py_TYPE(__pyx_t_2)->tp_name), 0))) __PYX_ERR(0, 53, __pyx_L1_error)
        __pyx_r = ((PyObject*)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":86
 *         cdef int pluralIndex, i
 *         cdef TxtWord compoundWord, currentRoot
 *         isRootVerb = morphologicalParse.getRootPos() == "VERB"             # <<<<<<<<<<<<<<
 *         containsVerb = morphologicalParse.containsTag(MorphologicalTag.VERB)
 *         verbTransition = Transition("mAk")
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_morphologicalParse->__pyx_vtab)->getRootPos(__pyx_v_morphologicalParse, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 86, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_n_u_VERB, Py_EQ)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 86, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_isRootVerb = __pyx_t_7;

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":87
 *         cdef TxtWord compoundWord, currentRoot
 *         isRootVerb = morphologicalParse.getRootPos() == "VERB"
 *         containsVerb = morphologicalParse.containsTag(MorphologicalTag.VERB)             # <<<<<<<<<<<<<<
 *         verbTransition = Transition("mAk")
 *         result = set()
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 87, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_VERB); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 87, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_containsVerb = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_morphologicalParse->__pyx_vtab)->containsTag(__pyx_v_morphologicalParse, __pyx_t_2, 0);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":88
 *         isRootVerb = morphologicalParse.getRootPos() == "VERB"
 *         containsVerb = morphologicalParse.containsTag(MorphologicalTag.VERB)
 *         verbTransition = Transition("mAk")             # <<<<<<<<<<<<<<
 *         result = set()
 *         if metamorphicParse is None or metamorphicParse.getWord() is None:
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_10Transition_Transition), __pyx_tuple_, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 88, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_verbTransition = ((struct __pyx_obj_21MorphologicalAnalysis_10Transition_Transition *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":89
 *         containsVerb = morphologicalParse.containsTag(MorphologicalTag.VERB)
 *         verbTransition = Transition("mAk")
 *         result = set()             # <<<<<<<<<<<<<<
 *         if metamorphicParse is None or metamorphicParse.getWord() is None:
 *             return result
 */
  __pyx_t_2 = PySet_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 89, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_result = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":90
 *         verbTransition = Transition("mAk")
 *         result = set()
 *         if metamorphicParse is None or metamorphicParse.getWord() is None:             # <<<<<<<<<<<<<<
 *             return result
 *         currentWord = metamorphicParse.getWord().getName()
 */
  __pyx_t_8 = (((PyObject *)__pyx_v_metamorphicParse) == Py_None);
  __pyx_t_9 = (__pyx_t_8 != 0);
  if (!__pyx_t_9) {
  } else {
    __pyx_t_7 = __pyx_t_9;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse *)__pyx_v_metamorphicParse->__pyx_vtab)->getWord(__pyx_v_metamorphicParse, 0)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 90, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_9 = (__pyx_t_2 == Py_None);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_8 = (__pyx_t_9 != 0);
  __pyx_t_7 = __pyx_t_8;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_7) {

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":91
 *         result = set()
 *         if metamorphicParse is None or metamorphicParse.getWord() is None:
 *             return result             # <<<<<<<<<<<<<<
 *         currentWord = metamorphicParse.getWord().getName()
 *         pluralIndex = -1
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_result);
    __pyx_r = __pyx_v_result;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":90
 *         verbTransition = Transition("mAk")
 *         result = set()
 *         if metamorphicParse is None or metamorphicParse.getWord() is None:             # <<<<<<<<<<<<<<
 *             return result
 *         currentWord = metamorphicParse.getWord().getName()
 */
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":92
 *         if metamorphicParse is None or metamorphicParse.getWord() is None:
 *             return result
 *         currentWord = metamorphicParse.getWord().getName()             # <<<<<<<<<<<<<<
 *         pluralIndex = -1
 *         compoundWord = self.__dictionaryTrie.getCompundWordStartingWith(currentWord)
 */
  __pyx_t_2 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse *)__pyx_v_metamorphicParse->__pyx_vtab)->getWord(__pyx_v_metamorphicParse, 0)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 92, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_10Dictionary_4Word_Word *)((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_t_2)->__pyx_vtab)->getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_t_2), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 92, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_currentWord = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":93
 *             return result
 *         currentWord = metamorphicParse.getWord().getName()
 *         pluralIndex = -1             # <<<<<<<<<<<<<<
 *         compoundWord = self.__dictionaryTrie.getCompundWordStartingWith(currentWord)
 *         if not isRootVerb:
 */
  __pyx_v_pluralIndex = -1;

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":94
 *         currentWord = metamorphicParse.getWord().getName()
 *         pluralIndex = -1
 *         compoundWord = self.__dictionaryTrie.getCompundWordStartingWith(currentWord)             # <<<<<<<<<<<<<<
 *         if not isRootVerb:
 *             if compoundWord is not None and len(compoundWord.getName()) - len(currentWord) < 3:
 */
  __pyx_t_1 = ((PyObject *)((struct __pyx_vtabstruct_10Dictionary_4Trie_4Trie_Trie *)__pyx_v_self->__pyx___dictionaryTrie->__pyx_vtab)->getCompundWordStartingWith(__pyx_v_self->__pyx___dictionaryTrie, __pyx_v_currentWord, 0)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 94, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_compoundWord = ((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":95
 *         pluralIndex = -1
 *         compoundWord = self.__dictionaryTrie.getCompundWordStartingWith(currentWord)
 *         if not isRootVerb:             # <<<<<<<<<<<<<<
 *             if compoundWord is not None and len(compoundWord.getName()) - len(currentWord) < 3:
 *                 result.add(compoundWord.getName())
 */
  __pyx_t_7 = ((!(__pyx_v_isRootVerb != 0)) != 0);
  if (__pyx_t_7) {

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":96
 *         compoundWord = self.__dictionaryTrie.getCompundWordStartingWith(currentWord)
 *         if not isRootVerb:
 *             if compoundWord is not None and len(compoundWord.getName()) - len(currentWord) < 3:             # <<<<<<<<<<<<<<
 *                 result.add(compoundWord.getName())
 *             result.add(currentWord)
 */
    __pyx_t_8 = (((PyObject *)__pyx_v_compoundWord) != Py_None);
    __pyx_t_9 = (__pyx_t_8 != 0);
    if (__pyx_t_9) {
    } else {
      __pyx_t_7 = __pyx_t_9;
      goto __pyx_L8_bool_binop_done;
    }
    __pyx_t_1 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_compoundWord->__pyx_base.__pyx_vtab)->__pyx_base.getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_v_compoundWord), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 96, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (unlikely(__pyx_t_1 == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
      __PYX_ERR(0, 96, __pyx_L1_error)
    }
    __pyx_t_10 = __Pyx_PyUnicode_GET_LENGTH(__pyx_t_1); if (unlikely(__pyx_t_10 == ((Py_ssize_t)-1))) __PYX_ERR(0, 96, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(__pyx_v_currentWord == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
      __PYX_ERR(0, 96, __pyx_L1_error)
    }
    __pyx_t_11 = __Pyx_PyUnicode_GET_LENGTH(__pyx_v_currentWord); if (unlikely(__pyx_t_11 == ((Py_ssize_t)-1))) __PYX_ERR(0, 96, __pyx_L1_error)
    __pyx_t_9 = (((__pyx_t_10 - __pyx_t_11) < 3) != 0);
    __pyx_t_7 = __pyx_t_9;
    __pyx_L8_bool_binop_done:;
    if (__pyx_t_7) {

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":97
 *         if not isRootVerb:
 *             if compoundWord is not None and len(compoundWord.getName()) - len(currentWord) < 3:
 *                 result.add(compoundWord.getName())             # <<<<<<<<<<<<<<
 *             result.add(currentWord)
 *         currentRoot = self.__dictionary.getWord(metamorphicParse.getWord().getName())
 */
      __pyx_t_1 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_compoundWord->__pyx_base.__pyx_vtab)->__pyx_base.getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_v_compoundWord), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 97, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_12 = PySet_Add(__pyx_v_result, __pyx_t_1); if (unlikely(__pyx_t_12 == ((int)-1))) __PYX_ERR(0, 97, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":96
 *         compoundWord = self.__dictionaryTrie.getCompundWordStartingWith(currentWord)
 *         if not isRootVerb:
 *             if compoundWord is not None and len(compoundWord.getName()) - len(currentWord) < 3:             # <<<<<<<<<<<<<<
 *                 result.add(compoundWord.getName())
 *             result.add(currentWord)
 */
    }

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":98
 *             if compoundWord is not None and len(compoundWord.getName()) - len(currentWord) < 3:
 *                 result.add(compoundWord.getName())
 *             result.add(currentWord)             # <<<<<<<<<<<<<<
 *         currentRoot = self.__dictionary.getWord(metamorphicParse.getWord().getName())
 *         if currentRoot is None and compoundWord is not None:
 */
    __pyx_t_12 = PySet_Add(__pyx_v_result, __pyx_v_currentWord); if (unlikely(__pyx_t_12 == ((int)-1))) __PYX_ERR(0, 98, __pyx_L1_error)

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":95
 *         pluralIndex = -1
 *         compoundWord = self.__dictionaryTrie.getCompundWordStartingWith(currentWord)
 *         if not isRootVerb:             # <<<<<<<<<<<<<<
 *             if compoundWord is not None and len(compoundWord.getName()) - len(currentWord) < 3:
 *                 result.add(compoundWord.getName())
 */
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":99
 *                 result.add(compoundWord.getName())
 *             result.add(currentWord)
 *         currentRoot = self.__dictionary.getWord(metamorphicParse.getWord().getName())             # <<<<<<<<<<<<<<
 *         if currentRoot is None and compoundWord is not None:
 *             currentRoot = compoundWord
 */
  __pyx_t_1 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse *)__pyx_v_metamorphicParse->__pyx_vtab)->getWord(__pyx_v_metamorphicParse, 0)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 99, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_10Dictionary_4Word_Word *)((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_t_1)->__pyx_vtab)->getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_t_1), 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 99, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = ((PyObject *)((struct __pyx_vtabstruct_10Dictionary_13TxtDictionary_TxtDictionary *)__pyx_v_self->__pyx___dictionary->__pyx_base.__pyx_vtab)->__pyx_base.getWord(((struct __pyx_obj_10Dictionary_10Dictionary_Dictionary *)__pyx_v_self->__pyx___dictionary), ((PyObject*)__pyx_t_2), 0)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 99, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_10Dictionary_7TxtWord_TxtWord))))) __PYX_ERR(0, 99, __pyx_L1_error)
  __pyx_v_currentRoot = ((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":100
 *             result.add(currentWord)
 *         currentRoot = self.__dictionary.getWord(metamorphicParse.getWord().getName())
 *         if currentRoot is None and compoundWord is not None:             # <<<<<<<<<<<<<<
 *             currentRoot = compoundWord
 *         if currentRoot is not None:
 */
  __pyx_t_9 = (((PyObject *)__pyx_v_currentRoot) == Py_None);
  __pyx_t_8 = (__pyx_t_9 != 0);
  if (__pyx_t_8) {
  } else {
    __pyx_t_7 = __pyx_t_8;
    goto __pyx_L11_bool_binop_done;
  }
  __pyx_t_8 = (((PyObject *)__pyx_v_compoundWord) != Py_None);
  __pyx_t_9 = (__pyx_t_8 != 0);
  __pyx_t_7 = __pyx_t_9;
  __pyx_L11_bool_binop_done:;
  if (__pyx_t_7) {

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":101
 *         currentRoot = self.__dictionary.getWord(metamorphicParse.getWord().getName())
 *         if currentRoot is None and compoundWord is not None:
 *             currentRoot = compoundWord             # <<<<<<<<<<<<<<
 *         if currentRoot is not None:
 *             if isRootVerb:
 */
    __Pyx_INCREF(((PyObject *)__pyx_v_compoundWord));
    __Pyx_DECREF_SET(__pyx_v_currentRoot, __pyx_v_compoundWord);

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":100
 *             result.add(currentWord)
 *         currentRoot = self.__dictionary.getWord(metamorphicParse.getWord().getName())
 *         if currentRoot is None and compoundWord is not None:             # <<<<<<<<<<<<<<
 *             currentRoot = compoundWord
 *         if currentRoot is not None:
 */
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":102
 *         if currentRoot is None and compoundWord is not None:
 *             currentRoot = compoundWord
 *         if currentRoot is not None:             # <<<<<<<<<<<<<<
 *             if isRootVerb:
 *                 verbWord = verbTransition.makeTransitionNoStartState(currentRoot, currentWord)
 */
  __pyx_t_7 = (((PyObject *)__pyx_v_currentRoot) != Py_None);
  __pyx_t_9 = (__pyx_t_7 != 0);
  if (__pyx_t_9) {

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":103
 *             currentRoot = compoundWord
 *         if currentRoot is not None:
 *             if isRootVerb:             # <<<<<<<<<<<<<<
 *                 verbWord = verbTransition.makeTransitionNoStartState(currentRoot, currentWord)
 *                 result.add(verbWord)
 */
    __pyx_t_9 = (__pyx_v_isRootVerb != 0);
    if (__pyx_t_9) {

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":104
 *         if currentRoot is not None:
 *             if isRootVerb:
 *                 verbWord = verbTransition.makeTransitionNoStartState(currentRoot, currentWord)             # <<<<<<<<<<<<<<
 *                 result.add(verbWord)
 *             pluralWord = None
 */
      __pyx_t_1 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_10Transition_Transition *)__pyx_v_verbTransition->__pyx_vtab)->makeTransitionNoStartState(__pyx_v_verbTransition, __pyx_v_currentRoot, __pyx_v_currentWord, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 104, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_v_verbWord = ((PyObject*)__pyx_t_1);
      __pyx_t_1 = 0;

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":105
 *             if isRootVerb:
 *                 verbWord = verbTransition.makeTransitionNoStartState(currentRoot, currentWord)
 *                 result.add(verbWord)             # <<<<<<<<<<<<<<
 *             pluralWord = None
 *             for i in range(1, metamorphicParse.size()):
 */
      __pyx_t_12 = PySet_Add(__pyx_v_result, __pyx_v_verbWord); if (unlikely(__pyx_t_12 == ((int)-1))) __PYX_ERR(0, 105, __pyx_L1_error)

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":103
 *             currentRoot = compoundWord
 *         if currentRoot is not None:
 *             if isRootVerb:             # <<<<<<<<<<<<<<
 *                 verbWord = verbTransition.makeTransitionNoStartState(currentRoot, currentWord)
 *                 result.add(verbWord)
 */
    }

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":106
 *                 verbWord = verbTransition.makeTransitionNoStartState(currentRoot, currentWord)
 *                 result.add(verbWord)
 *             pluralWord = None             # <<<<<<<<<<<<<<
 *             for i in range(1, metamorphicParse.size()):
 *                 transition = Transition(metamorphicParse.getMetaMorpheme(i))
 */
    __Pyx_INCREF(Py_None);
    __pyx_v_pluralWord = ((PyObject*)Py_None);

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":107
 *                 result.add(verbWord)
 *             pluralWord = None
 *             for i in range(1, metamorphicParse.size()):             # <<<<<<<<<<<<<<
 *                 transition = Transition(metamorphicParse.getMetaMorpheme(i))
 *                 if metamorphicParse.getMetaMorpheme(i) == "lAr":
 */
    __pyx_t_5 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse *)__pyx_v_metamorphicParse->__pyx_vtab)->size(__pyx_v_metamorphicParse, 0);
    __pyx_t_13 = __pyx_t_5;
    for (__pyx_t_14 = 1; __pyx_t_14 < __pyx_t_13; __pyx_t_14+=1) {
      __pyx_v_i = __pyx_t_14;

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":108
 *             pluralWord = None
 *             for i in range(1, metamorphicParse.size()):
 *                 transition = Transition(metamorphicParse.getMetaMorpheme(i))             # <<<<<<<<<<<<<<
 *                 if metamorphicParse.getMetaMorpheme(i) == "lAr":
 *                     pluralWord = currentWord
 */
      __pyx_t_1 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse *)__pyx_v_metamorphicParse->__pyx_vtab)->getMetaMorpheme(__pyx_v_metamorphicParse, __pyx_v_i, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 108, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_2 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_10Transition_Transition), __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 108, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF_SET(__pyx_v_transition, ((struct __pyx_obj_21MorphologicalAnalysis_10Transition_Transition *)__pyx_t_2));
      __pyx_t_2 = 0;

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":109
 *             for i in range(1, metamorphicParse.size()):
 *                 transition = Transition(metamorphicParse.getMetaMorpheme(i))
 *                 if metamorphicParse.getMetaMorpheme(i) == "lAr":             # <<<<<<<<<<<<<<
 *                     pluralWord = currentWord
 *                     pluralIndex = i + 1
 */
      __pyx_t_2 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse *)__pyx_v_metamorphicParse->__pyx_vtab)->getMetaMorpheme(__pyx_v_metamorphicParse, __pyx_v_i, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 109, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_t_2, __pyx_n_u_lAr, Py_EQ)); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 109, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_7 = (__pyx_t_9 != 0);
      if (__pyx_t_7) {

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":110
 *                 transition = Transition(metamorphicParse.getMetaMorpheme(i))
 *                 if metamorphicParse.getMetaMorpheme(i) == "lAr":
 *                     pluralWord = currentWord             # <<<<<<<<<<<<<<
 *                     pluralIndex = i + 1
 *                 currentWord = transition.makeTransitionNoStartState(currentRoot, currentWord)
 */
        __Pyx_INCREF(__pyx_v_currentWord);
        __Pyx_DECREF_SET(__pyx_v_pluralWord, __pyx_v_currentWord);

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":111
 *                 if metamorphicParse.getMetaMorpheme(i) == "lAr":
 *                     pluralWord = currentWord
 *                     pluralIndex = i + 1             # <<<<<<<<<<<<<<
 *                 currentWord = transition.makeTransitionNoStartState(currentRoot, currentWord)
 *                 result.add(currentWord)
 */
        __pyx_v_pluralIndex = (__pyx_v_i + 1);

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":109
 *             for i in range(1, metamorphicParse.size()):
 *                 transition = Transition(metamorphicParse.getMetaMorpheme(i))
 *                 if metamorphicParse.getMetaMorpheme(i) == "lAr":             # <<<<<<<<<<<<<<
 *                     pluralWord = currentWord
 *                     pluralIndex = i + 1
 */
      }

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":112
 *                     pluralWord = currentWord
 *                     pluralIndex = i + 1
 *                 currentWord = transition.makeTransitionNoStartState(currentRoot, currentWord)             # <<<<<<<<<<<<<<
 *                 result.add(currentWord)
 *                 if containsVerb:
 */
      __pyx_t_2 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_10Transition_Transition *)__pyx_v_transition->__pyx_vtab)->makeTransitionNoStartState(__pyx_v_transition, __pyx_v_currentRoot, __pyx_v_currentWord, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 112, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF_SET(__pyx_v_currentWord, ((PyObject*)__pyx_t_2));
      __pyx_t_2 = 0;

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":113
 *                     pluralIndex = i + 1
 *                 currentWord = transition.makeTransitionNoStartState(currentRoot, currentWord)
 *                 result.add(currentWord)             # <<<<<<<<<<<<<<
 *                 if containsVerb:
 *                     verbWord = verbTransition.makeTransitionNoStartState(currentRoot, currentWord)
 */
      __pyx_t_12 = PySet_Add(__pyx_v_result, __pyx_v_currentWord); if (unlikely(__pyx_t_12 == ((int)-1))) __PYX_ERR(0, 113, __pyx_L1_error)

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":114
 *                 currentWord = transition.makeTransitionNoStartState(currentRoot, currentWord)
 *                 result.add(currentWord)
 *                 if containsVerb:             # <<<<<<<<<<<<<<
 *                     verbWord = verbTransition.makeTransitionNoStartState(currentRoot, currentWord)
 *                     result.add(verbWord)
 */
      __pyx_t_7 = (__pyx_v_containsVerb != 0);
      if (__pyx_t_7) {

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":115
 *                 result.add(currentWord)
 *                 if containsVerb:
 *                     verbWord = verbTransition.makeTransitionNoStartState(currentRoot, currentWord)             # <<<<<<<<<<<<<<
 *                     result.add(verbWord)
 *             if pluralWord is not None:
 */
        __pyx_t_2 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_10Transition_Transition *)__pyx_v_verbTransition->__pyx_vtab)->makeTransitionNoStartState(__pyx_v_verbTransition, __pyx_v_currentRoot, __pyx_v_currentWord, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 115, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_XDECREF_SET(__pyx_v_verbWord, ((PyObject*)__pyx_t_2));
        __pyx_t_2 = 0;

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":116
 *                 if containsVerb:
 *                     verbWord = verbTransition.makeTransitionNoStartState(currentRoot, currentWord)
 *                     result.add(verbWord)             # <<<<<<<<<<<<<<
 *             if pluralWord is not None:
 *                 currentWord = pluralWord
 */
        __pyx_t_12 = PySet_Add(__pyx_v_result, __pyx_v_verbWord); if (unlikely(__pyx_t_12 == ((int)-1))) __PYX_ERR(0, 116, __pyx_L1_error)

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":114
 *                 currentWord = transition.makeTransitionNoStartState(currentRoot, currentWord)
 *                 result.add(currentWord)
 *                 if containsVerb:             # <<<<<<<<<<<<<<
 *                     verbWord = verbTransition.makeTransitionNoStartState(currentRoot, currentWord)
 *                     result.add(verbWord)
 */
      }
    }

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":117
 *                     verbWord = verbTransition.makeTransitionNoStartState(currentRoot, currentWord)
 *                     result.add(verbWord)
 *             if pluralWord is not None:             # <<<<<<<<<<<<<<
 *                 currentWord = pluralWord
 *                 for i in range(pluralIndex, metamorphicParse.size()):
 */
    __pyx_t_7 = (__pyx_v_pluralWord != ((PyObject*)Py_None));
    __pyx_t_9 = (__pyx_t_7 != 0);
    if (__pyx_t_9) {

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":118
 *                     result.add(verbWord)
 *             if pluralWord is not None:
 *                 currentWord = pluralWord             # <<<<<<<<<<<<<<
 *                 for i in range(pluralIndex, metamorphicParse.size()):
 *                     transition = Transition(metamorphicParse.getMetaMorpheme(i))
 */
      __Pyx_INCREF(__pyx_v_pluralWord);
      __Pyx_DECREF_SET(__pyx_v_currentWord, __pyx_v_pluralWord);

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":119
 *             if pluralWord is not None:
 *                 currentWord = pluralWord
 *                 for i in range(pluralIndex, metamorphicParse.size()):             # <<<<<<<<<<<<<<
 *                     transition = Transition(metamorphicParse.getMetaMorpheme(i))
 *                     currentWord = transition.makeTransitionNoStartState(currentRoot, currentWord)
 */
      __pyx_t_5 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse *)__pyx_v_metamorphicParse->__pyx_vtab)->size(__pyx_v_metamorphicParse, 0);
      __pyx_t_13 = __pyx_t_5;
      for (__pyx_t_14 = __pyx_v_pluralIndex; __pyx_t_14 < __pyx_t_13; __pyx_t_14+=1) {
        __pyx_v_i = __pyx_t_14;

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":120
 *                 currentWord = pluralWord
 *                 for i in range(pluralIndex, metamorphicParse.size()):
 *                     transition = Transition(metamorphicParse.getMetaMorpheme(i))             # <<<<<<<<<<<<<<
 *                     currentWord = transition.makeTransitionNoStartState(currentRoot, currentWord)
 *                     result.add(currentWord)
 */
        __pyx_t_2 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse *)__pyx_v_metamorphicParse->__pyx_vtab)->getMetaMorpheme(__pyx_v_metamorphicParse, __pyx_v_i, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 120, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_1 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_10Transition_Transition), __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 120, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_XDECREF_SET(__pyx_v_transition, ((struct __pyx_obj_21MorphologicalAnalysis_10Transition_Transition *)__pyx_t_1));
        __pyx_t_1 = 0;

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":121
 *                 for i in range(pluralIndex, metamorphicParse.size()):
 *                     transition = Transition(metamorphicParse.getMetaMorpheme(i))
 *                     currentWord = transition.makeTransitionNoStartState(currentRoot, currentWord)             # <<<<<<<<<<<<<<
 *                     result.add(currentWord)
 *                     if containsVerb:
 */
        __pyx_t_1 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_10Transition_Transition *)__pyx_v_transition->__pyx_vtab)->makeTransitionNoStartState(__pyx_v_transition, __pyx_v_currentRoot, __pyx_v_currentWord, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 121, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF_SET(__pyx_v_currentWord, ((PyObject*)__pyx_t_1));
        __pyx_t_1 = 0;

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":122
 *                     transition = Transition(metamorphicParse.getMetaMorpheme(i))
 *                     currentWord = transition.makeTransitionNoStartState(currentRoot, currentWord)
 *                     result.add(currentWord)             # <<<<<<<<<<<<<<
 *                     if containsVerb:
 *                         verbWord = verbTransition.makeTransitionNoStartState(currentRoot, currentWord)
 */
        __pyx_t_12 = PySet_Add(__pyx_v_result, __pyx_v_currentWord); if (unlikely(__pyx_t_12 == ((int)-1))) __PYX_ERR(0, 122, __pyx_L1_error)

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":123
 *                     currentWord = transition.makeTransitionNoStartState(currentRoot, currentWord)
 *                     result.add(currentWord)
 *                     if containsVerb:             # <<<<<<<<<<<<<<
 *                         verbWord = verbTransition.makeTransitionNoStartState(currentRoot, currentWord)
 *                         result.add(verbWord)
 */
        __pyx_t_9 = (__pyx_v_containsVerb != 0);
        if (__pyx_t_9) {

          /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":124
 *                     result.add(currentWord)
 *                     if containsVerb:
 *                         verbWord = verbTransition.makeTransitionNoStartState(currentRoot, currentWord)             # <<<<<<<<<<<<<<
 *                         result.add(verbWord)
 *         return result
 */
          __pyx_t_1 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_10Transition_Transition *)__pyx_v_verbTransition->__pyx_vtab)->makeTransitionNoStartState(__pyx_v_verbTransition, __pyx_v_currentRoot, __pyx_v_currentWord, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 124, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_XDECREF_SET(__pyx_v_verbWord, ((PyObject*)__pyx_t_1));
          __pyx_t_1 = 0;

          /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":125
 *                     if containsVerb:
 *                         verbWord = verbTransition.makeTransitionNoStartState(currentRoot, currentWord)
 *                         result.add(verbWord)             # <<<<<<<<<<<<<<
 *         return result
 * 
 */
          __pyx_t_12 = PySet_Add(__pyx_v_result, __pyx_v_verbWord); if (unlikely(__pyx_t_12 == ((int)-1))) __PYX_ERR(0, 125, __pyx_L1_error)

          /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":123
 *                     currentWord = transition.makeTransitionNoStartState(currentRoot, currentWord)
 *                     result.add(currentWord)
 *                     if containsVerb:             # <<<<<<<<<<<<<<
 *                         verbWord = verbTransition.makeTransitionNoStartState(currentRoot, currentWord)
 *                         result.add(verbWord)
 */
        }
      }

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":117
 *                     verbWord = verbTransition.makeTransitionNoStartState(currentRoot, currentWord)
 *                     result.add(verbWord)
 *             if pluralWord is not None:             # <<<<<<<<<<<<<<
 *                 currentWord = pluralWord
 *                 for i in range(pluralIndex, metamorphicParse.size()):
 */
    }

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":102
 *         if currentRoot is None and compoundWord is not None:
 *             currentRoot = compoundWord
 *         if currentRoot is not None:             # <<<<<<<<<<<<<<
 *             if isRootVerb:
 *                 verbWord = verbTransition.makeTransitionNoStartState(currentRoot, currentWord)
 */
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":126
 *                         verbWord = verbTransition.makeTransitionNoStartState(currentRoot, currentWord)
 *                         result.add(verbWord)
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     cpdef TxtDictionary getDictionary(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":53
 *             self.__parsedSurfaceForms.add(line.strip())
 * 
 *     cpdef set getPossibleWords(self, MorphologicalParse morphologicalParse, MetamorphicParse metamorphicParse):             # <<<<<<<<<<<<<<
 *         """
 *         The getPossibleWords method takes MorphologicalParse and MetamorphicParse as input.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("MorphologicalAnalysis.FsmMorphologicalAnalyzer.FsmMorphologicalAnalyzer.getPossibleWords", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_verbTransition);
  __Pyx_XDECREF((PyObject *)__pyx_v_transition);
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_currentWord);
  __Pyx_XDECREF(__pyx_v_verbWord);
  __Pyx_XDECREF(__pyx_v_pluralWord);
  __Pyx_XDECREF((PyObject *)__pyx_v_compoundWord);
  __Pyx_XDECREF((PyObject *)__pyx_v_currentRoot);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_5getPossibleWords(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_4getPossibleWords[] = "\n        The getPossibleWords method takes MorphologicalParse and MetamorphicParse as input.\n        First it determines whether the given morphologicalParse is the root verb and whether it contains a verb tag.\n        Then it creates new transition with -mak and creates a new set result.\n\n        It takes the given MetamorphicParse input as currentWord and if there is a compound word starting with the\n        currentWord, it gets this compoundWord from dictionaryTrie. If there is a compoundWord and the difference of the\n        currentWord and compundWords is less than 3 than compoundWord is added to the result, otherwise currentWord is\n        added\n\n        Then it gets the root from parse input as a currentRoot. If it is not null, and morphologicalParse input is\n        verb, it directly adds the verb to result after making transition to currentRoot with currentWord String. Else,\n        it creates a new transition with -lar and make this transition then adds to the result.\n\n        PARAMETERS\n        ----------\n        morphologicalParse : MorphologicalParse\n            MorphologicalParse type input.\n        metamorphicParse : MetamorphicParse\n            MetamorphicParse type input.\n\n        RETURNS\n        -------\n        set\n            set result.\n        ";
static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_5getPossibleWords(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_morphologicalParse = 0;
  struct __pyx_obj_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse *__pyx_v_metamorphicParse = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getPossibleWords (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_morphologicalParse,&__pyx_n_s_metamorphicParse,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_morphologicalParse)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_metamorphicParse)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("getPossibleWords", 1, 2, 2, 1); __PYX_ERR(0, 53, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "getPossibleWords") < 0)) __PYX_ERR(0, 53, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_morphologicalParse = ((struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)values[0]);
    __pyx_v_metamorphicParse = ((struct __pyx_obj_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse *)values[1]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("getPossibleWords", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 53, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("MorphologicalAnalysis.FsmMorphologicalAnalyzer.FsmMorphologicalAnalyzer.getPossibleWords", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_morphologicalParse), __pyx_ptype_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse, 1, "morphologicalParse", 0))) __PYX_ERR(0, 53, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_metamorphicParse), __pyx_ptype_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse, 1, "metamorphicParse", 0))) __PYX_ERR(0, 53, __pyx_L1_error)
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_4getPossibleWords(((struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self), __pyx_v_morphologicalParse, __pyx_v_metamorphicParse);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_4getPossibleWords(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_morphologicalParse, struct __pyx_obj_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse *__pyx_v_metamorphicParse) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getPossibleWords", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_getPossibleWords(__pyx_v_self, __pyx_v_morphologicalParse, __pyx_v_metamorphicParse, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 53, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.FsmMorphologicalAnalyzer.FsmMorphologicalAnalyzer.getPossibleWords", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":128
 *         return result
 * 
 *     cpdef TxtDictionary getDictionary(self):             # <<<<<<<<<<<<<<
 *         """
 *         The getDictionary method is used to get TxtDictionary.
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_7getDictionary(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static struct __pyx_obj_10Dictionary_13TxtDictionary_TxtDictionary *__pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_getDictionary(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, int __pyx_skip_dispatch) {
  struct __pyx_obj_10Dictionary_13TxtDictionary_TxtDictionary *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getDictionary", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_getDictionary); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 128, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_7getDictionary)) {
        __Pyx_XDECREF(((PyObject *)__pyx_r));
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 128, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_10Dictionary_13TxtDictionary_TxtDictionary))))) __PYX_ERR(0, 128, __pyx_L1_error)
        __pyx_r = ((struct __pyx_obj_10Dictionary_13TxtDictionary_TxtDictionary *)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":137
 *             TxtDictionary type dictionary.
 *         """
 *         return self.__dictionary             # <<<<<<<<<<<<<<
 * 
 *     cpdef FiniteStateMachine getFiniteStateMachine(self):
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __Pyx_INCREF(((PyObject *)__pyx_v_self->__pyx___dictionary));
  __pyx_r = __pyx_v_self->__pyx___dictionary;
  goto __pyx_L0;

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":128
 *         return result
 * 
 *     cpdef TxtDictionary getDictionary(self):             # <<<<<<<<<<<<<<
 *         """
 *         The getDictionary method is used to get TxtDictionary.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("MorphologicalAnalysis.FsmMorphologicalAnalyzer.FsmMorphologicalAnalyzer.getDictionary", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_7getDictionary(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_6getDictionary[] = "\n        The getDictionary method is used to get TxtDictionary.\n\n        RETURNS\n        -------\n        TxtDictionary\n            TxtDictionary type dictionary.\n        ";
static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_7getDictionary(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getDictionary (wrapper)", 0);
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_6getDictionary(((struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_6getDictionary(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getDictionary", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((PyObject *)__pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_getDictionary(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 128, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.FsmMorphologicalAnalyzer.FsmMorphologicalAnalyzer.getDictionary", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":139
 *         return self.__dictionary
 * 
 *     cpdef FiniteStateMachine getFiniteStateMachine(self):             # <<<<<<<<<<<<<<
 *         """
 *         The getFiniteStateMachine method is used to get FiniteStateMachine.
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_9getFiniteStateMachine(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static struct __pyx_obj_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine *__pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_getFiniteStateMachine(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, int __pyx_skip_dispatch) {
  struct __pyx_obj_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getFiniteStateMachine", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_getFiniteStateMachine); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 139, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_9getFiniteStateMachine)) {
        __Pyx_XDECREF(((PyObject *)__pyx_r));
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 139, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine))))) __PYX_ERR(0, 139, __pyx_L1_error)
        __pyx_r = ((struct __pyx_obj_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine *)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":148
 *             FiniteStateMachine type finiteStateMachine.
 *         """
 *         return self.__finiteStateMachine             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint __isPossibleSubstring(self, str shortString, str longString, TxtWord root):
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __Pyx_INCREF(((PyObject *)__pyx_v_self->__pyx___finiteStateMachine));
  __pyx_r = __pyx_v_self->__pyx___finiteStateMachine;
  goto __pyx_L0;

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":139
 *         return self.__dictionary
 * 
 *     cpdef FiniteStateMachine getFiniteStateMachine(self):             # <<<<<<<<<<<<<<
 *         """
 *         The getFiniteStateMachine method is used to get FiniteStateMachine.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("MorphologicalAnalysis.FsmMorphologicalAnalyzer.FsmMorphologicalAnalyzer.getFiniteStateMachine", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_9getFiniteStateMachine(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_8getFiniteStateMachine[] = "\n        The getFiniteStateMachine method is used to get FiniteStateMachine.\n\n        RETURNS\n        -------\n        FiniteStateMachine\n            FiniteStateMachine type finiteStateMachine.\n        ";
static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_9getFiniteStateMachine(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getFiniteStateMachine (wrapper)", 0);
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_8getFiniteStateMachine(((struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_8getFiniteStateMachine(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getFiniteStateMachine", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((PyObject *)__pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_getFiniteStateMachine(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 139, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.FsmMorphologicalAnalyzer.FsmMorphologicalAnalyzer.getFiniteStateMachine", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":150
 *         return self.__finiteStateMachine
 * 
 *     cpdef bint __isPossibleSubstring(self, str shortString, str longString, TxtWord root):             # <<<<<<<<<<<<<<
 *         """
 *         The isPossibleSubstring method first checks whether given short and long strings are equal to root word.
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_11__isPossibleSubstring(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer___isPossibleSubstring(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_shortString, PyObject *__pyx_v_longString, struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_root, int __pyx_skip_dispatch) {
  int __pyx_v_rootWord;
  int __pyx_v_distance;
  int __pyx_v_last;
  int __pyx_v_j;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_t_9;
  Py_ssize_t __pyx_t_10;
  Py_ssize_t __pyx_t_11;
  Py_UCS4 __pyx_t_12;
  Py_UCS4 __pyx_t_13;
  Py_ssize_t __pyx_t_14;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__isPossibleSubstring", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_isPossibleSubstring); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 150, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_11__isPossibleSubstring)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        __pyx_t_5 = 0;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_5 = 1;
          }
        }
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_3)) {
          PyObject *__pyx_temp[4] = {__pyx_t_4, __pyx_v_shortString, __pyx_v_longString, ((PyObject *)__pyx_v_root)};
          __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_5, 3+__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 150, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_GOTREF(__pyx_t_2);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
          PyObject *__pyx_temp[4] = {__pyx_t_4, __pyx_v_shortString, __pyx_v_longString, ((PyObject *)__pyx_v_root)};
          __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_5, 3+__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 150, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_GOTREF(__pyx_t_2);
        } else
        #endif
        {
          __pyx_t_6 = PyTuple_New(3+__pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 150, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          if (__pyx_t_4) {
            __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4); __pyx_t_4 = NULL;
          }
          __Pyx_INCREF(__pyx_v_shortString);
          __Pyx_GIVEREF(__pyx_v_shortString);
          PyTuple_SET_ITEM(__pyx_t_6, 0+__pyx_t_5, __pyx_v_shortString);
          __Pyx_INCREF(__pyx_v_longString);
          __Pyx_GIVEREF(__pyx_v_longString);
          PyTuple_SET_ITEM(__pyx_t_6, 1+__pyx_t_5, __pyx_v_longString);
          __Pyx_INCREF(((PyObject *)__pyx_v_root));
          __Pyx_GIVEREF(((PyObject *)__pyx_v_root));
          PyTuple_SET_ITEM(__pyx_t_6, 2+__pyx_t_5, ((PyObject *)__pyx_v_root));
          __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_6, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 150, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        }
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_7 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 150, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_7;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":182
 *         cdef bint rootWord
 *         cdef int distance, last, j
 *         rootWord = shortString == root.getName() or longString == root.getName()             # <<<<<<<<<<<<<<
 *         distance = 0
 *         last = 1
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->__pyx_base.getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_v_root), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 182, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_8 = (__Pyx_PyUnicode_Equals(__pyx_v_shortString, __pyx_t_1, Py_EQ)); if (unlikely(__pyx_t_8 < 0)) __PYX_ERR(0, 182, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_9 = (__pyx_t_8 != 0);
  if (!__pyx_t_9) {
  } else {
    __pyx_t_7 = __pyx_t_9;
    goto __pyx_L3_bool_binop_done;
  }
  __pyx_t_1 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->__pyx_base.getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_v_root), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 182, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_v_longString, __pyx_t_1, Py_EQ)); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 182, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_8 = (__pyx_t_9 != 0);
  __pyx_t_7 = __pyx_t_8;
  __pyx_L3_bool_binop_done:;
  __pyx_v_rootWord = __pyx_t_7;

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":183
 *         cdef int distance, last, j
 *         rootWord = shortString == root.getName() or longString == root.getName()
 *         distance = 0             # <<<<<<<<<<<<<<
 *         last = 1
 *         for j in range(len(shortString)):
 */
  __pyx_v_distance = 0;

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":184
 *         rootWord = shortString == root.getName() or longString == root.getName()
 *         distance = 0
 *         last = 1             # <<<<<<<<<<<<<<
 *         for j in range(len(shortString)):
 *             if shortString[j] != longString[j]:
 */
  __pyx_v_last = 1;

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":185
 *         distance = 0
 *         last = 1
 *         for j in range(len(shortString)):             # <<<<<<<<<<<<<<
 *             if shortString[j] != longString[j]:
 *                 if j < len(shortString) - 2:
 */
  if (unlikely(__pyx_v_shortString == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(0, 185, __pyx_L1_error)
  }
  __pyx_t_10 = __Pyx_PyUnicode_GET_LENGTH(__pyx_v_shortString); if (unlikely(__pyx_t_10 == ((Py_ssize_t)-1))) __PYX_ERR(0, 185, __pyx_L1_error)
  __pyx_t_11 = __pyx_t_10;
  for (__pyx_t_5 = 0; __pyx_t_5 < __pyx_t_11; __pyx_t_5+=1) {
    __pyx_v_j = __pyx_t_5;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":186
 *         last = 1
 *         for j in range(len(shortString)):
 *             if shortString[j] != longString[j]:             # <<<<<<<<<<<<<<
 *                 if j < len(shortString) - 2:
 *                     return False
 */
    __pyx_t_12 = __Pyx_GetItemInt_Unicode(__pyx_v_shortString, __pyx_v_j, int, 1, __Pyx_PyInt_From_int, 0, 1, 1); if (unlikely(__pyx_t_12 == (Py_UCS4)-1)) __PYX_ERR(0, 186, __pyx_L1_error)
    __pyx_t_13 = __Pyx_GetItemInt_Unicode(__pyx_v_longString, __pyx_v_j, int, 1, __Pyx_PyInt_From_int, 0, 1, 1); if (unlikely(__pyx_t_13 == (Py_UCS4)-1)) __PYX_ERR(0, 186, __pyx_L1_error)
    __pyx_t_7 = ((__pyx_t_12 != __pyx_t_13) != 0);
    if (__pyx_t_7) {

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":187
 *         for j in range(len(shortString)):
 *             if shortString[j] != longString[j]:
 *                 if j < len(shortString) - 2:             # <<<<<<<<<<<<<<
 *                     return False
 *                 last = len(shortString) - j
 */
      if (unlikely(__pyx_v_shortString == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
        __PYX_ERR(0, 187, __pyx_L1_error)
      }
      __pyx_t_14 = __Pyx_PyUnicode_GET_LENGTH(__pyx_v_shortString); if (unlikely(__pyx_t_14 == ((Py_ssize_t)-1))) __PYX_ERR(0, 187, __pyx_L1_error)
      __pyx_t_7 = ((__pyx_v_j < (__pyx_t_14 - 2)) != 0);
      if (__pyx_t_7) {

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":188
 *             if shortString[j] != longString[j]:
 *                 if j < len(shortString) - 2:
 *                     return False             # <<<<<<<<<<<<<<
 *                 last = len(shortString) - j
 *                 distance = distance + 1
 */
        __pyx_r = 0;
        goto __pyx_L0;

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":187
 *         for j in range(len(shortString)):
 *             if shortString[j] != longString[j]:
 *                 if j < len(shortString) - 2:             # <<<<<<<<<<<<<<
 *                     return False
 *                 last = len(shortString) - j
 */
      }

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":189
 *                 if j < len(shortString) - 2:
 *                     return False
 *                 last = len(shortString) - j             # <<<<<<<<<<<<<<
 *                 distance = distance + 1
 *                 if distance > self.MAX_DISTANCE:
 */
      if (unlikely(__pyx_v_shortString == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
        __PYX_ERR(0, 189, __pyx_L1_error)
      }
      __pyx_t_14 = __Pyx_PyUnicode_GET_LENGTH(__pyx_v_shortString); if (unlikely(__pyx_t_14 == ((Py_ssize_t)-1))) __PYX_ERR(0, 189, __pyx_L1_error)
      __pyx_v_last = (__pyx_t_14 - __pyx_v_j);

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":190
 *                     return False
 *                 last = len(shortString) - j
 *                 distance = distance + 1             # <<<<<<<<<<<<<<
 *                 if distance > self.MAX_DISTANCE:
 *                     break
 */
      __pyx_v_distance = (__pyx_v_distance + 1);

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":191
 *                 last = len(shortString) - j
 *                 distance = distance + 1
 *                 if distance > self.MAX_DISTANCE:             # <<<<<<<<<<<<<<
 *                     break
 *         if rootWord and (root.getName() == "ben" or root.lastIdropsDuringSuffixation()
 */
      __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_distance); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 191, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_MAX_DISTANCE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 191, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_3 = PyObject_RichCompare(__pyx_t_1, __pyx_t_2, Py_GT); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 191, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 191, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_7) {

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":192
 *                 distance = distance + 1
 *                 if distance > self.MAX_DISTANCE:
 *                     break             # <<<<<<<<<<<<<<
 *         if rootWord and (root.getName() == "ben" or root.lastIdropsDuringSuffixation()
 *                          or root.lastIdropsDuringPassiveSuffixation()):
 */
        goto __pyx_L6_break;

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":191
 *                 last = len(shortString) - j
 *                 distance = distance + 1
 *                 if distance > self.MAX_DISTANCE:             # <<<<<<<<<<<<<<
 *                     break
 *         if rootWord and (root.getName() == "ben" or root.lastIdropsDuringSuffixation()
 */
      }

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":186
 *         last = 1
 *         for j in range(len(shortString)):
 *             if shortString[j] != longString[j]:             # <<<<<<<<<<<<<<
 *                 if j < len(shortString) - 2:
 *                     return False
 */
    }
  }
  __pyx_L6_break:;

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":193
 *                 if distance > self.MAX_DISTANCE:
 *                     break
 *         if rootWord and (root.getName() == "ben" or root.lastIdropsDuringSuffixation()             # <<<<<<<<<<<<<<
 *                          or root.lastIdropsDuringPassiveSuffixation()):
 *             return distance <= self.MAX_DISTANCE
 */
  __pyx_t_8 = (__pyx_v_rootWord != 0);
  if (__pyx_t_8) {
  } else {
    __pyx_t_7 = __pyx_t_8;
    goto __pyx_L11_bool_binop_done;
  }
  __pyx_t_3 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->__pyx_base.getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_v_root), 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 193, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_8 = (__Pyx_PyUnicode_Equals(__pyx_t_3, __pyx_n_u_ben, Py_EQ)); if (unlikely(__pyx_t_8 < 0)) __PYX_ERR(0, 193, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_9 = (__pyx_t_8 != 0);
  if (!__pyx_t_9) {
  } else {
    __pyx_t_7 = __pyx_t_9;
    goto __pyx_L11_bool_binop_done;
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":194
 *                     break
 *         if rootWord and (root.getName() == "ben" or root.lastIdropsDuringSuffixation()
 *                          or root.lastIdropsDuringPassiveSuffixation()):             # <<<<<<<<<<<<<<
 *             return distance <= self.MAX_DISTANCE
 *         elif shortString.endswith("e") or shortString.endswith("a") or shortString.endswith("p") \
 */
  __pyx_t_9 = (((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->lastIdropsDuringSuffixation(__pyx_v_root, 0) != 0);
  if (!__pyx_t_9) {
  } else {
    __pyx_t_7 = __pyx_t_9;
    goto __pyx_L11_bool_binop_done;
  }
  __pyx_t_9 = (((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->lastIdropsDuringPassiveSuffixation(__pyx_v_root, 0) != 0);
  __pyx_t_7 = __pyx_t_9;
  __pyx_L11_bool_binop_done:;

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":193
 *                 if distance > self.MAX_DISTANCE:
 *                     break
 *         if rootWord and (root.getName() == "ben" or root.lastIdropsDuringSuffixation()             # <<<<<<<<<<<<<<
 *                          or root.lastIdropsDuringPassiveSuffixation()):
 *             return distance <= self.MAX_DISTANCE
 */
  if (__pyx_t_7) {

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":195
 *         if rootWord and (root.getName() == "ben" or root.lastIdropsDuringSuffixation()
 *                          or root.lastIdropsDuringPassiveSuffixation()):
 *             return distance <= self.MAX_DISTANCE             # <<<<<<<<<<<<<<
 *         elif shortString.endswith("e") or shortString.endswith("a") or shortString.endswith("p") \
 *                 or shortString.endswith("") or shortString.endswith("t") or shortString.endswith("k") \
 */
    __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_distance); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 195, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_MAX_DISTANCE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 195, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = PyObject_RichCompare(__pyx_t_3, __pyx_t_2, Py_LE); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 195, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_7 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 195, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_r = __pyx_t_7;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":193
 *                 if distance > self.MAX_DISTANCE:
 *                     break
 *         if rootWord and (root.getName() == "ben" or root.lastIdropsDuringSuffixation()             # <<<<<<<<<<<<<<
 *                          or root.lastIdropsDuringPassiveSuffixation()):
 *             return distance <= self.MAX_DISTANCE
 */
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":196
 *                          or root.lastIdropsDuringPassiveSuffixation()):
 *             return distance <= self.MAX_DISTANCE
 *         elif shortString.endswith("e") or shortString.endswith("a") or shortString.endswith("p") \             # <<<<<<<<<<<<<<
 *                 or shortString.endswith("") or shortString.endswith("t") or shortString.endswith("k") \
 *                 or (rootWord and (root.rootSoftenDuringSuffixation() or root.vowelEChangesToIDuringYSuffixation()
 */
  if (unlikely(__pyx_v_shortString == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "endswith");
    __PYX_ERR(0, 196, __pyx_L1_error)
  }
  __pyx_t_9 = __Pyx_PyUnicode_Tailmatch(__pyx_v_shortString, __pyx_n_u_e, 0, PY_SSIZE_T_MAX, 1); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 196, __pyx_L1_error)
  if (!(__pyx_t_9 != 0)) {
  } else {
    __pyx_t_7 = (__pyx_t_9 != 0);
    goto __pyx_L15_bool_binop_done;
  }
  if (unlikely(__pyx_v_shortString == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "endswith");
    __PYX_ERR(0, 196, __pyx_L1_error)
  }
  __pyx_t_9 = __Pyx_PyUnicode_Tailmatch(__pyx_v_shortString, __pyx_n_u_a, 0, PY_SSIZE_T_MAX, 1); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 196, __pyx_L1_error)
  if (!(__pyx_t_9 != 0)) {
  } else {
    __pyx_t_7 = (__pyx_t_9 != 0);
    goto __pyx_L15_bool_binop_done;
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":197
 *             return distance <= self.MAX_DISTANCE
 *         elif shortString.endswith("e") or shortString.endswith("a") or shortString.endswith("p") \
 *                 or shortString.endswith("") or shortString.endswith("t") or shortString.endswith("k") \             # <<<<<<<<<<<<<<
 *                 or (rootWord and (root.rootSoftenDuringSuffixation() or root.vowelEChangesToIDuringYSuffixation()
 *                                   or root.vowelAChangesToIDuringYSuffixation() or root.endingKChangesIntoG())):
 */
  if (unlikely(__pyx_v_shortString == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "endswith");
    __PYX_ERR(0, 196, __pyx_L1_error)
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":196
 *                          or root.lastIdropsDuringPassiveSuffixation()):
 *             return distance <= self.MAX_DISTANCE
 *         elif shortString.endswith("e") or shortString.endswith("a") or shortString.endswith("p") \             # <<<<<<<<<<<<<<
 *                 or shortString.endswith("") or shortString.endswith("t") or shortString.endswith("k") \
 *                 or (rootWord and (root.rootSoftenDuringSuffixation() or root.vowelEChangesToIDuringYSuffixation()
 */
  __pyx_t_9 = __Pyx_PyUnicode_Tailmatch(__pyx_v_shortString, __pyx_n_u_p, 0, PY_SSIZE_T_MAX, 1); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 196, __pyx_L1_error)
  if (!(__pyx_t_9 != 0)) {
  } else {
    __pyx_t_7 = (__pyx_t_9 != 0);
    goto __pyx_L15_bool_binop_done;
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":197
 *             return distance <= self.MAX_DISTANCE
 *         elif shortString.endswith("e") or shortString.endswith("a") or shortString.endswith("p") \
 *                 or shortString.endswith("") or shortString.endswith("t") or shortString.endswith("k") \             # <<<<<<<<<<<<<<
 *                 or (rootWord and (root.rootSoftenDuringSuffixation() or root.vowelEChangesToIDuringYSuffixation()
 *                                   or root.vowelAChangesToIDuringYSuffixation() or root.endingKChangesIntoG())):
 */
  if (unlikely(__pyx_v_shortString == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "endswith");
    __PYX_ERR(0, 197, __pyx_L1_error)
  }
  __pyx_t_9 = __Pyx_PyUnicode_Tailmatch(__pyx_v_shortString, __pyx_n_u__2, 0, PY_SSIZE_T_MAX, 1); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 197, __pyx_L1_error)
  if (!(__pyx_t_9 != 0)) {
  } else {
    __pyx_t_7 = (__pyx_t_9 != 0);
    goto __pyx_L15_bool_binop_done;
  }
  if (unlikely(__pyx_v_shortString == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "endswith");
    __PYX_ERR(0, 197, __pyx_L1_error)
  }
  __pyx_t_9 = __Pyx_PyUnicode_Tailmatch(__pyx_v_shortString, __pyx_n_u_t, 0, PY_SSIZE_T_MAX, 1); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 197, __pyx_L1_error)
  if (!(__pyx_t_9 != 0)) {
  } else {
    __pyx_t_7 = (__pyx_t_9 != 0);
    goto __pyx_L15_bool_binop_done;
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":198
 *         elif shortString.endswith("e") or shortString.endswith("a") or shortString.endswith("p") \
 *                 or shortString.endswith("") or shortString.endswith("t") or shortString.endswith("k") \
 *                 or (rootWord and (root.rootSoftenDuringSuffixation() or root.vowelEChangesToIDuringYSuffixation()             # <<<<<<<<<<<<<<
 *                                   or root.vowelAChangesToIDuringYSuffixation() or root.endingKChangesIntoG())):
 *             return last != 2 and distance <= self.MAX_DISTANCE - 1
 */
  if (unlikely(__pyx_v_shortString == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "endswith");
    __PYX_ERR(0, 197, __pyx_L1_error)
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":197
 *             return distance <= self.MAX_DISTANCE
 *         elif shortString.endswith("e") or shortString.endswith("a") or shortString.endswith("p") \
 *                 or shortString.endswith("") or shortString.endswith("t") or shortString.endswith("k") \             # <<<<<<<<<<<<<<
 *                 or (rootWord and (root.rootSoftenDuringSuffixation() or root.vowelEChangesToIDuringYSuffixation()
 *                                   or root.vowelAChangesToIDuringYSuffixation() or root.endingKChangesIntoG())):
 */
  __pyx_t_9 = __Pyx_PyUnicode_Tailmatch(__pyx_v_shortString, __pyx_n_u_k, 0, PY_SSIZE_T_MAX, 1); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 197, __pyx_L1_error)
  if (!(__pyx_t_9 != 0)) {
  } else {
    __pyx_t_7 = (__pyx_t_9 != 0);
    goto __pyx_L15_bool_binop_done;
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":198
 *         elif shortString.endswith("e") or shortString.endswith("a") or shortString.endswith("p") \
 *                 or shortString.endswith("") or shortString.endswith("t") or shortString.endswith("k") \
 *                 or (rootWord and (root.rootSoftenDuringSuffixation() or root.vowelEChangesToIDuringYSuffixation()             # <<<<<<<<<<<<<<
 *                                   or root.vowelAChangesToIDuringYSuffixation() or root.endingKChangesIntoG())):
 *             return last != 2 and distance <= self.MAX_DISTANCE - 1
 */
  __pyx_t_9 = (__pyx_v_rootWord != 0);
  if (__pyx_t_9) {
  } else {
    __pyx_t_7 = __pyx_t_9;
    goto __pyx_L15_bool_binop_done;
  }
  __pyx_t_9 = (((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->rootSoftenDuringSuffixation(__pyx_v_root, 0) != 0);
  if (!__pyx_t_9) {
  } else {
    __pyx_t_7 = __pyx_t_9;
    goto __pyx_L15_bool_binop_done;
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":199
 *                 or shortString.endswith("") or shortString.endswith("t") or shortString.endswith("k") \
 *                 or (rootWord and (root.rootSoftenDuringSuffixation() or root.vowelEChangesToIDuringYSuffixation()
 *                                   or root.vowelAChangesToIDuringYSuffixation() or root.endingKChangesIntoG())):             # <<<<<<<<<<<<<<
 *             return last != 2 and distance <= self.MAX_DISTANCE - 1
 *         else:
 */
  __pyx_t_9 = (((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->vowelEChangesToIDuringYSuffixation(__pyx_v_root, 0) != 0);
  if (!__pyx_t_9) {
  } else {
    __pyx_t_7 = __pyx_t_9;
    goto __pyx_L15_bool_binop_done;
  }
  __pyx_t_9 = (((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->vowelAChangesToIDuringYSuffixation(__pyx_v_root, 0) != 0);
  if (!__pyx_t_9) {
  } else {
    __pyx_t_7 = __pyx_t_9;
    goto __pyx_L15_bool_binop_done;
  }
  __pyx_t_9 = (((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->endingKChangesIntoG(__pyx_v_root, 0) != 0);
  __pyx_t_7 = __pyx_t_9;
  __pyx_L15_bool_binop_done:;

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":196
 *                          or root.lastIdropsDuringPassiveSuffixation()):
 *             return distance <= self.MAX_DISTANCE
 *         elif shortString.endswith("e") or shortString.endswith("a") or shortString.endswith("p") \             # <<<<<<<<<<<<<<
 *                 or shortString.endswith("") or shortString.endswith("t") or shortString.endswith("k") \
 *                 or (rootWord and (root.rootSoftenDuringSuffixation() or root.vowelEChangesToIDuringYSuffixation()
 */
  if (__pyx_t_7) {

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":200
 *                 or (rootWord and (root.rootSoftenDuringSuffixation() or root.vowelEChangesToIDuringYSuffixation()
 *                                   or root.vowelAChangesToIDuringYSuffixation() or root.endingKChangesIntoG())):
 *             return last != 2 and distance <= self.MAX_DISTANCE - 1             # <<<<<<<<<<<<<<
 *         else:
 *             return distance <= self.MAX_DISTANCE - 2
 */
    __pyx_t_9 = ((__pyx_v_last != 2) != 0);
    if (__pyx_t_9) {
    } else {
      __pyx_t_7 = __pyx_t_9;
      goto __pyx_L26_bool_binop_done;
    }
    __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_distance); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 200, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_MAX_DISTANCE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 200, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyInt_SubtractObjC(__pyx_t_2, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 200, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyObject_RichCompare(__pyx_t_1, __pyx_t_3, Py_LE); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 200, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 200, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_7 = __pyx_t_9;
    __pyx_L26_bool_binop_done:;
    __pyx_r = __pyx_t_7;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":196
 *                          or root.lastIdropsDuringPassiveSuffixation()):
 *             return distance <= self.MAX_DISTANCE
 *         elif shortString.endswith("e") or shortString.endswith("a") or shortString.endswith("p") \             # <<<<<<<<<<<<<<
 *                 or shortString.endswith("") or shortString.endswith("t") or shortString.endswith("k") \
 *                 or (rootWord and (root.rootSoftenDuringSuffixation() or root.vowelEChangesToIDuringYSuffixation()
 */
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":202
 *             return last != 2 and distance <= self.MAX_DISTANCE - 1
 *         else:
 *             return distance <= self.MAX_DISTANCE - 2             # <<<<<<<<<<<<<<
 * 
 *     cpdef __initializeParseList(self, list fsmParse, TxtWord root, bint isProper):
 */
  /*else*/ {
    __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_distance); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 202, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_MAX_DISTANCE); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 202, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __Pyx_PyInt_SubtractObjC(__pyx_t_3, __pyx_int_2, 2, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 202, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyObject_RichCompare(__pyx_t_2, __pyx_t_1, Py_LE); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 202, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_7 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 202, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_r = __pyx_t_7;
    goto __pyx_L0;
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":150
 *         return self.__finiteStateMachine
 * 
 *     cpdef bint __isPossibleSubstring(self, str shortString, str longString, TxtWord root):             # <<<<<<<<<<<<<<
 *         """
 *         The isPossibleSubstring method first checks whether given short and long strings are equal to root word.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_WriteUnraisable("MorphologicalAnalysis.FsmMorphologicalAnalyzer.FsmMorphologicalAnalyzer.__isPossibleSubstring", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_11__isPossibleSubstring(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_10__isPossibleSubstring[] = "\n        The isPossibleSubstring method first checks whether given short and long strings are equal to root word.\n        Then, compares both short and long strings' chars till the last two chars of short string. In the presence of\n        mismatch, false is returned. On the other hand, it counts the distance between two strings until it becomes\n        greater than 2, which is the MAX_DISTANCE also finds the index of the last char.\n\n        If the substring is a rootWord and equals to 'ben', which is a special case or root holds the\n        lastIdropsDuringSuffixation or lastIdropsDuringPassiveSuffixation conditions, then it returns true if distance\n        is not greater than MAX_DISTANCE.\n\n        On the other hand, if the shortStrong ends with one of these chars 'e, a, p, \303\247, t, k' and it 's a rootWord with\n        the conditions of rootSoftenDuringSuffixation, vowelEChangesToIDuringYSuffixation,\n        vowelAChangesToIDuringYSuffixation or endingKChangesIntoG then it returns true if the last index is not equal to\n        2 and distance is not greater than MAX_DISTANCE and false otherwise.\n\n        PARAMETERS\n        ----------\n        shortString : str\n            the possible substring.\n        longString : str\n            the long string to compare with substring.\n        root : TxtWord\n            the root of the long string.\n\n        RETURNS\n        -------\n        bool\n            True if given substring is the actual substring of the longString, false otherwise.\n        ";
static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_11__isPossibleSubstring(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_shortString = 0;
  PyObject *__pyx_v_longString = 0;
  struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_root = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__isPossibleSubstring (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_shortString,&__pyx_n_s_longString,&__pyx_n_s_root,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_shortString)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_longString)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__isPossibleSubstring", 1, 3, 3, 1); __PYX_ERR(0, 150, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_root)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__isPossibleSubstring", 1, 3, 3, 2); __PYX_ERR(0, 150, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__isPossibleSubstring") < 0)) __PYX_ERR(0, 150, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_shortString = ((PyObject*)values[0]);
    __pyx_v_longString = ((PyObject*)values[1]);
    __pyx_v_root = ((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)values[2]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__isPossibleSubstring", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 150, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("MorphologicalAnalysis.FsmMorphologicalAnalyzer.FsmMorphologicalAnalyzer.__isPossibleSubstring", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_shortString), (&PyUnicode_Type), 1, "shortString", 1))) __PYX_ERR(0, 150, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_longString), (&PyUnicode_Type), 1, "longString", 1))) __PYX_ERR(0, 150, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_root), __pyx_ptype_10Dictionary_7TxtWord_TxtWord, 1, "root", 0))) __PYX_ERR(0, 150, __pyx_L1_error)
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_10__isPossibleSubstring(((struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self), __pyx_v_shortString, __pyx_v_longString, __pyx_v_root);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_10__isPossibleSubstring(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_shortString, PyObject *__pyx_v_longString, struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_root) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__isPossibleSubstring", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer___isPossibleSubstring(__pyx_v_self, __pyx_v_shortString, __pyx_v_longString, __pyx_v_root, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 150, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.FsmMorphologicalAnalyzer.FsmMorphologicalAnalyzer.__isPossibleSubstring", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":204
 *             return distance <= self.MAX_DISTANCE - 2
 * 
 *     cpdef __initializeParseList(self, list fsmParse, TxtWord root, bint isProper):             # <<<<<<<<<<<<<<
 *         """
 *         The initializeParseList method initializes the given given fsm ArrayList with given root words by parsing them.
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_13__initializeParseList(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer___initializeParseList(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_fsmParse, struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_root, int __pyx_v_isProper, int __pyx_skip_dispatch) {
  struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *__pyx_v_currentFsmParse = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  int __pyx_t_9;
  Py_ssize_t __pyx_t_10;
  Py_ssize_t __pyx_t_11;
  Py_UCS4 __pyx_t_12;
  int __pyx_t_13;
  int __pyx_t_14;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__initializeParseList", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_initializeParseList); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 204, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_13__initializeParseList)) {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = __Pyx_PyBool_FromLong(__pyx_v_isProper); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 204, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; __pyx_t_5 = NULL;
        __pyx_t_6 = 0;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
          if (likely(__pyx_t_5)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
            __Pyx_INCREF(__pyx_t_5);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_4, function);
            __pyx_t_6 = 1;
          }
        }
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_4)) {
          PyObject *__pyx_temp[4] = {__pyx_t_5, __pyx_v_fsmParse, ((PyObject *)__pyx_v_root), __pyx_t_3};
          __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_6, 3+__pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 204, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
          PyObject *__pyx_temp[4] = {__pyx_t_5, __pyx_v_fsmParse, ((PyObject *)__pyx_v_root), __pyx_t_3};
          __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_6, 3+__pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 204, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        } else
        #endif
        {
          __pyx_t_7 = PyTuple_New(3+__pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 204, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          if (__pyx_t_5) {
            __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5); __pyx_t_5 = NULL;
          }
          __Pyx_INCREF(__pyx_v_fsmParse);
          __Pyx_GIVEREF(__pyx_v_fsmParse);
          PyTuple_SET_ITEM(__pyx_t_7, 0+__pyx_t_6, __pyx_v_fsmParse);
          __Pyx_INCREF(((PyObject *)__pyx_v_root));
          __Pyx_GIVEREF(((PyObject *)__pyx_v_root));
          PyTuple_SET_ITEM(__pyx_t_7, 1+__pyx_t_6, ((PyObject *)__pyx_v_root));
          __Pyx_GIVEREF(__pyx_t_3);
          PyTuple_SET_ITEM(__pyx_t_7, 2+__pyx_t_6, __pyx_t_3);
          __pyx_t_3 = 0;
          __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_7, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 204, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        }
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":323
 *         """
 *         cdef FsmParse currentFsmParse
 *         if root.isPlural():             # <<<<<<<<<<<<<<
 *             currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("NominalRootPlural"))
 *             fsmParse.append(currentFsmParse)
 */
  __pyx_t_8 = (((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->isPlural(__pyx_v_root, 0) != 0);
  if (__pyx_t_8) {

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":324
 *         cdef FsmParse currentFsmParse
 *         if root.isPlural():
 *             currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("NominalRootPlural"))             # <<<<<<<<<<<<<<
 *             fsmParse.append(currentFsmParse)
 *         elif root.isPortmanteauEndingWithSI():
 */
    __pyx_t_1 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine *)__pyx_v_self->__pyx___finiteStateMachine->__pyx_vtab)->getState(__pyx_v_self->__pyx___finiteStateMachine, __pyx_n_u_NominalRootPlural, 0)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 324, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 324, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(((PyObject *)__pyx_v_root));
    __Pyx_GIVEREF(((PyObject *)__pyx_v_root));
    PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_v_root));
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_1);
    __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse), __pyx_t_2, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 324, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_v_currentFsmParse = ((struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":325
 *         if root.isPlural():
 *             currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("NominalRootPlural"))
 *             fsmParse.append(currentFsmParse)             # <<<<<<<<<<<<<<
 *         elif root.isPortmanteauEndingWithSI():
 *             currentFsmParse = FsmParse(root.getName()[:len(root.getName()) - 2],
 */
    if (unlikely(__pyx_v_fsmParse == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
      __PYX_ERR(0, 325, __pyx_L1_error)
    }
    __pyx_t_9 = __Pyx_PyList_Append(__pyx_v_fsmParse, ((PyObject *)__pyx_v_currentFsmParse)); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 325, __pyx_L1_error)

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":323
 *         """
 *         cdef FsmParse currentFsmParse
 *         if root.isPlural():             # <<<<<<<<<<<<<<
 *             currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("NominalRootPlural"))
 *             fsmParse.append(currentFsmParse)
 */
    goto __pyx_L3;
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":326
 *             currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("NominalRootPlural"))
 *             fsmParse.append(currentFsmParse)
 *         elif root.isPortmanteauEndingWithSI():             # <<<<<<<<<<<<<<
 *             currentFsmParse = FsmParse(root.getName()[:len(root.getName()) - 2],
 *                                        self.__finiteStateMachine.getState("CompoundNounRoot"))
 */
  __pyx_t_8 = (((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->isPortmanteauEndingWithSI(__pyx_v_root, 0) != 0);
  if (__pyx_t_8) {

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":327
 *             fsmParse.append(currentFsmParse)
 *         elif root.isPortmanteauEndingWithSI():
 *             currentFsmParse = FsmParse(root.getName()[:len(root.getName()) - 2],             # <<<<<<<<<<<<<<
 *                                        self.__finiteStateMachine.getState("CompoundNounRoot"))
 *             fsmParse.append(currentFsmParse)
 */
    __pyx_t_1 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->__pyx_base.getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_v_root), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 327, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (unlikely(__pyx_t_1 == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 327, __pyx_L1_error)
    }
    __pyx_t_2 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->__pyx_base.getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_v_root), 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 327, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (unlikely(__pyx_t_2 == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
      __PYX_ERR(0, 327, __pyx_L1_error)
    }
    __pyx_t_10 = __Pyx_PyUnicode_GET_LENGTH(__pyx_t_2); if (unlikely(__pyx_t_10 == ((Py_ssize_t)-1))) __PYX_ERR(0, 327, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyUnicode_Substring(__pyx_t_1, 0, (__pyx_t_10 - 2)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 327, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":328
 *         elif root.isPortmanteauEndingWithSI():
 *             currentFsmParse = FsmParse(root.getName()[:len(root.getName()) - 2],
 *                                        self.__finiteStateMachine.getState("CompoundNounRoot"))             # <<<<<<<<<<<<<<
 *             fsmParse.append(currentFsmParse)
 *             currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("NominalRootNoPossesive"))
 */
    __pyx_t_1 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine *)__pyx_v_self->__pyx___finiteStateMachine->__pyx_vtab)->getState(__pyx_v_self->__pyx___finiteStateMachine, __pyx_n_u_CompoundNounRoot, 0)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 328, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":327
 *             fsmParse.append(currentFsmParse)
 *         elif root.isPortmanteauEndingWithSI():
 *             currentFsmParse = FsmParse(root.getName()[:len(root.getName()) - 2],             # <<<<<<<<<<<<<<
 *                                        self.__finiteStateMachine.getState("CompoundNounRoot"))
 *             fsmParse.append(currentFsmParse)
 */
    __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 327, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_1);
    __pyx_t_2 = 0;
    __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse), __pyx_t_4, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 327, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_v_currentFsmParse = ((struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":329
 *             currentFsmParse = FsmParse(root.getName()[:len(root.getName()) - 2],
 *                                        self.__finiteStateMachine.getState("CompoundNounRoot"))
 *             fsmParse.append(currentFsmParse)             # <<<<<<<<<<<<<<
 *             currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("NominalRootNoPossesive"))
 *             fsmParse.append(currentFsmParse)
 */
    if (unlikely(__pyx_v_fsmParse == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
      __PYX_ERR(0, 329, __pyx_L1_error)
    }
    __pyx_t_9 = __Pyx_PyList_Append(__pyx_v_fsmParse, ((PyObject *)__pyx_v_currentFsmParse)); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 329, __pyx_L1_error)

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":330
 *                                        self.__finiteStateMachine.getState("CompoundNounRoot"))
 *             fsmParse.append(currentFsmParse)
 *             currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("NominalRootNoPossesive"))             # <<<<<<<<<<<<<<
 *             fsmParse.append(currentFsmParse)
 *         elif root.isPortmanteau():
 */
    __pyx_t_1 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine *)__pyx_v_self->__pyx___finiteStateMachine->__pyx_vtab)->getState(__pyx_v_self->__pyx___finiteStateMachine, __pyx_n_u_NominalRootNoPossesive, 0)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 330, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 330, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_INCREF(((PyObject *)__pyx_v_root));
    __Pyx_GIVEREF(((PyObject *)__pyx_v_root));
    PyTuple_SET_ITEM(__pyx_t_4, 0, ((PyObject *)__pyx_v_root));
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_1);
    __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse), __pyx_t_4, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 330, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF_SET(__pyx_v_currentFsmParse, ((struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_t_1));
    __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":331
 *             fsmParse.append(currentFsmParse)
 *             currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("NominalRootNoPossesive"))
 *             fsmParse.append(currentFsmParse)             # <<<<<<<<<<<<<<
 *         elif root.isPortmanteau():
 *             if root.isPortmanteauFacedVowelEllipsis():
 */
    if (unlikely(__pyx_v_fsmParse == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
      __PYX_ERR(0, 331, __pyx_L1_error)
    }
    __pyx_t_9 = __Pyx_PyList_Append(__pyx_v_fsmParse, ((PyObject *)__pyx_v_currentFsmParse)); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 331, __pyx_L1_error)

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":326
 *             currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("NominalRootPlural"))
 *             fsmParse.append(currentFsmParse)
 *         elif root.isPortmanteauEndingWithSI():             # <<<<<<<<<<<<<<
 *             currentFsmParse = FsmParse(root.getName()[:len(root.getName()) - 2],
 *                                        self.__finiteStateMachine.getState("CompoundNounRoot"))
 */
    goto __pyx_L3;
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":332
 *             currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("NominalRootNoPossesive"))
 *             fsmParse.append(currentFsmParse)
 *         elif root.isPortmanteau():             # <<<<<<<<<<<<<<
 *             if root.isPortmanteauFacedVowelEllipsis():
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("NominalRootNoPossesive"))
 */
  __pyx_t_8 = (((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->isPortmanteau(__pyx_v_root, 0) != 0);
  if (__pyx_t_8) {

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":333
 *             fsmParse.append(currentFsmParse)
 *         elif root.isPortmanteau():
 *             if root.isPortmanteauFacedVowelEllipsis():             # <<<<<<<<<<<<<<
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("NominalRootNoPossesive"))
 *                 fsmParse.append(currentFsmParse)
 */
    __pyx_t_8 = (((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->isPortmanteauFacedVowelEllipsis(__pyx_v_root, 0) != 0);
    if (__pyx_t_8) {

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":334
 *         elif root.isPortmanteau():
 *             if root.isPortmanteauFacedVowelEllipsis():
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("NominalRootNoPossesive"))             # <<<<<<<<<<<<<<
 *                 fsmParse.append(currentFsmParse)
 *                 currentFsmParse = FsmParse(root.getName()[:len(root.getName()) - 2] +
 */
      __pyx_t_1 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine *)__pyx_v_self->__pyx___finiteStateMachine->__pyx_vtab)->getState(__pyx_v_self->__pyx___finiteStateMachine, __pyx_n_u_NominalRootNoPossesive, 0)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 334, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 334, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_INCREF(((PyObject *)__pyx_v_root));
      __Pyx_GIVEREF(((PyObject *)__pyx_v_root));
      PyTuple_SET_ITEM(__pyx_t_4, 0, ((PyObject *)__pyx_v_root));
      __Pyx_GIVEREF(__pyx_t_1);
      PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_1);
      __pyx_t_1 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse), __pyx_t_4, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 334, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_v_currentFsmParse = ((struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_t_1);
      __pyx_t_1 = 0;

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":335
 *             if root.isPortmanteauFacedVowelEllipsis():
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("NominalRootNoPossesive"))
 *                 fsmParse.append(currentFsmParse)             # <<<<<<<<<<<<<<
 *                 currentFsmParse = FsmParse(root.getName()[:len(root.getName()) - 2] +
 *                                            root.getName()[len(root.getName()) - 1] +
 */
      if (unlikely(__pyx_v_fsmParse == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
        __PYX_ERR(0, 335, __pyx_L1_error)
      }
      __pyx_t_9 = __Pyx_PyList_Append(__pyx_v_fsmParse, ((PyObject *)__pyx_v_currentFsmParse)); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 335, __pyx_L1_error)

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":336
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("NominalRootNoPossesive"))
 *                 fsmParse.append(currentFsmParse)
 *                 currentFsmParse = FsmParse(root.getName()[:len(root.getName()) - 2] +             # <<<<<<<<<<<<<<
 *                                            root.getName()[len(root.getName()) - 1] +
 *                                            root.getName()[len(root.getName()) - 2],
 */
      __pyx_t_1 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->__pyx_base.getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_v_root), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 336, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (unlikely(__pyx_t_1 == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        __PYX_ERR(0, 336, __pyx_L1_error)
      }
      __pyx_t_4 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->__pyx_base.getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_v_root), 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 336, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (unlikely(__pyx_t_4 == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
        __PYX_ERR(0, 336, __pyx_L1_error)
      }
      __pyx_t_10 = __Pyx_PyUnicode_GET_LENGTH(__pyx_t_4); if (unlikely(__pyx_t_10 == ((Py_ssize_t)-1))) __PYX_ERR(0, 336, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = __Pyx_PyUnicode_Substring(__pyx_t_1, 0, (__pyx_t_10 - 2)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 336, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":337
 *                 fsmParse.append(currentFsmParse)
 *                 currentFsmParse = FsmParse(root.getName()[:len(root.getName()) - 2] +
 *                                            root.getName()[len(root.getName()) - 1] +             # <<<<<<<<<<<<<<
 *                                            root.getName()[len(root.getName()) - 2],
 *                                            self.__finiteStateMachine.getState("CompoundNounRoot"))
 */
      __pyx_t_1 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->__pyx_base.getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_v_root), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 337, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_2 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->__pyx_base.getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_v_root), 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 337, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      if (unlikely(__pyx_t_2 == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
        __PYX_ERR(0, 337, __pyx_L1_error)
      }
      __pyx_t_10 = __Pyx_PyUnicode_GET_LENGTH(__pyx_t_2); if (unlikely(__pyx_t_10 == ((Py_ssize_t)-1))) __PYX_ERR(0, 337, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_11 = (__pyx_t_10 - 1);
      __pyx_t_12 = __Pyx_GetItemInt_Unicode(__pyx_t_1, __pyx_t_11, Py_ssize_t, 1, PyInt_FromSsize_t, 0, 1, 1); if (unlikely(__pyx_t_12 == (Py_UCS4)-1)) __PYX_ERR(0, 337, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = PyUnicode_FromOrdinal(__pyx_t_12); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 337, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":336
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("NominalRootNoPossesive"))
 *                 fsmParse.append(currentFsmParse)
 *                 currentFsmParse = FsmParse(root.getName()[:len(root.getName()) - 2] +             # <<<<<<<<<<<<<<
 *                                            root.getName()[len(root.getName()) - 1] +
 *                                            root.getName()[len(root.getName()) - 2],
 */
      __pyx_t_2 = __Pyx_PyUnicode_Concat(__pyx_t_4, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 336, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":338
 *                 currentFsmParse = FsmParse(root.getName()[:len(root.getName()) - 2] +
 *                                            root.getName()[len(root.getName()) - 1] +
 *                                            root.getName()[len(root.getName()) - 2],             # <<<<<<<<<<<<<<
 *                                            self.__finiteStateMachine.getState("CompoundNounRoot"))
 *             elif root.isPortmanteauFacedSoftening():
 */
      __pyx_t_1 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->__pyx_base.getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_v_root), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 338, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_4 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->__pyx_base.getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_v_root), 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 338, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (unlikely(__pyx_t_4 == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
        __PYX_ERR(0, 338, __pyx_L1_error)
      }
      __pyx_t_11 = __Pyx_PyUnicode_GET_LENGTH(__pyx_t_4); if (unlikely(__pyx_t_11 == ((Py_ssize_t)-1))) __PYX_ERR(0, 338, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_10 = (__pyx_t_11 - 2);
      __pyx_t_12 = __Pyx_GetItemInt_Unicode(__pyx_t_1, __pyx_t_10, Py_ssize_t, 1, PyInt_FromSsize_t, 0, 1, 1); if (unlikely(__pyx_t_12 == (Py_UCS4)-1)) __PYX_ERR(0, 338, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = PyUnicode_FromOrdinal(__pyx_t_12); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 338, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":337
 *                 fsmParse.append(currentFsmParse)
 *                 currentFsmParse = FsmParse(root.getName()[:len(root.getName()) - 2] +
 *                                            root.getName()[len(root.getName()) - 1] +             # <<<<<<<<<<<<<<
 *                                            root.getName()[len(root.getName()) - 2],
 *                                            self.__finiteStateMachine.getState("CompoundNounRoot"))
 */
      __pyx_t_4 = __Pyx_PyUnicode_Concat(__pyx_t_2, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 337, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":339
 *                                            root.getName()[len(root.getName()) - 1] +
 *                                            root.getName()[len(root.getName()) - 2],
 *                                            self.__finiteStateMachine.getState("CompoundNounRoot"))             # <<<<<<<<<<<<<<
 *             elif root.isPortmanteauFacedSoftening():
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("NominalRootNoPossesive"))
 */
      __pyx_t_1 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine *)__pyx_v_self->__pyx___finiteStateMachine->__pyx_vtab)->getState(__pyx_v_self->__pyx___finiteStateMachine, __pyx_n_u_CompoundNounRoot, 0)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 339, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":336
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("NominalRootNoPossesive"))
 *                 fsmParse.append(currentFsmParse)
 *                 currentFsmParse = FsmParse(root.getName()[:len(root.getName()) - 2] +             # <<<<<<<<<<<<<<
 *                                            root.getName()[len(root.getName()) - 1] +
 *                                            root.getName()[len(root.getName()) - 2],
 */
      __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 336, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_GIVEREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_1);
      PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_1);
      __pyx_t_4 = 0;
      __pyx_t_1 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse), __pyx_t_2, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 336, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF_SET(__pyx_v_currentFsmParse, ((struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_t_1));
      __pyx_t_1 = 0;

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":333
 *             fsmParse.append(currentFsmParse)
 *         elif root.isPortmanteau():
 *             if root.isPortmanteauFacedVowelEllipsis():             # <<<<<<<<<<<<<<
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("NominalRootNoPossesive"))
 *                 fsmParse.append(currentFsmParse)
 */
      goto __pyx_L4;
    }

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":340
 *                                            root.getName()[len(root.getName()) - 2],
 *                                            self.__finiteStateMachine.getState("CompoundNounRoot"))
 *             elif root.isPortmanteauFacedSoftening():             # <<<<<<<<<<<<<<
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("NominalRootNoPossesive"))
 *                 fsmParse.append(currentFsmParse)
 */
    __pyx_t_8 = (((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->isPortmanteauFacedSoftening(__pyx_v_root, 0) != 0);
    if (__pyx_t_8) {

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":341
 *                                            self.__finiteStateMachine.getState("CompoundNounRoot"))
 *             elif root.isPortmanteauFacedSoftening():
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("NominalRootNoPossesive"))             # <<<<<<<<<<<<<<
 *                 fsmParse.append(currentFsmParse)
 *                 if root.getName()[len(root.getName()) - 2] == "b":
 */
      __pyx_t_1 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine *)__pyx_v_self->__pyx___finiteStateMachine->__pyx_vtab)->getState(__pyx_v_self->__pyx___finiteStateMachine, __pyx_n_u_NominalRootNoPossesive, 0)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 341, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 341, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_INCREF(((PyObject *)__pyx_v_root));
      __Pyx_GIVEREF(((PyObject *)__pyx_v_root));
      PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_v_root));
      __Pyx_GIVEREF(__pyx_t_1);
      PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_1);
      __pyx_t_1 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse), __pyx_t_2, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 341, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_v_currentFsmParse = ((struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_t_1);
      __pyx_t_1 = 0;

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":342
 *             elif root.isPortmanteauFacedSoftening():
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("NominalRootNoPossesive"))
 *                 fsmParse.append(currentFsmParse)             # <<<<<<<<<<<<<<
 *                 if root.getName()[len(root.getName()) - 2] == "b":
 *                     currentFsmParse = FsmParse(root.getName()[:len(root.getName()) - 2] + "p",
 */
      if (unlikely(__pyx_v_fsmParse == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
        __PYX_ERR(0, 342, __pyx_L1_error)
      }
      __pyx_t_9 = __Pyx_PyList_Append(__pyx_v_fsmParse, ((PyObject *)__pyx_v_currentFsmParse)); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 342, __pyx_L1_error)

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":343
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("NominalRootNoPossesive"))
 *                 fsmParse.append(currentFsmParse)
 *                 if root.getName()[len(root.getName()) - 2] == "b":             # <<<<<<<<<<<<<<
 *                     currentFsmParse = FsmParse(root.getName()[:len(root.getName()) - 2] + "p",
 *                                                self.__finiteStateMachine.getState("CompoundNounRoot"))
 */
      __pyx_t_1 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->__pyx_base.getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_v_root), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 343, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_2 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->__pyx_base.getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_v_root), 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 343, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      if (unlikely(__pyx_t_2 == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
        __PYX_ERR(0, 343, __pyx_L1_error)
      }
      __pyx_t_10 = __Pyx_PyUnicode_GET_LENGTH(__pyx_t_2); if (unlikely(__pyx_t_10 == ((Py_ssize_t)-1))) __PYX_ERR(0, 343, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_11 = (__pyx_t_10 - 2);
      __pyx_t_12 = __Pyx_GetItemInt_Unicode(__pyx_t_1, __pyx_t_11, Py_ssize_t, 1, PyInt_FromSsize_t, 0, 1, 1); if (unlikely(__pyx_t_12 == (Py_UCS4)-1)) __PYX_ERR(0, 343, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_8 = ((__pyx_t_12 == 98) != 0);
      if (__pyx_t_8) {

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":344
 *                 fsmParse.append(currentFsmParse)
 *                 if root.getName()[len(root.getName()) - 2] == "b":
 *                     currentFsmParse = FsmParse(root.getName()[:len(root.getName()) - 2] + "p",             # <<<<<<<<<<<<<<
 *                                                self.__finiteStateMachine.getState("CompoundNounRoot"))
 *                 elif root.getName()[len(root.getName()) - 2] == "c":
 */
        __pyx_t_1 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->__pyx_base.getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_v_root), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 344, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        if (unlikely(__pyx_t_1 == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
          __PYX_ERR(0, 344, __pyx_L1_error)
        }
        __pyx_t_2 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->__pyx_base.getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_v_root), 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 344, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        if (unlikely(__pyx_t_2 == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
          __PYX_ERR(0, 344, __pyx_L1_error)
        }
        __pyx_t_11 = __Pyx_PyUnicode_GET_LENGTH(__pyx_t_2); if (unlikely(__pyx_t_11 == ((Py_ssize_t)-1))) __PYX_ERR(0, 344, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_t_2 = __Pyx_PyUnicode_Substring(__pyx_t_1, 0, (__pyx_t_11 - 2)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 344, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_1 = __Pyx_PyUnicode_Concat(__pyx_t_2, __pyx_n_u_p); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 344, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":345
 *                 if root.getName()[len(root.getName()) - 2] == "b":
 *                     currentFsmParse = FsmParse(root.getName()[:len(root.getName()) - 2] + "p",
 *                                                self.__finiteStateMachine.getState("CompoundNounRoot"))             # <<<<<<<<<<<<<<
 *                 elif root.getName()[len(root.getName()) - 2] == "c":
 *                     currentFsmParse = FsmParse(root.getName()[:len(root.getName()) - 2] + "",
 */
        __pyx_t_2 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine *)__pyx_v_self->__pyx___finiteStateMachine->__pyx_vtab)->getState(__pyx_v_self->__pyx___finiteStateMachine, __pyx_n_u_CompoundNounRoot, 0)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 345, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":344
 *                 fsmParse.append(currentFsmParse)
 *                 if root.getName()[len(root.getName()) - 2] == "b":
 *                     currentFsmParse = FsmParse(root.getName()[:len(root.getName()) - 2] + "p",             # <<<<<<<<<<<<<<
 *                                                self.__finiteStateMachine.getState("CompoundNounRoot"))
 *                 elif root.getName()[len(root.getName()) - 2] == "c":
 */
        __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 344, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_1);
        PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_1);
        __Pyx_GIVEREF(__pyx_t_2);
        PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_2);
        __pyx_t_1 = 0;
        __pyx_t_2 = 0;
        __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse), __pyx_t_4, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 344, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF_SET(__pyx_v_currentFsmParse, ((struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_t_2));
        __pyx_t_2 = 0;

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":343
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("NominalRootNoPossesive"))
 *                 fsmParse.append(currentFsmParse)
 *                 if root.getName()[len(root.getName()) - 2] == "b":             # <<<<<<<<<<<<<<
 *                     currentFsmParse = FsmParse(root.getName()[:len(root.getName()) - 2] + "p",
 *                                                self.__finiteStateMachine.getState("CompoundNounRoot"))
 */
        goto __pyx_L5;
      }

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":346
 *                     currentFsmParse = FsmParse(root.getName()[:len(root.getName()) - 2] + "p",
 *                                                self.__finiteStateMachine.getState("CompoundNounRoot"))
 *                 elif root.getName()[len(root.getName()) - 2] == "c":             # <<<<<<<<<<<<<<
 *                     currentFsmParse = FsmParse(root.getName()[:len(root.getName()) - 2] + "",
 *                                                self.__finiteStateMachine.getState("CompoundNounRoot"))
 */
      __pyx_t_2 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->__pyx_base.getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_v_root), 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 346, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_4 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->__pyx_base.getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_v_root), 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 346, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (unlikely(__pyx_t_4 == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
        __PYX_ERR(0, 346, __pyx_L1_error)
      }
      __pyx_t_11 = __Pyx_PyUnicode_GET_LENGTH(__pyx_t_4); if (unlikely(__pyx_t_11 == ((Py_ssize_t)-1))) __PYX_ERR(0, 346, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_10 = (__pyx_t_11 - 2);
      __pyx_t_12 = __Pyx_GetItemInt_Unicode(__pyx_t_2, __pyx_t_10, Py_ssize_t, 1, PyInt_FromSsize_t, 0, 1, 1); if (unlikely(__pyx_t_12 == (Py_UCS4)-1)) __PYX_ERR(0, 346, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_8 = ((__pyx_t_12 == 99) != 0);
      if (__pyx_t_8) {

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":347
 *                                                self.__finiteStateMachine.getState("CompoundNounRoot"))
 *                 elif root.getName()[len(root.getName()) - 2] == "c":
 *                     currentFsmParse = FsmParse(root.getName()[:len(root.getName()) - 2] + "",             # <<<<<<<<<<<<<<
 *                                                self.__finiteStateMachine.getState("CompoundNounRoot"))
 *                 elif root.getName()[len(root.getName()) - 2] == "d":
 */
        __pyx_t_2 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->__pyx_base.getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_v_root), 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 347, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        if (unlikely(__pyx_t_2 == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
          __PYX_ERR(0, 347, __pyx_L1_error)
        }
        __pyx_t_4 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->__pyx_base.getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_v_root), 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 347, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        if (unlikely(__pyx_t_4 == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
          __PYX_ERR(0, 347, __pyx_L1_error)
        }
        __pyx_t_10 = __Pyx_PyUnicode_GET_LENGTH(__pyx_t_4); if (unlikely(__pyx_t_10 == ((Py_ssize_t)-1))) __PYX_ERR(0, 347, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_4 = __Pyx_PyUnicode_Substring(__pyx_t_2, 0, (__pyx_t_10 - 2)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 347, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_t_2 = __Pyx_PyUnicode_Concat(__pyx_t_4, __pyx_n_u__2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 347, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":348
 *                 elif root.getName()[len(root.getName()) - 2] == "c":
 *                     currentFsmParse = FsmParse(root.getName()[:len(root.getName()) - 2] + "",
 *                                                self.__finiteStateMachine.getState("CompoundNounRoot"))             # <<<<<<<<<<<<<<
 *                 elif root.getName()[len(root.getName()) - 2] == "d":
 *                     currentFsmParse = FsmParse(root.getName()[:len(root.getName()) - 2] + "t",
 */
        __pyx_t_4 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine *)__pyx_v_self->__pyx___finiteStateMachine->__pyx_vtab)->getState(__pyx_v_self->__pyx___finiteStateMachine, __pyx_n_u_CompoundNounRoot, 0)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 348, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":347
 *                                                self.__finiteStateMachine.getState("CompoundNounRoot"))
 *                 elif root.getName()[len(root.getName()) - 2] == "c":
 *                     currentFsmParse = FsmParse(root.getName()[:len(root.getName()) - 2] + "",             # <<<<<<<<<<<<<<
 *                                                self.__finiteStateMachine.getState("CompoundNounRoot"))
 *                 elif root.getName()[len(root.getName()) - 2] == "d":
 */
        __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 347, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_GIVEREF(__pyx_t_2);
        PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_2);
        __Pyx_GIVEREF(__pyx_t_4);
        PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_4);
        __pyx_t_2 = 0;
        __pyx_t_4 = 0;
        __pyx_t_4 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse), __pyx_t_1, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 347, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF_SET(__pyx_v_currentFsmParse, ((struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_t_4));
        __pyx_t_4 = 0;

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":346
 *                     currentFsmParse = FsmParse(root.getName()[:len(root.getName()) - 2] + "p",
 *                                                self.__finiteStateMachine.getState("CompoundNounRoot"))
 *                 elif root.getName()[len(root.getName()) - 2] == "c":             # <<<<<<<<<<<<<<
 *                     currentFsmParse = FsmParse(root.getName()[:len(root.getName()) - 2] + "",
 *                                                self.__finiteStateMachine.getState("CompoundNounRoot"))
 */
        goto __pyx_L5;
      }

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":349
 *                     currentFsmParse = FsmParse(root.getName()[:len(root.getName()) - 2] + "",
 *                                                self.__finiteStateMachine.getState("CompoundNounRoot"))
 *                 elif root.getName()[len(root.getName()) - 2] == "d":             # <<<<<<<<<<<<<<
 *                     currentFsmParse = FsmParse(root.getName()[:len(root.getName()) - 2] + "t",
 *                                                self.__finiteStateMachine.getState("CompoundNounRoot"))
 */
      __pyx_t_4 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->__pyx_base.getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_v_root), 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 349, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_1 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->__pyx_base.getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_v_root), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 349, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (unlikely(__pyx_t_1 == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
        __PYX_ERR(0, 349, __pyx_L1_error)
      }
      __pyx_t_10 = __Pyx_PyUnicode_GET_LENGTH(__pyx_t_1); if (unlikely(__pyx_t_10 == ((Py_ssize_t)-1))) __PYX_ERR(0, 349, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_11 = (__pyx_t_10 - 2);
      __pyx_t_12 = __Pyx_GetItemInt_Unicode(__pyx_t_4, __pyx_t_11, Py_ssize_t, 1, PyInt_FromSsize_t, 0, 1, 1); if (unlikely(__pyx_t_12 == (Py_UCS4)-1)) __PYX_ERR(0, 349, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_8 = ((__pyx_t_12 == 0x64) != 0);
      if (__pyx_t_8) {

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":350
 *                                                self.__finiteStateMachine.getState("CompoundNounRoot"))
 *                 elif root.getName()[len(root.getName()) - 2] == "d":
 *                     currentFsmParse = FsmParse(root.getName()[:len(root.getName()) - 2] + "t",             # <<<<<<<<<<<<<<
 *                                                self.__finiteStateMachine.getState("CompoundNounRoot"))
 *                 elif root.getName()[len(root.getName()) - 2] == "":
 */
        __pyx_t_4 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->__pyx_base.getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_v_root), 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 350, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        if (unlikely(__pyx_t_4 == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
          __PYX_ERR(0, 350, __pyx_L1_error)
        }
        __pyx_t_1 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->__pyx_base.getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_v_root), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 350, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        if (unlikely(__pyx_t_1 == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
          __PYX_ERR(0, 350, __pyx_L1_error)
        }
        __pyx_t_11 = __Pyx_PyUnicode_GET_LENGTH(__pyx_t_1); if (unlikely(__pyx_t_11 == ((Py_ssize_t)-1))) __PYX_ERR(0, 350, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_1 = __Pyx_PyUnicode_Substring(__pyx_t_4, 0, (__pyx_t_11 - 2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 350, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_4 = __Pyx_PyUnicode_Concat(__pyx_t_1, __pyx_n_u_t); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 350, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":351
 *                 elif root.getName()[len(root.getName()) - 2] == "d":
 *                     currentFsmParse = FsmParse(root.getName()[:len(root.getName()) - 2] + "t",
 *                                                self.__finiteStateMachine.getState("CompoundNounRoot"))             # <<<<<<<<<<<<<<
 *                 elif root.getName()[len(root.getName()) - 2] == "":
 *                     currentFsmParse = FsmParse(root.getName()[:len(root.getName()) - 2] + "k",
 */
        __pyx_t_1 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine *)__pyx_v_self->__pyx___finiteStateMachine->__pyx_vtab)->getState(__pyx_v_self->__pyx___finiteStateMachine, __pyx_n_u_CompoundNounRoot, 0)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 351, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":350
 *                                                self.__finiteStateMachine.getState("CompoundNounRoot"))
 *                 elif root.getName()[len(root.getName()) - 2] == "d":
 *                     currentFsmParse = FsmParse(root.getName()[:len(root.getName()) - 2] + "t",             # <<<<<<<<<<<<<<
 *                                                self.__finiteStateMachine.getState("CompoundNounRoot"))
 *                 elif root.getName()[len(root.getName()) - 2] == "":
 */
        __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 350, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_GIVEREF(__pyx_t_4);
        PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_1);
        PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_1);
        __pyx_t_4 = 0;
        __pyx_t_1 = 0;
        __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse), __pyx_t_2, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 350, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF_SET(__pyx_v_currentFsmParse, ((struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_t_1));
        __pyx_t_1 = 0;

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":349
 *                     currentFsmParse = FsmParse(root.getName()[:len(root.getName()) - 2] + "",
 *                                                self.__finiteStateMachine.getState("CompoundNounRoot"))
 *                 elif root.getName()[len(root.getName()) - 2] == "d":             # <<<<<<<<<<<<<<
 *                     currentFsmParse = FsmParse(root.getName()[:len(root.getName()) - 2] + "t",
 *                                                self.__finiteStateMachine.getState("CompoundNounRoot"))
 */
        goto __pyx_L5;
      }

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":352
 *                     currentFsmParse = FsmParse(root.getName()[:len(root.getName()) - 2] + "t",
 *                                                self.__finiteStateMachine.getState("CompoundNounRoot"))
 *                 elif root.getName()[len(root.getName()) - 2] == "":             # <<<<<<<<<<<<<<
 *                     currentFsmParse = FsmParse(root.getName()[:len(root.getName()) - 2] + "k",
 *                                                self.__finiteStateMachine.getState("CompoundNounRoot"))
 */
      __pyx_t_1 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->__pyx_base.getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_v_root), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 352, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_2 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->__pyx_base.getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_v_root), 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 352, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      if (unlikely(__pyx_t_2 == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
        __PYX_ERR(0, 352, __pyx_L1_error)
      }
      __pyx_t_11 = __Pyx_PyUnicode_GET_LENGTH(__pyx_t_2); if (unlikely(__pyx_t_11 == ((Py_ssize_t)-1))) __PYX_ERR(0, 352, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_10 = (__pyx_t_11 - 2);
      __pyx_t_12 = __Pyx_GetItemInt_Unicode(__pyx_t_1, __pyx_t_10, Py_ssize_t, 1, PyInt_FromSsize_t, 0, 1, 1); if (unlikely(__pyx_t_12 == (Py_UCS4)-1)) __PYX_ERR(0, 352, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_8 = ((__pyx_t_12 == 0x11F) != 0);
      if (__pyx_t_8) {

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":353
 *                                                self.__finiteStateMachine.getState("CompoundNounRoot"))
 *                 elif root.getName()[len(root.getName()) - 2] == "":
 *                     currentFsmParse = FsmParse(root.getName()[:len(root.getName()) - 2] + "k",             # <<<<<<<<<<<<<<
 *                                                self.__finiteStateMachine.getState("CompoundNounRoot"))
 *                 else:
 */
        __pyx_t_1 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->__pyx_base.getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_v_root), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 353, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        if (unlikely(__pyx_t_1 == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
          __PYX_ERR(0, 353, __pyx_L1_error)
        }
        __pyx_t_2 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->__pyx_base.getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_v_root), 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 353, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        if (unlikely(__pyx_t_2 == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
          __PYX_ERR(0, 353, __pyx_L1_error)
        }
        __pyx_t_10 = __Pyx_PyUnicode_GET_LENGTH(__pyx_t_2); if (unlikely(__pyx_t_10 == ((Py_ssize_t)-1))) __PYX_ERR(0, 353, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_t_2 = __Pyx_PyUnicode_Substring(__pyx_t_1, 0, (__pyx_t_10 - 2)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 353, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_1 = __Pyx_PyUnicode_Concat(__pyx_t_2, __pyx_n_u_k); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 353, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":354
 *                 elif root.getName()[len(root.getName()) - 2] == "":
 *                     currentFsmParse = FsmParse(root.getName()[:len(root.getName()) - 2] + "k",
 *                                                self.__finiteStateMachine.getState("CompoundNounRoot"))             # <<<<<<<<<<<<<<
 *                 else:
 *                     currentFsmParse = FsmParse(root.getName()[:len(root.getName()) - 1],
 */
        __pyx_t_2 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine *)__pyx_v_self->__pyx___finiteStateMachine->__pyx_vtab)->getState(__pyx_v_self->__pyx___finiteStateMachine, __pyx_n_u_CompoundNounRoot, 0)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 354, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":353
 *                                                self.__finiteStateMachine.getState("CompoundNounRoot"))
 *                 elif root.getName()[len(root.getName()) - 2] == "":
 *                     currentFsmParse = FsmParse(root.getName()[:len(root.getName()) - 2] + "k",             # <<<<<<<<<<<<<<
 *                                                self.__finiteStateMachine.getState("CompoundNounRoot"))
 *                 else:
 */
        __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 353, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_1);
        PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_1);
        __Pyx_GIVEREF(__pyx_t_2);
        PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_2);
        __pyx_t_1 = 0;
        __pyx_t_2 = 0;
        __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse), __pyx_t_4, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 353, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF_SET(__pyx_v_currentFsmParse, ((struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_t_2));
        __pyx_t_2 = 0;

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":352
 *                     currentFsmParse = FsmParse(root.getName()[:len(root.getName()) - 2] + "t",
 *                                                self.__finiteStateMachine.getState("CompoundNounRoot"))
 *                 elif root.getName()[len(root.getName()) - 2] == "":             # <<<<<<<<<<<<<<
 *                     currentFsmParse = FsmParse(root.getName()[:len(root.getName()) - 2] + "k",
 *                                                self.__finiteStateMachine.getState("CompoundNounRoot"))
 */
        goto __pyx_L5;
      }

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":356
 *                                                self.__finiteStateMachine.getState("CompoundNounRoot"))
 *                 else:
 *                     currentFsmParse = FsmParse(root.getName()[:len(root.getName()) - 1],             # <<<<<<<<<<<<<<
 *                                                self.__finiteStateMachine.getState("CompoundNounRoot"))
 *             else:
 */
      /*else*/ {
        __pyx_t_2 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->__pyx_base.getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_v_root), 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 356, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        if (unlikely(__pyx_t_2 == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
          __PYX_ERR(0, 356, __pyx_L1_error)
        }
        __pyx_t_4 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->__pyx_base.getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_v_root), 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 356, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        if (unlikely(__pyx_t_4 == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
          __PYX_ERR(0, 356, __pyx_L1_error)
        }
        __pyx_t_10 = __Pyx_PyUnicode_GET_LENGTH(__pyx_t_4); if (unlikely(__pyx_t_10 == ((Py_ssize_t)-1))) __PYX_ERR(0, 356, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_4 = __Pyx_PyUnicode_Substring(__pyx_t_2, 0, (__pyx_t_10 - 1)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 356, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":357
 *                 else:
 *                     currentFsmParse = FsmParse(root.getName()[:len(root.getName()) - 1],
 *                                                self.__finiteStateMachine.getState("CompoundNounRoot"))             # <<<<<<<<<<<<<<
 *             else:
 *                 currentFsmParse = FsmParse(root.getName()[:len(root.getName()) - 1],
 */
        __pyx_t_2 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine *)__pyx_v_self->__pyx___finiteStateMachine->__pyx_vtab)->getState(__pyx_v_self->__pyx___finiteStateMachine, __pyx_n_u_CompoundNounRoot, 0)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 357, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":356
 *                                                self.__finiteStateMachine.getState("CompoundNounRoot"))
 *                 else:
 *                     currentFsmParse = FsmParse(root.getName()[:len(root.getName()) - 1],             # <<<<<<<<<<<<<<
 *                                                self.__finiteStateMachine.getState("CompoundNounRoot"))
 *             else:
 */
        __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 356, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_GIVEREF(__pyx_t_4);
        PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_2);
        PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_2);
        __pyx_t_4 = 0;
        __pyx_t_2 = 0;
        __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse), __pyx_t_1, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 356, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF_SET(__pyx_v_currentFsmParse, ((struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_t_2));
        __pyx_t_2 = 0;
      }
      __pyx_L5:;

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":340
 *                                            root.getName()[len(root.getName()) - 2],
 *                                            self.__finiteStateMachine.getState("CompoundNounRoot"))
 *             elif root.isPortmanteauFacedSoftening():             # <<<<<<<<<<<<<<
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("NominalRootNoPossesive"))
 *                 fsmParse.append(currentFsmParse)
 */
      goto __pyx_L4;
    }

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":359
 *                                                self.__finiteStateMachine.getState("CompoundNounRoot"))
 *             else:
 *                 currentFsmParse = FsmParse(root.getName()[:len(root.getName()) - 1],             # <<<<<<<<<<<<<<
 *                                            self.__finiteStateMachine.getState("CompoundNounRoot"))
 *             fsmParse.append(currentFsmParse)
 */
    /*else*/ {
      __pyx_t_2 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->__pyx_base.getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_v_root), 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 359, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      if (unlikely(__pyx_t_2 == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        __PYX_ERR(0, 359, __pyx_L1_error)
      }
      __pyx_t_1 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->__pyx_base.getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_v_root), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 359, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (unlikely(__pyx_t_1 == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
        __PYX_ERR(0, 359, __pyx_L1_error)
      }
      __pyx_t_10 = __Pyx_PyUnicode_GET_LENGTH(__pyx_t_1); if (unlikely(__pyx_t_10 == ((Py_ssize_t)-1))) __PYX_ERR(0, 359, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = __Pyx_PyUnicode_Substring(__pyx_t_2, 0, (__pyx_t_10 - 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 359, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":360
 *             else:
 *                 currentFsmParse = FsmParse(root.getName()[:len(root.getName()) - 1],
 *                                            self.__finiteStateMachine.getState("CompoundNounRoot"))             # <<<<<<<<<<<<<<
 *             fsmParse.append(currentFsmParse)
 *         else:
 */
      __pyx_t_2 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine *)__pyx_v_self->__pyx___finiteStateMachine->__pyx_vtab)->getState(__pyx_v_self->__pyx___finiteStateMachine, __pyx_n_u_CompoundNounRoot, 0)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 360, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":359
 *                                                self.__finiteStateMachine.getState("CompoundNounRoot"))
 *             else:
 *                 currentFsmParse = FsmParse(root.getName()[:len(root.getName()) - 1],             # <<<<<<<<<<<<<<
 *                                            self.__finiteStateMachine.getState("CompoundNounRoot"))
 *             fsmParse.append(currentFsmParse)
 */
      __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 359, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_1);
      PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_1);
      __Pyx_GIVEREF(__pyx_t_2);
      PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_2);
      __pyx_t_1 = 0;
      __pyx_t_2 = 0;
      __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse), __pyx_t_4, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 359, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_v_currentFsmParse = ((struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_t_2);
      __pyx_t_2 = 0;
    }
    __pyx_L4:;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":361
 *                 currentFsmParse = FsmParse(root.getName()[:len(root.getName()) - 1],
 *                                            self.__finiteStateMachine.getState("CompoundNounRoot"))
 *             fsmParse.append(currentFsmParse)             # <<<<<<<<<<<<<<
 *         else:
 *             if root.isHeader():
 */
    if (unlikely(__pyx_v_fsmParse == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
      __PYX_ERR(0, 361, __pyx_L1_error)
    }
    __pyx_t_9 = __Pyx_PyList_Append(__pyx_v_fsmParse, ((PyObject *)__pyx_v_currentFsmParse)); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 361, __pyx_L1_error)

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":332
 *             currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("NominalRootNoPossesive"))
 *             fsmParse.append(currentFsmParse)
 *         elif root.isPortmanteau():             # <<<<<<<<<<<<<<
 *             if root.isPortmanteauFacedVowelEllipsis():
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("NominalRootNoPossesive"))
 */
    goto __pyx_L3;
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":363
 *             fsmParse.append(currentFsmParse)
 *         else:
 *             if root.isHeader():             # <<<<<<<<<<<<<<
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("HeaderRoot"))
 *                 fsmParse.append(currentFsmParse)
 */
  /*else*/ {
    __pyx_t_8 = (((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->isHeader(__pyx_v_root, 0) != 0);
    if (__pyx_t_8) {

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":364
 *         else:
 *             if root.isHeader():
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("HeaderRoot"))             # <<<<<<<<<<<<<<
 *                 fsmParse.append(currentFsmParse)
 *             if root.isInterjection():
 */
      __pyx_t_2 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine *)__pyx_v_self->__pyx___finiteStateMachine->__pyx_vtab)->getState(__pyx_v_self->__pyx___finiteStateMachine, __pyx_n_u_HeaderRoot, 0)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 364, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 364, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_INCREF(((PyObject *)__pyx_v_root));
      __Pyx_GIVEREF(((PyObject *)__pyx_v_root));
      PyTuple_SET_ITEM(__pyx_t_4, 0, ((PyObject *)__pyx_v_root));
      __Pyx_GIVEREF(__pyx_t_2);
      PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_2);
      __pyx_t_2 = 0;
      __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse), __pyx_t_4, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 364, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_v_currentFsmParse = ((struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_t_2);
      __pyx_t_2 = 0;

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":365
 *             if root.isHeader():
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("HeaderRoot"))
 *                 fsmParse.append(currentFsmParse)             # <<<<<<<<<<<<<<
 *             if root.isInterjection():
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("InterjectionRoot"))
 */
      if (unlikely(__pyx_v_fsmParse == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
        __PYX_ERR(0, 365, __pyx_L1_error)
      }
      __pyx_t_9 = __Pyx_PyList_Append(__pyx_v_fsmParse, ((PyObject *)__pyx_v_currentFsmParse)); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 365, __pyx_L1_error)

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":363
 *             fsmParse.append(currentFsmParse)
 *         else:
 *             if root.isHeader():             # <<<<<<<<<<<<<<
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("HeaderRoot"))
 *                 fsmParse.append(currentFsmParse)
 */
    }

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":366
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("HeaderRoot"))
 *                 fsmParse.append(currentFsmParse)
 *             if root.isInterjection():             # <<<<<<<<<<<<<<
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("InterjectionRoot"))
 *                 fsmParse.append(currentFsmParse)
 */
    __pyx_t_8 = (((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->isInterjection(__pyx_v_root, 0) != 0);
    if (__pyx_t_8) {

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":367
 *                 fsmParse.append(currentFsmParse)
 *             if root.isInterjection():
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("InterjectionRoot"))             # <<<<<<<<<<<<<<
 *                 fsmParse.append(currentFsmParse)
 *             if root.isDuplicate():
 */
      __pyx_t_2 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine *)__pyx_v_self->__pyx___finiteStateMachine->__pyx_vtab)->getState(__pyx_v_self->__pyx___finiteStateMachine, __pyx_n_u_InterjectionRoot, 0)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 367, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 367, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_INCREF(((PyObject *)__pyx_v_root));
      __Pyx_GIVEREF(((PyObject *)__pyx_v_root));
      PyTuple_SET_ITEM(__pyx_t_4, 0, ((PyObject *)__pyx_v_root));
      __Pyx_GIVEREF(__pyx_t_2);
      PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_2);
      __pyx_t_2 = 0;
      __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse), __pyx_t_4, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 367, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF_SET(__pyx_v_currentFsmParse, ((struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_t_2));
      __pyx_t_2 = 0;

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":368
 *             if root.isInterjection():
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("InterjectionRoot"))
 *                 fsmParse.append(currentFsmParse)             # <<<<<<<<<<<<<<
 *             if root.isDuplicate():
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("DuplicateRoot"))
 */
      if (unlikely(__pyx_v_fsmParse == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
        __PYX_ERR(0, 368, __pyx_L1_error)
      }
      __pyx_t_9 = __Pyx_PyList_Append(__pyx_v_fsmParse, ((PyObject *)__pyx_v_currentFsmParse)); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 368, __pyx_L1_error)

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":366
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("HeaderRoot"))
 *                 fsmParse.append(currentFsmParse)
 *             if root.isInterjection():             # <<<<<<<<<<<<<<
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("InterjectionRoot"))
 *                 fsmParse.append(currentFsmParse)
 */
    }

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":369
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("InterjectionRoot"))
 *                 fsmParse.append(currentFsmParse)
 *             if root.isDuplicate():             # <<<<<<<<<<<<<<
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("DuplicateRoot"))
 *                 fsmParse.append(currentFsmParse)
 */
    __pyx_t_8 = (((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->isDuplicate(__pyx_v_root, 0) != 0);
    if (__pyx_t_8) {

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":370
 *                 fsmParse.append(currentFsmParse)
 *             if root.isDuplicate():
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("DuplicateRoot"))             # <<<<<<<<<<<<<<
 *                 fsmParse.append(currentFsmParse)
 *             if root.isNumeral():
 */
      __pyx_t_2 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine *)__pyx_v_self->__pyx___finiteStateMachine->__pyx_vtab)->getState(__pyx_v_self->__pyx___finiteStateMachine, __pyx_n_u_DuplicateRoot, 0)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 370, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 370, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_INCREF(((PyObject *)__pyx_v_root));
      __Pyx_GIVEREF(((PyObject *)__pyx_v_root));
      PyTuple_SET_ITEM(__pyx_t_4, 0, ((PyObject *)__pyx_v_root));
      __Pyx_GIVEREF(__pyx_t_2);
      PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_2);
      __pyx_t_2 = 0;
      __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse), __pyx_t_4, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 370, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF_SET(__pyx_v_currentFsmParse, ((struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_t_2));
      __pyx_t_2 = 0;

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":371
 *             if root.isDuplicate():
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("DuplicateRoot"))
 *                 fsmParse.append(currentFsmParse)             # <<<<<<<<<<<<<<
 *             if root.isNumeral():
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("CardinalRoot"))
 */
      if (unlikely(__pyx_v_fsmParse == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
        __PYX_ERR(0, 371, __pyx_L1_error)
      }
      __pyx_t_9 = __Pyx_PyList_Append(__pyx_v_fsmParse, ((PyObject *)__pyx_v_currentFsmParse)); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 371, __pyx_L1_error)

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":369
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("InterjectionRoot"))
 *                 fsmParse.append(currentFsmParse)
 *             if root.isDuplicate():             # <<<<<<<<<<<<<<
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("DuplicateRoot"))
 *                 fsmParse.append(currentFsmParse)
 */
    }

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":372
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("DuplicateRoot"))
 *                 fsmParse.append(currentFsmParse)
 *             if root.isNumeral():             # <<<<<<<<<<<<<<
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("CardinalRoot"))
 *                 fsmParse.append(currentFsmParse)
 */
    __pyx_t_8 = (((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->isNumeral(__pyx_v_root, 0) != 0);
    if (__pyx_t_8) {

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":373
 *                 fsmParse.append(currentFsmParse)
 *             if root.isNumeral():
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("CardinalRoot"))             # <<<<<<<<<<<<<<
 *                 fsmParse.append(currentFsmParse)
 *             if root.isReal():
 */
      __pyx_t_2 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine *)__pyx_v_self->__pyx___finiteStateMachine->__pyx_vtab)->getState(__pyx_v_self->__pyx___finiteStateMachine, __pyx_n_u_CardinalRoot, 0)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 373, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 373, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_INCREF(((PyObject *)__pyx_v_root));
      __Pyx_GIVEREF(((PyObject *)__pyx_v_root));
      PyTuple_SET_ITEM(__pyx_t_4, 0, ((PyObject *)__pyx_v_root));
      __Pyx_GIVEREF(__pyx_t_2);
      PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_2);
      __pyx_t_2 = 0;
      __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse), __pyx_t_4, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 373, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF_SET(__pyx_v_currentFsmParse, ((struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_t_2));
      __pyx_t_2 = 0;

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":374
 *             if root.isNumeral():
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("CardinalRoot"))
 *                 fsmParse.append(currentFsmParse)             # <<<<<<<<<<<<<<
 *             if root.isReal():
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("RealRoot"))
 */
      if (unlikely(__pyx_v_fsmParse == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
        __PYX_ERR(0, 374, __pyx_L1_error)
      }
      __pyx_t_9 = __Pyx_PyList_Append(__pyx_v_fsmParse, ((PyObject *)__pyx_v_currentFsmParse)); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 374, __pyx_L1_error)

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":372
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("DuplicateRoot"))
 *                 fsmParse.append(currentFsmParse)
 *             if root.isNumeral():             # <<<<<<<<<<<<<<
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("CardinalRoot"))
 *                 fsmParse.append(currentFsmParse)
 */
    }

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":375
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("CardinalRoot"))
 *                 fsmParse.append(currentFsmParse)
 *             if root.isReal():             # <<<<<<<<<<<<<<
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("RealRoot"))
 *                 fsmParse.append(currentFsmParse)
 */
    __pyx_t_8 = (((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->isReal(__pyx_v_root, 0) != 0);
    if (__pyx_t_8) {

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":376
 *                 fsmParse.append(currentFsmParse)
 *             if root.isReal():
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("RealRoot"))             # <<<<<<<<<<<<<<
 *                 fsmParse.append(currentFsmParse)
 *             if root.isFraction():
 */
      __pyx_t_2 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine *)__pyx_v_self->__pyx___finiteStateMachine->__pyx_vtab)->getState(__pyx_v_self->__pyx___finiteStateMachine, __pyx_n_u_RealRoot, 0)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 376, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 376, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_INCREF(((PyObject *)__pyx_v_root));
      __Pyx_GIVEREF(((PyObject *)__pyx_v_root));
      PyTuple_SET_ITEM(__pyx_t_4, 0, ((PyObject *)__pyx_v_root));
      __Pyx_GIVEREF(__pyx_t_2);
      PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_2);
      __pyx_t_2 = 0;
      __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse), __pyx_t_4, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 376, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF_SET(__pyx_v_currentFsmParse, ((struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_t_2));
      __pyx_t_2 = 0;

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":377
 *             if root.isReal():
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("RealRoot"))
 *                 fsmParse.append(currentFsmParse)             # <<<<<<<<<<<<<<
 *             if root.isFraction():
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("FractionRoot"))
 */
      if (unlikely(__pyx_v_fsmParse == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
        __PYX_ERR(0, 377, __pyx_L1_error)
      }
      __pyx_t_9 = __Pyx_PyList_Append(__pyx_v_fsmParse, ((PyObject *)__pyx_v_currentFsmParse)); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 377, __pyx_L1_error)

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":375
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("CardinalRoot"))
 *                 fsmParse.append(currentFsmParse)
 *             if root.isReal():             # <<<<<<<<<<<<<<
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("RealRoot"))
 *                 fsmParse.append(currentFsmParse)
 */
    }

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":378
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("RealRoot"))
 *                 fsmParse.append(currentFsmParse)
 *             if root.isFraction():             # <<<<<<<<<<<<<<
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("FractionRoot"))
 *                 fsmParse.append(currentFsmParse)
 */
    __pyx_t_8 = (((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->isFraction(__pyx_v_root, 0) != 0);
    if (__pyx_t_8) {

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":379
 *                 fsmParse.append(currentFsmParse)
 *             if root.isFraction():
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("FractionRoot"))             # <<<<<<<<<<<<<<
 *                 fsmParse.append(currentFsmParse)
 *             if root.isDate():
 */
      __pyx_t_2 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine *)__pyx_v_self->__pyx___finiteStateMachine->__pyx_vtab)->getState(__pyx_v_self->__pyx___finiteStateMachine, __pyx_n_u_FractionRoot, 0)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 379, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 379, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_INCREF(((PyObject *)__pyx_v_root));
      __Pyx_GIVEREF(((PyObject *)__pyx_v_root));
      PyTuple_SET_ITEM(__pyx_t_4, 0, ((PyObject *)__pyx_v_root));
      __Pyx_GIVEREF(__pyx_t_2);
      PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_2);
      __pyx_t_2 = 0;
      __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse), __pyx_t_4, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 379, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF_SET(__pyx_v_currentFsmParse, ((struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_t_2));
      __pyx_t_2 = 0;

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":380
 *             if root.isFraction():
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("FractionRoot"))
 *                 fsmParse.append(currentFsmParse)             # <<<<<<<<<<<<<<
 *             if root.isDate():
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("DateRoot"))
 */
      if (unlikely(__pyx_v_fsmParse == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
        __PYX_ERR(0, 380, __pyx_L1_error)
      }
      __pyx_t_9 = __Pyx_PyList_Append(__pyx_v_fsmParse, ((PyObject *)__pyx_v_currentFsmParse)); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 380, __pyx_L1_error)

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":378
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("RealRoot"))
 *                 fsmParse.append(currentFsmParse)
 *             if root.isFraction():             # <<<<<<<<<<<<<<
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("FractionRoot"))
 *                 fsmParse.append(currentFsmParse)
 */
    }

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":381
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("FractionRoot"))
 *                 fsmParse.append(currentFsmParse)
 *             if root.isDate():             # <<<<<<<<<<<<<<
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("DateRoot"))
 *                 fsmParse.append(currentFsmParse)
 */
    __pyx_t_8 = (((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->isDate(__pyx_v_root, 0) != 0);
    if (__pyx_t_8) {

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":382
 *                 fsmParse.append(currentFsmParse)
 *             if root.isDate():
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("DateRoot"))             # <<<<<<<<<<<<<<
 *                 fsmParse.append(currentFsmParse)
 *             if root.isPercent():
 */
      __pyx_t_2 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine *)__pyx_v_self->__pyx___finiteStateMachine->__pyx_vtab)->getState(__pyx_v_self->__pyx___finiteStateMachine, __pyx_n_u_DateRoot, 0)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 382, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 382, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_INCREF(((PyObject *)__pyx_v_root));
      __Pyx_GIVEREF(((PyObject *)__pyx_v_root));
      PyTuple_SET_ITEM(__pyx_t_4, 0, ((PyObject *)__pyx_v_root));
      __Pyx_GIVEREF(__pyx_t_2);
      PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_2);
      __pyx_t_2 = 0;
      __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse), __pyx_t_4, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 382, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF_SET(__pyx_v_currentFsmParse, ((struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_t_2));
      __pyx_t_2 = 0;

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":383
 *             if root.isDate():
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("DateRoot"))
 *                 fsmParse.append(currentFsmParse)             # <<<<<<<<<<<<<<
 *             if root.isPercent():
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("PercentRoot"))
 */
      if (unlikely(__pyx_v_fsmParse == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
        __PYX_ERR(0, 383, __pyx_L1_error)
      }
      __pyx_t_9 = __Pyx_PyList_Append(__pyx_v_fsmParse, ((PyObject *)__pyx_v_currentFsmParse)); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 383, __pyx_L1_error)

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":381
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("FractionRoot"))
 *                 fsmParse.append(currentFsmParse)
 *             if root.isDate():             # <<<<<<<<<<<<<<
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("DateRoot"))
 *                 fsmParse.append(currentFsmParse)
 */
    }

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":384
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("DateRoot"))
 *                 fsmParse.append(currentFsmParse)
 *             if root.isPercent():             # <<<<<<<<<<<<<<
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("PercentRoot"))
 *                 fsmParse.append(currentFsmParse)
 */
    __pyx_t_8 = (((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->isPercent(__pyx_v_root, 0) != 0);
    if (__pyx_t_8) {

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":385
 *                 fsmParse.append(currentFsmParse)
 *             if root.isPercent():
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("PercentRoot"))             # <<<<<<<<<<<<<<
 *                 fsmParse.append(currentFsmParse)
 *             if root.isRange():
 */
      __pyx_t_2 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine *)__pyx_v_self->__pyx___finiteStateMachine->__pyx_vtab)->getState(__pyx_v_self->__pyx___finiteStateMachine, __pyx_n_u_PercentRoot, 0)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 385, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 385, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_INCREF(((PyObject *)__pyx_v_root));
      __Pyx_GIVEREF(((PyObject *)__pyx_v_root));
      PyTuple_SET_ITEM(__pyx_t_4, 0, ((PyObject *)__pyx_v_root));
      __Pyx_GIVEREF(__pyx_t_2);
      PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_2);
      __pyx_t_2 = 0;
      __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse), __pyx_t_4, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 385, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF_SET(__pyx_v_currentFsmParse, ((struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_t_2));
      __pyx_t_2 = 0;

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":386
 *             if root.isPercent():
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("PercentRoot"))
 *                 fsmParse.append(currentFsmParse)             # <<<<<<<<<<<<<<
 *             if root.isRange():
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("RangeRoot"))
 */
      if (unlikely(__pyx_v_fsmParse == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
        __PYX_ERR(0, 386, __pyx_L1_error)
      }
      __pyx_t_9 = __Pyx_PyList_Append(__pyx_v_fsmParse, ((PyObject *)__pyx_v_currentFsmParse)); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 386, __pyx_L1_error)

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":384
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("DateRoot"))
 *                 fsmParse.append(currentFsmParse)
 *             if root.isPercent():             # <<<<<<<<<<<<<<
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("PercentRoot"))
 *                 fsmParse.append(currentFsmParse)
 */
    }

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":387
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("PercentRoot"))
 *                 fsmParse.append(currentFsmParse)
 *             if root.isRange():             # <<<<<<<<<<<<<<
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("RangeRoot"))
 *                 fsmParse.append(currentFsmParse)
 */
    __pyx_t_8 = (((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->isRange(__pyx_v_root, 0) != 0);
    if (__pyx_t_8) {

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":388
 *                 fsmParse.append(currentFsmParse)
 *             if root.isRange():
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("RangeRoot"))             # <<<<<<<<<<<<<<
 *                 fsmParse.append(currentFsmParse)
 *             if root.isTime():
 */
      __pyx_t_2 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine *)__pyx_v_self->__pyx___finiteStateMachine->__pyx_vtab)->getState(__pyx_v_self->__pyx___finiteStateMachine, __pyx_n_u_RangeRoot, 0)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 388, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 388, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_INCREF(((PyObject *)__pyx_v_root));
      __Pyx_GIVEREF(((PyObject *)__pyx_v_root));
      PyTuple_SET_ITEM(__pyx_t_4, 0, ((PyObject *)__pyx_v_root));
      __Pyx_GIVEREF(__pyx_t_2);
      PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_2);
      __pyx_t_2 = 0;
      __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse), __pyx_t_4, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 388, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF_SET(__pyx_v_currentFsmParse, ((struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_t_2));
      __pyx_t_2 = 0;

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":389
 *             if root.isRange():
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("RangeRoot"))
 *                 fsmParse.append(currentFsmParse)             # <<<<<<<<<<<<<<
 *             if root.isTime():
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("TimeRoot"))
 */
      if (unlikely(__pyx_v_fsmParse == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
        __PYX_ERR(0, 389, __pyx_L1_error)
      }
      __pyx_t_9 = __Pyx_PyList_Append(__pyx_v_fsmParse, ((PyObject *)__pyx_v_currentFsmParse)); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 389, __pyx_L1_error)

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":387
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("PercentRoot"))
 *                 fsmParse.append(currentFsmParse)
 *             if root.isRange():             # <<<<<<<<<<<<<<
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("RangeRoot"))
 *                 fsmParse.append(currentFsmParse)
 */
    }

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":390
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("RangeRoot"))
 *                 fsmParse.append(currentFsmParse)
 *             if root.isTime():             # <<<<<<<<<<<<<<
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("TimeRoot"))
 *                 fsmParse.append(currentFsmParse)
 */
    __pyx_t_8 = (((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->isTime(__pyx_v_root, 0) != 0);
    if (__pyx_t_8) {

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":391
 *                 fsmParse.append(currentFsmParse)
 *             if root.isTime():
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("TimeRoot"))             # <<<<<<<<<<<<<<
 *                 fsmParse.append(currentFsmParse)
 *             if root.isOrdinal():
 */
      __pyx_t_2 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine *)__pyx_v_self->__pyx___finiteStateMachine->__pyx_vtab)->getState(__pyx_v_self->__pyx___finiteStateMachine, __pyx_n_u_TimeRoot, 0)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 391, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 391, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_INCREF(((PyObject *)__pyx_v_root));
      __Pyx_GIVEREF(((PyObject *)__pyx_v_root));
      PyTuple_SET_ITEM(__pyx_t_4, 0, ((PyObject *)__pyx_v_root));
      __Pyx_GIVEREF(__pyx_t_2);
      PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_2);
      __pyx_t_2 = 0;
      __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse), __pyx_t_4, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 391, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF_SET(__pyx_v_currentFsmParse, ((struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_t_2));
      __pyx_t_2 = 0;

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":392
 *             if root.isTime():
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("TimeRoot"))
 *                 fsmParse.append(currentFsmParse)             # <<<<<<<<<<<<<<
 *             if root.isOrdinal():
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("OrdinalRoot"))
 */
      if (unlikely(__pyx_v_fsmParse == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
        __PYX_ERR(0, 392, __pyx_L1_error)
      }
      __pyx_t_9 = __Pyx_PyList_Append(__pyx_v_fsmParse, ((PyObject *)__pyx_v_currentFsmParse)); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 392, __pyx_L1_error)

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":390
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("RangeRoot"))
 *                 fsmParse.append(currentFsmParse)
 *             if root.isTime():             # <<<<<<<<<<<<<<
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("TimeRoot"))
 *                 fsmParse.append(currentFsmParse)
 */
    }

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":393
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("TimeRoot"))
 *                 fsmParse.append(currentFsmParse)
 *             if root.isOrdinal():             # <<<<<<<<<<<<<<
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("OrdinalRoot"))
 *                 fsmParse.append(currentFsmParse)
 */
    __pyx_t_8 = (((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->isOrdinal(__pyx_v_root, 0) != 0);
    if (__pyx_t_8) {

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":394
 *                 fsmParse.append(currentFsmParse)
 *             if root.isOrdinal():
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("OrdinalRoot"))             # <<<<<<<<<<<<<<
 *                 fsmParse.append(currentFsmParse)
 *             if root.isVerb() or root.isPassive():
 */
      __pyx_t_2 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine *)__pyx_v_self->__pyx___finiteStateMachine->__pyx_vtab)->getState(__pyx_v_self->__pyx___finiteStateMachine, __pyx_n_u_OrdinalRoot, 0)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 394, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 394, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_INCREF(((PyObject *)__pyx_v_root));
      __Pyx_GIVEREF(((PyObject *)__pyx_v_root));
      PyTuple_SET_ITEM(__pyx_t_4, 0, ((PyObject *)__pyx_v_root));
      __Pyx_GIVEREF(__pyx_t_2);
      PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_2);
      __pyx_t_2 = 0;
      __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse), __pyx_t_4, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 394, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF_SET(__pyx_v_currentFsmParse, ((struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_t_2));
      __pyx_t_2 = 0;

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":395
 *             if root.isOrdinal():
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("OrdinalRoot"))
 *                 fsmParse.append(currentFsmParse)             # <<<<<<<<<<<<<<
 *             if root.isVerb() or root.isPassive():
 *                 if root.verbType() != "":
 */
      if (unlikely(__pyx_v_fsmParse == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
        __PYX_ERR(0, 395, __pyx_L1_error)
      }
      __pyx_t_9 = __Pyx_PyList_Append(__pyx_v_fsmParse, ((PyObject *)__pyx_v_currentFsmParse)); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 395, __pyx_L1_error)

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":393
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("TimeRoot"))
 *                 fsmParse.append(currentFsmParse)
 *             if root.isOrdinal():             # <<<<<<<<<<<<<<
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("OrdinalRoot"))
 *                 fsmParse.append(currentFsmParse)
 */
    }

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":396
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("OrdinalRoot"))
 *                 fsmParse.append(currentFsmParse)
 *             if root.isVerb() or root.isPassive():             # <<<<<<<<<<<<<<
 *                 if root.verbType() != "":
 *                     currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("VerbalRoot("
 */
    __pyx_t_13 = (((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->isVerb(__pyx_v_root, 0) != 0);
    if (!__pyx_t_13) {
    } else {
      __pyx_t_8 = __pyx_t_13;
      goto __pyx_L18_bool_binop_done;
    }
    __pyx_t_13 = (((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->isPassive(__pyx_v_root, 0) != 0);
    __pyx_t_8 = __pyx_t_13;
    __pyx_L18_bool_binop_done:;
    if (__pyx_t_8) {

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":397
 *                 fsmParse.append(currentFsmParse)
 *             if root.isVerb() or root.isPassive():
 *                 if root.verbType() != "":             # <<<<<<<<<<<<<<
 *                     currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("VerbalRoot("
 *                                                                                         + root.verbType() + ")"))
 */
      __pyx_t_2 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->verbType(__pyx_v_root, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 397, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_8 = (__Pyx_PyUnicode_Equals(__pyx_t_2, __pyx_kp_u__3, Py_NE)); if (unlikely(__pyx_t_8 < 0)) __PYX_ERR(0, 397, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_13 = (__pyx_t_8 != 0);
      if (__pyx_t_13) {

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":399
 *                 if root.verbType() != "":
 *                     currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("VerbalRoot("
 *                                                                                         + root.verbType() + ")"))             # <<<<<<<<<<<<<<
 *                 elif not root.isPassive():
 *                     currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("VerbalRoot"))
 */
        __pyx_t_2 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->verbType(__pyx_v_root, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 399, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_4 = __Pyx_PyUnicode_ConcatSafe(__pyx_kp_u_VerbalRoot, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 399, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_t_2 = __Pyx_PyUnicode_Concat(__pyx_t_4, __pyx_kp_u__4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 399, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":398
 *             if root.isVerb() or root.isPassive():
 *                 if root.verbType() != "":
 *                     currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("VerbalRoot("             # <<<<<<<<<<<<<<
 *                                                                                         + root.verbType() + ")"))
 *                 elif not root.isPassive():
 */
        __pyx_t_4 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine *)__pyx_v_self->__pyx___finiteStateMachine->__pyx_vtab)->getState(__pyx_v_self->__pyx___finiteStateMachine, ((PyObject*)__pyx_t_2), 0)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 398, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 398, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_INCREF(((PyObject *)__pyx_v_root));
        __Pyx_GIVEREF(((PyObject *)__pyx_v_root));
        PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_v_root));
        __Pyx_GIVEREF(__pyx_t_4);
        PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_4);
        __pyx_t_4 = 0;
        __pyx_t_4 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse), __pyx_t_2, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 398, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_XDECREF_SET(__pyx_v_currentFsmParse, ((struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_t_4));
        __pyx_t_4 = 0;

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":397
 *                 fsmParse.append(currentFsmParse)
 *             if root.isVerb() or root.isPassive():
 *                 if root.verbType() != "":             # <<<<<<<<<<<<<<
 *                     currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("VerbalRoot("
 *                                                                                         + root.verbType() + ")"))
 */
        goto __pyx_L20;
      }

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":400
 *                     currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("VerbalRoot("
 *                                                                                         + root.verbType() + ")"))
 *                 elif not root.isPassive():             # <<<<<<<<<<<<<<
 *                     currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("VerbalRoot"))
 *                 else:
 */
      __pyx_t_13 = ((!(((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->isPassive(__pyx_v_root, 0) != 0)) != 0);
      if (__pyx_t_13) {

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":401
 *                                                                                         + root.verbType() + ")"))
 *                 elif not root.isPassive():
 *                     currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("VerbalRoot"))             # <<<<<<<<<<<<<<
 *                 else:
 *                     currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("PassiveHn"))
 */
        __pyx_t_4 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine *)__pyx_v_self->__pyx___finiteStateMachine->__pyx_vtab)->getState(__pyx_v_self->__pyx___finiteStateMachine, __pyx_n_u_VerbalRoot_2, 0)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 401, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 401, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_INCREF(((PyObject *)__pyx_v_root));
        __Pyx_GIVEREF(((PyObject *)__pyx_v_root));
        PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_v_root));
        __Pyx_GIVEREF(__pyx_t_4);
        PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_4);
        __pyx_t_4 = 0;
        __pyx_t_4 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse), __pyx_t_2, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 401, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_XDECREF_SET(__pyx_v_currentFsmParse, ((struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_t_4));
        __pyx_t_4 = 0;

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":400
 *                     currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("VerbalRoot("
 *                                                                                         + root.verbType() + ")"))
 *                 elif not root.isPassive():             # <<<<<<<<<<<<<<
 *                     currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("VerbalRoot"))
 *                 else:
 */
        goto __pyx_L20;
      }

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":403
 *                     currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("VerbalRoot"))
 *                 else:
 *                     currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("PassiveHn"))             # <<<<<<<<<<<<<<
 *                 fsmParse.append(currentFsmParse)
 *             if root.isPronoun():
 */
      /*else*/ {
        __pyx_t_4 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine *)__pyx_v_self->__pyx___finiteStateMachine->__pyx_vtab)->getState(__pyx_v_self->__pyx___finiteStateMachine, __pyx_n_u_PassiveHn, 0)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 403, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 403, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_INCREF(((PyObject *)__pyx_v_root));
        __Pyx_GIVEREF(((PyObject *)__pyx_v_root));
        PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_v_root));
        __Pyx_GIVEREF(__pyx_t_4);
        PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_4);
        __pyx_t_4 = 0;
        __pyx_t_4 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse), __pyx_t_2, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 403, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_XDECREF_SET(__pyx_v_currentFsmParse, ((struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_t_4));
        __pyx_t_4 = 0;
      }
      __pyx_L20:;

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":404
 *                 else:
 *                     currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("PassiveHn"))
 *                 fsmParse.append(currentFsmParse)             # <<<<<<<<<<<<<<
 *             if root.isPronoun():
 *                 if root.getName() == "kendi":
 */
      if (unlikely(__pyx_v_fsmParse == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
        __PYX_ERR(0, 404, __pyx_L1_error)
      }
      __pyx_t_9 = __Pyx_PyList_Append(__pyx_v_fsmParse, ((PyObject *)__pyx_v_currentFsmParse)); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 404, __pyx_L1_error)

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":396
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("OrdinalRoot"))
 *                 fsmParse.append(currentFsmParse)
 *             if root.isVerb() or root.isPassive():             # <<<<<<<<<<<<<<
 *                 if root.verbType() != "":
 *                     currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("VerbalRoot("
 */
    }

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":405
 *                     currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("PassiveHn"))
 *                 fsmParse.append(currentFsmParse)
 *             if root.isPronoun():             # <<<<<<<<<<<<<<
 *                 if root.getName() == "kendi":
 *                     currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("PronounRoot(REFLEX)"))
 */
    __pyx_t_13 = (((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->isPronoun(__pyx_v_root, 0) != 0);
    if (__pyx_t_13) {

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":406
 *                 fsmParse.append(currentFsmParse)
 *             if root.isPronoun():
 *                 if root.getName() == "kendi":             # <<<<<<<<<<<<<<
 *                     currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("PronounRoot(REFLEX)"))
 *                     fsmParse.append(currentFsmParse)
 */
      __pyx_t_4 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->__pyx_base.getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_v_root), 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 406, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_13 = (__Pyx_PyUnicode_Equals(__pyx_t_4, __pyx_n_u_kendi, Py_EQ)); if (unlikely(__pyx_t_13 < 0)) __PYX_ERR(0, 406, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_8 = (__pyx_t_13 != 0);
      if (__pyx_t_8) {

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":407
 *             if root.isPronoun():
 *                 if root.getName() == "kendi":
 *                     currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("PronounRoot(REFLEX)"))             # <<<<<<<<<<<<<<
 *                     fsmParse.append(currentFsmParse)
 *                 if root.getName() == "br" or root.getName() == "teki" or root.getName() == "hep" or \
 */
        __pyx_t_4 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine *)__pyx_v_self->__pyx___finiteStateMachine->__pyx_vtab)->getState(__pyx_v_self->__pyx___finiteStateMachine, __pyx_kp_u_PronounRoot_REFLEX, 0)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 407, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 407, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_INCREF(((PyObject *)__pyx_v_root));
        __Pyx_GIVEREF(((PyObject *)__pyx_v_root));
        PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_v_root));
        __Pyx_GIVEREF(__pyx_t_4);
        PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_4);
        __pyx_t_4 = 0;
        __pyx_t_4 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse), __pyx_t_2, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 407, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_XDECREF_SET(__pyx_v_currentFsmParse, ((struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_t_4));
        __pyx_t_4 = 0;

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":408
 *                 if root.getName() == "kendi":
 *                     currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("PronounRoot(REFLEX)"))
 *                     fsmParse.append(currentFsmParse)             # <<<<<<<<<<<<<<
 *                 if root.getName() == "br" or root.getName() == "teki" or root.getName() == "hep" or \
 *                         root.getName() == "kimse" or root.getName() == "dieri" or root.getName() == "hibiri" or \
 */
        if (unlikely(__pyx_v_fsmParse == Py_None)) {
          PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
          __PYX_ERR(0, 408, __pyx_L1_error)
        }
        __pyx_t_9 = __Pyx_PyList_Append(__pyx_v_fsmParse, ((PyObject *)__pyx_v_currentFsmParse)); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 408, __pyx_L1_error)

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":406
 *                 fsmParse.append(currentFsmParse)
 *             if root.isPronoun():
 *                 if root.getName() == "kendi":             # <<<<<<<<<<<<<<
 *                     currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("PronounRoot(REFLEX)"))
 *                     fsmParse.append(currentFsmParse)
 */
      }

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":409
 *                     currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("PronounRoot(REFLEX)"))
 *                     fsmParse.append(currentFsmParse)
 *                 if root.getName() == "br" or root.getName() == "teki" or root.getName() == "hep" or \             # <<<<<<<<<<<<<<
 *                         root.getName() == "kimse" or root.getName() == "dieri" or root.getName() == "hibiri" or \
 *                         root.getName() == "bylesi" or root.getName() == "birbiri" or root.getName() == "birbirleri" or\
 */
      __pyx_t_4 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->__pyx_base.getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_v_root), 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 409, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_13 = (__Pyx_PyUnicode_Equals(__pyx_t_4, __pyx_n_u_br, Py_EQ)); if (unlikely(__pyx_t_13 < 0)) __PYX_ERR(0, 409, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_14 = (__pyx_t_13 != 0);
      if (!__pyx_t_14) {
      } else {
        __pyx_t_8 = __pyx_t_14;
        goto __pyx_L24_bool_binop_done;
      }
      __pyx_t_4 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->__pyx_base.getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_v_root), 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 409, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_14 = (__Pyx_PyUnicode_Equals(__pyx_t_4, __pyx_n_u_teki, Py_EQ)); if (unlikely(__pyx_t_14 < 0)) __PYX_ERR(0, 409, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_13 = (__pyx_t_14 != 0);
      if (!__pyx_t_13) {
      } else {
        __pyx_t_8 = __pyx_t_13;
        goto __pyx_L24_bool_binop_done;
      }
      __pyx_t_4 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->__pyx_base.getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_v_root), 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 409, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_13 = (__Pyx_PyUnicode_Equals(__pyx_t_4, __pyx_n_u_hep, Py_EQ)); if (unlikely(__pyx_t_13 < 0)) __PYX_ERR(0, 409, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_14 = (__pyx_t_13 != 0);
      if (!__pyx_t_14) {
      } else {
        __pyx_t_8 = __pyx_t_14;
        goto __pyx_L24_bool_binop_done;
      }

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":410
 *                     fsmParse.append(currentFsmParse)
 *                 if root.getName() == "br" or root.getName() == "teki" or root.getName() == "hep" or \
 *                         root.getName() == "kimse" or root.getName() == "dieri" or root.getName() == "hibiri" or \             # <<<<<<<<<<<<<<
 *                         root.getName() == "bylesi" or root.getName() == "birbiri" or root.getName() == "birbirleri" or\
 *                         root.getName() == "biri" or root.getName() == "bakas" or root.getName() == "baz" or \
 */
      __pyx_t_4 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->__pyx_base.getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_v_root), 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 410, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_14 = (__Pyx_PyUnicode_Equals(__pyx_t_4, __pyx_n_u_kimse, Py_EQ)); if (unlikely(__pyx_t_14 < 0)) __PYX_ERR(0, 410, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_13 = (__pyx_t_14 != 0);
      if (!__pyx_t_13) {
      } else {
        __pyx_t_8 = __pyx_t_13;
        goto __pyx_L24_bool_binop_done;
      }
      __pyx_t_4 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->__pyx_base.getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_v_root), 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 410, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_13 = (__Pyx_PyUnicode_Equals(__pyx_t_4, __pyx_n_u_dieri, Py_EQ)); if (unlikely(__pyx_t_13 < 0)) __PYX_ERR(0, 410, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_14 = (__pyx_t_13 != 0);
      if (!__pyx_t_14) {
      } else {
        __pyx_t_8 = __pyx_t_14;
        goto __pyx_L24_bool_binop_done;
      }
      __pyx_t_4 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->__pyx_base.getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_v_root), 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 410, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_14 = (__Pyx_PyUnicode_Equals(__pyx_t_4, __pyx_n_u_hibiri, Py_EQ)); if (unlikely(__pyx_t_14 < 0)) __PYX_ERR(0, 410, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_13 = (__pyx_t_14 != 0);
      if (!__pyx_t_13) {
      } else {
        __pyx_t_8 = __pyx_t_13;
        goto __pyx_L24_bool_binop_done;
      }

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":411
 *                 if root.getName() == "br" or root.getName() == "teki" or root.getName() == "hep" or \
 *                         root.getName() == "kimse" or root.getName() == "dieri" or root.getName() == "hibiri" or \
 *                         root.getName() == "bylesi" or root.getName() == "birbiri" or root.getName() == "birbirleri" or\             # <<<<<<<<<<<<<<
 *                         root.getName() == "biri" or root.getName() == "bakas" or root.getName() == "baz" or \
 *                         root.getName() == "kimi":
 */
      __pyx_t_4 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->__pyx_base.getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_v_root), 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 411, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_13 = (__Pyx_PyUnicode_Equals(__pyx_t_4, __pyx_n_u_bylesi, Py_EQ)); if (unlikely(__pyx_t_13 < 0)) __PYX_ERR(0, 411, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_14 = (__pyx_t_13 != 0);
      if (!__pyx_t_14) {
      } else {
        __pyx_t_8 = __pyx_t_14;
        goto __pyx_L24_bool_binop_done;
      }
      __pyx_t_4 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->__pyx_base.getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_v_root), 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 411, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_14 = (__Pyx_PyUnicode_Equals(__pyx_t_4, __pyx_n_u_birbiri, Py_EQ)); if (unlikely(__pyx_t_14 < 0)) __PYX_ERR(0, 411, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_13 = (__pyx_t_14 != 0);
      if (!__pyx_t_13) {
      } else {
        __pyx_t_8 = __pyx_t_13;
        goto __pyx_L24_bool_binop_done;
      }
      __pyx_t_4 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->__pyx_base.getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_v_root), 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 411, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_13 = (__Pyx_PyUnicode_Equals(__pyx_t_4, __pyx_n_u_birbirleri, Py_EQ)); if (unlikely(__pyx_t_13 < 0)) __PYX_ERR(0, 411, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_14 = (__pyx_t_13 != 0);
      if (!__pyx_t_14) {
      } else {
        __pyx_t_8 = __pyx_t_14;
        goto __pyx_L24_bool_binop_done;
      }

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":412
 *                         root.getName() == "kimse" or root.getName() == "dieri" or root.getName() == "hibiri" or \
 *                         root.getName() == "bylesi" or root.getName() == "birbiri" or root.getName() == "birbirleri" or\
 *                         root.getName() == "biri" or root.getName() == "bakas" or root.getName() == "baz" or \             # <<<<<<<<<<<<<<
 *                         root.getName() == "kimi":
 *                     currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("PronounRoot(QUANT)"))
 */
      __pyx_t_4 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->__pyx_base.getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_v_root), 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 412, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_14 = (__Pyx_PyUnicode_Equals(__pyx_t_4, __pyx_n_u_biri, Py_EQ)); if (unlikely(__pyx_t_14 < 0)) __PYX_ERR(0, 412, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_13 = (__pyx_t_14 != 0);
      if (!__pyx_t_13) {
      } else {
        __pyx_t_8 = __pyx_t_13;
        goto __pyx_L24_bool_binop_done;
      }
      __pyx_t_4 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->__pyx_base.getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_v_root), 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 412, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_13 = (__Pyx_PyUnicode_Equals(__pyx_t_4, __pyx_n_u_bakas, Py_EQ)); if (unlikely(__pyx_t_13 < 0)) __PYX_ERR(0, 412, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_14 = (__pyx_t_13 != 0);
      if (!__pyx_t_14) {
      } else {
        __pyx_t_8 = __pyx_t_14;
        goto __pyx_L24_bool_binop_done;
      }
      __pyx_t_4 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->__pyx_base.getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_v_root), 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 412, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_14 = (__Pyx_PyUnicode_Equals(__pyx_t_4, __pyx_n_u_baz, Py_EQ)); if (unlikely(__pyx_t_14 < 0)) __PYX_ERR(0, 412, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_13 = (__pyx_t_14 != 0);
      if (!__pyx_t_13) {
      } else {
        __pyx_t_8 = __pyx_t_13;
        goto __pyx_L24_bool_binop_done;
      }

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":413
 *                         root.getName() == "bylesi" or root.getName() == "birbiri" or root.getName() == "birbirleri" or\
 *                         root.getName() == "biri" or root.getName() == "bakas" or root.getName() == "baz" or \
 *                         root.getName() == "kimi":             # <<<<<<<<<<<<<<
 *                     currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("PronounRoot(QUANT)"))
 *                     fsmParse.append(currentFsmParse)
 */
      __pyx_t_4 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->__pyx_base.getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_v_root), 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 413, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_13 = (__Pyx_PyUnicode_Equals(__pyx_t_4, __pyx_n_u_kimi, Py_EQ)); if (unlikely(__pyx_t_13 < 0)) __PYX_ERR(0, 413, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_14 = (__pyx_t_13 != 0);
      __pyx_t_8 = __pyx_t_14;
      __pyx_L24_bool_binop_done:;

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":409
 *                     currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("PronounRoot(REFLEX)"))
 *                     fsmParse.append(currentFsmParse)
 *                 if root.getName() == "br" or root.getName() == "teki" or root.getName() == "hep" or \             # <<<<<<<<<<<<<<
 *                         root.getName() == "kimse" or root.getName() == "dieri" or root.getName() == "hibiri" or \
 *                         root.getName() == "bylesi" or root.getName() == "birbiri" or root.getName() == "birbirleri" or\
 */
      if (__pyx_t_8) {

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":414
 *                         root.getName() == "biri" or root.getName() == "bakas" or root.getName() == "baz" or \
 *                         root.getName() == "kimi":
 *                     currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("PronounRoot(QUANT)"))             # <<<<<<<<<<<<<<
 *                     fsmParse.append(currentFsmParse)
 *                 if root.getName() == "tm" or root.getName() == "topu" or root.getName() == "herkes" or \
 */
        __pyx_t_4 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine *)__pyx_v_self->__pyx___finiteStateMachine->__pyx_vtab)->getState(__pyx_v_self->__pyx___finiteStateMachine, __pyx_kp_u_PronounRoot_QUANT, 0)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 414, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 414, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_INCREF(((PyObject *)__pyx_v_root));
        __Pyx_GIVEREF(((PyObject *)__pyx_v_root));
        PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_v_root));
        __Pyx_GIVEREF(__pyx_t_4);
        PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_4);
        __pyx_t_4 = 0;
        __pyx_t_4 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse), __pyx_t_2, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 414, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_XDECREF_SET(__pyx_v_currentFsmParse, ((struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_t_4));
        __pyx_t_4 = 0;

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":415
 *                         root.getName() == "kimi":
 *                     currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("PronounRoot(QUANT)"))
 *                     fsmParse.append(currentFsmParse)             # <<<<<<<<<<<<<<
 *                 if root.getName() == "tm" or root.getName() == "topu" or root.getName() == "herkes" or \
 *                         root.getName() == "cmlesi" or root.getName() == "ou" or root.getName() == "birou" or \
 */
        if (unlikely(__pyx_v_fsmParse == Py_None)) {
          PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
          __PYX_ERR(0, 415, __pyx_L1_error)
        }
        __pyx_t_9 = __Pyx_PyList_Append(__pyx_v_fsmParse, ((PyObject *)__pyx_v_currentFsmParse)); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 415, __pyx_L1_error)

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":409
 *                     currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("PronounRoot(REFLEX)"))
 *                     fsmParse.append(currentFsmParse)
 *                 if root.getName() == "br" or root.getName() == "teki" or root.getName() == "hep" or \             # <<<<<<<<<<<<<<
 *                         root.getName() == "kimse" or root.getName() == "dieri" or root.getName() == "hibiri" or \
 *                         root.getName() == "bylesi" or root.getName() == "birbiri" or root.getName() == "birbirleri" or\
 */
      }

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":416
 *                     currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("PronounRoot(QUANT)"))
 *                     fsmParse.append(currentFsmParse)
 *                 if root.getName() == "tm" or root.getName() == "topu" or root.getName() == "herkes" or \             # <<<<<<<<<<<<<<
 *                         root.getName() == "cmlesi" or root.getName() == "ou" or root.getName() == "birou" or \
 *                         root.getName() == "birka" or root.getName() == "biroklar" or root.getName() == "hepsi":
 */
      __pyx_t_4 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->__pyx_base.getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_v_root), 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 416, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_14 = (__Pyx_PyUnicode_Equals(__pyx_t_4, __pyx_n_u_tm, Py_EQ)); if (unlikely(__pyx_t_14 < 0)) __PYX_ERR(0, 416, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_13 = (__pyx_t_14 != 0);
      if (!__pyx_t_13) {
      } else {
        __pyx_t_8 = __pyx_t_13;
        goto __pyx_L38_bool_binop_done;
      }
      __pyx_t_4 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->__pyx_base.getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_v_root), 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 416, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_13 = (__Pyx_PyUnicode_Equals(__pyx_t_4, __pyx_n_u_topu, Py_EQ)); if (unlikely(__pyx_t_13 < 0)) __PYX_ERR(0, 416, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_14 = (__pyx_t_13 != 0);
      if (!__pyx_t_14) {
      } else {
        __pyx_t_8 = __pyx_t_14;
        goto __pyx_L38_bool_binop_done;
      }
      __pyx_t_4 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->__pyx_base.getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_v_root), 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 416, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_14 = (__Pyx_PyUnicode_Equals(__pyx_t_4, __pyx_n_u_herkes, Py_EQ)); if (unlikely(__pyx_t_14 < 0)) __PYX_ERR(0, 416, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_13 = (__pyx_t_14 != 0);
      if (!__pyx_t_13) {
      } else {
        __pyx_t_8 = __pyx_t_13;
        goto __pyx_L38_bool_binop_done;
      }

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":417
 *                     fsmParse.append(currentFsmParse)
 *                 if root.getName() == "tm" or root.getName() == "topu" or root.getName() == "herkes" or \
 *                         root.getName() == "cmlesi" or root.getName() == "ou" or root.getName() == "birou" or \             # <<<<<<<<<<<<<<
 *                         root.getName() == "birka" or root.getName() == "biroklar" or root.getName() == "hepsi":
 *                     currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("PronounRoot(QUANTPLURAL)"))
 */
      __pyx_t_4 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->__pyx_base.getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_v_root), 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 417, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_13 = (__Pyx_PyUnicode_Equals(__pyx_t_4, __pyx_n_u_cmlesi, Py_EQ)); if (unlikely(__pyx_t_13 < 0)) __PYX_ERR(0, 417, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_14 = (__pyx_t_13 != 0);
      if (!__pyx_t_14) {
      } else {
        __pyx_t_8 = __pyx_t_14;
        goto __pyx_L38_bool_binop_done;
      }
      __pyx_t_4 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->__pyx_base.getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_v_root), 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 417, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_14 = (__Pyx_PyUnicode_Equals(__pyx_t_4, __pyx_n_u_ou, Py_EQ)); if (unlikely(__pyx_t_14 < 0)) __PYX_ERR(0, 417, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_13 = (__pyx_t_14 != 0);
      if (!__pyx_t_13) {
      } else {
        __pyx_t_8 = __pyx_t_13;
        goto __pyx_L38_bool_binop_done;
      }
      __pyx_t_4 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->__pyx_base.getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_v_root), 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 417, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_13 = (__Pyx_PyUnicode_Equals(__pyx_t_4, __pyx_n_u_birou, Py_EQ)); if (unlikely(__pyx_t_13 < 0)) __PYX_ERR(0, 417, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_14 = (__pyx_t_13 != 0);
      if (!__pyx_t_14) {
      } else {
        __pyx_t_8 = __pyx_t_14;
        goto __pyx_L38_bool_binop_done;
      }

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":418
 *                 if root.getName() == "tm" or root.getName() == "topu" or root.getName() == "herkes" or \
 *                         root.getName() == "cmlesi" or root.getName() == "ou" or root.getName() == "birou" or \
 *                         root.getName() == "birka" or root.getName() == "biroklar" or root.getName() == "hepsi":             # <<<<<<<<<<<<<<
 *                     currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("PronounRoot(QUANTPLURAL)"))
 *                     fsmParse.append(currentFsmParse)
 */
      __pyx_t_4 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->__pyx_base.getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_v_root), 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 418, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_14 = (__Pyx_PyUnicode_Equals(__pyx_t_4, __pyx_n_u_birka, Py_EQ)); if (unlikely(__pyx_t_14 < 0)) __PYX_ERR(0, 418, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_13 = (__pyx_t_14 != 0);
      if (!__pyx_t_13) {
      } else {
        __pyx_t_8 = __pyx_t_13;
        goto __pyx_L38_bool_binop_done;
      }
      __pyx_t_4 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->__pyx_base.getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_v_root), 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 418, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_13 = (__Pyx_PyUnicode_Equals(__pyx_t_4, __pyx_n_u_biroklar, Py_EQ)); if (unlikely(__pyx_t_13 < 0)) __PYX_ERR(0, 418, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_14 = (__pyx_t_13 != 0);
      if (!__pyx_t_14) {
      } else {
        __pyx_t_8 = __pyx_t_14;
        goto __pyx_L38_bool_binop_done;
      }
      __pyx_t_4 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->__pyx_base.getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_v_root), 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 418, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_14 = (__Pyx_PyUnicode_Equals(__pyx_t_4, __pyx_n_u_hepsi, Py_EQ)); if (unlikely(__pyx_t_14 < 0)) __PYX_ERR(0, 418, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_13 = (__pyx_t_14 != 0);
      __pyx_t_8 = __pyx_t_13;
      __pyx_L38_bool_binop_done:;

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":416
 *                     currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("PronounRoot(QUANT)"))
 *                     fsmParse.append(currentFsmParse)
 *                 if root.getName() == "tm" or root.getName() == "topu" or root.getName() == "herkes" or \             # <<<<<<<<<<<<<<
 *                         root.getName() == "cmlesi" or root.getName() == "ou" or root.getName() == "birou" or \
 *                         root.getName() == "birka" or root.getName() == "biroklar" or root.getName() == "hepsi":
 */
      if (__pyx_t_8) {

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":419
 *                         root.getName() == "cmlesi" or root.getName() == "ou" or root.getName() == "birou" or \
 *                         root.getName() == "birka" or root.getName() == "biroklar" or root.getName() == "hepsi":
 *                     currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("PronounRoot(QUANTPLURAL)"))             # <<<<<<<<<<<<<<
 *                     fsmParse.append(currentFsmParse)
 *                 if root.getName() == "o" or root.getName() == "bu" or root.getName() == "u":
 */
        __pyx_t_4 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine *)__pyx_v_self->__pyx___finiteStateMachine->__pyx_vtab)->getState(__pyx_v_self->__pyx___finiteStateMachine, __pyx_kp_u_PronounRoot_QUANTPLURAL, 0)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 419, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 419, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_INCREF(((PyObject *)__pyx_v_root));
        __Pyx_GIVEREF(((PyObject *)__pyx_v_root));
        PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_v_root));
        __Pyx_GIVEREF(__pyx_t_4);
        PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_4);
        __pyx_t_4 = 0;
        __pyx_t_4 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse), __pyx_t_2, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 419, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_XDECREF_SET(__pyx_v_currentFsmParse, ((struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_t_4));
        __pyx_t_4 = 0;

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":420
 *                         root.getName() == "birka" or root.getName() == "biroklar" or root.getName() == "hepsi":
 *                     currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("PronounRoot(QUANTPLURAL)"))
 *                     fsmParse.append(currentFsmParse)             # <<<<<<<<<<<<<<
 *                 if root.getName() == "o" or root.getName() == "bu" or root.getName() == "u":
 *                     currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("PronounRoot(DEMONS)"))
 */
        if (unlikely(__pyx_v_fsmParse == Py_None)) {
          PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
          __PYX_ERR(0, 420, __pyx_L1_error)
        }
        __pyx_t_9 = __Pyx_PyList_Append(__pyx_v_fsmParse, ((PyObject *)__pyx_v_currentFsmParse)); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 420, __pyx_L1_error)

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":416
 *                     currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("PronounRoot(QUANT)"))
 *                     fsmParse.append(currentFsmParse)
 *                 if root.getName() == "tm" or root.getName() == "topu" or root.getName() == "herkes" or \             # <<<<<<<<<<<<<<
 *                         root.getName() == "cmlesi" or root.getName() == "ou" or root.getName() == "birou" or \
 *                         root.getName() == "birka" or root.getName() == "biroklar" or root.getName() == "hepsi":
 */
      }

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":421
 *                     currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("PronounRoot(QUANTPLURAL)"))
 *                     fsmParse.append(currentFsmParse)
 *                 if root.getName() == "o" or root.getName() == "bu" or root.getName() == "u":             # <<<<<<<<<<<<<<
 *                     currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("PronounRoot(DEMONS)"))
 *                     fsmParse.append(currentFsmParse)
 */
      __pyx_t_4 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->__pyx_base.getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_v_root), 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 421, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_13 = (__Pyx_PyUnicode_Equals(__pyx_t_4, __pyx_n_u_o, Py_EQ)); if (unlikely(__pyx_t_13 < 0)) __PYX_ERR(0, 421, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_14 = (__pyx_t_13 != 0);
      if (!__pyx_t_14) {
      } else {
        __pyx_t_8 = __pyx_t_14;
        goto __pyx_L48_bool_binop_done;
      }
      __pyx_t_4 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->__pyx_base.getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_v_root), 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 421, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_14 = (__Pyx_PyUnicode_Equals(__pyx_t_4, __pyx_n_u_bu, Py_EQ)); if (unlikely(__pyx_t_14 < 0)) __PYX_ERR(0, 421, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_13 = (__pyx_t_14 != 0);
      if (!__pyx_t_13) {
      } else {
        __pyx_t_8 = __pyx_t_13;
        goto __pyx_L48_bool_binop_done;
      }
      __pyx_t_4 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->__pyx_base.getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_v_root), 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 421, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_13 = (__Pyx_PyUnicode_Equals(__pyx_t_4, __pyx_n_u_u, Py_EQ)); if (unlikely(__pyx_t_13 < 0)) __PYX_ERR(0, 421, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_14 = (__pyx_t_13 != 0);
      __pyx_t_8 = __pyx_t_14;
      __pyx_L48_bool_binop_done:;
      if (__pyx_t_8) {

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":422
 *                     fsmParse.append(currentFsmParse)
 *                 if root.getName() == "o" or root.getName() == "bu" or root.getName() == "u":
 *                     currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("PronounRoot(DEMONS)"))             # <<<<<<<<<<<<<<
 *                     fsmParse.append(currentFsmParse)
 *                 if root.getName() == "ben" or root.getName() == "sen" or root.getName() == "o" or \
 */
        __pyx_t_4 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine *)__pyx_v_self->__pyx___finiteStateMachine->__pyx_vtab)->getState(__pyx_v_self->__pyx___finiteStateMachine, __pyx_kp_u_PronounRoot_DEMONS, 0)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 422, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 422, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_INCREF(((PyObject *)__pyx_v_root));
        __Pyx_GIVEREF(((PyObject *)__pyx_v_root));
        PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_v_root));
        __Pyx_GIVEREF(__pyx_t_4);
        PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_4);
        __pyx_t_4 = 0;
        __pyx_t_4 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse), __pyx_t_2, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 422, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_XDECREF_SET(__pyx_v_currentFsmParse, ((struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_t_4));
        __pyx_t_4 = 0;

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":423
 *                 if root.getName() == "o" or root.getName() == "bu" or root.getName() == "u":
 *                     currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("PronounRoot(DEMONS)"))
 *                     fsmParse.append(currentFsmParse)             # <<<<<<<<<<<<<<
 *                 if root.getName() == "ben" or root.getName() == "sen" or root.getName() == "o" or \
 *                         root.getName() == "biz" or root.getName() == "siz" or root.getName() == "onlar":
 */
        if (unlikely(__pyx_v_fsmParse == Py_None)) {
          PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
          __PYX_ERR(0, 423, __pyx_L1_error)
        }
        __pyx_t_9 = __Pyx_PyList_Append(__pyx_v_fsmParse, ((PyObject *)__pyx_v_currentFsmParse)); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 423, __pyx_L1_error)

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":421
 *                     currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("PronounRoot(QUANTPLURAL)"))
 *                     fsmParse.append(currentFsmParse)
 *                 if root.getName() == "o" or root.getName() == "bu" or root.getName() == "u":             # <<<<<<<<<<<<<<
 *                     currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("PronounRoot(DEMONS)"))
 *                     fsmParse.append(currentFsmParse)
 */
      }

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":424
 *                     currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("PronounRoot(DEMONS)"))
 *                     fsmParse.append(currentFsmParse)
 *                 if root.getName() == "ben" or root.getName() == "sen" or root.getName() == "o" or \             # <<<<<<<<<<<<<<
 *                         root.getName() == "biz" or root.getName() == "siz" or root.getName() == "onlar":
 *                     currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("PronounRoot(PERS)"))
 */
      __pyx_t_4 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->__pyx_base.getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_v_root), 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 424, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_14 = (__Pyx_PyUnicode_Equals(__pyx_t_4, __pyx_n_u_ben, Py_EQ)); if (unlikely(__pyx_t_14 < 0)) __PYX_ERR(0, 424, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_13 = (__pyx_t_14 != 0);
      if (!__pyx_t_13) {
      } else {
        __pyx_t_8 = __pyx_t_13;
        goto __pyx_L52_bool_binop_done;
      }
      __pyx_t_4 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->__pyx_base.getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_v_root), 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 424, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_13 = (__Pyx_PyUnicode_Equals(__pyx_t_4, __pyx_n_u_sen, Py_EQ)); if (unlikely(__pyx_t_13 < 0)) __PYX_ERR(0, 424, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_14 = (__pyx_t_13 != 0);
      if (!__pyx_t_14) {
      } else {
        __pyx_t_8 = __pyx_t_14;
        goto __pyx_L52_bool_binop_done;
      }
      __pyx_t_4 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->__pyx_base.getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_v_root), 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 424, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_14 = (__Pyx_PyUnicode_Equals(__pyx_t_4, __pyx_n_u_o, Py_EQ)); if (unlikely(__pyx_t_14 < 0)) __PYX_ERR(0, 424, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_13 = (__pyx_t_14 != 0);
      if (!__pyx_t_13) {
      } else {
        __pyx_t_8 = __pyx_t_13;
        goto __pyx_L52_bool_binop_done;
      }

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":425
 *                     fsmParse.append(currentFsmParse)
 *                 if root.getName() == "ben" or root.getName() == "sen" or root.getName() == "o" or \
 *                         root.getName() == "biz" or root.getName() == "siz" or root.getName() == "onlar":             # <<<<<<<<<<<<<<
 *                     currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("PronounRoot(PERS)"))
 *                     fsmParse.append(currentFsmParse)
 */
      __pyx_t_4 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->__pyx_base.getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_v_root), 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 425, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_13 = (__Pyx_PyUnicode_Equals(__pyx_t_4, __pyx_n_u_biz, Py_EQ)); if (unlikely(__pyx_t_13 < 0)) __PYX_ERR(0, 425, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_14 = (__pyx_t_13 != 0);
      if (!__pyx_t_14) {
      } else {
        __pyx_t_8 = __pyx_t_14;
        goto __pyx_L52_bool_binop_done;
      }
      __pyx_t_4 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->__pyx_base.getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_v_root), 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 425, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_14 = (__Pyx_PyUnicode_Equals(__pyx_t_4, __pyx_n_u_siz, Py_EQ)); if (unlikely(__pyx_t_14 < 0)) __PYX_ERR(0, 425, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_13 = (__pyx_t_14 != 0);
      if (!__pyx_t_13) {
      } else {
        __pyx_t_8 = __pyx_t_13;
        goto __pyx_L52_bool_binop_done;
      }
      __pyx_t_4 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->__pyx_base.getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_v_root), 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 425, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_13 = (__Pyx_PyUnicode_Equals(__pyx_t_4, __pyx_n_u_onlar, Py_EQ)); if (unlikely(__pyx_t_13 < 0)) __PYX_ERR(0, 425, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_14 = (__pyx_t_13 != 0);
      __pyx_t_8 = __pyx_t_14;
      __pyx_L52_bool_binop_done:;

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":424
 *                     currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("PronounRoot(DEMONS)"))
 *                     fsmParse.append(currentFsmParse)
 *                 if root.getName() == "ben" or root.getName() == "sen" or root.getName() == "o" or \             # <<<<<<<<<<<<<<
 *                         root.getName() == "biz" or root.getName() == "siz" or root.getName() == "onlar":
 *                     currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("PronounRoot(PERS)"))
 */
      if (__pyx_t_8) {

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":426
 *                 if root.getName() == "ben" or root.getName() == "sen" or root.getName() == "o" or \
 *                         root.getName() == "biz" or root.getName() == "siz" or root.getName() == "onlar":
 *                     currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("PronounRoot(PERS)"))             # <<<<<<<<<<<<<<
 *                     fsmParse.append(currentFsmParse)
 *                 if root.getName() == "nere" or root.getName() == "ne" or root.getName() == "ka" or \
 */
        __pyx_t_4 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine *)__pyx_v_self->__pyx___finiteStateMachine->__pyx_vtab)->getState(__pyx_v_self->__pyx___finiteStateMachine, __pyx_kp_u_PronounRoot_PERS, 0)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 426, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 426, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_INCREF(((PyObject *)__pyx_v_root));
        __Pyx_GIVEREF(((PyObject *)__pyx_v_root));
        PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_v_root));
        __Pyx_GIVEREF(__pyx_t_4);
        PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_4);
        __pyx_t_4 = 0;
        __pyx_t_4 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse), __pyx_t_2, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 426, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_XDECREF_SET(__pyx_v_currentFsmParse, ((struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_t_4));
        __pyx_t_4 = 0;

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":427
 *                         root.getName() == "biz" or root.getName() == "siz" or root.getName() == "onlar":
 *                     currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("PronounRoot(PERS)"))
 *                     fsmParse.append(currentFsmParse)             # <<<<<<<<<<<<<<
 *                 if root.getName() == "nere" or root.getName() == "ne" or root.getName() == "ka" or \
 *                         root.getName() == "kim" or root.getName() == "hangi":
 */
        if (unlikely(__pyx_v_fsmParse == Py_None)) {
          PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
          __PYX_ERR(0, 427, __pyx_L1_error)
        }
        __pyx_t_9 = __Pyx_PyList_Append(__pyx_v_fsmParse, ((PyObject *)__pyx_v_currentFsmParse)); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 427, __pyx_L1_error)

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":424
 *                     currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("PronounRoot(DEMONS)"))
 *                     fsmParse.append(currentFsmParse)
 *                 if root.getName() == "ben" or root.getName() == "sen" or root.getName() == "o" or \             # <<<<<<<<<<<<<<
 *                         root.getName() == "biz" or root.getName() == "siz" or root.getName() == "onlar":
 *                     currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("PronounRoot(PERS)"))
 */
      }

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":428
 *                     currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("PronounRoot(PERS)"))
 *                     fsmParse.append(currentFsmParse)
 *                 if root.getName() == "nere" or root.getName() == "ne" or root.getName() == "ka" or \             # <<<<<<<<<<<<<<
 *                         root.getName() == "kim" or root.getName() == "hangi":
 *                     currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("PronounRoot(QUES)"))
 */
      __pyx_t_4 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->__pyx_base.getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_v_root), 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 428, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_14 = (__Pyx_PyUnicode_Equals(__pyx_t_4, __pyx_n_u_nere, Py_EQ)); if (unlikely(__pyx_t_14 < 0)) __PYX_ERR(0, 428, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_13 = (__pyx_t_14 != 0);
      if (!__pyx_t_13) {
      } else {
        __pyx_t_8 = __pyx_t_13;
        goto __pyx_L59_bool_binop_done;
      }
      __pyx_t_4 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->__pyx_base.getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_v_root), 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 428, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_13 = (__Pyx_PyUnicode_Equals(__pyx_t_4, __pyx_n_u_ne, Py_EQ)); if (unlikely(__pyx_t_13 < 0)) __PYX_ERR(0, 428, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_14 = (__pyx_t_13 != 0);
      if (!__pyx_t_14) {
      } else {
        __pyx_t_8 = __pyx_t_14;
        goto __pyx_L59_bool_binop_done;
      }
      __pyx_t_4 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->__pyx_base.getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_v_root), 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 428, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_14 = (__Pyx_PyUnicode_Equals(__pyx_t_4, __pyx_n_u_ka, Py_EQ)); if (unlikely(__pyx_t_14 < 0)) __PYX_ERR(0, 428, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_13 = (__pyx_t_14 != 0);
      if (!__pyx_t_13) {
      } else {
        __pyx_t_8 = __pyx_t_13;
        goto __pyx_L59_bool_binop_done;
      }

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":429
 *                     fsmParse.append(currentFsmParse)
 *                 if root.getName() == "nere" or root.getName() == "ne" or root.getName() == "ka" or \
 *                         root.getName() == "kim" or root.getName() == "hangi":             # <<<<<<<<<<<<<<
 *                     currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("PronounRoot(QUES)"))
 *                     fsmParse.append(currentFsmParse)
 */
      __pyx_t_4 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->__pyx_base.getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_v_root), 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 429, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_13 = (__Pyx_PyUnicode_Equals(__pyx_t_4, __pyx_n_u_kim, Py_EQ)); if (unlikely(__pyx_t_13 < 0)) __PYX_ERR(0, 429, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_14 = (__pyx_t_13 != 0);
      if (!__pyx_t_14) {
      } else {
        __pyx_t_8 = __pyx_t_14;
        goto __pyx_L59_bool_binop_done;
      }
      __pyx_t_4 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->__pyx_base.getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_v_root), 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 429, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_14 = (__Pyx_PyUnicode_Equals(__pyx_t_4, __pyx_n_u_hangi, Py_EQ)); if (unlikely(__pyx_t_14 < 0)) __PYX_ERR(0, 429, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_13 = (__pyx_t_14 != 0);
      __pyx_t_8 = __pyx_t_13;
      __pyx_L59_bool_binop_done:;

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":428
 *                     currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("PronounRoot(PERS)"))
 *                     fsmParse.append(currentFsmParse)
 *                 if root.getName() == "nere" or root.getName() == "ne" or root.getName() == "ka" or \             # <<<<<<<<<<<<<<
 *                         root.getName() == "kim" or root.getName() == "hangi":
 *                     currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("PronounRoot(QUES)"))
 */
      if (__pyx_t_8) {

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":430
 *                 if root.getName() == "nere" or root.getName() == "ne" or root.getName() == "ka" or \
 *                         root.getName() == "kim" or root.getName() == "hangi":
 *                     currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("PronounRoot(QUES)"))             # <<<<<<<<<<<<<<
 *                     fsmParse.append(currentFsmParse)
 *             if root.isAdjective():
 */
        __pyx_t_4 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine *)__pyx_v_self->__pyx___finiteStateMachine->__pyx_vtab)->getState(__pyx_v_self->__pyx___finiteStateMachine, __pyx_kp_u_PronounRoot_QUES, 0)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 430, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 430, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_INCREF(((PyObject *)__pyx_v_root));
        __Pyx_GIVEREF(((PyObject *)__pyx_v_root));
        PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_v_root));
        __Pyx_GIVEREF(__pyx_t_4);
        PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_4);
        __pyx_t_4 = 0;
        __pyx_t_4 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse), __pyx_t_2, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 430, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_XDECREF_SET(__pyx_v_currentFsmParse, ((struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_t_4));
        __pyx_t_4 = 0;

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":431
 *                         root.getName() == "kim" or root.getName() == "hangi":
 *                     currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("PronounRoot(QUES)"))
 *                     fsmParse.append(currentFsmParse)             # <<<<<<<<<<<<<<
 *             if root.isAdjective():
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("AdjectiveRoot"))
 */
        if (unlikely(__pyx_v_fsmParse == Py_None)) {
          PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
          __PYX_ERR(0, 431, __pyx_L1_error)
        }
        __pyx_t_9 = __Pyx_PyList_Append(__pyx_v_fsmParse, ((PyObject *)__pyx_v_currentFsmParse)); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 431, __pyx_L1_error)

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":428
 *                     currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("PronounRoot(PERS)"))
 *                     fsmParse.append(currentFsmParse)
 *                 if root.getName() == "nere" or root.getName() == "ne" or root.getName() == "ka" or \             # <<<<<<<<<<<<<<
 *                         root.getName() == "kim" or root.getName() == "hangi":
 *                     currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("PronounRoot(QUES)"))
 */
      }

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":405
 *                     currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("PassiveHn"))
 *                 fsmParse.append(currentFsmParse)
 *             if root.isPronoun():             # <<<<<<<<<<<<<<
 *                 if root.getName() == "kendi":
 *                     currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("PronounRoot(REFLEX)"))
 */
    }

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":432
 *                     currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("PronounRoot(QUES)"))
 *                     fsmParse.append(currentFsmParse)
 *             if root.isAdjective():             # <<<<<<<<<<<<<<
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("AdjectiveRoot"))
 *                 fsmParse.append(currentFsmParse)
 */
    __pyx_t_8 = (((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->isAdjective(__pyx_v_root, 0) != 0);
    if (__pyx_t_8) {

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":433
 *                     fsmParse.append(currentFsmParse)
 *             if root.isAdjective():
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("AdjectiveRoot"))             # <<<<<<<<<<<<<<
 *                 fsmParse.append(currentFsmParse)
 *             if root.isPureAdjective():
 */
      __pyx_t_4 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine *)__pyx_v_self->__pyx___finiteStateMachine->__pyx_vtab)->getState(__pyx_v_self->__pyx___finiteStateMachine, __pyx_n_u_AdjectiveRoot, 0)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 433, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 433, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_INCREF(((PyObject *)__pyx_v_root));
      __Pyx_GIVEREF(((PyObject *)__pyx_v_root));
      PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_v_root));
      __Pyx_GIVEREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_4);
      __pyx_t_4 = 0;
      __pyx_t_4 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse), __pyx_t_2, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 433, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF_SET(__pyx_v_currentFsmParse, ((struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_t_4));
      __pyx_t_4 = 0;

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":434
 *             if root.isAdjective():
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("AdjectiveRoot"))
 *                 fsmParse.append(currentFsmParse)             # <<<<<<<<<<<<<<
 *             if root.isPureAdjective():
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("Adjective"))
 */
      if (unlikely(__pyx_v_fsmParse == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
        __PYX_ERR(0, 434, __pyx_L1_error)
      }
      __pyx_t_9 = __Pyx_PyList_Append(__pyx_v_fsmParse, ((PyObject *)__pyx_v_currentFsmParse)); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 434, __pyx_L1_error)

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":432
 *                     currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("PronounRoot(QUES)"))
 *                     fsmParse.append(currentFsmParse)
 *             if root.isAdjective():             # <<<<<<<<<<<<<<
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("AdjectiveRoot"))
 *                 fsmParse.append(currentFsmParse)
 */
    }

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":435
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("AdjectiveRoot"))
 *                 fsmParse.append(currentFsmParse)
 *             if root.isPureAdjective():             # <<<<<<<<<<<<<<
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("Adjective"))
 *                 fsmParse.append(currentFsmParse)
 */
    __pyx_t_8 = (((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->isPureAdjective(__pyx_v_root, 0) != 0);
    if (__pyx_t_8) {

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":436
 *                 fsmParse.append(currentFsmParse)
 *             if root.isPureAdjective():
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("Adjective"))             # <<<<<<<<<<<<<<
 *                 fsmParse.append(currentFsmParse)
 *             if root.isNominal():
 */
      __pyx_t_4 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine *)__pyx_v_self->__pyx___finiteStateMachine->__pyx_vtab)->getState(__pyx_v_self->__pyx___finiteStateMachine, __pyx_n_u_Adjective, 0)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 436, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 436, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_INCREF(((PyObject *)__pyx_v_root));
      __Pyx_GIVEREF(((PyObject *)__pyx_v_root));
      PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_v_root));
      __Pyx_GIVEREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_4);
      __pyx_t_4 = 0;
      __pyx_t_4 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse), __pyx_t_2, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 436, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF_SET(__pyx_v_currentFsmParse, ((struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_t_4));
      __pyx_t_4 = 0;

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":437
 *             if root.isPureAdjective():
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("Adjective"))
 *                 fsmParse.append(currentFsmParse)             # <<<<<<<<<<<<<<
 *             if root.isNominal():
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("NominalRoot"))
 */
      if (unlikely(__pyx_v_fsmParse == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
        __PYX_ERR(0, 437, __pyx_L1_error)
      }
      __pyx_t_9 = __Pyx_PyList_Append(__pyx_v_fsmParse, ((PyObject *)__pyx_v_currentFsmParse)); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 437, __pyx_L1_error)

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":435
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("AdjectiveRoot"))
 *                 fsmParse.append(currentFsmParse)
 *             if root.isPureAdjective():             # <<<<<<<<<<<<<<
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("Adjective"))
 *                 fsmParse.append(currentFsmParse)
 */
    }

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":438
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("Adjective"))
 *                 fsmParse.append(currentFsmParse)
 *             if root.isNominal():             # <<<<<<<<<<<<<<
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("NominalRoot"))
 *                 fsmParse.append(currentFsmParse)
 */
    __pyx_t_8 = (((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->isNominal(__pyx_v_root, 0) != 0);
    if (__pyx_t_8) {

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":439
 *                 fsmParse.append(currentFsmParse)
 *             if root.isNominal():
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("NominalRoot"))             # <<<<<<<<<<<<<<
 *                 fsmParse.append(currentFsmParse)
 *             if root.isAbbreviation():
 */
      __pyx_t_4 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine *)__pyx_v_self->__pyx___finiteStateMachine->__pyx_vtab)->getState(__pyx_v_self->__pyx___finiteStateMachine, __pyx_n_u_NominalRoot, 0)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 439, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 439, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_INCREF(((PyObject *)__pyx_v_root));
      __Pyx_GIVEREF(((PyObject *)__pyx_v_root));
      PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_v_root));
      __Pyx_GIVEREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_4);
      __pyx_t_4 = 0;
      __pyx_t_4 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse), __pyx_t_2, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 439, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF_SET(__pyx_v_currentFsmParse, ((struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_t_4));
      __pyx_t_4 = 0;

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":440
 *             if root.isNominal():
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("NominalRoot"))
 *                 fsmParse.append(currentFsmParse)             # <<<<<<<<<<<<<<
 *             if root.isAbbreviation():
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("NominalRoot"))
 */
      if (unlikely(__pyx_v_fsmParse == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
        __PYX_ERR(0, 440, __pyx_L1_error)
      }
      __pyx_t_9 = __Pyx_PyList_Append(__pyx_v_fsmParse, ((PyObject *)__pyx_v_currentFsmParse)); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 440, __pyx_L1_error)

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":438
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("Adjective"))
 *                 fsmParse.append(currentFsmParse)
 *             if root.isNominal():             # <<<<<<<<<<<<<<
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("NominalRoot"))
 *                 fsmParse.append(currentFsmParse)
 */
    }

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":441
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("NominalRoot"))
 *                 fsmParse.append(currentFsmParse)
 *             if root.isAbbreviation():             # <<<<<<<<<<<<<<
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("NominalRoot"))
 *                 fsmParse.append(currentFsmParse)
 */
    __pyx_t_8 = (((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->isAbbreviation(__pyx_v_root, 0) != 0);
    if (__pyx_t_8) {

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":442
 *                 fsmParse.append(currentFsmParse)
 *             if root.isAbbreviation():
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("NominalRoot"))             # <<<<<<<<<<<<<<
 *                 fsmParse.append(currentFsmParse)
 *             if root.isProperNoun() and isProper:
 */
      __pyx_t_4 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine *)__pyx_v_self->__pyx___finiteStateMachine->__pyx_vtab)->getState(__pyx_v_self->__pyx___finiteStateMachine, __pyx_n_u_NominalRoot, 0)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 442, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 442, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_INCREF(((PyObject *)__pyx_v_root));
      __Pyx_GIVEREF(((PyObject *)__pyx_v_root));
      PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_v_root));
      __Pyx_GIVEREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_4);
      __pyx_t_4 = 0;
      __pyx_t_4 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse), __pyx_t_2, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 442, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF_SET(__pyx_v_currentFsmParse, ((struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_t_4));
      __pyx_t_4 = 0;

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":443
 *             if root.isAbbreviation():
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("NominalRoot"))
 *                 fsmParse.append(currentFsmParse)             # <<<<<<<<<<<<<<
 *             if root.isProperNoun() and isProper:
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("ProperRoot"))
 */
      if (unlikely(__pyx_v_fsmParse == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
        __PYX_ERR(0, 443, __pyx_L1_error)
      }
      __pyx_t_9 = __Pyx_PyList_Append(__pyx_v_fsmParse, ((PyObject *)__pyx_v_currentFsmParse)); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 443, __pyx_L1_error)

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":441
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("NominalRoot"))
 *                 fsmParse.append(currentFsmParse)
 *             if root.isAbbreviation():             # <<<<<<<<<<<<<<
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("NominalRoot"))
 *                 fsmParse.append(currentFsmParse)
 */
    }

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":444
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("NominalRoot"))
 *                 fsmParse.append(currentFsmParse)
 *             if root.isProperNoun() and isProper:             # <<<<<<<<<<<<<<
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("ProperRoot"))
 *                 fsmParse.append(currentFsmParse)
 */
    __pyx_t_13 = (((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->isProperNoun(__pyx_v_root, 0) != 0);
    if (__pyx_t_13) {
    } else {
      __pyx_t_8 = __pyx_t_13;
      goto __pyx_L69_bool_binop_done;
    }
    __pyx_t_13 = (__pyx_v_isProper != 0);
    __pyx_t_8 = __pyx_t_13;
    __pyx_L69_bool_binop_done:;
    if (__pyx_t_8) {

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":445
 *                 fsmParse.append(currentFsmParse)
 *             if root.isProperNoun() and isProper:
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("ProperRoot"))             # <<<<<<<<<<<<<<
 *                 fsmParse.append(currentFsmParse)
 *             if root.isQuestion():
 */
      __pyx_t_4 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine *)__pyx_v_self->__pyx___finiteStateMachine->__pyx_vtab)->getState(__pyx_v_self->__pyx___finiteStateMachine, __pyx_n_u_ProperRoot, 0)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 445, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 445, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_INCREF(((PyObject *)__pyx_v_root));
      __Pyx_GIVEREF(((PyObject *)__pyx_v_root));
      PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_v_root));
      __Pyx_GIVEREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_4);
      __pyx_t_4 = 0;
      __pyx_t_4 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse), __pyx_t_2, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 445, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF_SET(__pyx_v_currentFsmParse, ((struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_t_4));
      __pyx_t_4 = 0;

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":446
 *             if root.isProperNoun() and isProper:
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("ProperRoot"))
 *                 fsmParse.append(currentFsmParse)             # <<<<<<<<<<<<<<
 *             if root.isQuestion():
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("QuestionRoot"))
 */
      if (unlikely(__pyx_v_fsmParse == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
        __PYX_ERR(0, 446, __pyx_L1_error)
      }
      __pyx_t_9 = __Pyx_PyList_Append(__pyx_v_fsmParse, ((PyObject *)__pyx_v_currentFsmParse)); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 446, __pyx_L1_error)

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":444
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("NominalRoot"))
 *                 fsmParse.append(currentFsmParse)
 *             if root.isProperNoun() and isProper:             # <<<<<<<<<<<<<<
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("ProperRoot"))
 *                 fsmParse.append(currentFsmParse)
 */
    }

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":447
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("ProperRoot"))
 *                 fsmParse.append(currentFsmParse)
 *             if root.isQuestion():             # <<<<<<<<<<<<<<
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("QuestionRoot"))
 *                 fsmParse.append(currentFsmParse)
 */
    __pyx_t_8 = (((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->isQuestion(__pyx_v_root, 0) != 0);
    if (__pyx_t_8) {

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":448
 *                 fsmParse.append(currentFsmParse)
 *             if root.isQuestion():
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("QuestionRoot"))             # <<<<<<<<<<<<<<
 *                 fsmParse.append(currentFsmParse)
 *             if root.isDeterminer():
 */
      __pyx_t_4 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine *)__pyx_v_self->__pyx___finiteStateMachine->__pyx_vtab)->getState(__pyx_v_self->__pyx___finiteStateMachine, __pyx_n_u_QuestionRoot, 0)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 448, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 448, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_INCREF(((PyObject *)__pyx_v_root));
      __Pyx_GIVEREF(((PyObject *)__pyx_v_root));
      PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_v_root));
      __Pyx_GIVEREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_4);
      __pyx_t_4 = 0;
      __pyx_t_4 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse), __pyx_t_2, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 448, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF_SET(__pyx_v_currentFsmParse, ((struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_t_4));
      __pyx_t_4 = 0;

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":449
 *             if root.isQuestion():
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("QuestionRoot"))
 *                 fsmParse.append(currentFsmParse)             # <<<<<<<<<<<<<<
 *             if root.isDeterminer():
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("DeterminerRoot"))
 */
      if (unlikely(__pyx_v_fsmParse == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
        __PYX_ERR(0, 449, __pyx_L1_error)
      }
      __pyx_t_9 = __Pyx_PyList_Append(__pyx_v_fsmParse, ((PyObject *)__pyx_v_currentFsmParse)); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 449, __pyx_L1_error)

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":447
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("ProperRoot"))
 *                 fsmParse.append(currentFsmParse)
 *             if root.isQuestion():             # <<<<<<<<<<<<<<
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("QuestionRoot"))
 *                 fsmParse.append(currentFsmParse)
 */
    }

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":450
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("QuestionRoot"))
 *                 fsmParse.append(currentFsmParse)
 *             if root.isDeterminer():             # <<<<<<<<<<<<<<
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("DeterminerRoot"))
 *                 fsmParse.append(currentFsmParse)
 */
    __pyx_t_8 = (((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->isDeterminer(__pyx_v_root, 0) != 0);
    if (__pyx_t_8) {

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":451
 *                 fsmParse.append(currentFsmParse)
 *             if root.isDeterminer():
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("DeterminerRoot"))             # <<<<<<<<<<<<<<
 *                 fsmParse.append(currentFsmParse)
 *             if root.isConjunction():
 */
      __pyx_t_4 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine *)__pyx_v_self->__pyx___finiteStateMachine->__pyx_vtab)->getState(__pyx_v_self->__pyx___finiteStateMachine, __pyx_n_u_DeterminerRoot, 0)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 451, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 451, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_INCREF(((PyObject *)__pyx_v_root));
      __Pyx_GIVEREF(((PyObject *)__pyx_v_root));
      PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_v_root));
      __Pyx_GIVEREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_4);
      __pyx_t_4 = 0;
      __pyx_t_4 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse), __pyx_t_2, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 451, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF_SET(__pyx_v_currentFsmParse, ((struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_t_4));
      __pyx_t_4 = 0;

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":452
 *             if root.isDeterminer():
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("DeterminerRoot"))
 *                 fsmParse.append(currentFsmParse)             # <<<<<<<<<<<<<<
 *             if root.isConjunction():
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("ConjunctionRoot"))
 */
      if (unlikely(__pyx_v_fsmParse == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
        __PYX_ERR(0, 452, __pyx_L1_error)
      }
      __pyx_t_9 = __Pyx_PyList_Append(__pyx_v_fsmParse, ((PyObject *)__pyx_v_currentFsmParse)); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 452, __pyx_L1_error)

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":450
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("QuestionRoot"))
 *                 fsmParse.append(currentFsmParse)
 *             if root.isDeterminer():             # <<<<<<<<<<<<<<
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("DeterminerRoot"))
 *                 fsmParse.append(currentFsmParse)
 */
    }

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":453
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("DeterminerRoot"))
 *                 fsmParse.append(currentFsmParse)
 *             if root.isConjunction():             # <<<<<<<<<<<<<<
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("ConjunctionRoot"))
 *                 fsmParse.append(currentFsmParse)
 */
    __pyx_t_8 = (((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->isConjunction(__pyx_v_root, 0) != 0);
    if (__pyx_t_8) {

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":454
 *                 fsmParse.append(currentFsmParse)
 *             if root.isConjunction():
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("ConjunctionRoot"))             # <<<<<<<<<<<<<<
 *                 fsmParse.append(currentFsmParse)
 *             if root.isPostP():
 */
      __pyx_t_4 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine *)__pyx_v_self->__pyx___finiteStateMachine->__pyx_vtab)->getState(__pyx_v_self->__pyx___finiteStateMachine, __pyx_n_u_ConjunctionRoot, 0)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 454, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 454, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_INCREF(((PyObject *)__pyx_v_root));
      __Pyx_GIVEREF(((PyObject *)__pyx_v_root));
      PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_v_root));
      __Pyx_GIVEREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_4);
      __pyx_t_4 = 0;
      __pyx_t_4 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse), __pyx_t_2, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 454, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF_SET(__pyx_v_currentFsmParse, ((struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_t_4));
      __pyx_t_4 = 0;

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":455
 *             if root.isConjunction():
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("ConjunctionRoot"))
 *                 fsmParse.append(currentFsmParse)             # <<<<<<<<<<<<<<
 *             if root.isPostP():
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("PostP"))
 */
      if (unlikely(__pyx_v_fsmParse == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
        __PYX_ERR(0, 455, __pyx_L1_error)
      }
      __pyx_t_9 = __Pyx_PyList_Append(__pyx_v_fsmParse, ((PyObject *)__pyx_v_currentFsmParse)); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 455, __pyx_L1_error)

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":453
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("DeterminerRoot"))
 *                 fsmParse.append(currentFsmParse)
 *             if root.isConjunction():             # <<<<<<<<<<<<<<
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("ConjunctionRoot"))
 *                 fsmParse.append(currentFsmParse)
 */
    }

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":456
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("ConjunctionRoot"))
 *                 fsmParse.append(currentFsmParse)
 *             if root.isPostP():             # <<<<<<<<<<<<<<
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("PostP"))
 *                 fsmParse.append(currentFsmParse)
 */
    __pyx_t_8 = (((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->isPostP(__pyx_v_root, 0) != 0);
    if (__pyx_t_8) {

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":457
 *                 fsmParse.append(currentFsmParse)
 *             if root.isPostP():
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("PostP"))             # <<<<<<<<<<<<<<
 *                 fsmParse.append(currentFsmParse)
 *             if root.isAdverb():
 */
      __pyx_t_4 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine *)__pyx_v_self->__pyx___finiteStateMachine->__pyx_vtab)->getState(__pyx_v_self->__pyx___finiteStateMachine, __pyx_n_u_PostP, 0)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 457, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 457, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_INCREF(((PyObject *)__pyx_v_root));
      __Pyx_GIVEREF(((PyObject *)__pyx_v_root));
      PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_v_root));
      __Pyx_GIVEREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_4);
      __pyx_t_4 = 0;
      __pyx_t_4 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse), __pyx_t_2, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 457, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF_SET(__pyx_v_currentFsmParse, ((struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_t_4));
      __pyx_t_4 = 0;

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":458
 *             if root.isPostP():
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("PostP"))
 *                 fsmParse.append(currentFsmParse)             # <<<<<<<<<<<<<<
 *             if root.isAdverb():
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("AdverbRoot"))
 */
      if (unlikely(__pyx_v_fsmParse == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
        __PYX_ERR(0, 458, __pyx_L1_error)
      }
      __pyx_t_9 = __Pyx_PyList_Append(__pyx_v_fsmParse, ((PyObject *)__pyx_v_currentFsmParse)); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 458, __pyx_L1_error)

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":456
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("ConjunctionRoot"))
 *                 fsmParse.append(currentFsmParse)
 *             if root.isPostP():             # <<<<<<<<<<<<<<
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("PostP"))
 *                 fsmParse.append(currentFsmParse)
 */
    }

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":459
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("PostP"))
 *                 fsmParse.append(currentFsmParse)
 *             if root.isAdverb():             # <<<<<<<<<<<<<<
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("AdverbRoot"))
 *                 fsmParse.append(currentFsmParse)
 */
    __pyx_t_8 = (((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->isAdverb(__pyx_v_root, 0) != 0);
    if (__pyx_t_8) {

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":460
 *                 fsmParse.append(currentFsmParse)
 *             if root.isAdverb():
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("AdverbRoot"))             # <<<<<<<<<<<<<<
 *                 fsmParse.append(currentFsmParse)
 * 
 */
      __pyx_t_4 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine *)__pyx_v_self->__pyx___finiteStateMachine->__pyx_vtab)->getState(__pyx_v_self->__pyx___finiteStateMachine, __pyx_n_u_AdverbRoot, 0)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 460, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 460, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_INCREF(((PyObject *)__pyx_v_root));
      __Pyx_GIVEREF(((PyObject *)__pyx_v_root));
      PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_v_root));
      __Pyx_GIVEREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_4);
      __pyx_t_4 = 0;
      __pyx_t_4 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse), __pyx_t_2, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 460, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF_SET(__pyx_v_currentFsmParse, ((struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_t_4));
      __pyx_t_4 = 0;

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":461
 *             if root.isAdverb():
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("AdverbRoot"))
 *                 fsmParse.append(currentFsmParse)             # <<<<<<<<<<<<<<
 * 
 *     cpdef __initializeParseListFromRoot(self, list parseList, TxtWord root, bint isProper):
 */
      if (unlikely(__pyx_v_fsmParse == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
        __PYX_ERR(0, 461, __pyx_L1_error)
      }
      __pyx_t_9 = __Pyx_PyList_Append(__pyx_v_fsmParse, ((PyObject *)__pyx_v_currentFsmParse)); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 461, __pyx_L1_error)

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":459
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("PostP"))
 *                 fsmParse.append(currentFsmParse)
 *             if root.isAdverb():             # <<<<<<<<<<<<<<
 *                 currentFsmParse = FsmParse(root, self.__finiteStateMachine.getState("AdverbRoot"))
 *                 fsmParse.append(currentFsmParse)
 */
    }
  }
  __pyx_L3:;

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":204
 *             return distance <= self.MAX_DISTANCE - 2
 * 
 *     cpdef __initializeParseList(self, list fsmParse, TxtWord root, bint isProper):             # <<<<<<<<<<<<<<
 *         """
 *         The initializeParseList method initializes the given given fsm ArrayList with given root words by parsing them.
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("MorphologicalAnalysis.FsmMorphologicalAnalyzer.FsmMorphologicalAnalyzer.__initializeParseList", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_currentFsmParse);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_13__initializeParseList(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_12__initializeParseList[] = "\n        The initializeParseList method initializes the given given fsm ArrayList with given root words by parsing them.\n\n        It checks many conditions;\n        isPlural; if root holds the condition then it gets the state with the name of NominalRootPlural, then\n        creates a new parsing and adds this to the input fsmParse Arraylist.\n        Ex : A\303\247\304\261ktohumlular\n\n        !isPlural and isPortmanteauEndingWithSI, if root holds the conditions then it gets the state with the\n        name of NominalRootNoPossesive.\n        Ex : Balar\304\261s\304\261\n\n        !isPlural and isPortmanteau, if root holds the conditions then it gets the state with the name of\n        CompoundNounRoot.\n        Ex : Aslana\304\237\304\261z\304\261\n\n        !isPlural, !isPortmanteau and isHeader, if root holds the conditions then it gets the state with the\n        name of HeaderRoot.\n        Ex :  </title>\n\n        !isPlural, !isPortmanteau and isInterjection, if root holds the conditions then it gets the state\n        with the name of InterjectionRoot.\n        Ex : Hey, Aa\n\n        !isPlural, !isPortmanteau and isDuplicate, if root holds the conditions then it gets the state\n        with the name of DuplicateRoot.\n\n        !isPlural, !isPortmanteau and isNumeral, if root holds the conditions then it gets the state\n        with the name of CardinalRoot.\n\n        !isPlural, !isPortmanteau and isReal, if root holds the conditions then it gets the state\n        with the name of RealRoot.\n\n        !isPlural, !isPortmanteau and isFraction, if root holds the conditions then it gets the state\n        with the name of FractionRoot.\n        Ex : 1/2\n\n        !isPlural, !isPortmanteau and isDate, if root holds the conditions then it gets the state\n        with the name of DateRoot.\n        Ex : 11/06/2018\n\n        !isPlural, !isPortmanteau and isPercent, if root holds the conditions then it gets the state\n        with the name of PercentRoot.""\n        Ex : %12.5\n\n        !isPlural, !isPortmanteau and isRange, if root holds the conditions then it gets the state\n        with the name of RangeRoot.\n        Ex : 3-5\n\n        !isPlural, !isPortmanteau and isTime, if root holds the conditions then it gets the state\n        with the name of TimeRoot.\n        Ex : 13:16:08\n\n        !isPlural, !isPortmanteau and isOrdinal, if root holds the conditions then it gets the state\n        with the name of OrdinalRoot.\n        Ex : Alt\304\261nc\304\261\n\n        !isPlural, !isPortmanteau, and isVerb if root holds the conditions then it gets the state\n        with the name of VerbalRoot. Or isPassive, then it gets the state with the name of PassiveHn.\n        Ex : Anla (!isPAssive)\n        Ex : \303\207a\304\237r\304\261l (isPassive)\n\n        !isPlural, !isPortmanteau and isPronoun, if root holds the conditions then it gets the state\n        with the name of PronounRoot. There are 6 different Pronoun state names, REFLEX, QUANT, QUANTPLURAL, DEMONS,\n        PERS, QUES.\n        REFLEX = Reflexive Pronouns Ex : kendi\n        QUANT = Quantitative Pronouns Ex : \303\266b\303\274r, hep, kimse, hi\303\247biri, baz\304\261, kimi, biri\n        QUANTPLURAL = Quantitative Plural Pronouns Ex : t\303\274m\303\274, \303\247o\304\237u, hepsi\n        DEMONS = Demonstrative Pronouns Ex : o, bu, \305\237u\n        PERS = Personal Pronouns Ex : ben, sen, o, biz, siz, onlar\n        QUES = Interrogat\304\261ve Pronouns Ex : nere, ne, kim, hangi\n\n        !isPlural, !isPortmanteau and isAdjective, if root holds the conditions then it gets the state\n        with the name of AdjectiveRoot.\n        Ex : Abs\303\274rt, Abes\n\n        !isPlural, !isPortmanteau and isPureAdjective, if root holds the conditions then it gets the state\n        with the name of Adjective.\n        Ex : Ge\303\247mi\305\237, Cam\n\n        !isPlural, !isPortmanteau and isNominal, if root holds the conditions then it gets the state\n       "" with the name of NominalRoot.\n        Ex : G\303\266r\303\274\305\237\n\n        !isPlural, !isPortmanteau and isProper, if root holds the conditions then it gets the state\n        with the name of ProperRoot.\n        Ex : Abdi\n\n        !isPlural, !isPortmanteau and isQuestion, if root holds the conditions then it gets the state\n        with the name of QuestionRoot.\n        Ex : Mi, m\303\274\n\n        !isPlural, !isPortmanteau and isDeterminer, if root holds the conditions then it gets the state\n        with the name of DeterminerRoot.\n        Ex : \303\207ok, bir\n\n        !isPlural, !isPortmanteau and isConjunction, if root holds the conditions then it gets the state\n        with the name of ConjunctionRoot.\n        Ex : Ama , ancak\n\n        !isPlural, !isPortmanteau and isPostP, if root holds the conditions then it gets the state\n        with the name of PostP.\n        Ex : Ait, dair\n\n        !isPlural, !isPortmanteau and isAdverb, if root holds the conditions then it gets the state\n        with the name of AdverbRoot.\n        Ex : Acilen\n\n        PARAMETERS\n        ----------\n        fsmParse : list\n            list to initialize.\n        root : TxtWord\n            word to check properties and add to fsmParse according to them.\n        isProper : bool\n            is used to check a word is proper or not.\n        ";
static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_13__initializeParseList(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_fsmParse = 0;
  struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_root = 0;
  int __pyx_v_isProper;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__initializeParseList (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_fsmParse,&__pyx_n_s_root,&__pyx_n_s_isProper,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_fsmParse)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_root)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__initializeParseList", 1, 3, 3, 1); __PYX_ERR(0, 204, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_isProper)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__initializeParseList", 1, 3, 3, 2); __PYX_ERR(0, 204, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__initializeParseList") < 0)) __PYX_ERR(0, 204, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_fsmParse = ((PyObject*)values[0]);
    __pyx_v_root = ((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)values[1]);
    __pyx_v_isProper = __Pyx_PyObject_IsTrue(values[2]); if (unlikely((__pyx_v_isProper == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 204, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__initializeParseList", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 204, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("MorphologicalAnalysis.FsmMorphologicalAnalyzer.FsmMorphologicalAnalyzer.__initializeParseList", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_fsmParse), (&PyList_Type), 1, "fsmParse", 1))) __PYX_ERR(0, 204, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_root), __pyx_ptype_10Dictionary_7TxtWord_TxtWord, 1, "root", 0))) __PYX_ERR(0, 204, __pyx_L1_error)
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_12__initializeParseList(((struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self), __pyx_v_fsmParse, __pyx_v_root, __pyx_v_isProper);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_12__initializeParseList(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_fsmParse, struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_root, int __pyx_v_isProper) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__initializeParseList", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer___initializeParseList(__pyx_v_self, __pyx_v_fsmParse, __pyx_v_root, __pyx_v_isProper, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 204, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.FsmMorphologicalAnalyzer.FsmMorphologicalAnalyzer.__initializeParseList", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":463
 *                 fsmParse.append(currentFsmParse)
 * 
 *     cpdef __initializeParseListFromRoot(self, list parseList, TxtWord root, bint isProper):             # <<<<<<<<<<<<<<
 *         """
 *         The initializeParseListFromRoot method is used to create a list which consists of initial fsm parsings. First,
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_15__initializeParseListFromRoot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer___initializeParseListFromRoot(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_parseList, struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_root, int __pyx_v_isProper, int __pyx_skip_dispatch) {
  struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_newRoot = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__initializeParseListFromRoot", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_initializeParseListFromRoot); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 463, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_15__initializeParseListFromRoot)) {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = __Pyx_PyBool_FromLong(__pyx_v_isProper); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 463, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; __pyx_t_5 = NULL;
        __pyx_t_6 = 0;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
          if (likely(__pyx_t_5)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
            __Pyx_INCREF(__pyx_t_5);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_4, function);
            __pyx_t_6 = 1;
          }
        }
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_4)) {
          PyObject *__pyx_temp[4] = {__pyx_t_5, __pyx_v_parseList, ((PyObject *)__pyx_v_root), __pyx_t_3};
          __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_6, 3+__pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 463, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
          PyObject *__pyx_temp[4] = {__pyx_t_5, __pyx_v_parseList, ((PyObject *)__pyx_v_root), __pyx_t_3};
          __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_6, 3+__pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 463, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        } else
        #endif
        {
          __pyx_t_7 = PyTuple_New(3+__pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 463, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          if (__pyx_t_5) {
            __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5); __pyx_t_5 = NULL;
          }
          __Pyx_INCREF(__pyx_v_parseList);
          __Pyx_GIVEREF(__pyx_v_parseList);
          PyTuple_SET_ITEM(__pyx_t_7, 0+__pyx_t_6, __pyx_v_parseList);
          __Pyx_INCREF(((PyObject *)__pyx_v_root));
          __Pyx_GIVEREF(((PyObject *)__pyx_v_root));
          PyTuple_SET_ITEM(__pyx_t_7, 1+__pyx_t_6, ((PyObject *)__pyx_v_root));
          __Pyx_GIVEREF(__pyx_t_3);
          PyTuple_SET_ITEM(__pyx_t_7, 2+__pyx_t_6, __pyx_t_3);
          __pyx_t_3 = 0;
          __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_7, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 463, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        }
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":479
 *         """
 *         cdef TxtWord newRoot
 *         self.__initializeParseList(parseList, root, isProper)             # <<<<<<<<<<<<<<
 *         if root.obeysAndNotObeysVowelHarmonyDuringAgglutination():
 *             newRoot = copy.deepcopy(root)
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->__pyx___initializeParseList(__pyx_v_self, __pyx_v_parseList, __pyx_v_root, __pyx_v_isProper, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 479, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":480
 *         cdef TxtWord newRoot
 *         self.__initializeParseList(parseList, root, isProper)
 *         if root.obeysAndNotObeysVowelHarmonyDuringAgglutination():             # <<<<<<<<<<<<<<
 *             newRoot = copy.deepcopy(root)
 *             newRoot.removeFlag("IS_UU")
 */
  __pyx_t_8 = (((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->obeysAndNotObeysVowelHarmonyDuringAgglutination(__pyx_v_root, 0) != 0);
  if (__pyx_t_8) {

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":481
 *         self.__initializeParseList(parseList, root, isProper)
 *         if root.obeysAndNotObeysVowelHarmonyDuringAgglutination():
 *             newRoot = copy.deepcopy(root)             # <<<<<<<<<<<<<<
 *             newRoot.removeFlag("IS_UU")
 *             newRoot.removeFlag("IS_UUU")
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_copy); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 481, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_deepcopy); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 481, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    __pyx_t_1 = (__pyx_t_2) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_2, ((PyObject *)__pyx_v_root)) : __Pyx_PyObject_CallOneArg(__pyx_t_4, ((PyObject *)__pyx_v_root));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 481, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_10Dictionary_7TxtWord_TxtWord))))) __PYX_ERR(0, 481, __pyx_L1_error)
    __pyx_v_newRoot = ((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":482
 *         if root.obeysAndNotObeysVowelHarmonyDuringAgglutination():
 *             newRoot = copy.deepcopy(root)
 *             newRoot.removeFlag("IS_UU")             # <<<<<<<<<<<<<<
 *             newRoot.removeFlag("IS_UUU")
 *             self.__initializeParseList(parseList, newRoot, isProper)
 */
    __pyx_t_1 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_newRoot->__pyx_base.__pyx_vtab)->removeFlag(__pyx_v_newRoot, __pyx_n_u_IS_UU, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 482, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":483
 *             newRoot = copy.deepcopy(root)
 *             newRoot.removeFlag("IS_UU")
 *             newRoot.removeFlag("IS_UUU")             # <<<<<<<<<<<<<<
 *             self.__initializeParseList(parseList, newRoot, isProper)
 *         if root.rootSoftenAndNotSoftenDuringSuffixation():
 */
    __pyx_t_1 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_newRoot->__pyx_base.__pyx_vtab)->removeFlag(__pyx_v_newRoot, __pyx_n_u_IS_UUU, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 483, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":484
 *             newRoot.removeFlag("IS_UU")
 *             newRoot.removeFlag("IS_UUU")
 *             self.__initializeParseList(parseList, newRoot, isProper)             # <<<<<<<<<<<<<<
 *         if root.rootSoftenAndNotSoftenDuringSuffixation():
 *             newRoot = copy.deepcopy(root)
 */
    __pyx_t_1 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->__pyx___initializeParseList(__pyx_v_self, __pyx_v_parseList, __pyx_v_newRoot, __pyx_v_isProper, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 484, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":480
 *         cdef TxtWord newRoot
 *         self.__initializeParseList(parseList, root, isProper)
 *         if root.obeysAndNotObeysVowelHarmonyDuringAgglutination():             # <<<<<<<<<<<<<<
 *             newRoot = copy.deepcopy(root)
 *             newRoot.removeFlag("IS_UU")
 */
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":485
 *             newRoot.removeFlag("IS_UUU")
 *             self.__initializeParseList(parseList, newRoot, isProper)
 *         if root.rootSoftenAndNotSoftenDuringSuffixation():             # <<<<<<<<<<<<<<
 *             newRoot = copy.deepcopy(root)
 *             newRoot.removeFlag("IS_SD")
 */
  __pyx_t_8 = (((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->rootSoftenAndNotSoftenDuringSuffixation(__pyx_v_root, 0) != 0);
  if (__pyx_t_8) {

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":486
 *             self.__initializeParseList(parseList, newRoot, isProper)
 *         if root.rootSoftenAndNotSoftenDuringSuffixation():
 *             newRoot = copy.deepcopy(root)             # <<<<<<<<<<<<<<
 *             newRoot.removeFlag("IS_SD")
 *             newRoot.removeFlag("IS_SDD")
 */
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_copy); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 486, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_deepcopy); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 486, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
      }
    }
    __pyx_t_1 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_4, ((PyObject *)__pyx_v_root)) : __Pyx_PyObject_CallOneArg(__pyx_t_2, ((PyObject *)__pyx_v_root));
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 486, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_10Dictionary_7TxtWord_TxtWord))))) __PYX_ERR(0, 486, __pyx_L1_error)
    __Pyx_XDECREF_SET(__pyx_v_newRoot, ((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)__pyx_t_1));
    __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":487
 *         if root.rootSoftenAndNotSoftenDuringSuffixation():
 *             newRoot = copy.deepcopy(root)
 *             newRoot.removeFlag("IS_SD")             # <<<<<<<<<<<<<<
 *             newRoot.removeFlag("IS_SDD")
 *             self.__initializeParseList(parseList, newRoot, isProper)
 */
    __pyx_t_1 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_newRoot->__pyx_base.__pyx_vtab)->removeFlag(__pyx_v_newRoot, __pyx_n_u_IS_SD, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 487, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":488
 *             newRoot = copy.deepcopy(root)
 *             newRoot.removeFlag("IS_SD")
 *             newRoot.removeFlag("IS_SDD")             # <<<<<<<<<<<<<<
 *             self.__initializeParseList(parseList, newRoot, isProper)
 *         if root.lastIDropsAndNotDropDuringSuffixation():
 */
    __pyx_t_1 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_newRoot->__pyx_base.__pyx_vtab)->removeFlag(__pyx_v_newRoot, __pyx_n_u_IS_SDD, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 488, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":489
 *             newRoot.removeFlag("IS_SD")
 *             newRoot.removeFlag("IS_SDD")
 *             self.__initializeParseList(parseList, newRoot, isProper)             # <<<<<<<<<<<<<<
 *         if root.lastIDropsAndNotDropDuringSuffixation():
 *             newRoot = copy.deepcopy(root)
 */
    __pyx_t_1 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->__pyx___initializeParseList(__pyx_v_self, __pyx_v_parseList, __pyx_v_newRoot, __pyx_v_isProper, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 489, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":485
 *             newRoot.removeFlag("IS_UUU")
 *             self.__initializeParseList(parseList, newRoot, isProper)
 *         if root.rootSoftenAndNotSoftenDuringSuffixation():             # <<<<<<<<<<<<<<
 *             newRoot = copy.deepcopy(root)
 *             newRoot.removeFlag("IS_SD")
 */
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":490
 *             newRoot.removeFlag("IS_SDD")
 *             self.__initializeParseList(parseList, newRoot, isProper)
 *         if root.lastIDropsAndNotDropDuringSuffixation():             # <<<<<<<<<<<<<<
 *             newRoot = copy.deepcopy(root)
 *             newRoot.removeFlag("IS_UD")
 */
  __pyx_t_8 = (((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->lastIDropsAndNotDropDuringSuffixation(__pyx_v_root, 0) != 0);
  if (__pyx_t_8) {

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":491
 *             self.__initializeParseList(parseList, newRoot, isProper)
 *         if root.lastIDropsAndNotDropDuringSuffixation():
 *             newRoot = copy.deepcopy(root)             # <<<<<<<<<<<<<<
 *             newRoot.removeFlag("IS_UD")
 *             newRoot.removeFlag("IS_UDD")
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_copy); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 491, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_deepcopy); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 491, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    __pyx_t_1 = (__pyx_t_2) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_2, ((PyObject *)__pyx_v_root)) : __Pyx_PyObject_CallOneArg(__pyx_t_4, ((PyObject *)__pyx_v_root));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 491, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_10Dictionary_7TxtWord_TxtWord))))) __PYX_ERR(0, 491, __pyx_L1_error)
    __Pyx_XDECREF_SET(__pyx_v_newRoot, ((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)__pyx_t_1));
    __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":492
 *         if root.lastIDropsAndNotDropDuringSuffixation():
 *             newRoot = copy.deepcopy(root)
 *             newRoot.removeFlag("IS_UD")             # <<<<<<<<<<<<<<
 *             newRoot.removeFlag("IS_UDD")
 *             self.__initializeParseList(parseList, newRoot, isProper)
 */
    __pyx_t_1 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_newRoot->__pyx_base.__pyx_vtab)->removeFlag(__pyx_v_newRoot, __pyx_n_u_IS_UD, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 492, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":493
 *             newRoot = copy.deepcopy(root)
 *             newRoot.removeFlag("IS_UD")
 *             newRoot.removeFlag("IS_UDD")             # <<<<<<<<<<<<<<
 *             self.__initializeParseList(parseList, newRoot, isProper)
 *         if root.duplicatesAndNotDuplicatesDuringSuffixation():
 */
    __pyx_t_1 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_newRoot->__pyx_base.__pyx_vtab)->removeFlag(__pyx_v_newRoot, __pyx_n_u_IS_UDD, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 493, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":494
 *             newRoot.removeFlag("IS_UD")
 *             newRoot.removeFlag("IS_UDD")
 *             self.__initializeParseList(parseList, newRoot, isProper)             # <<<<<<<<<<<<<<
 *         if root.duplicatesAndNotDuplicatesDuringSuffixation():
 *             newRoot = copy.deepcopy(root)
 */
    __pyx_t_1 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->__pyx___initializeParseList(__pyx_v_self, __pyx_v_parseList, __pyx_v_newRoot, __pyx_v_isProper, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 494, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":490
 *             newRoot.removeFlag("IS_SDD")
 *             self.__initializeParseList(parseList, newRoot, isProper)
 *         if root.lastIDropsAndNotDropDuringSuffixation():             # <<<<<<<<<<<<<<
 *             newRoot = copy.deepcopy(root)
 *             newRoot.removeFlag("IS_UD")
 */
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":495
 *             newRoot.removeFlag("IS_UDD")
 *             self.__initializeParseList(parseList, newRoot, isProper)
 *         if root.duplicatesAndNotDuplicatesDuringSuffixation():             # <<<<<<<<<<<<<<
 *             newRoot = copy.deepcopy(root)
 *             newRoot.removeFlag("IS_ST")
 */
  __pyx_t_8 = (((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->duplicatesAndNotDuplicatesDuringSuffixation(__pyx_v_root, 0) != 0);
  if (__pyx_t_8) {

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":496
 *             self.__initializeParseList(parseList, newRoot, isProper)
 *         if root.duplicatesAndNotDuplicatesDuringSuffixation():
 *             newRoot = copy.deepcopy(root)             # <<<<<<<<<<<<<<
 *             newRoot.removeFlag("IS_ST")
 *             newRoot.removeFlag("IS_STT")
 */
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_copy); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 496, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_deepcopy); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 496, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
      }
    }
    __pyx_t_1 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_4, ((PyObject *)__pyx_v_root)) : __Pyx_PyObject_CallOneArg(__pyx_t_2, ((PyObject *)__pyx_v_root));
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 496, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_10Dictionary_7TxtWord_TxtWord))))) __PYX_ERR(0, 496, __pyx_L1_error)
    __Pyx_XDECREF_SET(__pyx_v_newRoot, ((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)__pyx_t_1));
    __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":497
 *         if root.duplicatesAndNotDuplicatesDuringSuffixation():
 *             newRoot = copy.deepcopy(root)
 *             newRoot.removeFlag("IS_ST")             # <<<<<<<<<<<<<<
 *             newRoot.removeFlag("IS_STT")
 *             self.__initializeParseList(parseList, newRoot, isProper)
 */
    __pyx_t_1 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_newRoot->__pyx_base.__pyx_vtab)->removeFlag(__pyx_v_newRoot, __pyx_n_u_IS_ST, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 497, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":498
 *             newRoot = copy.deepcopy(root)
 *             newRoot.removeFlag("IS_ST")
 *             newRoot.removeFlag("IS_STT")             # <<<<<<<<<<<<<<
 *             self.__initializeParseList(parseList, newRoot, isProper)
 *         if root.endingKChangesIntoG() and root.containsFlag("IS_OA"):
 */
    __pyx_t_1 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_newRoot->__pyx_base.__pyx_vtab)->removeFlag(__pyx_v_newRoot, __pyx_n_u_IS_STT, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 498, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":499
 *             newRoot.removeFlag("IS_ST")
 *             newRoot.removeFlag("IS_STT")
 *             self.__initializeParseList(parseList, newRoot, isProper)             # <<<<<<<<<<<<<<
 *         if root.endingKChangesIntoG() and root.containsFlag("IS_OA"):
 *             newRoot = copy.deepcopy(root)
 */
    __pyx_t_1 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->__pyx___initializeParseList(__pyx_v_self, __pyx_v_parseList, __pyx_v_newRoot, __pyx_v_isProper, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 499, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":495
 *             newRoot.removeFlag("IS_UDD")
 *             self.__initializeParseList(parseList, newRoot, isProper)
 *         if root.duplicatesAndNotDuplicatesDuringSuffixation():             # <<<<<<<<<<<<<<
 *             newRoot = copy.deepcopy(root)
 *             newRoot.removeFlag("IS_ST")
 */
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":500
 *             newRoot.removeFlag("IS_STT")
 *             self.__initializeParseList(parseList, newRoot, isProper)
 *         if root.endingKChangesIntoG() and root.containsFlag("IS_OA"):             # <<<<<<<<<<<<<<
 *             newRoot = copy.deepcopy(root)
 *             newRoot.removeFlag("IS_OA")
 */
  __pyx_t_9 = (((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->endingKChangesIntoG(__pyx_v_root, 0) != 0);
  if (__pyx_t_9) {
  } else {
    __pyx_t_8 = __pyx_t_9;
    goto __pyx_L8_bool_binop_done;
  }
  __pyx_t_9 = (((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->containsFlag(__pyx_v_root, __pyx_n_u_IS_OA, 0) != 0);
  __pyx_t_8 = __pyx_t_9;
  __pyx_L8_bool_binop_done:;
  if (__pyx_t_8) {

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":501
 *             self.__initializeParseList(parseList, newRoot, isProper)
 *         if root.endingKChangesIntoG() and root.containsFlag("IS_OA"):
 *             newRoot = copy.deepcopy(root)             # <<<<<<<<<<<<<<
 *             newRoot.removeFlag("IS_OA")
 *             self.__initializeParseList(parseList, newRoot, isProper)
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_copy); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 501, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_deepcopy); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 501, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    __pyx_t_1 = (__pyx_t_2) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_2, ((PyObject *)__pyx_v_root)) : __Pyx_PyObject_CallOneArg(__pyx_t_4, ((PyObject *)__pyx_v_root));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 501, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_10Dictionary_7TxtWord_TxtWord))))) __PYX_ERR(0, 501, __pyx_L1_error)
    __Pyx_XDECREF_SET(__pyx_v_newRoot, ((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)__pyx_t_1));
    __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":502
 *         if root.endingKChangesIntoG() and root.containsFlag("IS_OA"):
 *             newRoot = copy.deepcopy(root)
 *             newRoot.removeFlag("IS_OA")             # <<<<<<<<<<<<<<
 *             self.__initializeParseList(parseList, newRoot, isProper)
 * 
 */
    __pyx_t_1 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_newRoot->__pyx_base.__pyx_vtab)->removeFlag(__pyx_v_newRoot, __pyx_n_u_IS_OA, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 502, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":503
 *             newRoot = copy.deepcopy(root)
 *             newRoot.removeFlag("IS_OA")
 *             self.__initializeParseList(parseList, newRoot, isProper)             # <<<<<<<<<<<<<<
 * 
 *     cpdef list __initializeParseListFromSurfaceForm(self, str surfaceForm, bint isProper):
 */
    __pyx_t_1 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->__pyx___initializeParseList(__pyx_v_self, __pyx_v_parseList, __pyx_v_newRoot, __pyx_v_isProper, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 503, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":500
 *             newRoot.removeFlag("IS_STT")
 *             self.__initializeParseList(parseList, newRoot, isProper)
 *         if root.endingKChangesIntoG() and root.containsFlag("IS_OA"):             # <<<<<<<<<<<<<<
 *             newRoot = copy.deepcopy(root)
 *             newRoot.removeFlag("IS_OA")
 */
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":463
 *                 fsmParse.append(currentFsmParse)
 * 
 *     cpdef __initializeParseListFromRoot(self, list parseList, TxtWord root, bint isProper):             # <<<<<<<<<<<<<<
 *         """
 *         The initializeParseListFromRoot method is used to create a list which consists of initial fsm parsings. First,
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("MorphologicalAnalysis.FsmMorphologicalAnalyzer.FsmMorphologicalAnalyzer.__initializeParseListFromRoot", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_newRoot);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_15__initializeParseListFromRoot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_14__initializeParseListFromRoot[] = "\n        The initializeParseListFromRoot method is used to create a list which consists of initial fsm parsings. First,\n        traverses this HashSet and uses each word as a root and calls initializeParseList method with this root and\n        list.\n\n        PARAMETERS\n        ----------\n        parseList : list\n            list to initialize.\n        root : TxtWord\n            the root form to generate initial parse list.\n        isProper : bool\n            is used to check a word is proper or not.\n        ";
static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_15__initializeParseListFromRoot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_parseList = 0;
  struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_root = 0;
  int __pyx_v_isProper;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__initializeParseListFromRoot (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_parseList,&__pyx_n_s_root,&__pyx_n_s_isProper,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_parseList)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_root)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__initializeParseListFromRoot", 1, 3, 3, 1); __PYX_ERR(0, 463, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_isProper)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__initializeParseListFromRoot", 1, 3, 3, 2); __PYX_ERR(0, 463, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__initializeParseListFromRoot") < 0)) __PYX_ERR(0, 463, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_parseList = ((PyObject*)values[0]);
    __pyx_v_root = ((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)values[1]);
    __pyx_v_isProper = __Pyx_PyObject_IsTrue(values[2]); if (unlikely((__pyx_v_isProper == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 463, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__initializeParseListFromRoot", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 463, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("MorphologicalAnalysis.FsmMorphologicalAnalyzer.FsmMorphologicalAnalyzer.__initializeParseListFromRoot", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_parseList), (&PyList_Type), 1, "parseList", 1))) __PYX_ERR(0, 463, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_root), __pyx_ptype_10Dictionary_7TxtWord_TxtWord, 1, "root", 0))) __PYX_ERR(0, 463, __pyx_L1_error)
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_14__initializeParseListFromRoot(((struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self), __pyx_v_parseList, __pyx_v_root, __pyx_v_isProper);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_14__initializeParseListFromRoot(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_parseList, struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_root, int __pyx_v_isProper) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__initializeParseListFromRoot", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer___initializeParseListFromRoot(__pyx_v_self, __pyx_v_parseList, __pyx_v_root, __pyx_v_isProper, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 463, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.FsmMorphologicalAnalyzer.FsmMorphologicalAnalyzer.__initializeParseListFromRoot", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":505
 *             self.__initializeParseList(parseList, newRoot, isProper)
 * 
 *     cpdef list __initializeParseListFromSurfaceForm(self, str surfaceForm, bint isProper):             # <<<<<<<<<<<<<<
 *         """
 *         The initializeParseListFromSurfaceForm method is used to create a list which consists of initial fsm parsings.
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_17__initializeParseListFromSurfaceForm(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer___initializeParseListFromSurfaceForm(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_surfaceForm, int __pyx_v_isProper, int __pyx_skip_dispatch) {
  PyObject *__pyx_v_initialFsmParse = 0;
  PyObject *__pyx_v_words = 0;
  struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_word = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  Py_ssize_t __pyx_t_8;
  int __pyx_t_9;
  Py_ssize_t __pyx_t_10;
  int __pyx_t_11;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__initializeParseListFromSurfaceForm", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_initializeParseListFromSurface); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 505, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_17__initializeParseListFromSurfaceForm)) {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = __Pyx_PyBool_FromLong(__pyx_v_isProper); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 505, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; __pyx_t_5 = NULL;
        __pyx_t_6 = 0;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
          if (likely(__pyx_t_5)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
            __Pyx_INCREF(__pyx_t_5);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_4, function);
            __pyx_t_6 = 1;
          }
        }
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_4)) {
          PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_v_surfaceForm, __pyx_t_3};
          __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 505, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
          PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_v_surfaceForm, __pyx_t_3};
          __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 505, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        } else
        #endif
        {
          __pyx_t_7 = PyTuple_New(2+__pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 505, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          if (__pyx_t_5) {
            __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5); __pyx_t_5 = NULL;
          }
          __Pyx_INCREF(__pyx_v_surfaceForm);
          __Pyx_GIVEREF(__pyx_v_surfaceForm);
          PyTuple_SET_ITEM(__pyx_t_7, 0+__pyx_t_6, __pyx_v_surfaceForm);
          __Pyx_GIVEREF(__pyx_t_3);
          PyTuple_SET_ITEM(__pyx_t_7, 1+__pyx_t_6, __pyx_t_3);
          __pyx_t_3 = 0;
          __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_7, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 505, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        }
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (!(likely(PyList_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "list", Py_TYPE(__pyx_t_2)->tp_name), 0))) __PYX_ERR(0, 505, __pyx_L1_error)
        __pyx_r = ((PyObject*)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":527
 *         cdef set words
 *         cdef TxtWord word
 *         initialFsmParse = []             # <<<<<<<<<<<<<<
 *         if len(surfaceForm) == 0:
 *             return initialFsmParse
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 527, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_initialFsmParse = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":528
 *         cdef TxtWord word
 *         initialFsmParse = []
 *         if len(surfaceForm) == 0:             # <<<<<<<<<<<<<<
 *             return initialFsmParse
 *         words = self.__dictionaryTrie.getWordsWithPrefix(surfaceForm)
 */
  if (unlikely(__pyx_v_surfaceForm == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(0, 528, __pyx_L1_error)
  }
  __pyx_t_8 = __Pyx_PyUnicode_GET_LENGTH(__pyx_v_surfaceForm); if (unlikely(__pyx_t_8 == ((Py_ssize_t)-1))) __PYX_ERR(0, 528, __pyx_L1_error)
  __pyx_t_9 = ((__pyx_t_8 == 0) != 0);
  if (__pyx_t_9) {

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":529
 *         initialFsmParse = []
 *         if len(surfaceForm) == 0:
 *             return initialFsmParse             # <<<<<<<<<<<<<<
 *         words = self.__dictionaryTrie.getWordsWithPrefix(surfaceForm)
 *         for word in words:
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_initialFsmParse);
    __pyx_r = __pyx_v_initialFsmParse;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":528
 *         cdef TxtWord word
 *         initialFsmParse = []
 *         if len(surfaceForm) == 0:             # <<<<<<<<<<<<<<
 *             return initialFsmParse
 *         words = self.__dictionaryTrie.getWordsWithPrefix(surfaceForm)
 */
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":530
 *         if len(surfaceForm) == 0:
 *             return initialFsmParse
 *         words = self.__dictionaryTrie.getWordsWithPrefix(surfaceForm)             # <<<<<<<<<<<<<<
 *         for word in words:
 *             self.__initializeParseListFromRoot(initialFsmParse, word, isProper)
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_10Dictionary_4Trie_4Trie_Trie *)__pyx_v_self->__pyx___dictionaryTrie->__pyx_vtab)->getWordsWithPrefix(__pyx_v_self->__pyx___dictionaryTrie, __pyx_v_surfaceForm, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 530, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_words = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":531
 *             return initialFsmParse
 *         words = self.__dictionaryTrie.getWordsWithPrefix(surfaceForm)
 *         for word in words:             # <<<<<<<<<<<<<<
 *             self.__initializeParseListFromRoot(initialFsmParse, word, isProper)
 *         return initialFsmParse
 */
  __pyx_t_8 = 0;
  __pyx_t_2 = __Pyx_set_iterator(__pyx_v_words, 1, (&__pyx_t_10), (&__pyx_t_6)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 531, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_1);
  __pyx_t_1 = __pyx_t_2;
  __pyx_t_2 = 0;
  while (1) {
    __pyx_t_11 = __Pyx_set_iter_next(__pyx_t_1, __pyx_t_10, &__pyx_t_8, &__pyx_t_2, __pyx_t_6);
    if (unlikely(__pyx_t_11 == 0)) break;
    if (unlikely(__pyx_t_11 == -1)) __PYX_ERR(0, 531, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_10Dictionary_7TxtWord_TxtWord))))) __PYX_ERR(0, 531, __pyx_L1_error)
    __Pyx_XDECREF_SET(__pyx_v_word, ((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)__pyx_t_2));
    __pyx_t_2 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":532
 *         words = self.__dictionaryTrie.getWordsWithPrefix(surfaceForm)
 *         for word in words:
 *             self.__initializeParseListFromRoot(initialFsmParse, word, isProper)             # <<<<<<<<<<<<<<
 *         return initialFsmParse
 * 
 */
    __pyx_t_2 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->__pyx___initializeParseListFromRoot(__pyx_v_self, __pyx_v_initialFsmParse, __pyx_v_word, __pyx_v_isProper, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 532, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":533
 *         for word in words:
 *             self.__initializeParseListFromRoot(initialFsmParse, word, isProper)
 *         return initialFsmParse             # <<<<<<<<<<<<<<
 * 
 *     cpdef __addNewParsesFromCurrentParse(self, FsmParse currentFsmParse, list fsmParse, maxLengthOrSurfaceForm,
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_initialFsmParse);
  __pyx_r = __pyx_v_initialFsmParse;
  goto __pyx_L0;

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":505
 *             self.__initializeParseList(parseList, newRoot, isProper)
 * 
 *     cpdef list __initializeParseListFromSurfaceForm(self, str surfaceForm, bint isProper):             # <<<<<<<<<<<<<<
 *         """
 *         The initializeParseListFromSurfaceForm method is used to create a list which consists of initial fsm parsings.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("MorphologicalAnalysis.FsmMorphologicalAnalyzer.FsmMorphologicalAnalyzer.__initializeParseListFromSurfaceForm", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_initialFsmParse);
  __Pyx_XDECREF(__pyx_v_words);
  __Pyx_XDECREF((PyObject *)__pyx_v_word);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_17__initializeParseListFromSurfaceForm(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_16__initializeParseListFromSurfaceForm[] = "\n        The initializeParseListFromSurfaceForm method is used to create a list which consists of initial fsm parsings.\n        First, it calls getWordsWithPrefix methods by using input String surfaceForm and generates a set. Then,\n        traverses this set and uses each word as a root and calls initializeParseListFromRoot method with this root and\n        list.\n\n        PARAMETERS\n        ----------\n        surfaceForm : str\n            the String used to generate a HashSet of words.\n        isProper : bool\n            is used to check a word is proper or not.\n\n        RETURNS\n        -------\n        list\n            initialFsmParse list.\n        ";
static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_17__initializeParseListFromSurfaceForm(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_surfaceForm = 0;
  int __pyx_v_isProper;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__initializeParseListFromSurfaceForm (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_surfaceForm,&__pyx_n_s_isProper,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_surfaceForm)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_isProper)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__initializeParseListFromSurfaceForm", 1, 2, 2, 1); __PYX_ERR(0, 505, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__initializeParseListFromSurfaceForm") < 0)) __PYX_ERR(0, 505, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_surfaceForm = ((PyObject*)values[0]);
    __pyx_v_isProper = __Pyx_PyObject_IsTrue(values[1]); if (unlikely((__pyx_v_isProper == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 505, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__initializeParseListFromSurfaceForm", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 505, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("MorphologicalAnalysis.FsmMorphologicalAnalyzer.FsmMorphologicalAnalyzer.__initializeParseListFromSurfaceForm", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_surfaceForm), (&PyUnicode_Type), 1, "surfaceForm", 1))) __PYX_ERR(0, 505, __pyx_L1_error)
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_16__initializeParseListFromSurfaceForm(((struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self), __pyx_v_surfaceForm, __pyx_v_isProper);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_16__initializeParseListFromSurfaceForm(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_surfaceForm, int __pyx_v_isProper) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__initializeParseListFromSurfaceForm", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer___initializeParseListFromSurfaceForm(__pyx_v_self, __pyx_v_surfaceForm, __pyx_v_isProper, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 505, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.FsmMorphologicalAnalyzer.FsmMorphologicalAnalyzer.__initializeParseListFromSurfaceForm", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":535
 *         return initialFsmParse
 * 
 *     cpdef __addNewParsesFromCurrentParse(self, FsmParse currentFsmParse, list fsmParse, maxLengthOrSurfaceForm,             # <<<<<<<<<<<<<<
 *                                        TxtWord root):
 *         """
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_19__addNewParsesFromCurrentParse(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer___addNewParsesFromCurrentParse(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *__pyx_v_currentFsmParse, PyObject *__pyx_v_fsmParse, PyObject *__pyx_v_maxLengthOrSurfaceForm, struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_root, int __pyx_skip_dispatch) {
  struct __pyx_obj_21MorphologicalAnalysis_5State_State *__pyx_v_currentState = 0;
  PyObject *__pyx_v_currentSurfaceForm = 0;
  PyObject *__pyx_v_tmp = 0;
  PyObject *__pyx_v_surfaceForm = 0;
  int __pyx_v_maxLength;
  struct __pyx_obj_21MorphologicalAnalysis_10Transition_Transition *__pyx_v_currentTransition = 0;
  struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *__pyx_v_newFsmParse = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_t_8;
  Py_ssize_t __pyx_t_9;
  int __pyx_t_10;
  Py_ssize_t __pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  int __pyx_t_13;
  Py_ssize_t __pyx_t_14;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__addNewParsesFromCurrentParse", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_addNewParsesFromCurrentParse); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 535, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_19__addNewParsesFromCurrentParse)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        __pyx_t_5 = 0;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_5 = 1;
          }
        }
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_3)) {
          PyObject *__pyx_temp[5] = {__pyx_t_4, ((PyObject *)__pyx_v_currentFsmParse), __pyx_v_fsmParse, __pyx_v_maxLengthOrSurfaceForm, ((PyObject *)__pyx_v_root)};
          __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_5, 4+__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 535, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_GOTREF(__pyx_t_2);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
          PyObject *__pyx_temp[5] = {__pyx_t_4, ((PyObject *)__pyx_v_currentFsmParse), __pyx_v_fsmParse, __pyx_v_maxLengthOrSurfaceForm, ((PyObject *)__pyx_v_root)};
          __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_5, 4+__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 535, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_GOTREF(__pyx_t_2);
        } else
        #endif
        {
          __pyx_t_6 = PyTuple_New(4+__pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 535, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          if (__pyx_t_4) {
            __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4); __pyx_t_4 = NULL;
          }
          __Pyx_INCREF(((PyObject *)__pyx_v_currentFsmParse));
          __Pyx_GIVEREF(((PyObject *)__pyx_v_currentFsmParse));
          PyTuple_SET_ITEM(__pyx_t_6, 0+__pyx_t_5, ((PyObject *)__pyx_v_currentFsmParse));
          __Pyx_INCREF(__pyx_v_fsmParse);
          __Pyx_GIVEREF(__pyx_v_fsmParse);
          PyTuple_SET_ITEM(__pyx_t_6, 1+__pyx_t_5, __pyx_v_fsmParse);
          __Pyx_INCREF(__pyx_v_maxLengthOrSurfaceForm);
          __Pyx_GIVEREF(__pyx_v_maxLengthOrSurfaceForm);
          PyTuple_SET_ITEM(__pyx_t_6, 2+__pyx_t_5, __pyx_v_maxLengthOrSurfaceForm);
          __Pyx_INCREF(((PyObject *)__pyx_v_root));
          __Pyx_GIVEREF(((PyObject *)__pyx_v_root));
          PyTuple_SET_ITEM(__pyx_t_6, 3+__pyx_t_5, ((PyObject *)__pyx_v_root));
          __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_6, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 535, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        }
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":561
 *         cdef Transition currentTransition
 *         cdef FsmParse newFsmParse
 *         currentState = currentFsmParse.getFinalSuffix()             # <<<<<<<<<<<<<<
 *         currentSurfaceForm = currentFsmParse.getSurfaceForm()
 *         if isinstance(maxLengthOrSurfaceForm, int):
 */
  __pyx_t_1 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_v_currentFsmParse->__pyx_base.__pyx_vtab)->getFinalSuffix(__pyx_v_currentFsmParse, 0)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 561, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_currentState = ((struct __pyx_obj_21MorphologicalAnalysis_5State_State *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":562
 *         cdef FsmParse newFsmParse
 *         currentState = currentFsmParse.getFinalSuffix()
 *         currentSurfaceForm = currentFsmParse.getSurfaceForm()             # <<<<<<<<<<<<<<
 *         if isinstance(maxLengthOrSurfaceForm, int):
 *             maxLength = maxLengthOrSurfaceForm
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_v_currentFsmParse->__pyx_base.__pyx_vtab)->getSurfaceForm(__pyx_v_currentFsmParse, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 562, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_currentSurfaceForm = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":563
 *         currentState = currentFsmParse.getFinalSuffix()
 *         currentSurfaceForm = currentFsmParse.getSurfaceForm()
 *         if isinstance(maxLengthOrSurfaceForm, int):             # <<<<<<<<<<<<<<
 *             maxLength = maxLengthOrSurfaceForm
 *             for currentTransition in self.__finiteStateMachine.getTransitions(currentState):
 */
  __pyx_t_7 = PyInt_Check(__pyx_v_maxLengthOrSurfaceForm); 
  __pyx_t_8 = (__pyx_t_7 != 0);
  if (__pyx_t_8) {

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":564
 *         currentSurfaceForm = currentFsmParse.getSurfaceForm()
 *         if isinstance(maxLengthOrSurfaceForm, int):
 *             maxLength = maxLengthOrSurfaceForm             # <<<<<<<<<<<<<<
 *             for currentTransition in self.__finiteStateMachine.getTransitions(currentState):
 *                 if currentTransition.transitionPossibleForParse(currentFsmParse) \
 */
    __pyx_t_5 = __Pyx_PyInt_As_int(__pyx_v_maxLengthOrSurfaceForm); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 564, __pyx_L1_error)
    __pyx_v_maxLength = __pyx_t_5;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":565
 *         if isinstance(maxLengthOrSurfaceForm, int):
 *             maxLength = maxLengthOrSurfaceForm
 *             for currentTransition in self.__finiteStateMachine.getTransitions(currentState):             # <<<<<<<<<<<<<<
 *                 if currentTransition.transitionPossibleForParse(currentFsmParse) \
 *                         and (currentSurfaceForm != root.getName()
 */
    __pyx_t_1 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine *)__pyx_v_self->__pyx___finiteStateMachine->__pyx_vtab)->getTransitions(__pyx_v_self->__pyx___finiteStateMachine, __pyx_v_currentState, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 565, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (unlikely(__pyx_t_1 == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
      __PYX_ERR(0, 565, __pyx_L1_error)
    }
    __pyx_t_2 = __pyx_t_1; __Pyx_INCREF(__pyx_t_2); __pyx_t_9 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    for (;;) {
      if (__pyx_t_9 >= PyList_GET_SIZE(__pyx_t_2)) break;
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      __pyx_t_1 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_9); __Pyx_INCREF(__pyx_t_1); __pyx_t_9++; if (unlikely(0 < 0)) __PYX_ERR(0, 565, __pyx_L1_error)
      #else
      __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_9); __pyx_t_9++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 565, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      #endif
      if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_21MorphologicalAnalysis_10Transition_Transition))))) __PYX_ERR(0, 565, __pyx_L1_error)
      __Pyx_XDECREF_SET(__pyx_v_currentTransition, ((struct __pyx_obj_21MorphologicalAnalysis_10Transition_Transition *)__pyx_t_1));
      __pyx_t_1 = 0;

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":566
 *             maxLength = maxLengthOrSurfaceForm
 *             for currentTransition in self.__finiteStateMachine.getTransitions(currentState):
 *                 if currentTransition.transitionPossibleForParse(currentFsmParse) \             # <<<<<<<<<<<<<<
 *                         and (currentSurfaceForm != root.getName()
 *                              or (currentSurfaceForm == root.getName() and
 */
      __pyx_t_7 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_10Transition_Transition *)__pyx_v_currentTransition->__pyx_vtab)->transitionPossibleForParse(__pyx_v_currentTransition, __pyx_v_currentFsmParse, 0) != 0);
      if (__pyx_t_7) {
      } else {
        __pyx_t_8 = __pyx_t_7;
        goto __pyx_L7_bool_binop_done;
      }

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":567
 *             for currentTransition in self.__finiteStateMachine.getTransitions(currentState):
 *                 if currentTransition.transitionPossibleForParse(currentFsmParse) \
 *                         and (currentSurfaceForm != root.getName()             # <<<<<<<<<<<<<<
 *                              or (currentSurfaceForm == root.getName() and
 *                                  currentTransition.transitionPossibleWord(root, currentState))):
 */
      __pyx_t_1 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->__pyx_base.getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_v_root), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 567, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_v_currentSurfaceForm, __pyx_t_1, Py_NE)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 567, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_10 = (__pyx_t_7 != 0);
      if (!__pyx_t_10) {
      } else {
        __pyx_t_8 = __pyx_t_10;
        goto __pyx_L7_bool_binop_done;
      }

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":568
 *                 if currentTransition.transitionPossibleForParse(currentFsmParse) \
 *                         and (currentSurfaceForm != root.getName()
 *                              or (currentSurfaceForm == root.getName() and             # <<<<<<<<<<<<<<
 *                                  currentTransition.transitionPossibleWord(root, currentState))):
 *                     tmp = currentTransition.makeTransition(root, currentSurfaceForm, currentFsmParse.getStartState())
 */
      __pyx_t_1 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->__pyx_base.getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_v_root), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 568, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_10 = (__Pyx_PyUnicode_Equals(__pyx_v_currentSurfaceForm, __pyx_t_1, Py_EQ)); if (unlikely(__pyx_t_10 < 0)) __PYX_ERR(0, 568, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_7 = (__pyx_t_10 != 0);
      if (__pyx_t_7) {
      } else {
        __pyx_t_8 = __pyx_t_7;
        goto __pyx_L7_bool_binop_done;
      }

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":569
 *                         and (currentSurfaceForm != root.getName()
 *                              or (currentSurfaceForm == root.getName() and
 *                                  currentTransition.transitionPossibleWord(root, currentState))):             # <<<<<<<<<<<<<<
 *                     tmp = currentTransition.makeTransition(root, currentSurfaceForm, currentFsmParse.getStartState())
 *                     if len(tmp) <= maxLength:
 */
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_currentTransition), __pyx_n_s_transitionPossibleWord); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 569, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_6 = NULL;
      __pyx_t_5 = 0;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
          __pyx_t_5 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_3)) {
        PyObject *__pyx_temp[3] = {__pyx_t_6, ((PyObject *)__pyx_v_root), ((PyObject *)__pyx_v_currentState)};
        __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 569, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
        PyObject *__pyx_temp[3] = {__pyx_t_6, ((PyObject *)__pyx_v_root), ((PyObject *)__pyx_v_currentState)};
        __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 569, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      {
        __pyx_t_4 = PyTuple_New(2+__pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 569, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        if (__pyx_t_6) {
          __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_6); __pyx_t_6 = NULL;
        }
        __Pyx_INCREF(((PyObject *)__pyx_v_root));
        __Pyx_GIVEREF(((PyObject *)__pyx_v_root));
        PyTuple_SET_ITEM(__pyx_t_4, 0+__pyx_t_5, ((PyObject *)__pyx_v_root));
        __Pyx_INCREF(((PyObject *)__pyx_v_currentState));
        __Pyx_GIVEREF(((PyObject *)__pyx_v_currentState));
        PyTuple_SET_ITEM(__pyx_t_4, 1+__pyx_t_5, ((PyObject *)__pyx_v_currentState));
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 569, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 569, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_8 = __pyx_t_7;
      __pyx_L7_bool_binop_done:;

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":566
 *             maxLength = maxLengthOrSurfaceForm
 *             for currentTransition in self.__finiteStateMachine.getTransitions(currentState):
 *                 if currentTransition.transitionPossibleForParse(currentFsmParse) \             # <<<<<<<<<<<<<<
 *                         and (currentSurfaceForm != root.getName()
 *                              or (currentSurfaceForm == root.getName() and
 */
      if (__pyx_t_8) {

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":570
 *                              or (currentSurfaceForm == root.getName() and
 *                                  currentTransition.transitionPossibleWord(root, currentState))):
 *                     tmp = currentTransition.makeTransition(root, currentSurfaceForm, currentFsmParse.getStartState())             # <<<<<<<<<<<<<<
 *                     if len(tmp) <= maxLength:
 *                         newFsmParse = copy.deepcopy(currentFsmParse)
 */
        __pyx_t_1 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_v_currentFsmParse->__pyx_base.__pyx_vtab)->getStartState(__pyx_v_currentFsmParse, 0)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 570, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_3 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_10Transition_Transition *)__pyx_v_currentTransition->__pyx_vtab)->makeTransition(__pyx_v_currentTransition, __pyx_v_root, __pyx_v_currentSurfaceForm, ((struct __pyx_obj_21MorphologicalAnalysis_5State_State *)__pyx_t_1), 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 570, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_XDECREF_SET(__pyx_v_tmp, ((PyObject*)__pyx_t_3));
        __pyx_t_3 = 0;

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":571
 *                                  currentTransition.transitionPossibleWord(root, currentState))):
 *                     tmp = currentTransition.makeTransition(root, currentSurfaceForm, currentFsmParse.getStartState())
 *                     if len(tmp) <= maxLength:             # <<<<<<<<<<<<<<
 *                         newFsmParse = copy.deepcopy(currentFsmParse)
 *                         newFsmParse.addSuffix(currentTransition.toState(), tmp, currentTransition.withName(),
 */
        if (unlikely(__pyx_v_tmp == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
          __PYX_ERR(0, 571, __pyx_L1_error)
        }
        __pyx_t_11 = __Pyx_PyUnicode_GET_LENGTH(__pyx_v_tmp); if (unlikely(__pyx_t_11 == ((Py_ssize_t)-1))) __PYX_ERR(0, 571, __pyx_L1_error)
        __pyx_t_8 = ((__pyx_t_11 <= __pyx_v_maxLength) != 0);
        if (__pyx_t_8) {

          /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":572
 *                     tmp = currentTransition.makeTransition(root, currentSurfaceForm, currentFsmParse.getStartState())
 *                     if len(tmp) <= maxLength:
 *                         newFsmParse = copy.deepcopy(currentFsmParse)             # <<<<<<<<<<<<<<
 *                         newFsmParse.addSuffix(currentTransition.toState(), tmp, currentTransition.withName(),
 *                                               currentTransition.__str__(), currentTransition.toPos())
 */
          __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_copy); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 572, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_deepcopy); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 572, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __pyx_t_1 = NULL;
          if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
            __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_4);
            if (likely(__pyx_t_1)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
              __Pyx_INCREF(__pyx_t_1);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_4, function);
            }
          }
          __pyx_t_3 = (__pyx_t_1) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_1, ((PyObject *)__pyx_v_currentFsmParse)) : __Pyx_PyObject_CallOneArg(__pyx_t_4, ((PyObject *)__pyx_v_currentFsmParse));
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 572, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse))))) __PYX_ERR(0, 572, __pyx_L1_error)
          __Pyx_XDECREF_SET(__pyx_v_newFsmParse, ((struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_t_3));
          __pyx_t_3 = 0;

          /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":573
 *                     if len(tmp) <= maxLength:
 *                         newFsmParse = copy.deepcopy(currentFsmParse)
 *                         newFsmParse.addSuffix(currentTransition.toState(), tmp, currentTransition.withName(),             # <<<<<<<<<<<<<<
 *                                               currentTransition.__str__(), currentTransition.toPos())
 *                         newFsmParse.setAgreement(currentTransition.withName())
 */
          __pyx_t_3 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_10Transition_Transition *)__pyx_v_currentTransition->__pyx_vtab)->toState(__pyx_v_currentTransition, 0)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 573, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __pyx_t_4 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_10Transition_Transition *)__pyx_v_currentTransition->__pyx_vtab)->withName(__pyx_v_currentTransition, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 573, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);

          /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":574
 *                         newFsmParse = copy.deepcopy(currentFsmParse)
 *                         newFsmParse.addSuffix(currentTransition.toState(), tmp, currentTransition.withName(),
 *                                               currentTransition.__str__(), currentTransition.toPos())             # <<<<<<<<<<<<<<
 *                         newFsmParse.setAgreement(currentTransition.withName())
 *                         fsmParse.append(newFsmParse)
 */
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_currentTransition), __pyx_n_s_str); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 574, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_12 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
            __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_6);
            if (likely(__pyx_t_12)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
              __Pyx_INCREF(__pyx_t_12);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_6, function);
            }
          }
          __pyx_t_1 = (__pyx_t_12) ? __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_12) : __Pyx_PyObject_CallNoArg(__pyx_t_6);
          __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 574, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          if (!(likely(PyUnicode_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_1)->tp_name), 0))) __PYX_ERR(0, 574, __pyx_L1_error)
          __pyx_t_6 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_10Transition_Transition *)__pyx_v_currentTransition->__pyx_vtab)->toPos(__pyx_v_currentTransition, 0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 574, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);

          /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":573
 *                     if len(tmp) <= maxLength:
 *                         newFsmParse = copy.deepcopy(currentFsmParse)
 *                         newFsmParse.addSuffix(currentTransition.toState(), tmp, currentTransition.withName(),             # <<<<<<<<<<<<<<
 *                                               currentTransition.__str__(), currentTransition.toPos())
 *                         newFsmParse.setAgreement(currentTransition.withName())
 */
          __pyx_t_12 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_v_newFsmParse->__pyx_base.__pyx_vtab)->addSuffix(__pyx_v_newFsmParse, ((struct __pyx_obj_21MorphologicalAnalysis_5State_State *)__pyx_t_3), __pyx_v_tmp, ((PyObject*)__pyx_t_4), ((PyObject*)__pyx_t_1), ((PyObject*)__pyx_t_6), 0); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 573, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

          /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":575
 *                         newFsmParse.addSuffix(currentTransition.toState(), tmp, currentTransition.withName(),
 *                                               currentTransition.__str__(), currentTransition.toPos())
 *                         newFsmParse.setAgreement(currentTransition.withName())             # <<<<<<<<<<<<<<
 *                         fsmParse.append(newFsmParse)
 *         elif isinstance(maxLengthOrSurfaceForm, str):
 */
          __pyx_t_12 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_10Transition_Transition *)__pyx_v_currentTransition->__pyx_vtab)->withName(__pyx_v_currentTransition, 0); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 575, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __pyx_t_6 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_v_newFsmParse->__pyx_base.__pyx_vtab)->setAgreement(__pyx_v_newFsmParse, ((PyObject*)__pyx_t_12), 0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 575, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

          /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":576
 *                                               currentTransition.__str__(), currentTransition.toPos())
 *                         newFsmParse.setAgreement(currentTransition.withName())
 *                         fsmParse.append(newFsmParse)             # <<<<<<<<<<<<<<
 *         elif isinstance(maxLengthOrSurfaceForm, str):
 *             surfaceForm = maxLengthOrSurfaceForm
 */
          if (unlikely(__pyx_v_fsmParse == Py_None)) {
            PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
            __PYX_ERR(0, 576, __pyx_L1_error)
          }
          __pyx_t_13 = __Pyx_PyList_Append(__pyx_v_fsmParse, ((PyObject *)__pyx_v_newFsmParse)); if (unlikely(__pyx_t_13 == ((int)-1))) __PYX_ERR(0, 576, __pyx_L1_error)

          /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":571
 *                                  currentTransition.transitionPossibleWord(root, currentState))):
 *                     tmp = currentTransition.makeTransition(root, currentSurfaceForm, currentFsmParse.getStartState())
 *                     if len(tmp) <= maxLength:             # <<<<<<<<<<<<<<
 *                         newFsmParse = copy.deepcopy(currentFsmParse)
 *                         newFsmParse.addSuffix(currentTransition.toState(), tmp, currentTransition.withName(),
 */
        }

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":566
 *             maxLength = maxLengthOrSurfaceForm
 *             for currentTransition in self.__finiteStateMachine.getTransitions(currentState):
 *                 if currentTransition.transitionPossibleForParse(currentFsmParse) \             # <<<<<<<<<<<<<<
 *                         and (currentSurfaceForm != root.getName()
 *                              or (currentSurfaceForm == root.getName() and
 */
      }

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":565
 *         if isinstance(maxLengthOrSurfaceForm, int):
 *             maxLength = maxLengthOrSurfaceForm
 *             for currentTransition in self.__finiteStateMachine.getTransitions(currentState):             # <<<<<<<<<<<<<<
 *                 if currentTransition.transitionPossibleForParse(currentFsmParse) \
 *                         and (currentSurfaceForm != root.getName()
 */
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":563
 *         currentState = currentFsmParse.getFinalSuffix()
 *         currentSurfaceForm = currentFsmParse.getSurfaceForm()
 *         if isinstance(maxLengthOrSurfaceForm, int):             # <<<<<<<<<<<<<<
 *             maxLength = maxLengthOrSurfaceForm
 *             for currentTransition in self.__finiteStateMachine.getTransitions(currentState):
 */
    goto __pyx_L3;
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":577
 *                         newFsmParse.setAgreement(currentTransition.withName())
 *                         fsmParse.append(newFsmParse)
 *         elif isinstance(maxLengthOrSurfaceForm, str):             # <<<<<<<<<<<<<<
 *             surfaceForm = maxLengthOrSurfaceForm
 *             for currentTransition in self.__finiteStateMachine.getTransitions(currentState):
 */
  __pyx_t_8 = PyUnicode_Check(__pyx_v_maxLengthOrSurfaceForm); 
  __pyx_t_7 = (__pyx_t_8 != 0);
  if (__pyx_t_7) {

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":578
 *                         fsmParse.append(newFsmParse)
 *         elif isinstance(maxLengthOrSurfaceForm, str):
 *             surfaceForm = maxLengthOrSurfaceForm             # <<<<<<<<<<<<<<
 *             for currentTransition in self.__finiteStateMachine.getTransitions(currentState):
 *                 if currentTransition.transitionPossibleForString(currentFsmParse.getSurfaceForm(), surfaceForm) and \
 */
    if (!(likely(PyUnicode_CheckExact(__pyx_v_maxLengthOrSurfaceForm))||((__pyx_v_maxLengthOrSurfaceForm) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_v_maxLengthOrSurfaceForm)->tp_name), 0))) __PYX_ERR(0, 578, __pyx_L1_error)
    __pyx_t_2 = __pyx_v_maxLengthOrSurfaceForm;
    __Pyx_INCREF(__pyx_t_2);
    __pyx_v_surfaceForm = ((PyObject*)__pyx_t_2);
    __pyx_t_2 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":579
 *         elif isinstance(maxLengthOrSurfaceForm, str):
 *             surfaceForm = maxLengthOrSurfaceForm
 *             for currentTransition in self.__finiteStateMachine.getTransitions(currentState):             # <<<<<<<<<<<<<<
 *                 if currentTransition.transitionPossibleForString(currentFsmParse.getSurfaceForm(), surfaceForm) and \
 *                         currentTransition.transitionPossibleForParse(currentFsmParse) and (
 */
    __pyx_t_2 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine *)__pyx_v_self->__pyx___finiteStateMachine->__pyx_vtab)->getTransitions(__pyx_v_self->__pyx___finiteStateMachine, __pyx_v_currentState, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 579, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (unlikely(__pyx_t_2 == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
      __PYX_ERR(0, 579, __pyx_L1_error)
    }
    __pyx_t_6 = __pyx_t_2; __Pyx_INCREF(__pyx_t_6); __pyx_t_9 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    for (;;) {
      if (__pyx_t_9 >= PyList_GET_SIZE(__pyx_t_6)) break;
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      __pyx_t_2 = PyList_GET_ITEM(__pyx_t_6, __pyx_t_9); __Pyx_INCREF(__pyx_t_2); __pyx_t_9++; if (unlikely(0 < 0)) __PYX_ERR(0, 579, __pyx_L1_error)
      #else
      __pyx_t_2 = PySequence_ITEM(__pyx_t_6, __pyx_t_9); __pyx_t_9++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 579, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      #endif
      if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_21MorphologicalAnalysis_10Transition_Transition))))) __PYX_ERR(0, 579, __pyx_L1_error)
      __Pyx_XDECREF_SET(__pyx_v_currentTransition, ((struct __pyx_obj_21MorphologicalAnalysis_10Transition_Transition *)__pyx_t_2));
      __pyx_t_2 = 0;

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":580
 *             surfaceForm = maxLengthOrSurfaceForm
 *             for currentTransition in self.__finiteStateMachine.getTransitions(currentState):
 *                 if currentTransition.transitionPossibleForString(currentFsmParse.getSurfaceForm(), surfaceForm) and \             # <<<<<<<<<<<<<<
 *                         currentTransition.transitionPossibleForParse(currentFsmParse) and (
 *                         currentSurfaceForm != root.getName()
 */
      __pyx_t_2 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_v_currentFsmParse->__pyx_base.__pyx_vtab)->getSurfaceForm(__pyx_v_currentFsmParse, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 580, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_8 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_10Transition_Transition *)__pyx_v_currentTransition->__pyx_vtab)->transitionPossibleForString(__pyx_v_currentTransition, ((PyObject*)__pyx_t_2), __pyx_v_surfaceForm, 0) != 0);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (__pyx_t_8) {
      } else {
        __pyx_t_7 = __pyx_t_8;
        goto __pyx_L15_bool_binop_done;
      }

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":581
 *             for currentTransition in self.__finiteStateMachine.getTransitions(currentState):
 *                 if currentTransition.transitionPossibleForString(currentFsmParse.getSurfaceForm(), surfaceForm) and \
 *                         currentTransition.transitionPossibleForParse(currentFsmParse) and (             # <<<<<<<<<<<<<<
 *                         currentSurfaceForm != root.getName()
 *                         or (currentSurfaceForm == root.getName() and
 */
      __pyx_t_8 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_10Transition_Transition *)__pyx_v_currentTransition->__pyx_vtab)->transitionPossibleForParse(__pyx_v_currentTransition, __pyx_v_currentFsmParse, 0) != 0);
      if (__pyx_t_8) {
      } else {
        __pyx_t_7 = __pyx_t_8;
        goto __pyx_L15_bool_binop_done;
      }

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":582
 *                 if currentTransition.transitionPossibleForString(currentFsmParse.getSurfaceForm(), surfaceForm) and \
 *                         currentTransition.transitionPossibleForParse(currentFsmParse) and (
 *                         currentSurfaceForm != root.getName()             # <<<<<<<<<<<<<<
 *                         or (currentSurfaceForm == root.getName() and
 *                             currentTransition.transitionPossibleForWord(root, currentState))):
 */
      __pyx_t_2 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->__pyx_base.getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_v_root), 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 582, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_8 = (__Pyx_PyUnicode_Equals(__pyx_v_currentSurfaceForm, __pyx_t_2, Py_NE)); if (unlikely(__pyx_t_8 < 0)) __PYX_ERR(0, 582, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_10 = (__pyx_t_8 != 0);
      if (!__pyx_t_10) {
      } else {
        __pyx_t_7 = __pyx_t_10;
        goto __pyx_L15_bool_binop_done;
      }

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":583
 *                         currentTransition.transitionPossibleForParse(currentFsmParse) and (
 *                         currentSurfaceForm != root.getName()
 *                         or (currentSurfaceForm == root.getName() and             # <<<<<<<<<<<<<<
 *                             currentTransition.transitionPossibleForWord(root, currentState))):
 *                     tmp = currentTransition.makeTransition(root, currentSurfaceForm, currentFsmParse.getStartState())
 */
      __pyx_t_2 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->__pyx_base.getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_v_root), 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 583, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_10 = (__Pyx_PyUnicode_Equals(__pyx_v_currentSurfaceForm, __pyx_t_2, Py_EQ)); if (unlikely(__pyx_t_10 < 0)) __PYX_ERR(0, 583, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_8 = (__pyx_t_10 != 0);
      if (__pyx_t_8) {
      } else {
        __pyx_t_7 = __pyx_t_8;
        goto __pyx_L15_bool_binop_done;
      }

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":584
 *                         currentSurfaceForm != root.getName()
 *                         or (currentSurfaceForm == root.getName() and
 *                             currentTransition.transitionPossibleForWord(root, currentState))):             # <<<<<<<<<<<<<<
 *                     tmp = currentTransition.makeTransition(root, currentSurfaceForm, currentFsmParse.getStartState())
 *                     if (len(tmp) < len(surfaceForm) and self.__isPossibleSubstring(tmp, surfaceForm, root)) or \
 */
      __pyx_t_8 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_10Transition_Transition *)__pyx_v_currentTransition->__pyx_vtab)->transitionPossibleForWord(__pyx_v_currentTransition, __pyx_v_root, __pyx_v_currentState, 0) != 0);
      __pyx_t_7 = __pyx_t_8;
      __pyx_L15_bool_binop_done:;

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":580
 *             surfaceForm = maxLengthOrSurfaceForm
 *             for currentTransition in self.__finiteStateMachine.getTransitions(currentState):
 *                 if currentTransition.transitionPossibleForString(currentFsmParse.getSurfaceForm(), surfaceForm) and \             # <<<<<<<<<<<<<<
 *                         currentTransition.transitionPossibleForParse(currentFsmParse) and (
 *                         currentSurfaceForm != root.getName()
 */
      if (__pyx_t_7) {

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":585
 *                         or (currentSurfaceForm == root.getName() and
 *                             currentTransition.transitionPossibleForWord(root, currentState))):
 *                     tmp = currentTransition.makeTransition(root, currentSurfaceForm, currentFsmParse.getStartState())             # <<<<<<<<<<<<<<
 *                     if (len(tmp) < len(surfaceForm) and self.__isPossibleSubstring(tmp, surfaceForm, root)) or \
 *                             (len(tmp) == len(surfaceForm) and (
 */
        __pyx_t_2 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_v_currentFsmParse->__pyx_base.__pyx_vtab)->getStartState(__pyx_v_currentFsmParse, 0)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 585, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_12 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_10Transition_Transition *)__pyx_v_currentTransition->__pyx_vtab)->makeTransition(__pyx_v_currentTransition, __pyx_v_root, __pyx_v_currentSurfaceForm, ((struct __pyx_obj_21MorphologicalAnalysis_5State_State *)__pyx_t_2), 0); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 585, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_12);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_XDECREF_SET(__pyx_v_tmp, ((PyObject*)__pyx_t_12));
        __pyx_t_12 = 0;

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":586
 *                             currentTransition.transitionPossibleForWord(root, currentState))):
 *                     tmp = currentTransition.makeTransition(root, currentSurfaceForm, currentFsmParse.getStartState())
 *                     if (len(tmp) < len(surfaceForm) and self.__isPossibleSubstring(tmp, surfaceForm, root)) or \             # <<<<<<<<<<<<<<
 *                             (len(tmp) == len(surfaceForm) and (
 *                                     root.lastIdropsDuringSuffixation() or tmp == surfaceForm)):
 */
        if (unlikely(__pyx_v_tmp == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
          __PYX_ERR(0, 586, __pyx_L1_error)
        }
        __pyx_t_11 = __Pyx_PyUnicode_GET_LENGTH(__pyx_v_tmp); if (unlikely(__pyx_t_11 == ((Py_ssize_t)-1))) __PYX_ERR(0, 586, __pyx_L1_error)
        if (unlikely(__pyx_v_surfaceForm == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
          __PYX_ERR(0, 586, __pyx_L1_error)
        }
        __pyx_t_14 = __Pyx_PyUnicode_GET_LENGTH(__pyx_v_surfaceForm); if (unlikely(__pyx_t_14 == ((Py_ssize_t)-1))) __PYX_ERR(0, 586, __pyx_L1_error)
        __pyx_t_8 = ((__pyx_t_11 < __pyx_t_14) != 0);
        if (!__pyx_t_8) {
          goto __pyx_L22_next_or;
        } else {
        }
        __pyx_t_8 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->__pyx___isPossibleSubstring(__pyx_v_self, __pyx_v_tmp, __pyx_v_surfaceForm, __pyx_v_root, 0) != 0);
        if (!__pyx_t_8) {
        } else {
          __pyx_t_7 = __pyx_t_8;
          goto __pyx_L21_bool_binop_done;
        }
        __pyx_L22_next_or:;

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":587
 *                     tmp = currentTransition.makeTransition(root, currentSurfaceForm, currentFsmParse.getStartState())
 *                     if (len(tmp) < len(surfaceForm) and self.__isPossibleSubstring(tmp, surfaceForm, root)) or \
 *                             (len(tmp) == len(surfaceForm) and (             # <<<<<<<<<<<<<<
 *                                     root.lastIdropsDuringSuffixation() or tmp == surfaceForm)):
 *                         newFsmParse = copy.deepcopy(currentFsmParse)
 */
        if (unlikely(__pyx_v_tmp == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
          __PYX_ERR(0, 587, __pyx_L1_error)
        }
        __pyx_t_14 = __Pyx_PyUnicode_GET_LENGTH(__pyx_v_tmp); if (unlikely(__pyx_t_14 == ((Py_ssize_t)-1))) __PYX_ERR(0, 587, __pyx_L1_error)
        if (unlikely(__pyx_v_surfaceForm == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
          __PYX_ERR(0, 587, __pyx_L1_error)
        }
        __pyx_t_11 = __Pyx_PyUnicode_GET_LENGTH(__pyx_v_surfaceForm); if (unlikely(__pyx_t_11 == ((Py_ssize_t)-1))) __PYX_ERR(0, 587, __pyx_L1_error)
        __pyx_t_8 = ((__pyx_t_14 == __pyx_t_11) != 0);
        if (__pyx_t_8) {
        } else {
          __pyx_t_7 = __pyx_t_8;
          goto __pyx_L21_bool_binop_done;
        }

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":588
 *                     if (len(tmp) < len(surfaceForm) and self.__isPossibleSubstring(tmp, surfaceForm, root)) or \
 *                             (len(tmp) == len(surfaceForm) and (
 *                                     root.lastIdropsDuringSuffixation() or tmp == surfaceForm)):             # <<<<<<<<<<<<<<
 *                         newFsmParse = copy.deepcopy(currentFsmParse)
 *                         newFsmParse.addSuffix(currentTransition.toState(), tmp, currentTransition.withName(),
 */
        __pyx_t_8 = (((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->lastIdropsDuringSuffixation(__pyx_v_root, 0) != 0);
        if (!__pyx_t_8) {
        } else {
          __pyx_t_7 = __pyx_t_8;
          goto __pyx_L21_bool_binop_done;
        }
        __pyx_t_8 = (__Pyx_PyUnicode_Equals(__pyx_v_tmp, __pyx_v_surfaceForm, Py_EQ)); if (unlikely(__pyx_t_8 < 0)) __PYX_ERR(0, 588, __pyx_L1_error)
        __pyx_t_10 = (__pyx_t_8 != 0);
        __pyx_t_7 = __pyx_t_10;
        __pyx_L21_bool_binop_done:;

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":586
 *                             currentTransition.transitionPossibleForWord(root, currentState))):
 *                     tmp = currentTransition.makeTransition(root, currentSurfaceForm, currentFsmParse.getStartState())
 *                     if (len(tmp) < len(surfaceForm) and self.__isPossibleSubstring(tmp, surfaceForm, root)) or \             # <<<<<<<<<<<<<<
 *                             (len(tmp) == len(surfaceForm) and (
 *                                     root.lastIdropsDuringSuffixation() or tmp == surfaceForm)):
 */
        if (__pyx_t_7) {

          /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":589
 *                             (len(tmp) == len(surfaceForm) and (
 *                                     root.lastIdropsDuringSuffixation() or tmp == surfaceForm)):
 *                         newFsmParse = copy.deepcopy(currentFsmParse)             # <<<<<<<<<<<<<<
 *                         newFsmParse.addSuffix(currentTransition.toState(), tmp, currentTransition.withName(),
 *                                               currentTransition.__str__(), currentTransition.toPos())
 */
          __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_copy); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 589, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_deepcopy); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 589, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __pyx_t_2 = NULL;
          if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
            __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_1);
            if (likely(__pyx_t_2)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
              __Pyx_INCREF(__pyx_t_2);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_1, function);
            }
          }
          __pyx_t_12 = (__pyx_t_2) ? __Pyx_PyObject_Call2Args(__pyx_t_1, __pyx_t_2, ((PyObject *)__pyx_v_currentFsmParse)) : __Pyx_PyObject_CallOneArg(__pyx_t_1, ((PyObject *)__pyx_v_currentFsmParse));
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
          if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 589, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          if (!(likely(((__pyx_t_12) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_12, __pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse))))) __PYX_ERR(0, 589, __pyx_L1_error)
          __Pyx_XDECREF_SET(__pyx_v_newFsmParse, ((struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_t_12));
          __pyx_t_12 = 0;

          /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":590
 *                                     root.lastIdropsDuringSuffixation() or tmp == surfaceForm)):
 *                         newFsmParse = copy.deepcopy(currentFsmParse)
 *                         newFsmParse.addSuffix(currentTransition.toState(), tmp, currentTransition.withName(),             # <<<<<<<<<<<<<<
 *                                               currentTransition.__str__(), currentTransition.toPos())
 *                         newFsmParse.setAgreement(currentTransition.withName())
 */
          __pyx_t_12 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_10Transition_Transition *)__pyx_v_currentTransition->__pyx_vtab)->toState(__pyx_v_currentTransition, 0)); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 590, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __pyx_t_1 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_10Transition_Transition *)__pyx_v_currentTransition->__pyx_vtab)->withName(__pyx_v_currentTransition, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 590, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);

          /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":591
 *                         newFsmParse = copy.deepcopy(currentFsmParse)
 *                         newFsmParse.addSuffix(currentTransition.toState(), tmp, currentTransition.withName(),
 *                                               currentTransition.__str__(), currentTransition.toPos())             # <<<<<<<<<<<<<<
 *                         newFsmParse.setAgreement(currentTransition.withName())
 *                         fsmParse.append(newFsmParse)
 */
          __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_currentTransition), __pyx_n_s_str); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 591, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_3 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
            __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
            if (likely(__pyx_t_3)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
              __Pyx_INCREF(__pyx_t_3);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_4, function);
            }
          }
          __pyx_t_2 = (__pyx_t_3) ? __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_3) : __Pyx_PyObject_CallNoArg(__pyx_t_4);
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 591, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (!(likely(PyUnicode_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_2)->tp_name), 0))) __PYX_ERR(0, 591, __pyx_L1_error)
          __pyx_t_4 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_10Transition_Transition *)__pyx_v_currentTransition->__pyx_vtab)->toPos(__pyx_v_currentTransition, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 591, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);

          /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":590
 *                                     root.lastIdropsDuringSuffixation() or tmp == surfaceForm)):
 *                         newFsmParse = copy.deepcopy(currentFsmParse)
 *                         newFsmParse.addSuffix(currentTransition.toState(), tmp, currentTransition.withName(),             # <<<<<<<<<<<<<<
 *                                               currentTransition.__str__(), currentTransition.toPos())
 *                         newFsmParse.setAgreement(currentTransition.withName())
 */
          __pyx_t_3 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_v_newFsmParse->__pyx_base.__pyx_vtab)->addSuffix(__pyx_v_newFsmParse, ((struct __pyx_obj_21MorphologicalAnalysis_5State_State *)__pyx_t_12), __pyx_v_tmp, ((PyObject*)__pyx_t_1), ((PyObject*)__pyx_t_2), ((PyObject*)__pyx_t_4), 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 590, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

          /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":592
 *                         newFsmParse.addSuffix(currentTransition.toState(), tmp, currentTransition.withName(),
 *                                               currentTransition.__str__(), currentTransition.toPos())
 *                         newFsmParse.setAgreement(currentTransition.withName())             # <<<<<<<<<<<<<<
 *                         fsmParse.append(newFsmParse)
 * 
 */
          __pyx_t_3 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_10Transition_Transition *)__pyx_v_currentTransition->__pyx_vtab)->withName(__pyx_v_currentTransition, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 592, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __pyx_t_4 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_v_newFsmParse->__pyx_base.__pyx_vtab)->setAgreement(__pyx_v_newFsmParse, ((PyObject*)__pyx_t_3), 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 592, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

          /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":593
 *                                               currentTransition.__str__(), currentTransition.toPos())
 *                         newFsmParse.setAgreement(currentTransition.withName())
 *                         fsmParse.append(newFsmParse)             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint __parseExists(self, list fsmParse, str surfaceForm):
 */
          if (unlikely(__pyx_v_fsmParse == Py_None)) {
            PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
            __PYX_ERR(0, 593, __pyx_L1_error)
          }
          __pyx_t_13 = __Pyx_PyList_Append(__pyx_v_fsmParse, ((PyObject *)__pyx_v_newFsmParse)); if (unlikely(__pyx_t_13 == ((int)-1))) __PYX_ERR(0, 593, __pyx_L1_error)

          /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":586
 *                             currentTransition.transitionPossibleForWord(root, currentState))):
 *                     tmp = currentTransition.makeTransition(root, currentSurfaceForm, currentFsmParse.getStartState())
 *                     if (len(tmp) < len(surfaceForm) and self.__isPossibleSubstring(tmp, surfaceForm, root)) or \             # <<<<<<<<<<<<<<
 *                             (len(tmp) == len(surfaceForm) and (
 *                                     root.lastIdropsDuringSuffixation() or tmp == surfaceForm)):
 */
        }

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":580
 *             surfaceForm = maxLengthOrSurfaceForm
 *             for currentTransition in self.__finiteStateMachine.getTransitions(currentState):
 *                 if currentTransition.transitionPossibleForString(currentFsmParse.getSurfaceForm(), surfaceForm) and \             # <<<<<<<<<<<<<<
 *                         currentTransition.transitionPossibleForParse(currentFsmParse) and (
 *                         currentSurfaceForm != root.getName()
 */
      }

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":579
 *         elif isinstance(maxLengthOrSurfaceForm, str):
 *             surfaceForm = maxLengthOrSurfaceForm
 *             for currentTransition in self.__finiteStateMachine.getTransitions(currentState):             # <<<<<<<<<<<<<<
 *                 if currentTransition.transitionPossibleForString(currentFsmParse.getSurfaceForm(), surfaceForm) and \
 *                         currentTransition.transitionPossibleForParse(currentFsmParse) and (
 */
    }
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":577
 *                         newFsmParse.setAgreement(currentTransition.withName())
 *                         fsmParse.append(newFsmParse)
 *         elif isinstance(maxLengthOrSurfaceForm, str):             # <<<<<<<<<<<<<<
 *             surfaceForm = maxLengthOrSurfaceForm
 *             for currentTransition in self.__finiteStateMachine.getTransitions(currentState):
 */
  }
  __pyx_L3:;

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":535
 *         return initialFsmParse
 * 
 *     cpdef __addNewParsesFromCurrentParse(self, FsmParse currentFsmParse, list fsmParse, maxLengthOrSurfaceForm,             # <<<<<<<<<<<<<<
 *                                        TxtWord root):
 *         """
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_AddTraceback("MorphologicalAnalysis.FsmMorphologicalAnalyzer.FsmMorphologicalAnalyzer.__addNewParsesFromCurrentParse", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_currentState);
  __Pyx_XDECREF(__pyx_v_currentSurfaceForm);
  __Pyx_XDECREF(__pyx_v_tmp);
  __Pyx_XDECREF(__pyx_v_surfaceForm);
  __Pyx_XDECREF((PyObject *)__pyx_v_currentTransition);
  __Pyx_XDECREF((PyObject *)__pyx_v_newFsmParse);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_19__addNewParsesFromCurrentParse(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_18__addNewParsesFromCurrentParse[] = "\n        The addNewParsesFromCurrentParseSurfaceForm method initially gets the final suffixes from input currentFsmParse\n        called as currentState, and by using the currentState information it gets the currentSurfaceForm. Then loops\n        through each currentState's transition. If the currentTransition is possible, it makes the transition.\n        The addNewParsesFromCurrentParseMaxLength method initially gets the final suffixes from input currentFsmParse\n        called as currentState, and by using the currentState information it gets the new analysis. Then loops through\n        each currentState's transition. If the currentTransition is possible, it makes the transition.\n\n        PARAMETERS\n        ----------\n        currentFsmParse : FsmParse\n            FsmParse type input.\n        fsmParse : list\n            List of FsmParse.\n        maxLengthOrSurfaceForm\n            Maximum length of the parse.\n        root : TxtWord\n            TxtWord used to make transition.\n        ";
static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_19__addNewParsesFromCurrentParse(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *__pyx_v_currentFsmParse = 0;
  PyObject *__pyx_v_fsmParse = 0;
  PyObject *__pyx_v_maxLengthOrSurfaceForm = 0;
  struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_root = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__addNewParsesFromCurrentParse (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_currentFsmParse,&__pyx_n_s_fsmParse,&__pyx_n_s_maxLengthOrSurfaceForm,&__pyx_n_s_root,0};
    PyObject* values[4] = {0,0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_currentFsmParse)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_fsmParse)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__addNewParsesFromCurrentParse", 1, 4, 4, 1); __PYX_ERR(0, 535, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_maxLengthOrSurfaceForm)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__addNewParsesFromCurrentParse", 1, 4, 4, 2); __PYX_ERR(0, 535, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_root)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__addNewParsesFromCurrentParse", 1, 4, 4, 3); __PYX_ERR(0, 535, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__addNewParsesFromCurrentParse") < 0)) __PYX_ERR(0, 535, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 4) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
      values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
    }
    __pyx_v_currentFsmParse = ((struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *)values[0]);
    __pyx_v_fsmParse = ((PyObject*)values[1]);
    __pyx_v_maxLengthOrSurfaceForm = values[2];
    __pyx_v_root = ((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)values[3]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__addNewParsesFromCurrentParse", 1, 4, 4, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 535, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("MorphologicalAnalysis.FsmMorphologicalAnalyzer.FsmMorphologicalAnalyzer.__addNewParsesFromCurrentParse", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_currentFsmParse), __pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse, 1, "currentFsmParse", 0))) __PYX_ERR(0, 535, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_fsmParse), (&PyList_Type), 1, "fsmParse", 1))) __PYX_ERR(0, 535, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_root), __pyx_ptype_10Dictionary_7TxtWord_TxtWord, 1, "root", 0))) __PYX_ERR(0, 536, __pyx_L1_error)
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_18__addNewParsesFromCurrentParse(((struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self), __pyx_v_currentFsmParse, __pyx_v_fsmParse, __pyx_v_maxLengthOrSurfaceForm, __pyx_v_root);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_18__addNewParsesFromCurrentParse(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *__pyx_v_currentFsmParse, PyObject *__pyx_v_fsmParse, PyObject *__pyx_v_maxLengthOrSurfaceForm, struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_root) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__addNewParsesFromCurrentParse", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer___addNewParsesFromCurrentParse(__pyx_v_self, __pyx_v_currentFsmParse, __pyx_v_fsmParse, __pyx_v_maxLengthOrSurfaceForm, __pyx_v_root, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 535, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.FsmMorphologicalAnalyzer.FsmMorphologicalAnalyzer.__addNewParsesFromCurrentParse", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":595
 *                         fsmParse.append(newFsmParse)
 * 
 *     cpdef bint __parseExists(self, list fsmParse, str surfaceForm):             # <<<<<<<<<<<<<<
 *         """
 *         The parseExists method is used to check the existence of the parse.
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_21__parseExists(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer___parseExists(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_fsmParse, PyObject *__pyx_v_surfaceForm, int __pyx_skip_dispatch) {
  struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *__pyx_v_currentFsmParse = 0;
  struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_root = 0;
  struct __pyx_obj_21MorphologicalAnalysis_5State_State *__pyx_v_currentState = 0;
  PyObject *__pyx_v_currentSurfaceForm = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  Py_ssize_t __pyx_t_8;
  int __pyx_t_9;
  int __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__parseExists", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_parseExists); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 595, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_21__parseExists)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        __pyx_t_5 = 0;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_5 = 1;
          }
        }
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_3)) {
          PyObject *__pyx_temp[3] = {__pyx_t_4, __pyx_v_fsmParse, __pyx_v_surfaceForm};
          __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 595, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_GOTREF(__pyx_t_2);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
          PyObject *__pyx_temp[3] = {__pyx_t_4, __pyx_v_fsmParse, __pyx_v_surfaceForm};
          __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 595, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_GOTREF(__pyx_t_2);
        } else
        #endif
        {
          __pyx_t_6 = PyTuple_New(2+__pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 595, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          if (__pyx_t_4) {
            __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4); __pyx_t_4 = NULL;
          }
          __Pyx_INCREF(__pyx_v_fsmParse);
          __Pyx_GIVEREF(__pyx_v_fsmParse);
          PyTuple_SET_ITEM(__pyx_t_6, 0+__pyx_t_5, __pyx_v_fsmParse);
          __Pyx_INCREF(__pyx_v_surfaceForm);
          __Pyx_GIVEREF(__pyx_v_surfaceForm);
          PyTuple_SET_ITEM(__pyx_t_6, 1+__pyx_t_5, __pyx_v_surfaceForm);
          __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_6, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 595, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        }
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_7 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 595, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_7;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":615
 *         cdef State currentState
 *         cdef str currentSurfaceForm
 *         while len(fsmParse) > 0:             # <<<<<<<<<<<<<<
 *             currentFsmParse = fsmParse.pop(0)
 *             root = currentFsmParse.getWord()
 */
  while (1) {
    if (unlikely(__pyx_v_fsmParse == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
      __PYX_ERR(0, 615, __pyx_L1_error)
    }
    __pyx_t_8 = PyList_GET_SIZE(__pyx_v_fsmParse); if (unlikely(__pyx_t_8 == ((Py_ssize_t)-1))) __PYX_ERR(0, 615, __pyx_L1_error)
    __pyx_t_7 = ((__pyx_t_8 > 0) != 0);
    if (!__pyx_t_7) break;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":616
 *         cdef str currentSurfaceForm
 *         while len(fsmParse) > 0:
 *             currentFsmParse = fsmParse.pop(0)             # <<<<<<<<<<<<<<
 *             root = currentFsmParse.getWord()
 *             currentState = currentFsmParse.getFinalSuffix()
 */
    if (unlikely(__pyx_v_fsmParse == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "pop");
      __PYX_ERR(0, 616, __pyx_L1_error)
    }
    __pyx_t_1 = __Pyx_PyList_PopIndex(__pyx_v_fsmParse, __pyx_int_0, 0, 1, Py_ssize_t, PyInt_FromSsize_t); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 616, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse))))) __PYX_ERR(0, 616, __pyx_L1_error)
    __Pyx_XDECREF_SET(__pyx_v_currentFsmParse, ((struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_t_1));
    __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":617
 *         while len(fsmParse) > 0:
 *             currentFsmParse = fsmParse.pop(0)
 *             root = currentFsmParse.getWord()             # <<<<<<<<<<<<<<
 *             currentState = currentFsmParse.getFinalSuffix()
 *             currentSurfaceForm = currentFsmParse.getSurfaceForm()
 */
    __pyx_t_1 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_v_currentFsmParse->__pyx_base.__pyx_vtab)->__pyx_base.getWord(((struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_currentFsmParse), 0)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 617, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_10Dictionary_7TxtWord_TxtWord))))) __PYX_ERR(0, 617, __pyx_L1_error)
    __Pyx_XDECREF_SET(__pyx_v_root, ((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)__pyx_t_1));
    __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":618
 *             currentFsmParse = fsmParse.pop(0)
 *             root = currentFsmParse.getWord()
 *             currentState = currentFsmParse.getFinalSuffix()             # <<<<<<<<<<<<<<
 *             currentSurfaceForm = currentFsmParse.getSurfaceForm()
 *             if currentState.isEndState() and currentSurfaceForm == surfaceForm:
 */
    __pyx_t_1 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_v_currentFsmParse->__pyx_base.__pyx_vtab)->getFinalSuffix(__pyx_v_currentFsmParse, 0)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 618, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_currentState, ((struct __pyx_obj_21MorphologicalAnalysis_5State_State *)__pyx_t_1));
    __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":619
 *             root = currentFsmParse.getWord()
 *             currentState = currentFsmParse.getFinalSuffix()
 *             currentSurfaceForm = currentFsmParse.getSurfaceForm()             # <<<<<<<<<<<<<<
 *             if currentState.isEndState() and currentSurfaceForm == surfaceForm:
 *                 return True
 */
    __pyx_t_1 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_v_currentFsmParse->__pyx_base.__pyx_vtab)->getSurfaceForm(__pyx_v_currentFsmParse, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 619, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_currentSurfaceForm, ((PyObject*)__pyx_t_1));
    __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":620
 *             currentState = currentFsmParse.getFinalSuffix()
 *             currentSurfaceForm = currentFsmParse.getSurfaceForm()
 *             if currentState.isEndState() and currentSurfaceForm == surfaceForm:             # <<<<<<<<<<<<<<
 *                 return True
 *             self.__addNewParsesFromCurrentParse(currentFsmParse, fsmParse, surfaceForm, root)
 */
    __pyx_t_9 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_5State_State *)__pyx_v_currentState->__pyx_vtab)->isEndState(__pyx_v_currentState, 0) != 0);
    if (__pyx_t_9) {
    } else {
      __pyx_t_7 = __pyx_t_9;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_v_currentSurfaceForm, __pyx_v_surfaceForm, Py_EQ)); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 620, __pyx_L1_error)
    __pyx_t_10 = (__pyx_t_9 != 0);
    __pyx_t_7 = __pyx_t_10;
    __pyx_L6_bool_binop_done:;
    if (__pyx_t_7) {

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":621
 *             currentSurfaceForm = currentFsmParse.getSurfaceForm()
 *             if currentState.isEndState() and currentSurfaceForm == surfaceForm:
 *                 return True             # <<<<<<<<<<<<<<
 *             self.__addNewParsesFromCurrentParse(currentFsmParse, fsmParse, surfaceForm, root)
 *         return False
 */
      __pyx_r = 1;
      goto __pyx_L0;

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":620
 *             currentState = currentFsmParse.getFinalSuffix()
 *             currentSurfaceForm = currentFsmParse.getSurfaceForm()
 *             if currentState.isEndState() and currentSurfaceForm == surfaceForm:             # <<<<<<<<<<<<<<
 *                 return True
 *             self.__addNewParsesFromCurrentParse(currentFsmParse, fsmParse, surfaceForm, root)
 */
    }

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":622
 *             if currentState.isEndState() and currentSurfaceForm == surfaceForm:
 *                 return True
 *             self.__addNewParsesFromCurrentParse(currentFsmParse, fsmParse, surfaceForm, root)             # <<<<<<<<<<<<<<
 *         return False
 * 
 */
    __pyx_t_1 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->__pyx___addNewParsesFromCurrentParse(__pyx_v_self, __pyx_v_currentFsmParse, __pyx_v_fsmParse, __pyx_v_surfaceForm, __pyx_v_root, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 622, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":623
 *                 return True
 *             self.__addNewParsesFromCurrentParse(currentFsmParse, fsmParse, surfaceForm, root)
 *         return False             # <<<<<<<<<<<<<<
 * 
 *     cpdef list __parseWord(self, list fsmParse, maxLengthOrSurfaceForm):
 */
  __pyx_r = 0;
  goto __pyx_L0;

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":595
 *                         fsmParse.append(newFsmParse)
 * 
 *     cpdef bint __parseExists(self, list fsmParse, str surfaceForm):             # <<<<<<<<<<<<<<
 *         """
 *         The parseExists method is used to check the existence of the parse.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_WriteUnraisable("MorphologicalAnalysis.FsmMorphologicalAnalyzer.FsmMorphologicalAnalyzer.__parseExists", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_currentFsmParse);
  __Pyx_XDECREF((PyObject *)__pyx_v_root);
  __Pyx_XDECREF((PyObject *)__pyx_v_currentState);
  __Pyx_XDECREF(__pyx_v_currentSurfaceForm);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_21__parseExists(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_20__parseExists[] = "\n        The parseExists method is used to check the existence of the parse.\n\n        PARAMETERS\n        ----------\n        fsmParse : list\n            List of FsmParse\n        surfaceForm : str\n            String to use during transition.\n\n        RETURNS\n        -------\n        bool\n            True when the currentState is end state and input surfaceForm id equal to currentSurfaceForm, otherwise false.\n        ";
static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_21__parseExists(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_fsmParse = 0;
  PyObject *__pyx_v_surfaceForm = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__parseExists (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_fsmParse,&__pyx_n_s_surfaceForm,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_fsmParse)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_surfaceForm)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__parseExists", 1, 2, 2, 1); __PYX_ERR(0, 595, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__parseExists") < 0)) __PYX_ERR(0, 595, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_fsmParse = ((PyObject*)values[0]);
    __pyx_v_surfaceForm = ((PyObject*)values[1]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__parseExists", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 595, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("MorphologicalAnalysis.FsmMorphologicalAnalyzer.FsmMorphologicalAnalyzer.__parseExists", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_fsmParse), (&PyList_Type), 1, "fsmParse", 1))) __PYX_ERR(0, 595, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_surfaceForm), (&PyUnicode_Type), 1, "surfaceForm", 1))) __PYX_ERR(0, 595, __pyx_L1_error)
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_20__parseExists(((struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self), __pyx_v_fsmParse, __pyx_v_surfaceForm);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_20__parseExists(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_fsmParse, PyObject *__pyx_v_surfaceForm) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__parseExists", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer___parseExists(__pyx_v_self, __pyx_v_fsmParse, __pyx_v_surfaceForm, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 595, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.FsmMorphologicalAnalyzer.FsmMorphologicalAnalyzer.__parseExists", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":625
 *         return False
 * 
 *     cpdef list __parseWord(self, list fsmParse, maxLengthOrSurfaceForm):             # <<<<<<<<<<<<<<
 *         """
 *         The parseWordSurfaceForm method is used to parse a given fsmParse. It simply adds new parses to the current
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_23__parseWord(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer___parseWord(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_fsmParse, PyObject *__pyx_v_maxLengthOrSurfaceForm, int __pyx_skip_dispatch) {
  PyObject *__pyx_v_result = 0;
  int __pyx_v_maxLength;
  int __pyx_v_i;
  struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *__pyx_v_currentFsmParse = 0;
  struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_root = 0;
  struct __pyx_obj_21MorphologicalAnalysis_5State_State *__pyx_v_currentState = 0;
  PyObject *__pyx_v_currentSurfaceForm = 0;
  PyObject *__pyx_v_surfaceForm = 0;
  int __pyx_v_exists;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_t_8;
  Py_ssize_t __pyx_t_9;
  Py_ssize_t __pyx_t_10;
  int __pyx_t_11;
  int __pyx_t_12;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__parseWord", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_parseWord); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 625, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_23__parseWord)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        __pyx_t_5 = 0;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_5 = 1;
          }
        }
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_3)) {
          PyObject *__pyx_temp[3] = {__pyx_t_4, __pyx_v_fsmParse, __pyx_v_maxLengthOrSurfaceForm};
          __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 625, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_GOTREF(__pyx_t_2);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
          PyObject *__pyx_temp[3] = {__pyx_t_4, __pyx_v_fsmParse, __pyx_v_maxLengthOrSurfaceForm};
          __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 625, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_GOTREF(__pyx_t_2);
        } else
        #endif
        {
          __pyx_t_6 = PyTuple_New(2+__pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 625, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          if (__pyx_t_4) {
            __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4); __pyx_t_4 = NULL;
          }
          __Pyx_INCREF(__pyx_v_fsmParse);
          __Pyx_GIVEREF(__pyx_v_fsmParse);
          PyTuple_SET_ITEM(__pyx_t_6, 0+__pyx_t_5, __pyx_v_fsmParse);
          __Pyx_INCREF(__pyx_v_maxLengthOrSurfaceForm);
          __Pyx_GIVEREF(__pyx_v_maxLengthOrSurfaceForm);
          PyTuple_SET_ITEM(__pyx_t_6, 1+__pyx_t_5, __pyx_v_maxLengthOrSurfaceForm);
          __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_6, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 625, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        }
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (!(likely(PyList_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "list", Py_TYPE(__pyx_t_2)->tp_name), 0))) __PYX_ERR(0, 625, __pyx_L1_error)
        __pyx_r = ((PyObject*)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":651
 *         cdef str currentSurfaceForm, surfaceForm
 *         cdef bint exists
 *         result = []             # <<<<<<<<<<<<<<
 *         if isinstance(maxLengthOrSurfaceForm, int):
 *             maxLength = maxLengthOrSurfaceForm
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 651, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_result = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":652
 *         cdef bint exists
 *         result = []
 *         if isinstance(maxLengthOrSurfaceForm, int):             # <<<<<<<<<<<<<<
 *             maxLength = maxLengthOrSurfaceForm
 *             while len(fsmParse) > 0:
 */
  __pyx_t_7 = PyInt_Check(__pyx_v_maxLengthOrSurfaceForm); 
  __pyx_t_8 = (__pyx_t_7 != 0);
  if (__pyx_t_8) {

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":653
 *         result = []
 *         if isinstance(maxLengthOrSurfaceForm, int):
 *             maxLength = maxLengthOrSurfaceForm             # <<<<<<<<<<<<<<
 *             while len(fsmParse) > 0:
 *                 currentFsmParse = fsmParse.pop(0)
 */
    __pyx_t_5 = __Pyx_PyInt_As_int(__pyx_v_maxLengthOrSurfaceForm); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 653, __pyx_L1_error)
    __pyx_v_maxLength = __pyx_t_5;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":654
 *         if isinstance(maxLengthOrSurfaceForm, int):
 *             maxLength = maxLengthOrSurfaceForm
 *             while len(fsmParse) > 0:             # <<<<<<<<<<<<<<
 *                 currentFsmParse = fsmParse.pop(0)
 *                 root = currentFsmParse.getWord()
 */
    while (1) {
      if (unlikely(__pyx_v_fsmParse == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
        __PYX_ERR(0, 654, __pyx_L1_error)
      }
      __pyx_t_9 = PyList_GET_SIZE(__pyx_v_fsmParse); if (unlikely(__pyx_t_9 == ((Py_ssize_t)-1))) __PYX_ERR(0, 654, __pyx_L1_error)
      __pyx_t_8 = ((__pyx_t_9 > 0) != 0);
      if (!__pyx_t_8) break;

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":655
 *             maxLength = maxLengthOrSurfaceForm
 *             while len(fsmParse) > 0:
 *                 currentFsmParse = fsmParse.pop(0)             # <<<<<<<<<<<<<<
 *                 root = currentFsmParse.getWord()
 *                 currentState = currentFsmParse.getFinalSuffix()
 */
      if (unlikely(__pyx_v_fsmParse == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "pop");
        __PYX_ERR(0, 655, __pyx_L1_error)
      }
      __pyx_t_1 = __Pyx_PyList_PopIndex(__pyx_v_fsmParse, __pyx_int_0, 0, 1, Py_ssize_t, PyInt_FromSsize_t); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 655, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse))))) __PYX_ERR(0, 655, __pyx_L1_error)
      __Pyx_XDECREF_SET(__pyx_v_currentFsmParse, ((struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_t_1));
      __pyx_t_1 = 0;

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":656
 *             while len(fsmParse) > 0:
 *                 currentFsmParse = fsmParse.pop(0)
 *                 root = currentFsmParse.getWord()             # <<<<<<<<<<<<<<
 *                 currentState = currentFsmParse.getFinalSuffix()
 *                 currentSurfaceForm = currentFsmParse.getSurfaceForm()
 */
      __pyx_t_1 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_v_currentFsmParse->__pyx_base.__pyx_vtab)->__pyx_base.getWord(((struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_currentFsmParse), 0)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 656, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_10Dictionary_7TxtWord_TxtWord))))) __PYX_ERR(0, 656, __pyx_L1_error)
      __Pyx_XDECREF_SET(__pyx_v_root, ((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)__pyx_t_1));
      __pyx_t_1 = 0;

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":657
 *                 currentFsmParse = fsmParse.pop(0)
 *                 root = currentFsmParse.getWord()
 *                 currentState = currentFsmParse.getFinalSuffix()             # <<<<<<<<<<<<<<
 *                 currentSurfaceForm = currentFsmParse.getSurfaceForm()
 *                 if currentState.isEndState() and len(currentSurfaceForm) <= maxLength:
 */
      __pyx_t_1 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_v_currentFsmParse->__pyx_base.__pyx_vtab)->getFinalSuffix(__pyx_v_currentFsmParse, 0)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 657, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_currentState, ((struct __pyx_obj_21MorphologicalAnalysis_5State_State *)__pyx_t_1));
      __pyx_t_1 = 0;

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":658
 *                 root = currentFsmParse.getWord()
 *                 currentState = currentFsmParse.getFinalSuffix()
 *                 currentSurfaceForm = currentFsmParse.getSurfaceForm()             # <<<<<<<<<<<<<<
 *                 if currentState.isEndState() and len(currentSurfaceForm) <= maxLength:
 *                     exists = False
 */
      __pyx_t_1 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_v_currentFsmParse->__pyx_base.__pyx_vtab)->getSurfaceForm(__pyx_v_currentFsmParse, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 658, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_currentSurfaceForm, ((PyObject*)__pyx_t_1));
      __pyx_t_1 = 0;

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":659
 *                 currentState = currentFsmParse.getFinalSuffix()
 *                 currentSurfaceForm = currentFsmParse.getSurfaceForm()
 *                 if currentState.isEndState() and len(currentSurfaceForm) <= maxLength:             # <<<<<<<<<<<<<<
 *                     exists = False
 *                     for i in range(len(result)):
 */
      __pyx_t_7 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_5State_State *)__pyx_v_currentState->__pyx_vtab)->isEndState(__pyx_v_currentState, 0) != 0);
      if (__pyx_t_7) {
      } else {
        __pyx_t_8 = __pyx_t_7;
        goto __pyx_L7_bool_binop_done;
      }
      if (unlikely(__pyx_v_currentSurfaceForm == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
        __PYX_ERR(0, 659, __pyx_L1_error)
      }
      __pyx_t_9 = __Pyx_PyUnicode_GET_LENGTH(__pyx_v_currentSurfaceForm); if (unlikely(__pyx_t_9 == ((Py_ssize_t)-1))) __PYX_ERR(0, 659, __pyx_L1_error)
      __pyx_t_7 = ((__pyx_t_9 <= __pyx_v_maxLength) != 0);
      __pyx_t_8 = __pyx_t_7;
      __pyx_L7_bool_binop_done:;
      if (__pyx_t_8) {

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":660
 *                 currentSurfaceForm = currentFsmParse.getSurfaceForm()
 *                 if currentState.isEndState() and len(currentSurfaceForm) <= maxLength:
 *                     exists = False             # <<<<<<<<<<<<<<
 *                     for i in range(len(result)):
 *                         if currentFsmParse.suffixList() == result[i].suffixList():
 */
        __pyx_v_exists = 0;

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":661
 *                 if currentState.isEndState() and len(currentSurfaceForm) <= maxLength:
 *                     exists = False
 *                     for i in range(len(result)):             # <<<<<<<<<<<<<<
 *                         if currentFsmParse.suffixList() == result[i].suffixList():
 *                             exists = True
 */
        __pyx_t_9 = PyList_GET_SIZE(__pyx_v_result); if (unlikely(__pyx_t_9 == ((Py_ssize_t)-1))) __PYX_ERR(0, 661, __pyx_L1_error)
        __pyx_t_10 = __pyx_t_9;
        for (__pyx_t_5 = 0; __pyx_t_5 < __pyx_t_10; __pyx_t_5+=1) {
          __pyx_v_i = __pyx_t_5;

          /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":662
 *                     exists = False
 *                     for i in range(len(result)):
 *                         if currentFsmParse.suffixList() == result[i].suffixList():             # <<<<<<<<<<<<<<
 *                             exists = True
 *                             break
 */
          __pyx_t_1 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_v_currentFsmParse->__pyx_base.__pyx_vtab)->suffixList(__pyx_v_currentFsmParse, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 662, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_3 = __Pyx_GetItemInt_List(__pyx_v_result, __pyx_v_i, int, 1, __Pyx_PyInt_From_int, 1, 1, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 662, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_suffixList); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 662, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __pyx_t_3 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
            __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_6);
            if (likely(__pyx_t_3)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
              __Pyx_INCREF(__pyx_t_3);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_6, function);
            }
          }
          __pyx_t_2 = (__pyx_t_3) ? __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_3) : __Pyx_PyObject_CallNoArg(__pyx_t_6);
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 662, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_8 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_t_2, Py_EQ)); if (unlikely(__pyx_t_8 < 0)) __PYX_ERR(0, 662, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          if (__pyx_t_8) {

            /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":663
 *                     for i in range(len(result)):
 *                         if currentFsmParse.suffixList() == result[i].suffixList():
 *                             exists = True             # <<<<<<<<<<<<<<
 *                             break
 *                     if not exists:
 */
            __pyx_v_exists = 1;

            /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":664
 *                         if currentFsmParse.suffixList() == result[i].suffixList():
 *                             exists = True
 *                             break             # <<<<<<<<<<<<<<
 *                     if not exists:
 *                         result.append(currentFsmParse)
 */
            goto __pyx_L10_break;

            /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":662
 *                     exists = False
 *                     for i in range(len(result)):
 *                         if currentFsmParse.suffixList() == result[i].suffixList():             # <<<<<<<<<<<<<<
 *                             exists = True
 *                             break
 */
          }
        }
        __pyx_L10_break:;

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":665
 *                             exists = True
 *                             break
 *                     if not exists:             # <<<<<<<<<<<<<<
 *                         result.append(currentFsmParse)
 *                         currentFsmParse.constructInflectionalGroups()
 */
        __pyx_t_8 = ((!(__pyx_v_exists != 0)) != 0);
        if (__pyx_t_8) {

          /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":666
 *                             break
 *                     if not exists:
 *                         result.append(currentFsmParse)             # <<<<<<<<<<<<<<
 *                         currentFsmParse.constructInflectionalGroups()
 *                 self.__addNewParsesFromCurrentParse(currentFsmParse, fsmParse, maxLength, root)
 */
          __pyx_t_11 = __Pyx_PyList_Append(__pyx_v_result, ((PyObject *)__pyx_v_currentFsmParse)); if (unlikely(__pyx_t_11 == ((int)-1))) __PYX_ERR(0, 666, __pyx_L1_error)

          /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":667
 *                     if not exists:
 *                         result.append(currentFsmParse)
 *                         currentFsmParse.constructInflectionalGroups()             # <<<<<<<<<<<<<<
 *                 self.__addNewParsesFromCurrentParse(currentFsmParse, fsmParse, maxLength, root)
 *         elif isinstance(maxLengthOrSurfaceForm, str):
 */
          __pyx_t_2 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_v_currentFsmParse->__pyx_base.__pyx_vtab)->constructInflectionalGroups(__pyx_v_currentFsmParse, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 667, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

          /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":665
 *                             exists = True
 *                             break
 *                     if not exists:             # <<<<<<<<<<<<<<
 *                         result.append(currentFsmParse)
 *                         currentFsmParse.constructInflectionalGroups()
 */
        }

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":659
 *                 currentState = currentFsmParse.getFinalSuffix()
 *                 currentSurfaceForm = currentFsmParse.getSurfaceForm()
 *                 if currentState.isEndState() and len(currentSurfaceForm) <= maxLength:             # <<<<<<<<<<<<<<
 *                     exists = False
 *                     for i in range(len(result)):
 */
      }

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":668
 *                         result.append(currentFsmParse)
 *                         currentFsmParse.constructInflectionalGroups()
 *                 self.__addNewParsesFromCurrentParse(currentFsmParse, fsmParse, maxLength, root)             # <<<<<<<<<<<<<<
 *         elif isinstance(maxLengthOrSurfaceForm, str):
 *             surfaceForm = maxLengthOrSurfaceForm
 */
      __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_maxLength); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 668, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_1 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->__pyx___addNewParsesFromCurrentParse(__pyx_v_self, __pyx_v_currentFsmParse, __pyx_v_fsmParse, __pyx_t_2, __pyx_v_root, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 668, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":652
 *         cdef bint exists
 *         result = []
 *         if isinstance(maxLengthOrSurfaceForm, int):             # <<<<<<<<<<<<<<
 *             maxLength = maxLengthOrSurfaceForm
 *             while len(fsmParse) > 0:
 */
    goto __pyx_L3;
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":669
 *                         currentFsmParse.constructInflectionalGroups()
 *                 self.__addNewParsesFromCurrentParse(currentFsmParse, fsmParse, maxLength, root)
 *         elif isinstance(maxLengthOrSurfaceForm, str):             # <<<<<<<<<<<<<<
 *             surfaceForm = maxLengthOrSurfaceForm
 *             while len(fsmParse) > 0:
 */
  __pyx_t_8 = PyUnicode_Check(__pyx_v_maxLengthOrSurfaceForm); 
  __pyx_t_7 = (__pyx_t_8 != 0);
  if (__pyx_t_7) {

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":670
 *                 self.__addNewParsesFromCurrentParse(currentFsmParse, fsmParse, maxLength, root)
 *         elif isinstance(maxLengthOrSurfaceForm, str):
 *             surfaceForm = maxLengthOrSurfaceForm             # <<<<<<<<<<<<<<
 *             while len(fsmParse) > 0:
 *                 currentFsmParse = fsmParse.pop(0)
 */
    if (!(likely(PyUnicode_CheckExact(__pyx_v_maxLengthOrSurfaceForm))||((__pyx_v_maxLengthOrSurfaceForm) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_v_maxLengthOrSurfaceForm)->tp_name), 0))) __PYX_ERR(0, 670, __pyx_L1_error)
    __pyx_t_1 = __pyx_v_maxLengthOrSurfaceForm;
    __Pyx_INCREF(__pyx_t_1);
    __pyx_v_surfaceForm = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":671
 *         elif isinstance(maxLengthOrSurfaceForm, str):
 *             surfaceForm = maxLengthOrSurfaceForm
 *             while len(fsmParse) > 0:             # <<<<<<<<<<<<<<
 *                 currentFsmParse = fsmParse.pop(0)
 *                 root = currentFsmParse.getWord()
 */
    while (1) {
      if (unlikely(__pyx_v_fsmParse == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
        __PYX_ERR(0, 671, __pyx_L1_error)
      }
      __pyx_t_9 = PyList_GET_SIZE(__pyx_v_fsmParse); if (unlikely(__pyx_t_9 == ((Py_ssize_t)-1))) __PYX_ERR(0, 671, __pyx_L1_error)
      __pyx_t_7 = ((__pyx_t_9 > 0) != 0);
      if (!__pyx_t_7) break;

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":672
 *             surfaceForm = maxLengthOrSurfaceForm
 *             while len(fsmParse) > 0:
 *                 currentFsmParse = fsmParse.pop(0)             # <<<<<<<<<<<<<<
 *                 root = currentFsmParse.getWord()
 *                 currentState = currentFsmParse.getFinalSuffix()
 */
      if (unlikely(__pyx_v_fsmParse == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "pop");
        __PYX_ERR(0, 672, __pyx_L1_error)
      }
      __pyx_t_1 = __Pyx_PyList_PopIndex(__pyx_v_fsmParse, __pyx_int_0, 0, 1, Py_ssize_t, PyInt_FromSsize_t); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 672, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse))))) __PYX_ERR(0, 672, __pyx_L1_error)
      __Pyx_XDECREF_SET(__pyx_v_currentFsmParse, ((struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_t_1));
      __pyx_t_1 = 0;

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":673
 *             while len(fsmParse) > 0:
 *                 currentFsmParse = fsmParse.pop(0)
 *                 root = currentFsmParse.getWord()             # <<<<<<<<<<<<<<
 *                 currentState = currentFsmParse.getFinalSuffix()
 *                 currentSurfaceForm = currentFsmParse.getSurfaceForm()
 */
      __pyx_t_1 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_v_currentFsmParse->__pyx_base.__pyx_vtab)->__pyx_base.getWord(((struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_currentFsmParse), 0)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 673, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_10Dictionary_7TxtWord_TxtWord))))) __PYX_ERR(0, 673, __pyx_L1_error)
      __Pyx_XDECREF_SET(__pyx_v_root, ((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)__pyx_t_1));
      __pyx_t_1 = 0;

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":674
 *                 currentFsmParse = fsmParse.pop(0)
 *                 root = currentFsmParse.getWord()
 *                 currentState = currentFsmParse.getFinalSuffix()             # <<<<<<<<<<<<<<
 *                 currentSurfaceForm = currentFsmParse.getSurfaceForm()
 *                 if currentState.isEndState() and currentSurfaceForm == surfaceForm:
 */
      __pyx_t_1 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_v_currentFsmParse->__pyx_base.__pyx_vtab)->getFinalSuffix(__pyx_v_currentFsmParse, 0)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 674, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_currentState, ((struct __pyx_obj_21MorphologicalAnalysis_5State_State *)__pyx_t_1));
      __pyx_t_1 = 0;

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":675
 *                 root = currentFsmParse.getWord()
 *                 currentState = currentFsmParse.getFinalSuffix()
 *                 currentSurfaceForm = currentFsmParse.getSurfaceForm()             # <<<<<<<<<<<<<<
 *                 if currentState.isEndState() and currentSurfaceForm == surfaceForm:
 *                     exists = False
 */
      __pyx_t_1 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_v_currentFsmParse->__pyx_base.__pyx_vtab)->getSurfaceForm(__pyx_v_currentFsmParse, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 675, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_currentSurfaceForm, ((PyObject*)__pyx_t_1));
      __pyx_t_1 = 0;

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":676
 *                 currentState = currentFsmParse.getFinalSuffix()
 *                 currentSurfaceForm = currentFsmParse.getSurfaceForm()
 *                 if currentState.isEndState() and currentSurfaceForm == surfaceForm:             # <<<<<<<<<<<<<<
 *                     exists = False
 *                     for i in range(len(result)):
 */
      __pyx_t_8 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_5State_State *)__pyx_v_currentState->__pyx_vtab)->isEndState(__pyx_v_currentState, 0) != 0);
      if (__pyx_t_8) {
      } else {
        __pyx_t_7 = __pyx_t_8;
        goto __pyx_L16_bool_binop_done;
      }
      __pyx_t_8 = (__Pyx_PyUnicode_Equals(__pyx_v_currentSurfaceForm, __pyx_v_surfaceForm, Py_EQ)); if (unlikely(__pyx_t_8 < 0)) __PYX_ERR(0, 676, __pyx_L1_error)
      __pyx_t_12 = (__pyx_t_8 != 0);
      __pyx_t_7 = __pyx_t_12;
      __pyx_L16_bool_binop_done:;
      if (__pyx_t_7) {

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":677
 *                 currentSurfaceForm = currentFsmParse.getSurfaceForm()
 *                 if currentState.isEndState() and currentSurfaceForm == surfaceForm:
 *                     exists = False             # <<<<<<<<<<<<<<
 *                     for i in range(len(result)):
 *                         if currentFsmParse.suffixList() == result[i].suffixList():
 */
        __pyx_v_exists = 0;

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":678
 *                 if currentState.isEndState() and currentSurfaceForm == surfaceForm:
 *                     exists = False
 *                     for i in range(len(result)):             # <<<<<<<<<<<<<<
 *                         if currentFsmParse.suffixList() == result[i].suffixList():
 *                             exists = True
 */
        __pyx_t_9 = PyList_GET_SIZE(__pyx_v_result); if (unlikely(__pyx_t_9 == ((Py_ssize_t)-1))) __PYX_ERR(0, 678, __pyx_L1_error)
        __pyx_t_10 = __pyx_t_9;
        for (__pyx_t_5 = 0; __pyx_t_5 < __pyx_t_10; __pyx_t_5+=1) {
          __pyx_v_i = __pyx_t_5;

          /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":679
 *                     exists = False
 *                     for i in range(len(result)):
 *                         if currentFsmParse.suffixList() == result[i].suffixList():             # <<<<<<<<<<<<<<
 *                             exists = True
 *                             break
 */
          __pyx_t_1 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_v_currentFsmParse->__pyx_base.__pyx_vtab)->suffixList(__pyx_v_currentFsmParse, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 679, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_6 = __Pyx_GetItemInt_List(__pyx_v_result, __pyx_v_i, int, 1, __Pyx_PyInt_From_int, 1, 1, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 679, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_suffixList); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 679, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_6 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
            __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
            if (likely(__pyx_t_6)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
              __Pyx_INCREF(__pyx_t_6);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_3, function);
            }
          }
          __pyx_t_2 = (__pyx_t_6) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_6) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 679, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_t_2, Py_EQ)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 679, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          if (__pyx_t_7) {

            /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":680
 *                     for i in range(len(result)):
 *                         if currentFsmParse.suffixList() == result[i].suffixList():
 *                             exists = True             # <<<<<<<<<<<<<<
 *                             break
 *                     if not exists:
 */
            __pyx_v_exists = 1;

            /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":681
 *                         if currentFsmParse.suffixList() == result[i].suffixList():
 *                             exists = True
 *                             break             # <<<<<<<<<<<<<<
 *                     if not exists:
 *                         result.append(currentFsmParse)
 */
            goto __pyx_L19_break;

            /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":679
 *                     exists = False
 *                     for i in range(len(result)):
 *                         if currentFsmParse.suffixList() == result[i].suffixList():             # <<<<<<<<<<<<<<
 *                             exists = True
 *                             break
 */
          }
        }
        __pyx_L19_break:;

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":682
 *                             exists = True
 *                             break
 *                     if not exists:             # <<<<<<<<<<<<<<
 *                         result.append(currentFsmParse)
 *                         currentFsmParse.constructInflectionalGroups()
 */
        __pyx_t_7 = ((!(__pyx_v_exists != 0)) != 0);
        if (__pyx_t_7) {

          /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":683
 *                             break
 *                     if not exists:
 *                         result.append(currentFsmParse)             # <<<<<<<<<<<<<<
 *                         currentFsmParse.constructInflectionalGroups()
 *                 self.__addNewParsesFromCurrentParse(currentFsmParse, fsmParse, surfaceForm, root)
 */
          __pyx_t_11 = __Pyx_PyList_Append(__pyx_v_result, ((PyObject *)__pyx_v_currentFsmParse)); if (unlikely(__pyx_t_11 == ((int)-1))) __PYX_ERR(0, 683, __pyx_L1_error)

          /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":684
 *                     if not exists:
 *                         result.append(currentFsmParse)
 *                         currentFsmParse.constructInflectionalGroups()             # <<<<<<<<<<<<<<
 *                 self.__addNewParsesFromCurrentParse(currentFsmParse, fsmParse, surfaceForm, root)
 *         return result
 */
          __pyx_t_2 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_v_currentFsmParse->__pyx_base.__pyx_vtab)->constructInflectionalGroups(__pyx_v_currentFsmParse, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 684, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

          /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":682
 *                             exists = True
 *                             break
 *                     if not exists:             # <<<<<<<<<<<<<<
 *                         result.append(currentFsmParse)
 *                         currentFsmParse.constructInflectionalGroups()
 */
        }

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":676
 *                 currentState = currentFsmParse.getFinalSuffix()
 *                 currentSurfaceForm = currentFsmParse.getSurfaceForm()
 *                 if currentState.isEndState() and currentSurfaceForm == surfaceForm:             # <<<<<<<<<<<<<<
 *                     exists = False
 *                     for i in range(len(result)):
 */
      }

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":685
 *                         result.append(currentFsmParse)
 *                         currentFsmParse.constructInflectionalGroups()
 *                 self.__addNewParsesFromCurrentParse(currentFsmParse, fsmParse, surfaceForm, root)             # <<<<<<<<<<<<<<
 *         return result
 * 
 */
      __pyx_t_2 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->__pyx___addNewParsesFromCurrentParse(__pyx_v_self, __pyx_v_currentFsmParse, __pyx_v_fsmParse, __pyx_v_surfaceForm, __pyx_v_root, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 685, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":669
 *                         currentFsmParse.constructInflectionalGroups()
 *                 self.__addNewParsesFromCurrentParse(currentFsmParse, fsmParse, maxLength, root)
 *         elif isinstance(maxLengthOrSurfaceForm, str):             # <<<<<<<<<<<<<<
 *             surfaceForm = maxLengthOrSurfaceForm
 *             while len(fsmParse) > 0:
 */
  }
  __pyx_L3:;

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":686
 *                         currentFsmParse.constructInflectionalGroups()
 *                 self.__addNewParsesFromCurrentParse(currentFsmParse, fsmParse, surfaceForm, root)
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     cpdef list morphologicalAnalysisRoot(self, str surfaceForm, TxtWord root, state=None):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":625
 *         return False
 * 
 *     cpdef list __parseWord(self, list fsmParse, maxLengthOrSurfaceForm):             # <<<<<<<<<<<<<<
 *         """
 *         The parseWordSurfaceForm method is used to parse a given fsmParse. It simply adds new parses to the current
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("MorphologicalAnalysis.FsmMorphologicalAnalyzer.FsmMorphologicalAnalyzer.__parseWord", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF((PyObject *)__pyx_v_currentFsmParse);
  __Pyx_XDECREF((PyObject *)__pyx_v_root);
  __Pyx_XDECREF((PyObject *)__pyx_v_currentState);
  __Pyx_XDECREF(__pyx_v_currentSurfaceForm);
  __Pyx_XDECREF(__pyx_v_surfaceForm);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_23__parseWord(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_22__parseWord[] = "\n        The parseWordSurfaceForm method is used to parse a given fsmParse. It simply adds new parses to the current\n        parse by using addNewParsesFromCurrentParse method.\n        The parseWordMaxLength method is used to parse a given fsmParse. It simply adds new parses to the current parse\n        by using addNewParsesFromCurrentParse method.\n\n        PARAMETERS\n        ----------\n        fsmParse : list\n            a list of FsmParse\n        maxLengthOrSurfaceForm\n            maximum length of the surfaceform.\n\n        RETURNS\n        -------\n        list\n            Result list which has the currentFsmParse.\n        ";
static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_23__parseWord(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_fsmParse = 0;
  PyObject *__pyx_v_maxLengthOrSurfaceForm = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__parseWord (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_fsmParse,&__pyx_n_s_maxLengthOrSurfaceForm,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_fsmParse)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_maxLengthOrSurfaceForm)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__parseWord", 1, 2, 2, 1); __PYX_ERR(0, 625, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__parseWord") < 0)) __PYX_ERR(0, 625, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_fsmParse = ((PyObject*)values[0]);
    __pyx_v_maxLengthOrSurfaceForm = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__parseWord", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 625, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("MorphologicalAnalysis.FsmMorphologicalAnalyzer.FsmMorphologicalAnalyzer.__parseWord", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_fsmParse), (&PyList_Type), 1, "fsmParse", 1))) __PYX_ERR(0, 625, __pyx_L1_error)
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_22__parseWord(((struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self), __pyx_v_fsmParse, __pyx_v_maxLengthOrSurfaceForm);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_22__parseWord(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_fsmParse, PyObject *__pyx_v_maxLengthOrSurfaceForm) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__parseWord", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer___parseWord(__pyx_v_self, __pyx_v_fsmParse, __pyx_v_maxLengthOrSurfaceForm, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 625, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.FsmMorphologicalAnalyzer.FsmMorphologicalAnalyzer.__parseWord", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":688
 *         return result
 * 
 *     cpdef list morphologicalAnalysisRoot(self, str surfaceForm, TxtWord root, state=None):             # <<<<<<<<<<<<<<
 *         """
 *         The morphologicalAnalysis with 3 inputs is used to initialize an {@link ArrayList} and add a new FsmParse
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_25morphologicalAnalysisRoot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_morphologicalAnalysisRoot(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_surfaceForm, struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_root, int __pyx_skip_dispatch, struct __pyx_opt_args_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_morphologicalAnalysisRoot *__pyx_optional_args) {
  PyObject *__pyx_v_state = ((PyObject *)Py_None);
  PyObject *__pyx_v_initialFsmParse = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("morphologicalAnalysisRoot", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_state = __pyx_optional_args->state;
    }
  }
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_morphologicalAnalysisRoot); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 688, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_25morphologicalAnalysisRoot)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        __pyx_t_5 = 0;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_5 = 1;
          }
        }
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_3)) {
          PyObject *__pyx_temp[4] = {__pyx_t_4, __pyx_v_surfaceForm, ((PyObject *)__pyx_v_root), __pyx_v_state};
          __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_5, 3+__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 688, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_GOTREF(__pyx_t_2);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
          PyObject *__pyx_temp[4] = {__pyx_t_4, __pyx_v_surfaceForm, ((PyObject *)__pyx_v_root), __pyx_v_state};
          __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_5, 3+__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 688, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_GOTREF(__pyx_t_2);
        } else
        #endif
        {
          __pyx_t_6 = PyTuple_New(3+__pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 688, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          if (__pyx_t_4) {
            __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4); __pyx_t_4 = NULL;
          }
          __Pyx_INCREF(__pyx_v_surfaceForm);
          __Pyx_GIVEREF(__pyx_v_surfaceForm);
          PyTuple_SET_ITEM(__pyx_t_6, 0+__pyx_t_5, __pyx_v_surfaceForm);
          __Pyx_INCREF(((PyObject *)__pyx_v_root));
          __Pyx_GIVEREF(((PyObject *)__pyx_v_root));
          PyTuple_SET_ITEM(__pyx_t_6, 1+__pyx_t_5, ((PyObject *)__pyx_v_root));
          __Pyx_INCREF(__pyx_v_state);
          __Pyx_GIVEREF(__pyx_v_state);
          PyTuple_SET_ITEM(__pyx_t_6, 2+__pyx_t_5, __pyx_v_state);
          __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_6, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 688, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        }
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (!(likely(PyList_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "list", Py_TYPE(__pyx_t_2)->tp_name), 0))) __PYX_ERR(0, 688, __pyx_L1_error)
        __pyx_r = ((PyObject*)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":708
 *         """
 *         cdef list initialFsmParse
 *         if state is None:             # <<<<<<<<<<<<<<
 *             initialFsmParse = []
 *             self.__initializeParseListFromRoot(initialFsmParse, root, self.isProperNoun(surfaceForm))
 */
  __pyx_t_7 = (__pyx_v_state == Py_None);
  __pyx_t_8 = (__pyx_t_7 != 0);
  if (__pyx_t_8) {

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":709
 *         cdef list initialFsmParse
 *         if state is None:
 *             initialFsmParse = []             # <<<<<<<<<<<<<<
 *             self.__initializeParseListFromRoot(initialFsmParse, root, self.isProperNoun(surfaceForm))
 *         else:
 */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 709, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_initialFsmParse = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":710
 *         if state is None:
 *             initialFsmParse = []
 *             self.__initializeParseListFromRoot(initialFsmParse, root, self.isProperNoun(surfaceForm))             # <<<<<<<<<<<<<<
 *         else:
 *             initialFsmParse = [FsmParse(root, self.__finiteStateMachine.getState(state))]
 */
    __pyx_t_1 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->__pyx___initializeParseListFromRoot(__pyx_v_self, __pyx_v_initialFsmParse, __pyx_v_root, ((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->isProperNoun(__pyx_v_self, __pyx_v_surfaceForm, 0), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 710, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":708
 *         """
 *         cdef list initialFsmParse
 *         if state is None:             # <<<<<<<<<<<<<<
 *             initialFsmParse = []
 *             self.__initializeParseListFromRoot(initialFsmParse, root, self.isProperNoun(surfaceForm))
 */
    goto __pyx_L3;
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":712
 *             self.__initializeParseListFromRoot(initialFsmParse, root, self.isProperNoun(surfaceForm))
 *         else:
 *             initialFsmParse = [FsmParse(root, self.__finiteStateMachine.getState(state))]             # <<<<<<<<<<<<<<
 *         return self.__parseWord(initialFsmParse, surfaceForm)
 * 
 */
  /*else*/ {
    if (!(likely(PyUnicode_CheckExact(__pyx_v_state))||((__pyx_v_state) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_v_state)->tp_name), 0))) __PYX_ERR(0, 712, __pyx_L1_error)
    __pyx_t_1 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine *)__pyx_v_self->__pyx___finiteStateMachine->__pyx_vtab)->getState(__pyx_v_self->__pyx___finiteStateMachine, ((PyObject*)__pyx_v_state), 0)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 712, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 712, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(((PyObject *)__pyx_v_root));
    __Pyx_GIVEREF(((PyObject *)__pyx_v_root));
    PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_v_root));
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_1);
    __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse), __pyx_t_2, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 712, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 712, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_1);
    PyList_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
    __pyx_t_1 = 0;
    __pyx_v_initialFsmParse = ((PyObject*)__pyx_t_2);
    __pyx_t_2 = 0;
  }
  __pyx_L3:;

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":713
 *         else:
 *             initialFsmParse = [FsmParse(root, self.__finiteStateMachine.getState(state))]
 *         return self.__parseWord(initialFsmParse, surfaceForm)             # <<<<<<<<<<<<<<
 * 
 *     cpdef list generateAllParses(self, TxtWord root, int maxLength):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->__pyx___parseWord(__pyx_v_self, __pyx_v_initialFsmParse, __pyx_v_surfaceForm, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 713, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":688
 *         return result
 * 
 *     cpdef list morphologicalAnalysisRoot(self, str surfaceForm, TxtWord root, state=None):             # <<<<<<<<<<<<<<
 *         """
 *         The morphologicalAnalysis with 3 inputs is used to initialize an {@link ArrayList} and add a new FsmParse
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("MorphologicalAnalysis.FsmMorphologicalAnalyzer.FsmMorphologicalAnalyzer.morphologicalAnalysisRoot", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_initialFsmParse);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_25morphologicalAnalysisRoot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_24morphologicalAnalysisRoot[] = "\n        The morphologicalAnalysis with 3 inputs is used to initialize an {@link ArrayList} and add a new FsmParse\n        with given root and state.\n\n        PARAMETERS\n        ----------\n        root : TxtWord\n            TxtWord input.\n        surfaceForm : str\n            String input to use for parsing.\n        state : str\n            String input.\n\n        RETURNS\n        -------\n        list\n            parseWord method with newly populated FsmParse ArrayList and input surfaceForm.\n        ";
static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_25morphologicalAnalysisRoot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_surfaceForm = 0;
  struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_root = 0;
  PyObject *__pyx_v_state = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("morphologicalAnalysisRoot (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_surfaceForm,&__pyx_n_s_root,&__pyx_n_s_state,0};
    PyObject* values[3] = {0,0,0};
    values[2] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_surfaceForm)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_root)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("morphologicalAnalysisRoot", 0, 2, 3, 1); __PYX_ERR(0, 688, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_state);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "morphologicalAnalysisRoot") < 0)) __PYX_ERR(0, 688, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_surfaceForm = ((PyObject*)values[0]);
    __pyx_v_root = ((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)values[1]);
    __pyx_v_state = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("morphologicalAnalysisRoot", 0, 2, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 688, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("MorphologicalAnalysis.FsmMorphologicalAnalyzer.FsmMorphologicalAnalyzer.morphologicalAnalysisRoot", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_surfaceForm), (&PyUnicode_Type), 1, "surfaceForm", 1))) __PYX_ERR(0, 688, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_root), __pyx_ptype_10Dictionary_7TxtWord_TxtWord, 1, "root", 0))) __PYX_ERR(0, 688, __pyx_L1_error)
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_24morphologicalAnalysisRoot(((struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self), __pyx_v_surfaceForm, __pyx_v_root, __pyx_v_state);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_24morphologicalAnalysisRoot(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_surfaceForm, struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_root, PyObject *__pyx_v_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_opt_args_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_morphologicalAnalysisRoot __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("morphologicalAnalysisRoot", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2.__pyx_n = 1;
  __pyx_t_2.state = __pyx_v_state;
  __pyx_t_1 = __pyx_vtabptr_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer->morphologicalAnalysisRoot(__pyx_v_self, __pyx_v_surfaceForm, __pyx_v_root, 1, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 688, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.FsmMorphologicalAnalyzer.FsmMorphologicalAnalyzer.morphologicalAnalysisRoot", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":715
 *         return self.__parseWord(initialFsmParse, surfaceForm)
 * 
 *     cpdef list generateAllParses(self, TxtWord root, int maxLength):             # <<<<<<<<<<<<<<
 *         """
 *         The generateAllParses with 2 inputs is used to generate all parses with given root. Then it calls
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_27generateAllParses(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_generateAllParses(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_root, int __pyx_v_maxLength, int __pyx_skip_dispatch) {
  PyObject *__pyx_v_initialFsmParse = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("generateAllParses", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_generateAllParses); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 715, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_27generateAllParses)) {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_maxLength); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 715, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; __pyx_t_5 = NULL;
        __pyx_t_6 = 0;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
          if (likely(__pyx_t_5)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
            __Pyx_INCREF(__pyx_t_5);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_4, function);
            __pyx_t_6 = 1;
          }
        }
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_4)) {
          PyObject *__pyx_temp[3] = {__pyx_t_5, ((PyObject *)__pyx_v_root), __pyx_t_3};
          __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 715, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
          PyObject *__pyx_temp[3] = {__pyx_t_5, ((PyObject *)__pyx_v_root), __pyx_t_3};
          __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 715, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        } else
        #endif
        {
          __pyx_t_7 = PyTuple_New(2+__pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 715, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          if (__pyx_t_5) {
            __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5); __pyx_t_5 = NULL;
          }
          __Pyx_INCREF(((PyObject *)__pyx_v_root));
          __Pyx_GIVEREF(((PyObject *)__pyx_v_root));
          PyTuple_SET_ITEM(__pyx_t_7, 0+__pyx_t_6, ((PyObject *)__pyx_v_root));
          __Pyx_GIVEREF(__pyx_t_3);
          PyTuple_SET_ITEM(__pyx_t_7, 1+__pyx_t_6, __pyx_t_3);
          __pyx_t_3 = 0;
          __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_7, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 715, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        }
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (!(likely(PyList_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "list", Py_TYPE(__pyx_t_2)->tp_name), 0))) __PYX_ERR(0, 715, __pyx_L1_error)
        __pyx_r = ((PyObject*)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":734
 *         """
 *         cdef list initialFsmParse
 *         initialFsmParse = []             # <<<<<<<<<<<<<<
 *         if root.isProperNoun():
 *             self.__initializeParseListFromRoot(initialFsmParse, root, True)
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 734, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_initialFsmParse = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":735
 *         cdef list initialFsmParse
 *         initialFsmParse = []
 *         if root.isProperNoun():             # <<<<<<<<<<<<<<
 *             self.__initializeParseListFromRoot(initialFsmParse, root, True)
 *         self.__initializeParseListFromRoot(initialFsmParse, root, False)
 */
  __pyx_t_8 = (((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_root->__pyx_base.__pyx_vtab)->isProperNoun(__pyx_v_root, 0) != 0);
  if (__pyx_t_8) {

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":736
 *         initialFsmParse = []
 *         if root.isProperNoun():
 *             self.__initializeParseListFromRoot(initialFsmParse, root, True)             # <<<<<<<<<<<<<<
 *         self.__initializeParseListFromRoot(initialFsmParse, root, False)
 *         return self.__parseWord(initialFsmParse, maxLength)
 */
    __pyx_t_1 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->__pyx___initializeParseListFromRoot(__pyx_v_self, __pyx_v_initialFsmParse, __pyx_v_root, 1, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 736, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":735
 *         cdef list initialFsmParse
 *         initialFsmParse = []
 *         if root.isProperNoun():             # <<<<<<<<<<<<<<
 *             self.__initializeParseListFromRoot(initialFsmParse, root, True)
 *         self.__initializeParseListFromRoot(initialFsmParse, root, False)
 */
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":737
 *         if root.isProperNoun():
 *             self.__initializeParseListFromRoot(initialFsmParse, root, True)
 *         self.__initializeParseListFromRoot(initialFsmParse, root, False)             # <<<<<<<<<<<<<<
 *         return self.__parseWord(initialFsmParse, maxLength)
 * 
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->__pyx___initializeParseListFromRoot(__pyx_v_self, __pyx_v_initialFsmParse, __pyx_v_root, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 737, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":738
 *             self.__initializeParseListFromRoot(initialFsmParse, root, True)
 *         self.__initializeParseListFromRoot(initialFsmParse, root, False)
 *         return self.__parseWord(initialFsmParse, maxLength)             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint __analysisExists(self, TxtWord rootWord, str surfaceForm, bint isProper):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_maxLength); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 738, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->__pyx___parseWord(__pyx_v_self, __pyx_v_initialFsmParse, __pyx_t_1, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 738, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":715
 *         return self.__parseWord(initialFsmParse, surfaceForm)
 * 
 *     cpdef list generateAllParses(self, TxtWord root, int maxLength):             # <<<<<<<<<<<<<<
 *         """
 *         The generateAllParses with 2 inputs is used to generate all parses with given root. Then it calls
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("MorphologicalAnalysis.FsmMorphologicalAnalyzer.FsmMorphologicalAnalyzer.generateAllParses", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_initialFsmParse);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_27generateAllParses(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_26generateAllParses[] = "\n        The generateAllParses with 2 inputs is used to generate all parses with given root. Then it calls\n        initializeParseListFromRoot method to initialize list with newly created ArrayList, input root, and maximum\n        length.\n\n        PARAMETERS\n        ----------\n        root : TxtWord\n            TxtWord input.\n        maxLength : int\n            Maximum length of the surface form.\n\n        RETURNS\n        -------\n        list\n            parseWordMaxLength method with newly populated FsmParse ArrayList and maximum length.\n        ";
static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_27generateAllParses(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_root = 0;
  int __pyx_v_maxLength;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("generateAllParses (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_root,&__pyx_n_s_maxLength,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_root)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_maxLength)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("generateAllParses", 1, 2, 2, 1); __PYX_ERR(0, 715, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "generateAllParses") < 0)) __PYX_ERR(0, 715, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_root = ((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)values[0]);
    __pyx_v_maxLength = __Pyx_PyInt_As_int(values[1]); if (unlikely((__pyx_v_maxLength == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 715, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("generateAllParses", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 715, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("MorphologicalAnalysis.FsmMorphologicalAnalyzer.FsmMorphologicalAnalyzer.generateAllParses", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_root), __pyx_ptype_10Dictionary_7TxtWord_TxtWord, 1, "root", 0))) __PYX_ERR(0, 715, __pyx_L1_error)
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_26generateAllParses(((struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self), __pyx_v_root, __pyx_v_maxLength);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_26generateAllParses(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_root, int __pyx_v_maxLength) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("generateAllParses", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_generateAllParses(__pyx_v_self, __pyx_v_root, __pyx_v_maxLength, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 715, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.FsmMorphologicalAnalyzer.FsmMorphologicalAnalyzer.generateAllParses", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":740
 *         return self.__parseWord(initialFsmParse, maxLength)
 * 
 *     cpdef bint __analysisExists(self, TxtWord rootWord, str surfaceForm, bint isProper):             # <<<<<<<<<<<<<<
 *         """
 *         The analysisExists method checks several cases. If the given surfaceForm is a punctuation or double then it
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_29__analysisExists(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer___analysisExists(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_rootWord, PyObject *__pyx_v_surfaceForm, int __pyx_v_isProper, int __pyx_skip_dispatch) {
  PyObject *__pyx_v_initialFsmParse = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__analysisExists", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_analysisExists); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 740, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_29__analysisExists)) {
        __pyx_t_3 = __Pyx_PyBool_FromLong(__pyx_v_isProper); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 740, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; __pyx_t_5 = NULL;
        __pyx_t_6 = 0;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
          if (likely(__pyx_t_5)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
            __Pyx_INCREF(__pyx_t_5);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_4, function);
            __pyx_t_6 = 1;
          }
        }
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_4)) {
          PyObject *__pyx_temp[4] = {__pyx_t_5, ((PyObject *)__pyx_v_rootWord), __pyx_v_surfaceForm, __pyx_t_3};
          __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_6, 3+__pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 740, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
          PyObject *__pyx_temp[4] = {__pyx_t_5, ((PyObject *)__pyx_v_rootWord), __pyx_v_surfaceForm, __pyx_t_3};
          __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_6, 3+__pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 740, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        } else
        #endif
        {
          __pyx_t_7 = PyTuple_New(3+__pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 740, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          if (__pyx_t_5) {
            __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5); __pyx_t_5 = NULL;
          }
          __Pyx_INCREF(((PyObject *)__pyx_v_rootWord));
          __Pyx_GIVEREF(((PyObject *)__pyx_v_rootWord));
          PyTuple_SET_ITEM(__pyx_t_7, 0+__pyx_t_6, ((PyObject *)__pyx_v_rootWord));
          __Pyx_INCREF(__pyx_v_surfaceForm);
          __Pyx_GIVEREF(__pyx_v_surfaceForm);
          PyTuple_SET_ITEM(__pyx_t_7, 1+__pyx_t_6, __pyx_v_surfaceForm);
          __Pyx_GIVEREF(__pyx_t_3);
          PyTuple_SET_ITEM(__pyx_t_7, 2+__pyx_t_6, __pyx_t_3);
          __pyx_t_3 = 0;
          __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_7, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 740, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        }
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_8 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 740, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_8;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":761
 *         """
 *         cdef list initialFsmParse
 *         if Word.isPunctuationSymbol(surfaceForm):             # <<<<<<<<<<<<<<
 *             return True
 *         if self.__isDouble(surfaceForm):
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype_10Dictionary_4Word_Word), __pyx_n_s_isPunctuationSymbol); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 761, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_4, __pyx_v_surfaceForm) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v_surfaceForm);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 761, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_8 < 0)) __PYX_ERR(0, 761, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_8) {

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":762
 *         cdef list initialFsmParse
 *         if Word.isPunctuationSymbol(surfaceForm):
 *             return True             # <<<<<<<<<<<<<<
 *         if self.__isDouble(surfaceForm):
 *             return True
 */
    __pyx_r = 1;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":761
 *         """
 *         cdef list initialFsmParse
 *         if Word.isPunctuationSymbol(surfaceForm):             # <<<<<<<<<<<<<<
 *             return True
 *         if self.__isDouble(surfaceForm):
 */
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":763
 *         if Word.isPunctuationSymbol(surfaceForm):
 *             return True
 *         if self.__isDouble(surfaceForm):             # <<<<<<<<<<<<<<
 *             return True
 *         if rootWord is not None:
 */
  __pyx_t_8 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->__pyx___isDouble(__pyx_v_self, __pyx_v_surfaceForm, 0) != 0);
  if (__pyx_t_8) {

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":764
 *             return True
 *         if self.__isDouble(surfaceForm):
 *             return True             # <<<<<<<<<<<<<<
 *         if rootWord is not None:
 *             initialFsmParse = []
 */
    __pyx_r = 1;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":763
 *         if Word.isPunctuationSymbol(surfaceForm):
 *             return True
 *         if self.__isDouble(surfaceForm):             # <<<<<<<<<<<<<<
 *             return True
 *         if rootWord is not None:
 */
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":765
 *         if self.__isDouble(surfaceForm):
 *             return True
 *         if rootWord is not None:             # <<<<<<<<<<<<<<
 *             initialFsmParse = []
 *             self.__initializeParseListFromRoot(initialFsmParse, rootWord, isProper)
 */
  __pyx_t_8 = (((PyObject *)__pyx_v_rootWord) != Py_None);
  __pyx_t_9 = (__pyx_t_8 != 0);
  if (__pyx_t_9) {

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":766
 *             return True
 *         if rootWord is not None:
 *             initialFsmParse = []             # <<<<<<<<<<<<<<
 *             self.__initializeParseListFromRoot(initialFsmParse, rootWord, isProper)
 *         else:
 */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 766, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_initialFsmParse = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":767
 *         if rootWord is not None:
 *             initialFsmParse = []
 *             self.__initializeParseListFromRoot(initialFsmParse, rootWord, isProper)             # <<<<<<<<<<<<<<
 *         else:
 *             initialFsmParse = self.__initializeParseListFromSurfaceForm(surfaceForm, isProper)
 */
    __pyx_t_1 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->__pyx___initializeParseListFromRoot(__pyx_v_self, __pyx_v_initialFsmParse, __pyx_v_rootWord, __pyx_v_isProper, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 767, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":765
 *         if self.__isDouble(surfaceForm):
 *             return True
 *         if rootWord is not None:             # <<<<<<<<<<<<<<
 *             initialFsmParse = []
 *             self.__initializeParseListFromRoot(initialFsmParse, rootWord, isProper)
 */
    goto __pyx_L5;
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":769
 *             self.__initializeParseListFromRoot(initialFsmParse, rootWord, isProper)
 *         else:
 *             initialFsmParse = self.__initializeParseListFromSurfaceForm(surfaceForm, isProper)             # <<<<<<<<<<<<<<
 *         return self.__parseExists(initialFsmParse, surfaceForm)
 * 
 */
  /*else*/ {
    __pyx_t_1 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->__pyx___initializeParseListFromSurfaceForm(__pyx_v_self, __pyx_v_surfaceForm, __pyx_v_isProper, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 769, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_initialFsmParse = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;
  }
  __pyx_L5:;

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":770
 *         else:
 *             initialFsmParse = self.__initializeParseListFromSurfaceForm(surfaceForm, isProper)
 *         return self.__parseExists(initialFsmParse, surfaceForm)             # <<<<<<<<<<<<<<
 * 
 *     cpdef list __analysis(self, str surfaceForm, bint isProper):
 */
  __pyx_r = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->__pyx___parseExists(__pyx_v_self, __pyx_v_initialFsmParse, __pyx_v_surfaceForm, 0);
  goto __pyx_L0;

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":740
 *         return self.__parseWord(initialFsmParse, maxLength)
 * 
 *     cpdef bint __analysisExists(self, TxtWord rootWord, str surfaceForm, bint isProper):             # <<<<<<<<<<<<<<
 *         """
 *         The analysisExists method checks several cases. If the given surfaceForm is a punctuation or double then it
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_WriteUnraisable("MorphologicalAnalysis.FsmMorphologicalAnalyzer.FsmMorphologicalAnalyzer.__analysisExists", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_initialFsmParse);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_29__analysisExists(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_28__analysisExists[] = "\n        The analysisExists method checks several cases. If the given surfaceForm is a punctuation or double then it\n        returns true. If it is not a root word, then it initializes the parse list and returns the parseExists method with\n        this newly initialized list and surfaceForm.\n\n        PARAMETERS\n        ----------\n        rootWord : TxtWord\n            TxtWord root.\n        surfaceForm : str\n            String input.\n        isProper : bool\n            boolean variable indicates a word is proper or not.\n\n        RETURNS\n        -------\n        bool\n            True if surfaceForm is punctuation or double, otherwise returns parseExist method with given surfaceForm.\n        ";
static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_29__analysisExists(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_rootWord = 0;
  PyObject *__pyx_v_surfaceForm = 0;
  int __pyx_v_isProper;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__analysisExists (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_rootWord,&__pyx_n_s_surfaceForm,&__pyx_n_s_isProper,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_rootWord)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_surfaceForm)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__analysisExists", 1, 3, 3, 1); __PYX_ERR(0, 740, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_isProper)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__analysisExists", 1, 3, 3, 2); __PYX_ERR(0, 740, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__analysisExists") < 0)) __PYX_ERR(0, 740, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_rootWord = ((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)values[0]);
    __pyx_v_surfaceForm = ((PyObject*)values[1]);
    __pyx_v_isProper = __Pyx_PyObject_IsTrue(values[2]); if (unlikely((__pyx_v_isProper == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 740, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__analysisExists", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 740, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("MorphologicalAnalysis.FsmMorphologicalAnalyzer.FsmMorphologicalAnalyzer.__analysisExists", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_rootWord), __pyx_ptype_10Dictionary_7TxtWord_TxtWord, 1, "rootWord", 0))) __PYX_ERR(0, 740, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_surfaceForm), (&PyUnicode_Type), 1, "surfaceForm", 1))) __PYX_ERR(0, 740, __pyx_L1_error)
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_28__analysisExists(((struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self), __pyx_v_rootWord, __pyx_v_surfaceForm, __pyx_v_isProper);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_28__analysisExists(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_rootWord, PyObject *__pyx_v_surfaceForm, int __pyx_v_isProper) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__analysisExists", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer___analysisExists(__pyx_v_self, __pyx_v_rootWord, __pyx_v_surfaceForm, __pyx_v_isProper, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 740, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.FsmMorphologicalAnalyzer.FsmMorphologicalAnalyzer.__analysisExists", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":772
 *         return self.__parseExists(initialFsmParse, surfaceForm)
 * 
 *     cpdef list __analysis(self, str surfaceForm, bint isProper):             # <<<<<<<<<<<<<<
 *         """
 *         The analysis method is used by the morphologicalAnalysis method. It gets String surfaceForm as an input and
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_31__analysis(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer___analysis(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_surfaceForm, int __pyx_v_isProper, int __pyx_skip_dispatch) {
  PyObject *__pyx_v_initialFsmParse = 0;
  struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *__pyx_v_fsmParse = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  int __pyx_t_9;
  int __pyx_t_10;
  int __pyx_t_11;
  Py_ssize_t __pyx_t_12;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__analysis", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_analysis); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 772, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_31__analysis)) {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = __Pyx_PyBool_FromLong(__pyx_v_isProper); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 772, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; __pyx_t_5 = NULL;
        __pyx_t_6 = 0;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
          if (likely(__pyx_t_5)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
            __Pyx_INCREF(__pyx_t_5);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_4, function);
            __pyx_t_6 = 1;
          }
        }
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_4)) {
          PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_v_surfaceForm, __pyx_t_3};
          __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 772, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
          PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_v_surfaceForm, __pyx_t_3};
          __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 772, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        } else
        #endif
        {
          __pyx_t_7 = PyTuple_New(2+__pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 772, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          if (__pyx_t_5) {
            __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5); __pyx_t_5 = NULL;
          }
          __Pyx_INCREF(__pyx_v_surfaceForm);
          __Pyx_GIVEREF(__pyx_v_surfaceForm);
          PyTuple_SET_ITEM(__pyx_t_7, 0+__pyx_t_6, __pyx_v_surfaceForm);
          __Pyx_GIVEREF(__pyx_t_3);
          PyTuple_SET_ITEM(__pyx_t_7, 1+__pyx_t_6, __pyx_t_3);
          __pyx_t_3 = 0;
          __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_7, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 772, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        }
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (!(likely(PyList_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "list", Py_TYPE(__pyx_t_2)->tp_name), 0))) __PYX_ERR(0, 772, __pyx_L1_error)
        __pyx_r = ((PyObject*)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":792
 *         """
 *         cdef list initialFsmParse
 *         if Word.isPunctuationSymbol(surfaceForm) and surfaceForm != "%":             # <<<<<<<<<<<<<<
 *             initialFsmParse = []
 *             fsmParse = FsmParse(surfaceForm, State("Punctuation", True, True))
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype_10Dictionary_4Word_Word), __pyx_n_s_isPunctuationSymbol); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 792, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_4, __pyx_v_surfaceForm) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v_surfaceForm);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 792, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 792, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_9) {
  } else {
    __pyx_t_8 = __pyx_t_9;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_v_surfaceForm, __pyx_kp_u__5, Py_NE)); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 792, __pyx_L1_error)
  __pyx_t_10 = (__pyx_t_9 != 0);
  __pyx_t_8 = __pyx_t_10;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_8) {

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":793
 *         cdef list initialFsmParse
 *         if Word.isPunctuationSymbol(surfaceForm) and surfaceForm != "%":
 *             initialFsmParse = []             # <<<<<<<<<<<<<<
 *             fsmParse = FsmParse(surfaceForm, State("Punctuation", True, True))
 *             fsmParse.constructInflectionalGroups()
 */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 793, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_initialFsmParse = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":794
 *         if Word.isPunctuationSymbol(surfaceForm) and surfaceForm != "%":
 *             initialFsmParse = []
 *             fsmParse = FsmParse(surfaceForm, State("Punctuation", True, True))             # <<<<<<<<<<<<<<
 *             fsmParse.constructInflectionalGroups()
 *             initialFsmParse.append(fsmParse)
 */
    __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_5State_State), __pyx_tuple__6, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 794, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 794, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_v_surfaceForm);
    __Pyx_GIVEREF(__pyx_v_surfaceForm);
    PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_surfaceForm);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_1);
    __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse), __pyx_t_2, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 794, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_v_fsmParse = ((struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":795
 *             initialFsmParse = []
 *             fsmParse = FsmParse(surfaceForm, State("Punctuation", True, True))
 *             fsmParse.constructInflectionalGroups()             # <<<<<<<<<<<<<<
 *             initialFsmParse.append(fsmParse)
 *             return initialFsmParse
 */
    __pyx_t_1 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_v_fsmParse->__pyx_base.__pyx_vtab)->constructInflectionalGroups(__pyx_v_fsmParse, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 795, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":796
 *             fsmParse = FsmParse(surfaceForm, State("Punctuation", True, True))
 *             fsmParse.constructInflectionalGroups()
 *             initialFsmParse.append(fsmParse)             # <<<<<<<<<<<<<<
 *             return initialFsmParse
 *         if self.__isNumber(surfaceForm):
 */
    __pyx_t_11 = __Pyx_PyList_Append(__pyx_v_initialFsmParse, ((PyObject *)__pyx_v_fsmParse)); if (unlikely(__pyx_t_11 == ((int)-1))) __PYX_ERR(0, 796, __pyx_L1_error)

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":797
 *             fsmParse.constructInflectionalGroups()
 *             initialFsmParse.append(fsmParse)
 *             return initialFsmParse             # <<<<<<<<<<<<<<
 *         if self.__isNumber(surfaceForm):
 *             initialFsmParse = []
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_initialFsmParse);
    __pyx_r = __pyx_v_initialFsmParse;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":792
 *         """
 *         cdef list initialFsmParse
 *         if Word.isPunctuationSymbol(surfaceForm) and surfaceForm != "%":             # <<<<<<<<<<<<<<
 *             initialFsmParse = []
 *             fsmParse = FsmParse(surfaceForm, State("Punctuation", True, True))
 */
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":798
 *             initialFsmParse.append(fsmParse)
 *             return initialFsmParse
 *         if self.__isNumber(surfaceForm):             # <<<<<<<<<<<<<<
 *             initialFsmParse = []
 *             fsmParse = FsmParse(surfaceForm, State("CardinalRoot", True, True))
 */
  __pyx_t_8 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->__pyx___isNumber(__pyx_v_self, __pyx_v_surfaceForm, 0) != 0);
  if (__pyx_t_8) {

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":799
 *             return initialFsmParse
 *         if self.__isNumber(surfaceForm):
 *             initialFsmParse = []             # <<<<<<<<<<<<<<
 *             fsmParse = FsmParse(surfaceForm, State("CardinalRoot", True, True))
 *             fsmParse.constructInflectionalGroups()
 */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 799, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_initialFsmParse = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":800
 *         if self.__isNumber(surfaceForm):
 *             initialFsmParse = []
 *             fsmParse = FsmParse(surfaceForm, State("CardinalRoot", True, True))             # <<<<<<<<<<<<<<
 *             fsmParse.constructInflectionalGroups()
 *             initialFsmParse.append(fsmParse)
 */
    __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_5State_State), __pyx_tuple__7, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 800, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 800, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_v_surfaceForm);
    __Pyx_GIVEREF(__pyx_v_surfaceForm);
    PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_surfaceForm);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_1);
    __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse), __pyx_t_2, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 800, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_v_fsmParse = ((struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":801
 *             initialFsmParse = []
 *             fsmParse = FsmParse(surfaceForm, State("CardinalRoot", True, True))
 *             fsmParse.constructInflectionalGroups()             # <<<<<<<<<<<<<<
 *             initialFsmParse.append(fsmParse)
 *             return initialFsmParse
 */
    __pyx_t_1 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_v_fsmParse->__pyx_base.__pyx_vtab)->constructInflectionalGroups(__pyx_v_fsmParse, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 801, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":802
 *             fsmParse = FsmParse(surfaceForm, State("CardinalRoot", True, True))
 *             fsmParse.constructInflectionalGroups()
 *             initialFsmParse.append(fsmParse)             # <<<<<<<<<<<<<<
 *             return initialFsmParse
 *         if self.patternMatches("\\d+/\\d+", surfaceForm):
 */
    __pyx_t_11 = __Pyx_PyList_Append(__pyx_v_initialFsmParse, ((PyObject *)__pyx_v_fsmParse)); if (unlikely(__pyx_t_11 == ((int)-1))) __PYX_ERR(0, 802, __pyx_L1_error)

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":803
 *             fsmParse.constructInflectionalGroups()
 *             initialFsmParse.append(fsmParse)
 *             return initialFsmParse             # <<<<<<<<<<<<<<
 *         if self.patternMatches("\\d+/\\d+", surfaceForm):
 *             initialFsmParse = []
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_initialFsmParse);
    __pyx_r = __pyx_v_initialFsmParse;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":798
 *             initialFsmParse.append(fsmParse)
 *             return initialFsmParse
 *         if self.__isNumber(surfaceForm):             # <<<<<<<<<<<<<<
 *             initialFsmParse = []
 *             fsmParse = FsmParse(surfaceForm, State("CardinalRoot", True, True))
 */
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":804
 *             initialFsmParse.append(fsmParse)
 *             return initialFsmParse
 *         if self.patternMatches("\\d+/\\d+", surfaceForm):             # <<<<<<<<<<<<<<
 *             initialFsmParse = []
 *             fsmParse = FsmParse(surfaceForm, State("FractionRoot", True, True))
 */
  __pyx_t_8 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->patternMatches(__pyx_v_self, __pyx_kp_u_d_d, __pyx_v_surfaceForm, 0) != 0);
  if (__pyx_t_8) {

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":805
 *             return initialFsmParse
 *         if self.patternMatches("\\d+/\\d+", surfaceForm):
 *             initialFsmParse = []             # <<<<<<<<<<<<<<
 *             fsmParse = FsmParse(surfaceForm, State("FractionRoot", True, True))
 *             fsmParse.constructInflectionalGroups()
 */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 805, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_initialFsmParse = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":806
 *         if self.patternMatches("\\d+/\\d+", surfaceForm):
 *             initialFsmParse = []
 *             fsmParse = FsmParse(surfaceForm, State("FractionRoot", True, True))             # <<<<<<<<<<<<<<
 *             fsmParse.constructInflectionalGroups()
 *             initialFsmParse.append(fsmParse)
 */
    __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_5State_State), __pyx_tuple__8, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 806, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 806, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_v_surfaceForm);
    __Pyx_GIVEREF(__pyx_v_surfaceForm);
    PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_surfaceForm);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_1);
    __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse), __pyx_t_2, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 806, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_v_fsmParse = ((struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":807
 *             initialFsmParse = []
 *             fsmParse = FsmParse(surfaceForm, State("FractionRoot", True, True))
 *             fsmParse.constructInflectionalGroups()             # <<<<<<<<<<<<<<
 *             initialFsmParse.append(fsmParse)
 *             fsmParse = FsmParse(surfaceForm, State("DateRoot", True, True))
 */
    __pyx_t_1 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_v_fsmParse->__pyx_base.__pyx_vtab)->constructInflectionalGroups(__pyx_v_fsmParse, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 807, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":808
 *             fsmParse = FsmParse(surfaceForm, State("FractionRoot", True, True))
 *             fsmParse.constructInflectionalGroups()
 *             initialFsmParse.append(fsmParse)             # <<<<<<<<<<<<<<
 *             fsmParse = FsmParse(surfaceForm, State("DateRoot", True, True))
 *             fsmParse.constructInflectionalGroups()
 */
    __pyx_t_11 = __Pyx_PyList_Append(__pyx_v_initialFsmParse, ((PyObject *)__pyx_v_fsmParse)); if (unlikely(__pyx_t_11 == ((int)-1))) __PYX_ERR(0, 808, __pyx_L1_error)

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":809
 *             fsmParse.constructInflectionalGroups()
 *             initialFsmParse.append(fsmParse)
 *             fsmParse = FsmParse(surfaceForm, State("DateRoot", True, True))             # <<<<<<<<<<<<<<
 *             fsmParse.constructInflectionalGroups()
 *             initialFsmParse.append(fsmParse)
 */
    __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_5State_State), __pyx_tuple__9, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 809, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 809, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_v_surfaceForm);
    __Pyx_GIVEREF(__pyx_v_surfaceForm);
    PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_surfaceForm);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_1);
    __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse), __pyx_t_2, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 809, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF_SET(__pyx_v_fsmParse, ((struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_t_1));
    __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":810
 *             initialFsmParse.append(fsmParse)
 *             fsmParse = FsmParse(surfaceForm, State("DateRoot", True, True))
 *             fsmParse.constructInflectionalGroups()             # <<<<<<<<<<<<<<
 *             initialFsmParse.append(fsmParse)
 *             return initialFsmParse
 */
    __pyx_t_1 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_v_fsmParse->__pyx_base.__pyx_vtab)->constructInflectionalGroups(__pyx_v_fsmParse, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 810, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":811
 *             fsmParse = FsmParse(surfaceForm, State("DateRoot", True, True))
 *             fsmParse.constructInflectionalGroups()
 *             initialFsmParse.append(fsmParse)             # <<<<<<<<<<<<<<
 *             return initialFsmParse
 *         if self.__isDate(surfaceForm):
 */
    __pyx_t_11 = __Pyx_PyList_Append(__pyx_v_initialFsmParse, ((PyObject *)__pyx_v_fsmParse)); if (unlikely(__pyx_t_11 == ((int)-1))) __PYX_ERR(0, 811, __pyx_L1_error)

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":812
 *             fsmParse.constructInflectionalGroups()
 *             initialFsmParse.append(fsmParse)
 *             return initialFsmParse             # <<<<<<<<<<<<<<
 *         if self.__isDate(surfaceForm):
 *             initialFsmParse = []
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_initialFsmParse);
    __pyx_r = __pyx_v_initialFsmParse;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":804
 *             initialFsmParse.append(fsmParse)
 *             return initialFsmParse
 *         if self.patternMatches("\\d+/\\d+", surfaceForm):             # <<<<<<<<<<<<<<
 *             initialFsmParse = []
 *             fsmParse = FsmParse(surfaceForm, State("FractionRoot", True, True))
 */
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":813
 *             initialFsmParse.append(fsmParse)
 *             return initialFsmParse
 *         if self.__isDate(surfaceForm):             # <<<<<<<<<<<<<<
 *             initialFsmParse = []
 *             fsmParse = FsmParse(surfaceForm, State("DateRoot", True, True))
 */
  __pyx_t_8 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->__pyx___isDate(__pyx_v_self, __pyx_v_surfaceForm, 0) != 0);
  if (__pyx_t_8) {

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":814
 *             return initialFsmParse
 *         if self.__isDate(surfaceForm):
 *             initialFsmParse = []             # <<<<<<<<<<<<<<
 *             fsmParse = FsmParse(surfaceForm, State("DateRoot", True, True))
 *             fsmParse.constructInflectionalGroups()
 */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 814, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_initialFsmParse = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":815
 *         if self.__isDate(surfaceForm):
 *             initialFsmParse = []
 *             fsmParse = FsmParse(surfaceForm, State("DateRoot", True, True))             # <<<<<<<<<<<<<<
 *             fsmParse.constructInflectionalGroups()
 *             initialFsmParse.append(fsmParse)
 */
    __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_5State_State), __pyx_tuple__9, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 815, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 815, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_v_surfaceForm);
    __Pyx_GIVEREF(__pyx_v_surfaceForm);
    PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_surfaceForm);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_1);
    __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse), __pyx_t_2, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 815, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_v_fsmParse = ((struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":816
 *             initialFsmParse = []
 *             fsmParse = FsmParse(surfaceForm, State("DateRoot", True, True))
 *             fsmParse.constructInflectionalGroups()             # <<<<<<<<<<<<<<
 *             initialFsmParse.append(fsmParse)
 *             return initialFsmParse
 */
    __pyx_t_1 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_v_fsmParse->__pyx_base.__pyx_vtab)->constructInflectionalGroups(__pyx_v_fsmParse, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 816, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":817
 *             fsmParse = FsmParse(surfaceForm, State("DateRoot", True, True))
 *             fsmParse.constructInflectionalGroups()
 *             initialFsmParse.append(fsmParse)             # <<<<<<<<<<<<<<
 *             return initialFsmParse
 *         if self.patternMatches("\\d+\\\\/\\d+", surfaceForm):
 */
    __pyx_t_11 = __Pyx_PyList_Append(__pyx_v_initialFsmParse, ((PyObject *)__pyx_v_fsmParse)); if (unlikely(__pyx_t_11 == ((int)-1))) __PYX_ERR(0, 817, __pyx_L1_error)

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":818
 *             fsmParse.constructInflectionalGroups()
 *             initialFsmParse.append(fsmParse)
 *             return initialFsmParse             # <<<<<<<<<<<<<<
 *         if self.patternMatches("\\d+\\\\/\\d+", surfaceForm):
 *             initialFsmParse = []
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_initialFsmParse);
    __pyx_r = __pyx_v_initialFsmParse;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":813
 *             initialFsmParse.append(fsmParse)
 *             return initialFsmParse
 *         if self.__isDate(surfaceForm):             # <<<<<<<<<<<<<<
 *             initialFsmParse = []
 *             fsmParse = FsmParse(surfaceForm, State("DateRoot", True, True))
 */
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":819
 *             initialFsmParse.append(fsmParse)
 *             return initialFsmParse
 *         if self.patternMatches("\\d+\\\\/\\d+", surfaceForm):             # <<<<<<<<<<<<<<
 *             initialFsmParse = []
 *             fsmParse = FsmParse(surfaceForm, State("FractionRoot", True, True))
 */
  __pyx_t_8 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->patternMatches(__pyx_v_self, __pyx_kp_u_d_d_2, __pyx_v_surfaceForm, 0) != 0);
  if (__pyx_t_8) {

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":820
 *             return initialFsmParse
 *         if self.patternMatches("\\d+\\\\/\\d+", surfaceForm):
 *             initialFsmParse = []             # <<<<<<<<<<<<<<
 *             fsmParse = FsmParse(surfaceForm, State("FractionRoot", True, True))
 *             fsmParse.constructInflectionalGroups()
 */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 820, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_initialFsmParse = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":821
 *         if self.patternMatches("\\d+\\\\/\\d+", surfaceForm):
 *             initialFsmParse = []
 *             fsmParse = FsmParse(surfaceForm, State("FractionRoot", True, True))             # <<<<<<<<<<<<<<
 *             fsmParse.constructInflectionalGroups()
 *             initialFsmParse.append(fsmParse)
 */
    __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_5State_State), __pyx_tuple__8, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 821, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 821, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_v_surfaceForm);
    __Pyx_GIVEREF(__pyx_v_surfaceForm);
    PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_surfaceForm);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_1);
    __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse), __pyx_t_2, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 821, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_v_fsmParse = ((struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":822
 *             initialFsmParse = []
 *             fsmParse = FsmParse(surfaceForm, State("FractionRoot", True, True))
 *             fsmParse.constructInflectionalGroups()             # <<<<<<<<<<<<<<
 *             initialFsmParse.append(fsmParse)
 *             return initialFsmParse
 */
    __pyx_t_1 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_v_fsmParse->__pyx_base.__pyx_vtab)->constructInflectionalGroups(__pyx_v_fsmParse, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 822, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":823
 *             fsmParse = FsmParse(surfaceForm, State("FractionRoot", True, True))
 *             fsmParse.constructInflectionalGroups()
 *             initialFsmParse.append(fsmParse)             # <<<<<<<<<<<<<<
 *             return initialFsmParse
 *         if surfaceForm == "%" or self.__isPercent(surfaceForm):
 */
    __pyx_t_11 = __Pyx_PyList_Append(__pyx_v_initialFsmParse, ((PyObject *)__pyx_v_fsmParse)); if (unlikely(__pyx_t_11 == ((int)-1))) __PYX_ERR(0, 823, __pyx_L1_error)

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":824
 *             fsmParse.constructInflectionalGroups()
 *             initialFsmParse.append(fsmParse)
 *             return initialFsmParse             # <<<<<<<<<<<<<<
 *         if surfaceForm == "%" or self.__isPercent(surfaceForm):
 *             initialFsmParse = []
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_initialFsmParse);
    __pyx_r = __pyx_v_initialFsmParse;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":819
 *             initialFsmParse.append(fsmParse)
 *             return initialFsmParse
 *         if self.patternMatches("\\d+\\\\/\\d+", surfaceForm):             # <<<<<<<<<<<<<<
 *             initialFsmParse = []
 *             fsmParse = FsmParse(surfaceForm, State("FractionRoot", True, True))
 */
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":825
 *             initialFsmParse.append(fsmParse)
 *             return initialFsmParse
 *         if surfaceForm == "%" or self.__isPercent(surfaceForm):             # <<<<<<<<<<<<<<
 *             initialFsmParse = []
 *             fsmParse = FsmParse(surfaceForm, State("PercentRoot", True, True))
 */
  __pyx_t_10 = (__Pyx_PyUnicode_Equals(__pyx_v_surfaceForm, __pyx_kp_u__5, Py_EQ)); if (unlikely(__pyx_t_10 < 0)) __PYX_ERR(0, 825, __pyx_L1_error)
  __pyx_t_9 = (__pyx_t_10 != 0);
  if (!__pyx_t_9) {
  } else {
    __pyx_t_8 = __pyx_t_9;
    goto __pyx_L11_bool_binop_done;
  }
  __pyx_t_9 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->__pyx___isPercent(__pyx_v_self, __pyx_v_surfaceForm, 0) != 0);
  __pyx_t_8 = __pyx_t_9;
  __pyx_L11_bool_binop_done:;
  if (__pyx_t_8) {

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":826
 *             return initialFsmParse
 *         if surfaceForm == "%" or self.__isPercent(surfaceForm):
 *             initialFsmParse = []             # <<<<<<<<<<<<<<
 *             fsmParse = FsmParse(surfaceForm, State("PercentRoot", True, True))
 *             fsmParse.constructInflectionalGroups()
 */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 826, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_initialFsmParse = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":827
 *         if surfaceForm == "%" or self.__isPercent(surfaceForm):
 *             initialFsmParse = []
 *             fsmParse = FsmParse(surfaceForm, State("PercentRoot", True, True))             # <<<<<<<<<<<<<<
 *             fsmParse.constructInflectionalGroups()
 *             initialFsmParse.append(fsmParse)
 */
    __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_5State_State), __pyx_tuple__10, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 827, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 827, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_v_surfaceForm);
    __Pyx_GIVEREF(__pyx_v_surfaceForm);
    PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_surfaceForm);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_1);
    __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse), __pyx_t_2, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 827, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_v_fsmParse = ((struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":828
 *             initialFsmParse = []
 *             fsmParse = FsmParse(surfaceForm, State("PercentRoot", True, True))
 *             fsmParse.constructInflectionalGroups()             # <<<<<<<<<<<<<<
 *             initialFsmParse.append(fsmParse)
 *             return initialFsmParse
 */
    __pyx_t_1 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_v_fsmParse->__pyx_base.__pyx_vtab)->constructInflectionalGroups(__pyx_v_fsmParse, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 828, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":829
 *             fsmParse = FsmParse(surfaceForm, State("PercentRoot", True, True))
 *             fsmParse.constructInflectionalGroups()
 *             initialFsmParse.append(fsmParse)             # <<<<<<<<<<<<<<
 *             return initialFsmParse
 *         if self.__isTime(surfaceForm):
 */
    __pyx_t_11 = __Pyx_PyList_Append(__pyx_v_initialFsmParse, ((PyObject *)__pyx_v_fsmParse)); if (unlikely(__pyx_t_11 == ((int)-1))) __PYX_ERR(0, 829, __pyx_L1_error)

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":830
 *             fsmParse.constructInflectionalGroups()
 *             initialFsmParse.append(fsmParse)
 *             return initialFsmParse             # <<<<<<<<<<<<<<
 *         if self.__isTime(surfaceForm):
 *             initialFsmParse = []
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_initialFsmParse);
    __pyx_r = __pyx_v_initialFsmParse;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":825
 *             initialFsmParse.append(fsmParse)
 *             return initialFsmParse
 *         if surfaceForm == "%" or self.__isPercent(surfaceForm):             # <<<<<<<<<<<<<<
 *             initialFsmParse = []
 *             fsmParse = FsmParse(surfaceForm, State("PercentRoot", True, True))
 */
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":831
 *             initialFsmParse.append(fsmParse)
 *             return initialFsmParse
 *         if self.__isTime(surfaceForm):             # <<<<<<<<<<<<<<
 *             initialFsmParse = []
 *             fsmParse = FsmParse(surfaceForm, State("TimeRoot", True, True))
 */
  __pyx_t_8 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->__pyx___isTime(__pyx_v_self, __pyx_v_surfaceForm, 0) != 0);
  if (__pyx_t_8) {

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":832
 *             return initialFsmParse
 *         if self.__isTime(surfaceForm):
 *             initialFsmParse = []             # <<<<<<<<<<<<<<
 *             fsmParse = FsmParse(surfaceForm, State("TimeRoot", True, True))
 *             fsmParse.constructInflectionalGroups()
 */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 832, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_initialFsmParse = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":833
 *         if self.__isTime(surfaceForm):
 *             initialFsmParse = []
 *             fsmParse = FsmParse(surfaceForm, State("TimeRoot", True, True))             # <<<<<<<<<<<<<<
 *             fsmParse.constructInflectionalGroups()
 *             initialFsmParse.append(fsmParse)
 */
    __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_5State_State), __pyx_tuple__11, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 833, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 833, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_v_surfaceForm);
    __Pyx_GIVEREF(__pyx_v_surfaceForm);
    PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_surfaceForm);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_1);
    __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse), __pyx_t_2, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 833, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_v_fsmParse = ((struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":834
 *             initialFsmParse = []
 *             fsmParse = FsmParse(surfaceForm, State("TimeRoot", True, True))
 *             fsmParse.constructInflectionalGroups()             # <<<<<<<<<<<<<<
 *             initialFsmParse.append(fsmParse)
 *             return initialFsmParse
 */
    __pyx_t_1 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_v_fsmParse->__pyx_base.__pyx_vtab)->constructInflectionalGroups(__pyx_v_fsmParse, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 834, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":835
 *             fsmParse = FsmParse(surfaceForm, State("TimeRoot", True, True))
 *             fsmParse.constructInflectionalGroups()
 *             initialFsmParse.append(fsmParse)             # <<<<<<<<<<<<<<
 *             return initialFsmParse
 *         if self.__isRange(surfaceForm):
 */
    __pyx_t_11 = __Pyx_PyList_Append(__pyx_v_initialFsmParse, ((PyObject *)__pyx_v_fsmParse)); if (unlikely(__pyx_t_11 == ((int)-1))) __PYX_ERR(0, 835, __pyx_L1_error)

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":836
 *             fsmParse.constructInflectionalGroups()
 *             initialFsmParse.append(fsmParse)
 *             return initialFsmParse             # <<<<<<<<<<<<<<
 *         if self.__isRange(surfaceForm):
 *             initialFsmParse = []
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_initialFsmParse);
    __pyx_r = __pyx_v_initialFsmParse;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":831
 *             initialFsmParse.append(fsmParse)
 *             return initialFsmParse
 *         if self.__isTime(surfaceForm):             # <<<<<<<<<<<<<<
 *             initialFsmParse = []
 *             fsmParse = FsmParse(surfaceForm, State("TimeRoot", True, True))
 */
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":837
 *             initialFsmParse.append(fsmParse)
 *             return initialFsmParse
 *         if self.__isRange(surfaceForm):             # <<<<<<<<<<<<<<
 *             initialFsmParse = []
 *             fsmParse = FsmParse(surfaceForm, State("RangeRoot", True, True))
 */
  __pyx_t_8 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->__pyx___isRange(__pyx_v_self, __pyx_v_surfaceForm, 0) != 0);
  if (__pyx_t_8) {

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":838
 *             return initialFsmParse
 *         if self.__isRange(surfaceForm):
 *             initialFsmParse = []             # <<<<<<<<<<<<<<
 *             fsmParse = FsmParse(surfaceForm, State("RangeRoot", True, True))
 *             fsmParse.constructInflectionalGroups()
 */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 838, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_initialFsmParse = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":839
 *         if self.__isRange(surfaceForm):
 *             initialFsmParse = []
 *             fsmParse = FsmParse(surfaceForm, State("RangeRoot", True, True))             # <<<<<<<<<<<<<<
 *             fsmParse.constructInflectionalGroups()
 *             initialFsmParse.append(fsmParse)
 */
    __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_5State_State), __pyx_tuple__12, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 839, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 839, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_v_surfaceForm);
    __Pyx_GIVEREF(__pyx_v_surfaceForm);
    PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_surfaceForm);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_1);
    __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse), __pyx_t_2, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 839, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_v_fsmParse = ((struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":840
 *             initialFsmParse = []
 *             fsmParse = FsmParse(surfaceForm, State("RangeRoot", True, True))
 *             fsmParse.constructInflectionalGroups()             # <<<<<<<<<<<<<<
 *             initialFsmParse.append(fsmParse)
 *             return initialFsmParse
 */
    __pyx_t_1 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_v_fsmParse->__pyx_base.__pyx_vtab)->constructInflectionalGroups(__pyx_v_fsmParse, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 840, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":841
 *             fsmParse = FsmParse(surfaceForm, State("RangeRoot", True, True))
 *             fsmParse.constructInflectionalGroups()
 *             initialFsmParse.append(fsmParse)             # <<<<<<<<<<<<<<
 *             return initialFsmParse
 *         if surfaceForm.startswith("#"):
 */
    __pyx_t_11 = __Pyx_PyList_Append(__pyx_v_initialFsmParse, ((PyObject *)__pyx_v_fsmParse)); if (unlikely(__pyx_t_11 == ((int)-1))) __PYX_ERR(0, 841, __pyx_L1_error)

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":842
 *             fsmParse.constructInflectionalGroups()
 *             initialFsmParse.append(fsmParse)
 *             return initialFsmParse             # <<<<<<<<<<<<<<
 *         if surfaceForm.startswith("#"):
 *             initialFsmParse = []
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_initialFsmParse);
    __pyx_r = __pyx_v_initialFsmParse;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":837
 *             initialFsmParse.append(fsmParse)
 *             return initialFsmParse
 *         if self.__isRange(surfaceForm):             # <<<<<<<<<<<<<<
 *             initialFsmParse = []
 *             fsmParse = FsmParse(surfaceForm, State("RangeRoot", True, True))
 */
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":843
 *             initialFsmParse.append(fsmParse)
 *             return initialFsmParse
 *         if surfaceForm.startswith("#"):             # <<<<<<<<<<<<<<
 *             initialFsmParse = []
 *             fsmParse = FsmParse(surfaceForm, State("Hashtag", True, True))
 */
  if (unlikely(__pyx_v_surfaceForm == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "startswith");
    __PYX_ERR(0, 843, __pyx_L1_error)
  }
  __pyx_t_8 = __Pyx_PyUnicode_Tailmatch(__pyx_v_surfaceForm, __pyx_kp_u__13, 0, PY_SSIZE_T_MAX, -1); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 843, __pyx_L1_error)
  if ((__pyx_t_8 != 0)) {

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":844
 *             return initialFsmParse
 *         if surfaceForm.startswith("#"):
 *             initialFsmParse = []             # <<<<<<<<<<<<<<
 *             fsmParse = FsmParse(surfaceForm, State("Hashtag", True, True))
 *             fsmParse.constructInflectionalGroups()
 */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 844, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_initialFsmParse = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":845
 *         if surfaceForm.startswith("#"):
 *             initialFsmParse = []
 *             fsmParse = FsmParse(surfaceForm, State("Hashtag", True, True))             # <<<<<<<<<<<<<<
 *             fsmParse.constructInflectionalGroups()
 *             initialFsmParse.append(fsmParse)
 */
    __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_5State_State), __pyx_tuple__14, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 845, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 845, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_v_surfaceForm);
    __Pyx_GIVEREF(__pyx_v_surfaceForm);
    PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_surfaceForm);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_1);
    __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse), __pyx_t_2, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 845, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_v_fsmParse = ((struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":846
 *             initialFsmParse = []
 *             fsmParse = FsmParse(surfaceForm, State("Hashtag", True, True))
 *             fsmParse.constructInflectionalGroups()             # <<<<<<<<<<<<<<
 *             initialFsmParse.append(fsmParse)
 *             return initialFsmParse
 */
    __pyx_t_1 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_v_fsmParse->__pyx_base.__pyx_vtab)->constructInflectionalGroups(__pyx_v_fsmParse, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 846, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":847
 *             fsmParse = FsmParse(surfaceForm, State("Hashtag", True, True))
 *             fsmParse.constructInflectionalGroups()
 *             initialFsmParse.append(fsmParse)             # <<<<<<<<<<<<<<
 *             return initialFsmParse
 *         if "@" in surfaceForm:
 */
    __pyx_t_11 = __Pyx_PyList_Append(__pyx_v_initialFsmParse, ((PyObject *)__pyx_v_fsmParse)); if (unlikely(__pyx_t_11 == ((int)-1))) __PYX_ERR(0, 847, __pyx_L1_error)

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":848
 *             fsmParse.constructInflectionalGroups()
 *             initialFsmParse.append(fsmParse)
 *             return initialFsmParse             # <<<<<<<<<<<<<<
 *         if "@" in surfaceForm:
 *             initialFsmParse = []
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_initialFsmParse);
    __pyx_r = __pyx_v_initialFsmParse;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":843
 *             initialFsmParse.append(fsmParse)
 *             return initialFsmParse
 *         if surfaceForm.startswith("#"):             # <<<<<<<<<<<<<<
 *             initialFsmParse = []
 *             fsmParse = FsmParse(surfaceForm, State("Hashtag", True, True))
 */
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":849
 *             initialFsmParse.append(fsmParse)
 *             return initialFsmParse
 *         if "@" in surfaceForm:             # <<<<<<<<<<<<<<
 *             initialFsmParse = []
 *             fsmParse = FsmParse(surfaceForm, State("Email", True, True))
 */
  if (unlikely(__pyx_v_surfaceForm == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(0, 849, __pyx_L1_error)
  }
  __pyx_t_8 = (__Pyx_PyUnicode_ContainsTF(__pyx_kp_u__15, __pyx_v_surfaceForm, Py_EQ)); if (unlikely(__pyx_t_8 < 0)) __PYX_ERR(0, 849, __pyx_L1_error)
  __pyx_t_9 = (__pyx_t_8 != 0);
  if (__pyx_t_9) {

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":850
 *             return initialFsmParse
 *         if "@" in surfaceForm:
 *             initialFsmParse = []             # <<<<<<<<<<<<<<
 *             fsmParse = FsmParse(surfaceForm, State("Email", True, True))
 *             fsmParse.constructInflectionalGroups()
 */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 850, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_initialFsmParse = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":851
 *         if "@" in surfaceForm:
 *             initialFsmParse = []
 *             fsmParse = FsmParse(surfaceForm, State("Email", True, True))             # <<<<<<<<<<<<<<
 *             fsmParse.constructInflectionalGroups()
 *             initialFsmParse.append(fsmParse)
 */
    __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_5State_State), __pyx_tuple__16, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 851, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 851, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_v_surfaceForm);
    __Pyx_GIVEREF(__pyx_v_surfaceForm);
    PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_surfaceForm);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_1);
    __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse), __pyx_t_2, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 851, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_v_fsmParse = ((struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":852
 *             initialFsmParse = []
 *             fsmParse = FsmParse(surfaceForm, State("Email", True, True))
 *             fsmParse.constructInflectionalGroups()             # <<<<<<<<<<<<<<
 *             initialFsmParse.append(fsmParse)
 *             return initialFsmParse
 */
    __pyx_t_1 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_v_fsmParse->__pyx_base.__pyx_vtab)->constructInflectionalGroups(__pyx_v_fsmParse, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 852, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":853
 *             fsmParse = FsmParse(surfaceForm, State("Email", True, True))
 *             fsmParse.constructInflectionalGroups()
 *             initialFsmParse.append(fsmParse)             # <<<<<<<<<<<<<<
 *             return initialFsmParse
 *         if surfaceForm.endswith(".") and self.__isInteger(surfaceForm[:len(surfaceForm) - 1]):
 */
    __pyx_t_11 = __Pyx_PyList_Append(__pyx_v_initialFsmParse, ((PyObject *)__pyx_v_fsmParse)); if (unlikely(__pyx_t_11 == ((int)-1))) __PYX_ERR(0, 853, __pyx_L1_error)

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":854
 *             fsmParse.constructInflectionalGroups()
 *             initialFsmParse.append(fsmParse)
 *             return initialFsmParse             # <<<<<<<<<<<<<<
 *         if surfaceForm.endswith(".") and self.__isInteger(surfaceForm[:len(surfaceForm) - 1]):
 *             initialFsmParse = []
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_initialFsmParse);
    __pyx_r = __pyx_v_initialFsmParse;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":849
 *             initialFsmParse.append(fsmParse)
 *             return initialFsmParse
 *         if "@" in surfaceForm:             # <<<<<<<<<<<<<<
 *             initialFsmParse = []
 *             fsmParse = FsmParse(surfaceForm, State("Email", True, True))
 */
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":855
 *             initialFsmParse.append(fsmParse)
 *             return initialFsmParse
 *         if surfaceForm.endswith(".") and self.__isInteger(surfaceForm[:len(surfaceForm) - 1]):             # <<<<<<<<<<<<<<
 *             initialFsmParse = []
 *             fsmParse = FsmParse(int(surfaceForm[:len(surfaceForm) - 1]),
 */
  if (unlikely(__pyx_v_surfaceForm == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "endswith");
    __PYX_ERR(0, 855, __pyx_L1_error)
  }
  __pyx_t_8 = __Pyx_PyUnicode_Tailmatch(__pyx_v_surfaceForm, __pyx_kp_u__17, 0, PY_SSIZE_T_MAX, 1); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 855, __pyx_L1_error)
  if ((__pyx_t_8 != 0)) {
  } else {
    __pyx_t_9 = (__pyx_t_8 != 0);
    goto __pyx_L18_bool_binop_done;
  }
  if (unlikely(__pyx_v_surfaceForm == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 855, __pyx_L1_error)
  }
  if (unlikely(__pyx_v_surfaceForm == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(0, 855, __pyx_L1_error)
  }
  __pyx_t_12 = __Pyx_PyUnicode_GET_LENGTH(__pyx_v_surfaceForm); if (unlikely(__pyx_t_12 == ((Py_ssize_t)-1))) __PYX_ERR(0, 855, __pyx_L1_error)
  __pyx_t_1 = __Pyx_PyUnicode_Substring(__pyx_v_surfaceForm, 0, (__pyx_t_12 - 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 855, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_8 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->__pyx___isInteger(__pyx_v_self, ((PyObject*)__pyx_t_1), 0) != 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_9 = __pyx_t_8;
  __pyx_L18_bool_binop_done:;
  if (__pyx_t_9) {

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":856
 *             return initialFsmParse
 *         if surfaceForm.endswith(".") and self.__isInteger(surfaceForm[:len(surfaceForm) - 1]):
 *             initialFsmParse = []             # <<<<<<<<<<<<<<
 *             fsmParse = FsmParse(int(surfaceForm[:len(surfaceForm) - 1]),
 *                                 self.__finiteStateMachine.getState("OrdinalRoot"))
 */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 856, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_initialFsmParse = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":857
 *         if surfaceForm.endswith(".") and self.__isInteger(surfaceForm[:len(surfaceForm) - 1]):
 *             initialFsmParse = []
 *             fsmParse = FsmParse(int(surfaceForm[:len(surfaceForm) - 1]),             # <<<<<<<<<<<<<<
 *                                 self.__finiteStateMachine.getState("OrdinalRoot"))
 *             fsmParse.constructInflectionalGroups()
 */
    if (unlikely(__pyx_v_surfaceForm == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 857, __pyx_L1_error)
    }
    if (unlikely(__pyx_v_surfaceForm == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
      __PYX_ERR(0, 857, __pyx_L1_error)
    }
    __pyx_t_12 = __Pyx_PyUnicode_GET_LENGTH(__pyx_v_surfaceForm); if (unlikely(__pyx_t_12 == ((Py_ssize_t)-1))) __PYX_ERR(0, 857, __pyx_L1_error)
    __pyx_t_1 = __Pyx_PyUnicode_Substring(__pyx_v_surfaceForm, 0, (__pyx_t_12 - 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 857, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyNumber_Int(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 857, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":858
 *             initialFsmParse = []
 *             fsmParse = FsmParse(int(surfaceForm[:len(surfaceForm) - 1]),
 *                                 self.__finiteStateMachine.getState("OrdinalRoot"))             # <<<<<<<<<<<<<<
 *             fsmParse.constructInflectionalGroups()
 *             initialFsmParse.append(fsmParse)
 */
    __pyx_t_1 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine *)__pyx_v_self->__pyx___finiteStateMachine->__pyx_vtab)->getState(__pyx_v_self->__pyx___finiteStateMachine, __pyx_n_u_OrdinalRoot, 0)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 858, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":857
 *         if surfaceForm.endswith(".") and self.__isInteger(surfaceForm[:len(surfaceForm) - 1]):
 *             initialFsmParse = []
 *             fsmParse = FsmParse(int(surfaceForm[:len(surfaceForm) - 1]),             # <<<<<<<<<<<<<<
 *                                 self.__finiteStateMachine.getState("OrdinalRoot"))
 *             fsmParse.constructInflectionalGroups()
 */
    __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 857, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_1);
    __pyx_t_2 = 0;
    __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse), __pyx_t_4, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 857, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_v_fsmParse = ((struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":859
 *             fsmParse = FsmParse(int(surfaceForm[:len(surfaceForm) - 1]),
 *                                 self.__finiteStateMachine.getState("OrdinalRoot"))
 *             fsmParse.constructInflectionalGroups()             # <<<<<<<<<<<<<<
 *             initialFsmParse.append(fsmParse)
 *             return initialFsmParse
 */
    __pyx_t_1 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_v_fsmParse->__pyx_base.__pyx_vtab)->constructInflectionalGroups(__pyx_v_fsmParse, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 859, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":860
 *                                 self.__finiteStateMachine.getState("OrdinalRoot"))
 *             fsmParse.constructInflectionalGroups()
 *             initialFsmParse.append(fsmParse)             # <<<<<<<<<<<<<<
 *             return initialFsmParse
 *         if self.__isInteger(surfaceForm):
 */
    __pyx_t_11 = __Pyx_PyList_Append(__pyx_v_initialFsmParse, ((PyObject *)__pyx_v_fsmParse)); if (unlikely(__pyx_t_11 == ((int)-1))) __PYX_ERR(0, 860, __pyx_L1_error)

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":861
 *             fsmParse.constructInflectionalGroups()
 *             initialFsmParse.append(fsmParse)
 *             return initialFsmParse             # <<<<<<<<<<<<<<
 *         if self.__isInteger(surfaceForm):
 *             initialFsmParse = []
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_initialFsmParse);
    __pyx_r = __pyx_v_initialFsmParse;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":855
 *             initialFsmParse.append(fsmParse)
 *             return initialFsmParse
 *         if surfaceForm.endswith(".") and self.__isInteger(surfaceForm[:len(surfaceForm) - 1]):             # <<<<<<<<<<<<<<
 *             initialFsmParse = []
 *             fsmParse = FsmParse(int(surfaceForm[:len(surfaceForm) - 1]),
 */
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":862
 *             initialFsmParse.append(fsmParse)
 *             return initialFsmParse
 *         if self.__isInteger(surfaceForm):             # <<<<<<<<<<<<<<
 *             initialFsmParse = []
 *             fsmParse = FsmParse(int(surfaceForm), self.__finiteStateMachine.getState("CardinalRoot"))
 */
  __pyx_t_9 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->__pyx___isInteger(__pyx_v_self, __pyx_v_surfaceForm, 0) != 0);
  if (__pyx_t_9) {

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":863
 *             return initialFsmParse
 *         if self.__isInteger(surfaceForm):
 *             initialFsmParse = []             # <<<<<<<<<<<<<<
 *             fsmParse = FsmParse(int(surfaceForm), self.__finiteStateMachine.getState("CardinalRoot"))
 *             fsmParse.constructInflectionalGroups()
 */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 863, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_initialFsmParse = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":864
 *         if self.__isInteger(surfaceForm):
 *             initialFsmParse = []
 *             fsmParse = FsmParse(int(surfaceForm), self.__finiteStateMachine.getState("CardinalRoot"))             # <<<<<<<<<<<<<<
 *             fsmParse.constructInflectionalGroups()
 *             initialFsmParse.append(fsmParse)
 */
    __pyx_t_1 = __Pyx_PyNumber_Int(__pyx_v_surfaceForm); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 864, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine *)__pyx_v_self->__pyx___finiteStateMachine->__pyx_vtab)->getState(__pyx_v_self->__pyx___finiteStateMachine, __pyx_n_u_CardinalRoot, 0)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 864, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 864, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_4);
    __pyx_t_1 = 0;
    __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse), __pyx_t_2, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 864, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_v_fsmParse = ((struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_t_4);
    __pyx_t_4 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":865
 *             initialFsmParse = []
 *             fsmParse = FsmParse(int(surfaceForm), self.__finiteStateMachine.getState("CardinalRoot"))
 *             fsmParse.constructInflectionalGroups()             # <<<<<<<<<<<<<<
 *             initialFsmParse.append(fsmParse)
 *             return initialFsmParse
 */
    __pyx_t_4 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_v_fsmParse->__pyx_base.__pyx_vtab)->constructInflectionalGroups(__pyx_v_fsmParse, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 865, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":866
 *             fsmParse = FsmParse(int(surfaceForm), self.__finiteStateMachine.getState("CardinalRoot"))
 *             fsmParse.constructInflectionalGroups()
 *             initialFsmParse.append(fsmParse)             # <<<<<<<<<<<<<<
 *             return initialFsmParse
 *         if self.__isDouble(surfaceForm):
 */
    __pyx_t_11 = __Pyx_PyList_Append(__pyx_v_initialFsmParse, ((PyObject *)__pyx_v_fsmParse)); if (unlikely(__pyx_t_11 == ((int)-1))) __PYX_ERR(0, 866, __pyx_L1_error)

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":867
 *             fsmParse.constructInflectionalGroups()
 *             initialFsmParse.append(fsmParse)
 *             return initialFsmParse             # <<<<<<<<<<<<<<
 *         if self.__isDouble(surfaceForm):
 *             initialFsmParse = []
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_initialFsmParse);
    __pyx_r = __pyx_v_initialFsmParse;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":862
 *             initialFsmParse.append(fsmParse)
 *             return initialFsmParse
 *         if self.__isInteger(surfaceForm):             # <<<<<<<<<<<<<<
 *             initialFsmParse = []
 *             fsmParse = FsmParse(int(surfaceForm), self.__finiteStateMachine.getState("CardinalRoot"))
 */
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":868
 *             initialFsmParse.append(fsmParse)
 *             return initialFsmParse
 *         if self.__isDouble(surfaceForm):             # <<<<<<<<<<<<<<
 *             initialFsmParse = []
 *             fsmParse = FsmParse(float(surfaceForm), self.__finiteStateMachine.getState("RealRoot"))
 */
  __pyx_t_9 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->__pyx___isDouble(__pyx_v_self, __pyx_v_surfaceForm, 0) != 0);
  if (__pyx_t_9) {

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":869
 *             return initialFsmParse
 *         if self.__isDouble(surfaceForm):
 *             initialFsmParse = []             # <<<<<<<<<<<<<<
 *             fsmParse = FsmParse(float(surfaceForm), self.__finiteStateMachine.getState("RealRoot"))
 *             fsmParse.constructInflectionalGroups()
 */
    __pyx_t_4 = PyList_New(0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 869, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_v_initialFsmParse = ((PyObject*)__pyx_t_4);
    __pyx_t_4 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":870
 *         if self.__isDouble(surfaceForm):
 *             initialFsmParse = []
 *             fsmParse = FsmParse(float(surfaceForm), self.__finiteStateMachine.getState("RealRoot"))             # <<<<<<<<<<<<<<
 *             fsmParse.constructInflectionalGroups()
 *             initialFsmParse.append(fsmParse)
 */
    __pyx_t_4 = __Pyx_PyNumber_Float(__pyx_v_surfaceForm); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 870, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_2 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine *)__pyx_v_self->__pyx___finiteStateMachine->__pyx_vtab)->getState(__pyx_v_self->__pyx___finiteStateMachine, __pyx_n_u_RealRoot, 0)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 870, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 870, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_2);
    __pyx_t_4 = 0;
    __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse), __pyx_t_1, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 870, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_v_fsmParse = ((struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_t_2);
    __pyx_t_2 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":871
 *             initialFsmParse = []
 *             fsmParse = FsmParse(float(surfaceForm), self.__finiteStateMachine.getState("RealRoot"))
 *             fsmParse.constructInflectionalGroups()             # <<<<<<<<<<<<<<
 *             initialFsmParse.append(fsmParse)
 *             return initialFsmParse
 */
    __pyx_t_2 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_v_fsmParse->__pyx_base.__pyx_vtab)->constructInflectionalGroups(__pyx_v_fsmParse, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 871, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":872
 *             fsmParse = FsmParse(float(surfaceForm), self.__finiteStateMachine.getState("RealRoot"))
 *             fsmParse.constructInflectionalGroups()
 *             initialFsmParse.append(fsmParse)             # <<<<<<<<<<<<<<
 *             return initialFsmParse
 *         initialFsmParse = self.__initializeParseListFromSurfaceForm(surfaceForm, isProper)
 */
    __pyx_t_11 = __Pyx_PyList_Append(__pyx_v_initialFsmParse, ((PyObject *)__pyx_v_fsmParse)); if (unlikely(__pyx_t_11 == ((int)-1))) __PYX_ERR(0, 872, __pyx_L1_error)

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":873
 *             fsmParse.constructInflectionalGroups()
 *             initialFsmParse.append(fsmParse)
 *             return initialFsmParse             # <<<<<<<<<<<<<<
 *         initialFsmParse = self.__initializeParseListFromSurfaceForm(surfaceForm, isProper)
 *         return self.__parseWord(initialFsmParse, surfaceForm)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_initialFsmParse);
    __pyx_r = __pyx_v_initialFsmParse;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":868
 *             initialFsmParse.append(fsmParse)
 *             return initialFsmParse
 *         if self.__isDouble(surfaceForm):             # <<<<<<<<<<<<<<
 *             initialFsmParse = []
 *             fsmParse = FsmParse(float(surfaceForm), self.__finiteStateMachine.getState("RealRoot"))
 */
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":874
 *             initialFsmParse.append(fsmParse)
 *             return initialFsmParse
 *         initialFsmParse = self.__initializeParseListFromSurfaceForm(surfaceForm, isProper)             # <<<<<<<<<<<<<<
 *         return self.__parseWord(initialFsmParse, surfaceForm)
 * 
 */
  __pyx_t_2 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->__pyx___initializeParseListFromSurfaceForm(__pyx_v_self, __pyx_v_surfaceForm, __pyx_v_isProper, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 874, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_initialFsmParse = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":875
 *             return initialFsmParse
 *         initialFsmParse = self.__initializeParseListFromSurfaceForm(surfaceForm, isProper)
 *         return self.__parseWord(initialFsmParse, surfaceForm)             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint patternMatches(self, str expr, str value):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->__pyx___parseWord(__pyx_v_self, __pyx_v_initialFsmParse, __pyx_v_surfaceForm, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 875, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":772
 *         return self.__parseExists(initialFsmParse, surfaceForm)
 * 
 *     cpdef list __analysis(self, str surfaceForm, bint isProper):             # <<<<<<<<<<<<<<
 *         """
 *         The analysis method is used by the morphologicalAnalysis method. It gets String surfaceForm as an input and
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("MorphologicalAnalysis.FsmMorphologicalAnalyzer.FsmMorphologicalAnalyzer.__analysis", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_initialFsmParse);
  __Pyx_XDECREF((PyObject *)__pyx_v_fsmParse);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_31__analysis(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_30__analysis[] = "\n        The analysis method is used by the morphologicalAnalysis method. It gets String surfaceForm as an input and\n        checks its type such as punctuation, number or compares with the regex for date, fraction, percent, time, range,\n        hashtag, and mail or checks its variable type as integer or double. After finding the right case for given\n        surfaceForm, it calls constructInflectionalGroups method which creates sub-word units.\n\n        PARAMETERS\n        ----------\n        surfaceForm : str\n            String to analyse.\n        isProper : bool\n            is used to indicate the proper words.\n\n        RETURNS\n        -------\n        list\n            List type initialFsmParse which holds the analyses.\n        ";
static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_31__analysis(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_surfaceForm = 0;
  int __pyx_v_isProper;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__analysis (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_surfaceForm,&__pyx_n_s_isProper,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_surfaceForm)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_isProper)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__analysis", 1, 2, 2, 1); __PYX_ERR(0, 772, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__analysis") < 0)) __PYX_ERR(0, 772, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_surfaceForm = ((PyObject*)values[0]);
    __pyx_v_isProper = __Pyx_PyObject_IsTrue(values[1]); if (unlikely((__pyx_v_isProper == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 772, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__analysis", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 772, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("MorphologicalAnalysis.FsmMorphologicalAnalyzer.FsmMorphologicalAnalyzer.__analysis", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_surfaceForm), (&PyUnicode_Type), 1, "surfaceForm", 1))) __PYX_ERR(0, 772, __pyx_L1_error)
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_30__analysis(((struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self), __pyx_v_surfaceForm, __pyx_v_isProper);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_30__analysis(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_surfaceForm, int __pyx_v_isProper) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__analysis", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer___analysis(__pyx_v_self, __pyx_v_surfaceForm, __pyx_v_isProper, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 772, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.FsmMorphologicalAnalyzer.FsmMorphologicalAnalyzer.__analysis", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":877
 *         return self.__parseWord(initialFsmParse, surfaceForm)
 * 
 *     cpdef bint patternMatches(self, str expr, str value):             # <<<<<<<<<<<<<<
 *         if expr in self.__mostUsedPatterns:
 *             return self.__mostUsedPatterns[expr].fullmatch(value) is not None
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_33patternMatches(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_patternMatches(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_expr, PyObject *__pyx_v_value, int __pyx_skip_dispatch) {
  PyObject *__pyx_v_compiledExpression = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("patternMatches", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_patternMatches); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 877, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_33patternMatches)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        __pyx_t_5 = 0;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_5 = 1;
          }
        }
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_3)) {
          PyObject *__pyx_temp[3] = {__pyx_t_4, __pyx_v_expr, __pyx_v_value};
          __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 877, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_GOTREF(__pyx_t_2);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
          PyObject *__pyx_temp[3] = {__pyx_t_4, __pyx_v_expr, __pyx_v_value};
          __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 877, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_GOTREF(__pyx_t_2);
        } else
        #endif
        {
          __pyx_t_6 = PyTuple_New(2+__pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 877, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          if (__pyx_t_4) {
            __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4); __pyx_t_4 = NULL;
          }
          __Pyx_INCREF(__pyx_v_expr);
          __Pyx_GIVEREF(__pyx_v_expr);
          PyTuple_SET_ITEM(__pyx_t_6, 0+__pyx_t_5, __pyx_v_expr);
          __Pyx_INCREF(__pyx_v_value);
          __Pyx_GIVEREF(__pyx_v_value);
          PyTuple_SET_ITEM(__pyx_t_6, 1+__pyx_t_5, __pyx_v_value);
          __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_6, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 877, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        }
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_7 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 877, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_7;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":878
 * 
 *     cpdef bint patternMatches(self, str expr, str value):
 *         if expr in self.__mostUsedPatterns:             # <<<<<<<<<<<<<<
 *             return self.__mostUsedPatterns[expr].fullmatch(value) is not None
 *         else:
 */
  if (unlikely(__pyx_v_self->__pyx___mostUsedPatterns == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(0, 878, __pyx_L1_error)
  }
  __pyx_t_7 = (__Pyx_PyDict_ContainsTF(__pyx_v_expr, __pyx_v_self->__pyx___mostUsedPatterns, Py_EQ)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 878, __pyx_L1_error)
  __pyx_t_8 = (__pyx_t_7 != 0);
  if (__pyx_t_8) {

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":879
 *     cpdef bint patternMatches(self, str expr, str value):
 *         if expr in self.__mostUsedPatterns:
 *             return self.__mostUsedPatterns[expr].fullmatch(value) is not None             # <<<<<<<<<<<<<<
 *         else:
 *             compiledExpression = re.compile(expr)
 */
    if (unlikely(__pyx_v_self->__pyx___mostUsedPatterns == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 879, __pyx_L1_error)
    }
    __pyx_t_2 = __Pyx_PyDict_GetItem(__pyx_v_self->__pyx___mostUsedPatterns, __pyx_v_expr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 879, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_fullmatch); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 879, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    __pyx_t_1 = (__pyx_t_2) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_2, __pyx_v_value) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_value);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 879, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_8 = (__pyx_t_1 != Py_None);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_r = __pyx_t_8;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":878
 * 
 *     cpdef bint patternMatches(self, str expr, str value):
 *         if expr in self.__mostUsedPatterns:             # <<<<<<<<<<<<<<
 *             return self.__mostUsedPatterns[expr].fullmatch(value) is not None
 *         else:
 */
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":881
 *             return self.__mostUsedPatterns[expr].fullmatch(value) is not None
 *         else:
 *             compiledExpression = re.compile(expr)             # <<<<<<<<<<<<<<
 *             self.__mostUsedPatterns[expr] = compiledExpression
 *             return compiledExpression.fullmatch(value) is not None
 */
  /*else*/ {
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_re); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 881, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_compile); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 881, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
      }
    }
    __pyx_t_1 = (__pyx_t_3) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_3, __pyx_v_expr) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v_expr);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 881, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_v_compiledExpression = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":882
 *         else:
 *             compiledExpression = re.compile(expr)
 *             self.__mostUsedPatterns[expr] = compiledExpression             # <<<<<<<<<<<<<<
 *             return compiledExpression.fullmatch(value) is not None
 * 
 */
    if (unlikely(__pyx_v_self->__pyx___mostUsedPatterns == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 882, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__pyx_v_self->__pyx___mostUsedPatterns, __pyx_v_expr, __pyx_v_compiledExpression) < 0)) __PYX_ERR(0, 882, __pyx_L1_error)

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":883
 *             compiledExpression = re.compile(expr)
 *             self.__mostUsedPatterns[expr] = compiledExpression
 *             return compiledExpression.fullmatch(value) is not None             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint isProperNoun(self, str surfaceForm):
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_compiledExpression, __pyx_n_s_fullmatch); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 883, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
      }
    }
    __pyx_t_1 = (__pyx_t_3) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_3, __pyx_v_value) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v_value);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 883, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_8 = (__pyx_t_1 != Py_None);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_r = __pyx_t_8;
    goto __pyx_L0;
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":877
 *         return self.__parseWord(initialFsmParse, surfaceForm)
 * 
 *     cpdef bint patternMatches(self, str expr, str value):             # <<<<<<<<<<<<<<
 *         if expr in self.__mostUsedPatterns:
 *             return self.__mostUsedPatterns[expr].fullmatch(value) is not None
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_WriteUnraisable("MorphologicalAnalysis.FsmMorphologicalAnalyzer.FsmMorphologicalAnalyzer.patternMatches", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_compiledExpression);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_33patternMatches(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_33patternMatches(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_expr = 0;
  PyObject *__pyx_v_value = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("patternMatches (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_expr,&__pyx_n_s_value,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_expr)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_value)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("patternMatches", 1, 2, 2, 1); __PYX_ERR(0, 877, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "patternMatches") < 0)) __PYX_ERR(0, 877, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_expr = ((PyObject*)values[0]);
    __pyx_v_value = ((PyObject*)values[1]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("patternMatches", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 877, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("MorphologicalAnalysis.FsmMorphologicalAnalyzer.FsmMorphologicalAnalyzer.patternMatches", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_expr), (&PyUnicode_Type), 1, "expr", 1))) __PYX_ERR(0, 877, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_value), (&PyUnicode_Type), 1, "value", 1))) __PYX_ERR(0, 877, __pyx_L1_error)
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_32patternMatches(((struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self), __pyx_v_expr, __pyx_v_value);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_32patternMatches(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_expr, PyObject *__pyx_v_value) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("patternMatches", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_patternMatches(__pyx_v_self, __pyx_v_expr, __pyx_v_value, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 877, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.FsmMorphologicalAnalyzer.FsmMorphologicalAnalyzer.patternMatches", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":885
 *             return compiledExpression.fullmatch(value) is not None
 * 
 *     cpdef bint isProperNoun(self, str surfaceForm):             # <<<<<<<<<<<<<<
 *         """
 *         The isProperNoun method takes surfaceForm String as input and checks its each char whether they are in the range
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_35isProperNoun(PyObject *__pyx_v_self, PyObject *__pyx_v_surfaceForm); /*proto*/
static int __pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_isProperNoun(CYTHON_UNUSED struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_surfaceForm, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  Py_ssize_t __pyx_t_8;
  Py_UCS4 __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isProperNoun", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_isProperNoun); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 885, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_35isProperNoun)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_v_surfaceForm) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_surfaceForm);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 885, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 885, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":900
 *             False if surfaceForm is null or length of 0, return true if it is a letter.
 *         """
 *         if surfaceForm is None or len(surfaceForm) == 0:             # <<<<<<<<<<<<<<
 *             return False
 *         return "A" <= surfaceForm[0] <= "Z" or surfaceForm[0] == "" or surfaceForm[0] == "" or surfaceForm[0] == "" \
 */
  __pyx_t_6 = (__pyx_v_surfaceForm == ((PyObject*)Py_None));
  __pyx_t_7 = (__pyx_t_6 != 0);
  if (!__pyx_t_7) {
  } else {
    __pyx_t_5 = __pyx_t_7;
    goto __pyx_L4_bool_binop_done;
  }
  if (unlikely(__pyx_v_surfaceForm == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(0, 900, __pyx_L1_error)
  }
  __pyx_t_8 = __Pyx_PyUnicode_GET_LENGTH(__pyx_v_surfaceForm); if (unlikely(__pyx_t_8 == ((Py_ssize_t)-1))) __PYX_ERR(0, 900, __pyx_L1_error)
  __pyx_t_7 = ((__pyx_t_8 == 0) != 0);
  __pyx_t_5 = __pyx_t_7;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_5) {

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":901
 *         """
 *         if surfaceForm is None or len(surfaceForm) == 0:
 *             return False             # <<<<<<<<<<<<<<
 *         return "A" <= surfaceForm[0] <= "Z" or surfaceForm[0] == "" or surfaceForm[0] == "" or surfaceForm[0] == "" \
 *                or surfaceForm[0] == "" or surfaceForm[0] == "" or surfaceForm[0] == ""
 */
    __pyx_r = 0;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":900
 *             False if surfaceForm is null or length of 0, return true if it is a letter.
 *         """
 *         if surfaceForm is None or len(surfaceForm) == 0:             # <<<<<<<<<<<<<<
 *             return False
 *         return "A" <= surfaceForm[0] <= "Z" or surfaceForm[0] == "" or surfaceForm[0] == "" or surfaceForm[0] == "" \
 */
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":902
 *         if surfaceForm is None or len(surfaceForm) == 0:
 *             return False
 *         return "A" <= surfaceForm[0] <= "Z" or surfaceForm[0] == "" or surfaceForm[0] == "" or surfaceForm[0] == "" \             # <<<<<<<<<<<<<<
 *                or surfaceForm[0] == "" or surfaceForm[0] == "" or surfaceForm[0] == ""
 * 
 */
  __pyx_t_9 = __Pyx_GetItemInt_Unicode(__pyx_v_surfaceForm, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(__pyx_t_9 == (Py_UCS4)-1)) __PYX_ERR(0, 902, __pyx_L1_error)
  __pyx_t_7 = (65 <= __pyx_t_9);
  if (__pyx_t_7) {
    __pyx_t_7 = (__pyx_t_9 <= 90);
  }
  __pyx_t_6 = (__pyx_t_7 != 0);
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L6_bool_binop_done;
  }
  __pyx_t_9 = __Pyx_GetItemInt_Unicode(__pyx_v_surfaceForm, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(__pyx_t_9 == (Py_UCS4)-1)) __PYX_ERR(0, 902, __pyx_L1_error)
  __pyx_t_6 = ((__pyx_t_9 == 0xC7) != 0);
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L6_bool_binop_done;
  }
  __pyx_t_9 = __Pyx_GetItemInt_Unicode(__pyx_v_surfaceForm, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(__pyx_t_9 == (Py_UCS4)-1)) __PYX_ERR(0, 902, __pyx_L1_error)
  __pyx_t_6 = ((__pyx_t_9 == 0xD6) != 0);
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L6_bool_binop_done;
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":903
 *             return False
 *         return "A" <= surfaceForm[0] <= "Z" or surfaceForm[0] == "" or surfaceForm[0] == "" or surfaceForm[0] == "" \
 *                or surfaceForm[0] == "" or surfaceForm[0] == "" or surfaceForm[0] == ""             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint __isPercent(self, str surfaceForm):
 */
  __pyx_t_9 = __Pyx_GetItemInt_Unicode(__pyx_v_surfaceForm, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(__pyx_t_9 == (Py_UCS4)-1)) __PYX_ERR(0, 902, __pyx_L1_error)

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":902
 *         if surfaceForm is None or len(surfaceForm) == 0:
 *             return False
 *         return "A" <= surfaceForm[0] <= "Z" or surfaceForm[0] == "" or surfaceForm[0] == "" or surfaceForm[0] == "" \             # <<<<<<<<<<<<<<
 *                or surfaceForm[0] == "" or surfaceForm[0] == "" or surfaceForm[0] == ""
 * 
 */
  __pyx_t_6 = ((__pyx_t_9 == 0x11E) != 0);
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L6_bool_binop_done;
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":903
 *             return False
 *         return "A" <= surfaceForm[0] <= "Z" or surfaceForm[0] == "" or surfaceForm[0] == "" or surfaceForm[0] == "" \
 *                or surfaceForm[0] == "" or surfaceForm[0] == "" or surfaceForm[0] == ""             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint __isPercent(self, str surfaceForm):
 */
  __pyx_t_9 = __Pyx_GetItemInt_Unicode(__pyx_v_surfaceForm, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(__pyx_t_9 == (Py_UCS4)-1)) __PYX_ERR(0, 903, __pyx_L1_error)
  __pyx_t_6 = ((__pyx_t_9 == 0xDC) != 0);
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L6_bool_binop_done;
  }
  __pyx_t_9 = __Pyx_GetItemInt_Unicode(__pyx_v_surfaceForm, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(__pyx_t_9 == (Py_UCS4)-1)) __PYX_ERR(0, 903, __pyx_L1_error)
  __pyx_t_6 = ((__pyx_t_9 == 0x15E) != 0);
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L6_bool_binop_done;
  }
  __pyx_t_9 = __Pyx_GetItemInt_Unicode(__pyx_v_surfaceForm, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(__pyx_t_9 == (Py_UCS4)-1)) __PYX_ERR(0, 903, __pyx_L1_error)
  __pyx_t_6 = ((__pyx_t_9 == 0x130) != 0);
  __pyx_t_5 = __pyx_t_6;
  __pyx_L6_bool_binop_done:;
  __pyx_r = __pyx_t_5;
  goto __pyx_L0;

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":885
 *             return compiledExpression.fullmatch(value) is not None
 * 
 *     cpdef bint isProperNoun(self, str surfaceForm):             # <<<<<<<<<<<<<<
 *         """
 *         The isProperNoun method takes surfaceForm String as input and checks its each char whether they are in the range
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("MorphologicalAnalysis.FsmMorphologicalAnalyzer.FsmMorphologicalAnalyzer.isProperNoun", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_35isProperNoun(PyObject *__pyx_v_self, PyObject *__pyx_v_surfaceForm); /*proto*/
static char __pyx_doc_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_34isProperNoun[] = "\n        The isProperNoun method takes surfaceForm String as input and checks its each char whether they are in the range\n        of letters between A to Z or one of the Turkish letters such as \304\260, \303\234, \304\236, \305\236, \303\207, and \303\226.\n\n        PARAMETERS\n        ----------\n        surfaceForm : str\n            String to check for proper noun.\n\n        RETURNS\n        -------\n        bool\n            False if surfaceForm is null or length of 0, return true if it is a letter.\n        ";
static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_35isProperNoun(PyObject *__pyx_v_self, PyObject *__pyx_v_surfaceForm) {
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("isProperNoun (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_surfaceForm), (&PyUnicode_Type), 1, "surfaceForm", 1))) __PYX_ERR(0, 885, __pyx_L1_error)
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_34isProperNoun(((struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self), ((PyObject*)__pyx_v_surfaceForm));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_34isProperNoun(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_surfaceForm) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isProperNoun", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_isProperNoun(__pyx_v_self, __pyx_v_surfaceForm, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 885, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.FsmMorphologicalAnalyzer.FsmMorphologicalAnalyzer.isProperNoun", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":905
 *                or surfaceForm[0] == "" or surfaceForm[0] == "" or surfaceForm[0] == ""
 * 
 *     cpdef bint __isPercent(self, str surfaceForm):             # <<<<<<<<<<<<<<
 *         return self.patternMatches("%(\\d\\d|\\d)", surfaceForm) or \
 *                self.patternMatches("%(\\d\\d|\\d)\\.\\d+", surfaceForm)
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_37__isPercent(PyObject *__pyx_v_self, PyObject *__pyx_v_surfaceForm); /*proto*/
static int __pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer___isPercent(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_surfaceForm, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__isPercent", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_isPercent); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 905, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_37__isPercent)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_v_surfaceForm) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_surfaceForm);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 905, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 905, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":906
 * 
 *     cpdef bint __isPercent(self, str surfaceForm):
 *         return self.patternMatches("%(\\d\\d|\\d)", surfaceForm) or \             # <<<<<<<<<<<<<<
 *                self.patternMatches("%(\\d\\d|\\d)\\.\\d+", surfaceForm)
 * 
 */
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->patternMatches(__pyx_v_self, __pyx_kp_u_d_d_d, __pyx_v_surfaceForm, 0) != 0);
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L3_bool_binop_done;
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":907
 *     cpdef bint __isPercent(self, str surfaceForm):
 *         return self.patternMatches("%(\\d\\d|\\d)", surfaceForm) or \
 *                self.patternMatches("%(\\d\\d|\\d)\\.\\d+", surfaceForm)             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint __isTime(self, str surfaceForm):
 */
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->patternMatches(__pyx_v_self, __pyx_kp_u_d_d_d_d, __pyx_v_surfaceForm, 0) != 0);
  __pyx_t_5 = __pyx_t_6;
  __pyx_L3_bool_binop_done:;
  __pyx_r = __pyx_t_5;
  goto __pyx_L0;

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":905
 *                or surfaceForm[0] == "" or surfaceForm[0] == "" or surfaceForm[0] == ""
 * 
 *     cpdef bint __isPercent(self, str surfaceForm):             # <<<<<<<<<<<<<<
 *         return self.patternMatches("%(\\d\\d|\\d)", surfaceForm) or \
 *                self.patternMatches("%(\\d\\d|\\d)\\.\\d+", surfaceForm)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("MorphologicalAnalysis.FsmMorphologicalAnalyzer.FsmMorphologicalAnalyzer.__isPercent", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_37__isPercent(PyObject *__pyx_v_self, PyObject *__pyx_v_surfaceForm); /*proto*/
static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_37__isPercent(PyObject *__pyx_v_self, PyObject *__pyx_v_surfaceForm) {
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__isPercent (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_surfaceForm), (&PyUnicode_Type), 1, "surfaceForm", 1))) __PYX_ERR(0, 905, __pyx_L1_error)
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_36__isPercent(((struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self), ((PyObject*)__pyx_v_surfaceForm));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_36__isPercent(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_surfaceForm) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__isPercent", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer___isPercent(__pyx_v_self, __pyx_v_surfaceForm, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 905, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.FsmMorphologicalAnalyzer.FsmMorphologicalAnalyzer.__isPercent", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":909
 *                self.patternMatches("%(\\d\\d|\\d)\\.\\d+", surfaceForm)
 * 
 *     cpdef bint __isTime(self, str surfaceForm):             # <<<<<<<<<<<<<<
 *         return self.patternMatches("(\\d\\d|\\d):(\\d\\d|\\d):(\\d\\d|\\d)", surfaceForm) or \
 *                 self.patternMatches("(\\d\\d|\\d):(\\d\\d|\\d)", surfaceForm)
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_39__isTime(PyObject *__pyx_v_self, PyObject *__pyx_v_surfaceForm); /*proto*/
static int __pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer___isTime(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_surfaceForm, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__isTime", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_isTime); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 909, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_39__isTime)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_v_surfaceForm) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_surfaceForm);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 909, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 909, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":910
 * 
 *     cpdef bint __isTime(self, str surfaceForm):
 *         return self.patternMatches("(\\d\\d|\\d):(\\d\\d|\\d):(\\d\\d|\\d)", surfaceForm) or \             # <<<<<<<<<<<<<<
 *                 self.patternMatches("(\\d\\d|\\d):(\\d\\d|\\d)", surfaceForm)
 * 
 */
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->patternMatches(__pyx_v_self, __pyx_kp_u_d_d_d_d_d_d_d_d_d, __pyx_v_surfaceForm, 0) != 0);
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L3_bool_binop_done;
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":911
 *     cpdef bint __isTime(self, str surfaceForm):
 *         return self.patternMatches("(\\d\\d|\\d):(\\d\\d|\\d):(\\d\\d|\\d)", surfaceForm) or \
 *                 self.patternMatches("(\\d\\d|\\d):(\\d\\d|\\d)", surfaceForm)             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint __isRange(self, str surfaceForm):
 */
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->patternMatches(__pyx_v_self, __pyx_kp_u_d_d_d_d_d_d, __pyx_v_surfaceForm, 0) != 0);
  __pyx_t_5 = __pyx_t_6;
  __pyx_L3_bool_binop_done:;
  __pyx_r = __pyx_t_5;
  goto __pyx_L0;

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":909
 *                self.patternMatches("%(\\d\\d|\\d)\\.\\d+", surfaceForm)
 * 
 *     cpdef bint __isTime(self, str surfaceForm):             # <<<<<<<<<<<<<<
 *         return self.patternMatches("(\\d\\d|\\d):(\\d\\d|\\d):(\\d\\d|\\d)", surfaceForm) or \
 *                 self.patternMatches("(\\d\\d|\\d):(\\d\\d|\\d)", surfaceForm)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("MorphologicalAnalysis.FsmMorphologicalAnalyzer.FsmMorphologicalAnalyzer.__isTime", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_39__isTime(PyObject *__pyx_v_self, PyObject *__pyx_v_surfaceForm); /*proto*/
static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_39__isTime(PyObject *__pyx_v_self, PyObject *__pyx_v_surfaceForm) {
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__isTime (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_surfaceForm), (&PyUnicode_Type), 1, "surfaceForm", 1))) __PYX_ERR(0, 909, __pyx_L1_error)
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_38__isTime(((struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self), ((PyObject*)__pyx_v_surfaceForm));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_38__isTime(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_surfaceForm) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__isTime", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer___isTime(__pyx_v_self, __pyx_v_surfaceForm, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 909, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.FsmMorphologicalAnalyzer.FsmMorphologicalAnalyzer.__isTime", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":913
 *                 self.patternMatches("(\\d\\d|\\d):(\\d\\d|\\d)", surfaceForm)
 * 
 *     cpdef bint __isRange(self, str surfaceForm):             # <<<<<<<<<<<<<<
 *         return self.patternMatches("\\d+-\\d+", surfaceForm) or \
 *                             self.patternMatches("(\\d\\d|\\d):(\\d\\d|\\d)-(\\d\\d|\\d):(\\d\\d|\\d)", surfaceForm) or \
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_41__isRange(PyObject *__pyx_v_self, PyObject *__pyx_v_surfaceForm); /*proto*/
static int __pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer___isRange(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_surfaceForm, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__isRange", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_isRange); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 913, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_41__isRange)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_v_surfaceForm) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_surfaceForm);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 913, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 913, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":914
 * 
 *     cpdef bint __isRange(self, str surfaceForm):
 *         return self.patternMatches("\\d+-\\d+", surfaceForm) or \             # <<<<<<<<<<<<<<
 *                             self.patternMatches("(\\d\\d|\\d):(\\d\\d|\\d)-(\\d\\d|\\d):(\\d\\d|\\d)", surfaceForm) or \
 *                             self.patternMatches("(\\d\\d|\\d)\\.(\\d\\d|\\d)-(\\d\\d|\\d)\\.(\\d\\d|\\d)",
 */
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->patternMatches(__pyx_v_self, __pyx_kp_u_d_d_3, __pyx_v_surfaceForm, 0) != 0);
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L3_bool_binop_done;
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":915
 *     cpdef bint __isRange(self, str surfaceForm):
 *         return self.patternMatches("\\d+-\\d+", surfaceForm) or \
 *                             self.patternMatches("(\\d\\d|\\d):(\\d\\d|\\d)-(\\d\\d|\\d):(\\d\\d|\\d)", surfaceForm) or \             # <<<<<<<<<<<<<<
 *                             self.patternMatches("(\\d\\d|\\d)\\.(\\d\\d|\\d)-(\\d\\d|\\d)\\.(\\d\\d|\\d)",
 *                                                 surfaceForm)
 */
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->patternMatches(__pyx_v_self, __pyx_kp_u_d_d_d_d_d_d_d_d_d_d_d_d, __pyx_v_surfaceForm, 0) != 0);
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L3_bool_binop_done;
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":916
 *         return self.patternMatches("\\d+-\\d+", surfaceForm) or \
 *                             self.patternMatches("(\\d\\d|\\d):(\\d\\d|\\d)-(\\d\\d|\\d):(\\d\\d|\\d)", surfaceForm) or \
 *                             self.patternMatches("(\\d\\d|\\d)\\.(\\d\\d|\\d)-(\\d\\d|\\d)\\.(\\d\\d|\\d)",             # <<<<<<<<<<<<<<
 *                                                 surfaceForm)
 * 
 */
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->patternMatches(__pyx_v_self, __pyx_kp_u_d_d_d_d_d_d_d_d_d_d_d_d_2, __pyx_v_surfaceForm, 0) != 0);
  __pyx_t_5 = __pyx_t_6;
  __pyx_L3_bool_binop_done:;
  __pyx_r = __pyx_t_5;
  goto __pyx_L0;

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":913
 *                 self.patternMatches("(\\d\\d|\\d):(\\d\\d|\\d)", surfaceForm)
 * 
 *     cpdef bint __isRange(self, str surfaceForm):             # <<<<<<<<<<<<<<
 *         return self.patternMatches("\\d+-\\d+", surfaceForm) or \
 *                             self.patternMatches("(\\d\\d|\\d):(\\d\\d|\\d)-(\\d\\d|\\d):(\\d\\d|\\d)", surfaceForm) or \
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("MorphologicalAnalysis.FsmMorphologicalAnalyzer.FsmMorphologicalAnalyzer.__isRange", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_41__isRange(PyObject *__pyx_v_self, PyObject *__pyx_v_surfaceForm); /*proto*/
static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_41__isRange(PyObject *__pyx_v_self, PyObject *__pyx_v_surfaceForm) {
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__isRange (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_surfaceForm), (&PyUnicode_Type), 1, "surfaceForm", 1))) __PYX_ERR(0, 913, __pyx_L1_error)
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_40__isRange(((struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self), ((PyObject*)__pyx_v_surfaceForm));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_40__isRange(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_surfaceForm) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__isRange", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer___isRange(__pyx_v_self, __pyx_v_surfaceForm, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 913, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.FsmMorphologicalAnalyzer.FsmMorphologicalAnalyzer.__isRange", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":919
 *                                                 surfaceForm)
 * 
 *     cpdef bint __isDate(self, str surfaceForm):             # <<<<<<<<<<<<<<
 *         return self.patternMatches("(\\d\\d|\\d)/(\\d\\d|\\d)/\\d+", surfaceForm) or \
 *                self.patternMatches("(\\d\\d|\\d)\\.(\\d\\d|\\d)\\.\\d+", surfaceForm)
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_43__isDate(PyObject *__pyx_v_self, PyObject *__pyx_v_surfaceForm); /*proto*/
static int __pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer___isDate(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_surfaceForm, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__isDate", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_isDate); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 919, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_43__isDate)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_v_surfaceForm) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_surfaceForm);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 919, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 919, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":920
 * 
 *     cpdef bint __isDate(self, str surfaceForm):
 *         return self.patternMatches("(\\d\\d|\\d)/(\\d\\d|\\d)/\\d+", surfaceForm) or \             # <<<<<<<<<<<<<<
 *                self.patternMatches("(\\d\\d|\\d)\\.(\\d\\d|\\d)\\.\\d+", surfaceForm)
 * 
 */
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->patternMatches(__pyx_v_self, __pyx_kp_u_d_d_d_d_d_d_d, __pyx_v_surfaceForm, 0) != 0);
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L3_bool_binop_done;
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":921
 *     cpdef bint __isDate(self, str surfaceForm):
 *         return self.patternMatches("(\\d\\d|\\d)/(\\d\\d|\\d)/\\d+", surfaceForm) or \
 *                self.patternMatches("(\\d\\d|\\d)\\.(\\d\\d|\\d)\\.\\d+", surfaceForm)             # <<<<<<<<<<<<<<
 * 
 *     cpdef morphologicalAnalysis(self, sentenceOrSurfaceForm):
 */
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->patternMatches(__pyx_v_self, __pyx_kp_u_d_d_d_d_d_d_d_2, __pyx_v_surfaceForm, 0) != 0);
  __pyx_t_5 = __pyx_t_6;
  __pyx_L3_bool_binop_done:;
  __pyx_r = __pyx_t_5;
  goto __pyx_L0;

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":919
 *                                                 surfaceForm)
 * 
 *     cpdef bint __isDate(self, str surfaceForm):             # <<<<<<<<<<<<<<
 *         return self.patternMatches("(\\d\\d|\\d)/(\\d\\d|\\d)/\\d+", surfaceForm) or \
 *                self.patternMatches("(\\d\\d|\\d)\\.(\\d\\d|\\d)\\.\\d+", surfaceForm)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("MorphologicalAnalysis.FsmMorphologicalAnalyzer.FsmMorphologicalAnalyzer.__isDate", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_43__isDate(PyObject *__pyx_v_self, PyObject *__pyx_v_surfaceForm); /*proto*/
static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_43__isDate(PyObject *__pyx_v_self, PyObject *__pyx_v_surfaceForm) {
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__isDate (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_surfaceForm), (&PyUnicode_Type), 1, "surfaceForm", 1))) __PYX_ERR(0, 919, __pyx_L1_error)
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_42__isDate(((struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self), ((PyObject*)__pyx_v_surfaceForm));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_42__isDate(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_surfaceForm) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__isDate", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer___isDate(__pyx_v_self, __pyx_v_surfaceForm, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 919, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.FsmMorphologicalAnalyzer.FsmMorphologicalAnalyzer.__isDate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":923
 *                self.patternMatches("(\\d\\d|\\d)\\.(\\d\\d|\\d)\\.\\d+", surfaceForm)
 * 
 *     cpdef morphologicalAnalysis(self, sentenceOrSurfaceForm):             # <<<<<<<<<<<<<<
 *         """
 *         The morphologicalAnalysis method is used to analyse a FsmParseList by comparing with the regex.
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_45morphologicalAnalysis(PyObject *__pyx_v_self, PyObject *__pyx_v_sentenceOrSurfaceForm); /*proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_morphologicalAnalysis(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_sentenceOrSurfaceForm, int __pyx_skip_dispatch) {
  struct __pyx_obj_6Corpus_8Sentence_Sentence *__pyx_v_sentence = 0;
  PyObject *__pyx_v_result = 0;
  PyObject *__pyx_v_fsmParse = 0;
  int __pyx_v_i;
  PyObject *__pyx_v_originalForm = 0;
  PyObject *__pyx_v_spellCorrectedForm = 0;
  PyObject *__pyx_v_surfaceForm = 0;
  PyObject *__pyx_v_possibleRoot = 0;
  struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *__pyx_v_wordFsmParseList = 0;
  struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *__pyx_v_fsmParseList = 0;
  struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_newWord = 0;
  struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_word = 0;
  PyObject *__pyx_v_defaultFsmParse = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_t_9;
  Py_ssize_t __pyx_t_10;
  int __pyx_t_11;
  int __pyx_t_12;
  Py_ssize_t __pyx_t_13;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("morphologicalAnalysis", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_morphologicalAnalysis); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 923, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_45morphologicalAnalysis)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_v_sentenceOrSurfaceForm) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_sentenceOrSurfaceForm);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 923, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":958
 *         cdef FsmParseList wordFsmParseList, fsmParseList
 *         cdef TxtWord newWord, word
 *         if isinstance(sentenceOrSurfaceForm, Sentence):             # <<<<<<<<<<<<<<
 *             sentence = sentenceOrSurfaceForm
 *             result = []
 */
  __pyx_t_5 = __Pyx_TypeCheck(__pyx_v_sentenceOrSurfaceForm, __pyx_ptype_6Corpus_8Sentence_Sentence); 
  __pyx_t_6 = (__pyx_t_5 != 0);
  if (__pyx_t_6) {

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":959
 *         cdef TxtWord newWord, word
 *         if isinstance(sentenceOrSurfaceForm, Sentence):
 *             sentence = sentenceOrSurfaceForm             # <<<<<<<<<<<<<<
 *             result = []
 *             for i in range(sentence.wordCount()):
 */
    if (!(likely(((__pyx_v_sentenceOrSurfaceForm) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_sentenceOrSurfaceForm, __pyx_ptype_6Corpus_8Sentence_Sentence))))) __PYX_ERR(0, 959, __pyx_L1_error)
    __pyx_t_1 = __pyx_v_sentenceOrSurfaceForm;
    __Pyx_INCREF(__pyx_t_1);
    __pyx_v_sentence = ((struct __pyx_obj_6Corpus_8Sentence_Sentence *)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":960
 *         if isinstance(sentenceOrSurfaceForm, Sentence):
 *             sentence = sentenceOrSurfaceForm
 *             result = []             # <<<<<<<<<<<<<<
 *             for i in range(sentence.wordCount()):
 *                 originalForm = sentence.getWord(i).getName()
 */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 960, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_result = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":961
 *             sentence = sentenceOrSurfaceForm
 *             result = []
 *             for i in range(sentence.wordCount()):             # <<<<<<<<<<<<<<
 *                 originalForm = sentence.getWord(i).getName()
 *                 spellCorrectedForm = self.__dictionary.getCorrectForm(originalForm)
 */
    __pyx_t_7 = ((struct __pyx_vtabstruct_6Corpus_8Sentence_Sentence *)__pyx_v_sentence->__pyx_vtab)->wordCount(__pyx_v_sentence, 0);
    __pyx_t_8 = __pyx_t_7;
    for (__pyx_t_9 = 0; __pyx_t_9 < __pyx_t_8; __pyx_t_9+=1) {
      __pyx_v_i = __pyx_t_9;

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":962
 *             result = []
 *             for i in range(sentence.wordCount()):
 *                 originalForm = sentence.getWord(i).getName()             # <<<<<<<<<<<<<<
 *                 spellCorrectedForm = self.__dictionary.getCorrectForm(originalForm)
 *                 if len(spellCorrectedForm) == 0:
 */
      __pyx_t_1 = ((PyObject *)((struct __pyx_vtabstruct_6Corpus_8Sentence_Sentence *)__pyx_v_sentence->__pyx_vtab)->getWord(__pyx_v_sentence, __pyx_v_i, 0)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 962, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_2 = ((struct __pyx_vtabstruct_10Dictionary_4Word_Word *)((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_t_1)->__pyx_vtab)->getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_t_1), 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 962, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF_SET(__pyx_v_originalForm, ((PyObject*)__pyx_t_2));
      __pyx_t_2 = 0;

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":963
 *             for i in range(sentence.wordCount()):
 *                 originalForm = sentence.getWord(i).getName()
 *                 spellCorrectedForm = self.__dictionary.getCorrectForm(originalForm)             # <<<<<<<<<<<<<<
 *                 if len(spellCorrectedForm) == 0:
 *                     spellCorrectedForm = originalForm
 */
      __pyx_t_2 = ((struct __pyx_vtabstruct_10Dictionary_13TxtDictionary_TxtDictionary *)__pyx_v_self->__pyx___dictionary->__pyx_base.__pyx_vtab)->getCorrectForm(__pyx_v_self->__pyx___dictionary, __pyx_v_originalForm, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 963, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_XDECREF_SET(__pyx_v_spellCorrectedForm, ((PyObject*)__pyx_t_2));
      __pyx_t_2 = 0;

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":964
 *                 originalForm = sentence.getWord(i).getName()
 *                 spellCorrectedForm = self.__dictionary.getCorrectForm(originalForm)
 *                 if len(spellCorrectedForm) == 0:             # <<<<<<<<<<<<<<
 *                     spellCorrectedForm = originalForm
 *                 wordFsmParseList = self.morphologicalAnalysis(spellCorrectedForm)
 */
      if (unlikely(__pyx_v_spellCorrectedForm == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
        __PYX_ERR(0, 964, __pyx_L1_error)
      }
      __pyx_t_10 = __Pyx_PyUnicode_GET_LENGTH(__pyx_v_spellCorrectedForm); if (unlikely(__pyx_t_10 == ((Py_ssize_t)-1))) __PYX_ERR(0, 964, __pyx_L1_error)
      __pyx_t_6 = ((__pyx_t_10 == 0) != 0);
      if (__pyx_t_6) {

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":965
 *                 spellCorrectedForm = self.__dictionary.getCorrectForm(originalForm)
 *                 if len(spellCorrectedForm) == 0:
 *                     spellCorrectedForm = originalForm             # <<<<<<<<<<<<<<
 *                 wordFsmParseList = self.morphologicalAnalysis(spellCorrectedForm)
 *                 result.append(wordFsmParseList)
 */
        __Pyx_INCREF(__pyx_v_originalForm);
        __Pyx_DECREF_SET(__pyx_v_spellCorrectedForm, __pyx_v_originalForm);

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":964
 *                 originalForm = sentence.getWord(i).getName()
 *                 spellCorrectedForm = self.__dictionary.getCorrectForm(originalForm)
 *                 if len(spellCorrectedForm) == 0:             # <<<<<<<<<<<<<<
 *                     spellCorrectedForm = originalForm
 *                 wordFsmParseList = self.morphologicalAnalysis(spellCorrectedForm)
 */
      }

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":966
 *                 if len(spellCorrectedForm) == 0:
 *                     spellCorrectedForm = originalForm
 *                 wordFsmParseList = self.morphologicalAnalysis(spellCorrectedForm)             # <<<<<<<<<<<<<<
 *                 result.append(wordFsmParseList)
 *             return result
 */
      __pyx_t_2 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->morphologicalAnalysis(__pyx_v_self, __pyx_v_spellCorrectedForm, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 966, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_21MorphologicalAnalysis_12FsmParseList_FsmParseList))))) __PYX_ERR(0, 966, __pyx_L1_error)
      __Pyx_XDECREF_SET(__pyx_v_wordFsmParseList, ((struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *)__pyx_t_2));
      __pyx_t_2 = 0;

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":967
 *                     spellCorrectedForm = originalForm
 *                 wordFsmParseList = self.morphologicalAnalysis(spellCorrectedForm)
 *                 result.append(wordFsmParseList)             # <<<<<<<<<<<<<<
 *             return result
 *         elif isinstance(sentenceOrSurfaceForm, str):
 */
      __pyx_t_11 = __Pyx_PyList_Append(__pyx_v_result, ((PyObject *)__pyx_v_wordFsmParseList)); if (unlikely(__pyx_t_11 == ((int)-1))) __PYX_ERR(0, 967, __pyx_L1_error)
    }

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":968
 *                 wordFsmParseList = self.morphologicalAnalysis(spellCorrectedForm)
 *                 result.append(wordFsmParseList)
 *             return result             # <<<<<<<<<<<<<<
 *         elif isinstance(sentenceOrSurfaceForm, str):
 *             surfaceForm = sentenceOrSurfaceForm
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_result);
    __pyx_r = __pyx_v_result;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":958
 *         cdef FsmParseList wordFsmParseList, fsmParseList
 *         cdef TxtWord newWord, word
 *         if isinstance(sentenceOrSurfaceForm, Sentence):             # <<<<<<<<<<<<<<
 *             sentence = sentenceOrSurfaceForm
 *             result = []
 */
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":969
 *                 result.append(wordFsmParseList)
 *             return result
 *         elif isinstance(sentenceOrSurfaceForm, str):             # <<<<<<<<<<<<<<
 *             surfaceForm = sentenceOrSurfaceForm
 *             if self.__parsedSurfaceForms is not None and surfaceForm not in self.__parsedSurfaceForms \
 */
  __pyx_t_6 = PyUnicode_Check(__pyx_v_sentenceOrSurfaceForm); 
  __pyx_t_5 = (__pyx_t_6 != 0);
  if (__pyx_t_5) {

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":970
 *             return result
 *         elif isinstance(sentenceOrSurfaceForm, str):
 *             surfaceForm = sentenceOrSurfaceForm             # <<<<<<<<<<<<<<
 *             if self.__parsedSurfaceForms is not None and surfaceForm not in self.__parsedSurfaceForms \
 *                     and not self.__isRange(surfaceForm) and not self.__isTime(surfaceForm) \
 */
    if (!(likely(PyUnicode_CheckExact(__pyx_v_sentenceOrSurfaceForm))||((__pyx_v_sentenceOrSurfaceForm) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_v_sentenceOrSurfaceForm)->tp_name), 0))) __PYX_ERR(0, 970, __pyx_L1_error)
    __pyx_t_2 = __pyx_v_sentenceOrSurfaceForm;
    __Pyx_INCREF(__pyx_t_2);
    __pyx_v_surfaceForm = ((PyObject*)__pyx_t_2);
    __pyx_t_2 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":971
 *         elif isinstance(sentenceOrSurfaceForm, str):
 *             surfaceForm = sentenceOrSurfaceForm
 *             if self.__parsedSurfaceForms is not None and surfaceForm not in self.__parsedSurfaceForms \             # <<<<<<<<<<<<<<
 *                     and not self.__isRange(surfaceForm) and not self.__isTime(surfaceForm) \
 *                     and not self.__isInteger(surfaceForm) and not self.__isDouble(surfaceForm) \
 */
    __pyx_t_6 = (__pyx_v_self->__pyx___parsedSurfaceForms != ((PyObject*)Py_None));
    __pyx_t_12 = (__pyx_t_6 != 0);
    if (__pyx_t_12) {
    } else {
      __pyx_t_5 = __pyx_t_12;
      goto __pyx_L8_bool_binop_done;
    }

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":972
 *             surfaceForm = sentenceOrSurfaceForm
 *             if self.__parsedSurfaceForms is not None and surfaceForm not in self.__parsedSurfaceForms \
 *                     and not self.__isRange(surfaceForm) and not self.__isTime(surfaceForm) \             # <<<<<<<<<<<<<<
 *                     and not self.__isInteger(surfaceForm) and not self.__isDouble(surfaceForm) \
 *                     and not self.__isDate(surfaceForm) and not self.__isPercent(surfaceForm):
 */
    if (unlikely(__pyx_v_self->__pyx___parsedSurfaceForms == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
      __PYX_ERR(0, 971, __pyx_L1_error)
    }
    __pyx_t_12 = (__Pyx_PySet_ContainsTF(__pyx_v_surfaceForm, __pyx_v_self->__pyx___parsedSurfaceForms, Py_NE)); if (unlikely(__pyx_t_12 < 0)) __PYX_ERR(0, 971, __pyx_L1_error)

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":971
 *         elif isinstance(sentenceOrSurfaceForm, str):
 *             surfaceForm = sentenceOrSurfaceForm
 *             if self.__parsedSurfaceForms is not None and surfaceForm not in self.__parsedSurfaceForms \             # <<<<<<<<<<<<<<
 *                     and not self.__isRange(surfaceForm) and not self.__isTime(surfaceForm) \
 *                     and not self.__isInteger(surfaceForm) and not self.__isDouble(surfaceForm) \
 */
    __pyx_t_6 = (__pyx_t_12 != 0);
    if (__pyx_t_6) {
    } else {
      __pyx_t_5 = __pyx_t_6;
      goto __pyx_L8_bool_binop_done;
    }

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":972
 *             surfaceForm = sentenceOrSurfaceForm
 *             if self.__parsedSurfaceForms is not None and surfaceForm not in self.__parsedSurfaceForms \
 *                     and not self.__isRange(surfaceForm) and not self.__isTime(surfaceForm) \             # <<<<<<<<<<<<<<
 *                     and not self.__isInteger(surfaceForm) and not self.__isDouble(surfaceForm) \
 *                     and not self.__isDate(surfaceForm) and not self.__isPercent(surfaceForm):
 */
    __pyx_t_6 = ((!(((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->__pyx___isRange(__pyx_v_self, __pyx_v_surfaceForm, 0) != 0)) != 0);
    if (__pyx_t_6) {
    } else {
      __pyx_t_5 = __pyx_t_6;
      goto __pyx_L8_bool_binop_done;
    }

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":973
 *             if self.__parsedSurfaceForms is not None and surfaceForm not in self.__parsedSurfaceForms \
 *                     and not self.__isRange(surfaceForm) and not self.__isTime(surfaceForm) \
 *                     and not self.__isInteger(surfaceForm) and not self.__isDouble(surfaceForm) \             # <<<<<<<<<<<<<<
 *                     and not self.__isDate(surfaceForm) and not self.__isPercent(surfaceForm):
 *                 return FsmParseList([])
 */
    __pyx_t_6 = ((!(((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->__pyx___isTime(__pyx_v_self, __pyx_v_surfaceForm, 0) != 0)) != 0);
    if (__pyx_t_6) {
    } else {
      __pyx_t_5 = __pyx_t_6;
      goto __pyx_L8_bool_binop_done;
    }
    __pyx_t_6 = ((!(((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->__pyx___isInteger(__pyx_v_self, __pyx_v_surfaceForm, 0) != 0)) != 0);
    if (__pyx_t_6) {
    } else {
      __pyx_t_5 = __pyx_t_6;
      goto __pyx_L8_bool_binop_done;
    }

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":974
 *                     and not self.__isRange(surfaceForm) and not self.__isTime(surfaceForm) \
 *                     and not self.__isInteger(surfaceForm) and not self.__isDouble(surfaceForm) \
 *                     and not self.__isDate(surfaceForm) and not self.__isPercent(surfaceForm):             # <<<<<<<<<<<<<<
 *                 return FsmParseList([])
 *             if self.__cache.contains(surfaceForm):
 */
    __pyx_t_6 = ((!(((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->__pyx___isDouble(__pyx_v_self, __pyx_v_surfaceForm, 0) != 0)) != 0);
    if (__pyx_t_6) {
    } else {
      __pyx_t_5 = __pyx_t_6;
      goto __pyx_L8_bool_binop_done;
    }
    __pyx_t_6 = ((!(((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->__pyx___isDate(__pyx_v_self, __pyx_v_surfaceForm, 0) != 0)) != 0);
    if (__pyx_t_6) {
    } else {
      __pyx_t_5 = __pyx_t_6;
      goto __pyx_L8_bool_binop_done;
    }
    __pyx_t_6 = ((!(((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->__pyx___isPercent(__pyx_v_self, __pyx_v_surfaceForm, 0) != 0)) != 0);
    __pyx_t_5 = __pyx_t_6;
    __pyx_L8_bool_binop_done:;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":971
 *         elif isinstance(sentenceOrSurfaceForm, str):
 *             surfaceForm = sentenceOrSurfaceForm
 *             if self.__parsedSurfaceForms is not None and surfaceForm not in self.__parsedSurfaceForms \             # <<<<<<<<<<<<<<
 *                     and not self.__isRange(surfaceForm) and not self.__isTime(surfaceForm) \
 *                     and not self.__isInteger(surfaceForm) and not self.__isDouble(surfaceForm) \
 */
    if (__pyx_t_5) {

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":975
 *                     and not self.__isInteger(surfaceForm) and not self.__isDouble(surfaceForm) \
 *                     and not self.__isDate(surfaceForm) and not self.__isPercent(surfaceForm):
 *                 return FsmParseList([])             # <<<<<<<<<<<<<<
 *             if self.__cache.contains(surfaceForm):
 *                 return self.__cache.get(surfaceForm)
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 975, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_12FsmParseList_FsmParseList), __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 975, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_r = __pyx_t_1;
      __pyx_t_1 = 0;
      goto __pyx_L0;

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":971
 *         elif isinstance(sentenceOrSurfaceForm, str):
 *             surfaceForm = sentenceOrSurfaceForm
 *             if self.__parsedSurfaceForms is not None and surfaceForm not in self.__parsedSurfaceForms \             # <<<<<<<<<<<<<<
 *                     and not self.__isRange(surfaceForm) and not self.__isTime(surfaceForm) \
 *                     and not self.__isInteger(surfaceForm) and not self.__isDouble(surfaceForm) \
 */
    }

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":976
 *                     and not self.__isDate(surfaceForm) and not self.__isPercent(surfaceForm):
 *                 return FsmParseList([])
 *             if self.__cache.contains(surfaceForm):             # <<<<<<<<<<<<<<
 *                 return self.__cache.get(surfaceForm)
 *             if self.patternMatches("(\\w|||||)\\.", surfaceForm):
 */
    __pyx_t_5 = (((struct __pyx_vtabstruct_13DataStructure_5Cache_8LRUCache_LRUCache *)__pyx_v_self->__pyx___cache->__pyx_vtab)->contains(__pyx_v_self->__pyx___cache, __pyx_v_surfaceForm, 0) != 0);
    if (__pyx_t_5) {

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":977
 *                 return FsmParseList([])
 *             if self.__cache.contains(surfaceForm):
 *                 return self.__cache.get(surfaceForm)             # <<<<<<<<<<<<<<
 *             if self.patternMatches("(\\w|||||)\\.", surfaceForm):
 *                 self.__dictionaryTrie.addWord(self.__toLower(surfaceForm), TxtWord(self.__toLower(surfaceForm), "IS_OA"))
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_1 = ((struct __pyx_vtabstruct_13DataStructure_5Cache_8LRUCache_LRUCache *)__pyx_v_self->__pyx___cache->__pyx_vtab)->get(__pyx_v_self->__pyx___cache, __pyx_v_surfaceForm, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 977, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_r = __pyx_t_1;
      __pyx_t_1 = 0;
      goto __pyx_L0;

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":976
 *                     and not self.__isDate(surfaceForm) and not self.__isPercent(surfaceForm):
 *                 return FsmParseList([])
 *             if self.__cache.contains(surfaceForm):             # <<<<<<<<<<<<<<
 *                 return self.__cache.get(surfaceForm)
 *             if self.patternMatches("(\\w|||||)\\.", surfaceForm):
 */
    }

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":978
 *             if self.__cache.contains(surfaceForm):
 *                 return self.__cache.get(surfaceForm)
 *             if self.patternMatches("(\\w|||||)\\.", surfaceForm):             # <<<<<<<<<<<<<<
 *                 self.__dictionaryTrie.addWord(self.__toLower(surfaceForm), TxtWord(self.__toLower(surfaceForm), "IS_OA"))
 *             defaultFsmParse = self.__analysis(self.__toLower(surfaceForm), self.isProperNoun(surfaceForm))
 */
    __pyx_t_5 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->patternMatches(__pyx_v_self, __pyx_kp_u_w, __pyx_v_surfaceForm, 0) != 0);
    if (__pyx_t_5) {

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":979
 *                 return self.__cache.get(surfaceForm)
 *             if self.patternMatches("(\\w|||||)\\.", surfaceForm):
 *                 self.__dictionaryTrie.addWord(self.__toLower(surfaceForm), TxtWord(self.__toLower(surfaceForm), "IS_OA"))             # <<<<<<<<<<<<<<
 *             defaultFsmParse = self.__analysis(self.__toLower(surfaceForm), self.isProperNoun(surfaceForm))
 *             if len(defaultFsmParse) > 0:
 */
      __pyx_t_1 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->__pyx___toLower(__pyx_v_self, __pyx_v_surfaceForm, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 979, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_2 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->__pyx___toLower(__pyx_v_self, __pyx_v_surfaceForm, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 979, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 979, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_GIVEREF(__pyx_t_2);
      PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
      __Pyx_INCREF(__pyx_n_u_IS_OA);
      __Pyx_GIVEREF(__pyx_n_u_IS_OA);
      PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_n_u_IS_OA);
      __pyx_t_2 = 0;
      __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_10Dictionary_7TxtWord_TxtWord), __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 979, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = ((struct __pyx_vtabstruct_10Dictionary_4Trie_4Trie_Trie *)__pyx_v_self->__pyx___dictionaryTrie->__pyx_vtab)->addWord(__pyx_v_self->__pyx___dictionaryTrie, ((PyObject*)__pyx_t_1), ((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_t_2), 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 979, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":978
 *             if self.__cache.contains(surfaceForm):
 *                 return self.__cache.get(surfaceForm)
 *             if self.patternMatches("(\\w|||||)\\.", surfaceForm):             # <<<<<<<<<<<<<<
 *                 self.__dictionaryTrie.addWord(self.__toLower(surfaceForm), TxtWord(self.__toLower(surfaceForm), "IS_OA"))
 *             defaultFsmParse = self.__analysis(self.__toLower(surfaceForm), self.isProperNoun(surfaceForm))
 */
    }

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":980
 *             if self.patternMatches("(\\w|||||)\\.", surfaceForm):
 *                 self.__dictionaryTrie.addWord(self.__toLower(surfaceForm), TxtWord(self.__toLower(surfaceForm), "IS_OA"))
 *             defaultFsmParse = self.__analysis(self.__toLower(surfaceForm), self.isProperNoun(surfaceForm))             # <<<<<<<<<<<<<<
 *             if len(defaultFsmParse) > 0:
 *                 fsmParseList = FsmParseList(defaultFsmParse)
 */
    __pyx_t_3 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->__pyx___toLower(__pyx_v_self, __pyx_v_surfaceForm, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 980, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->__pyx___analysis(__pyx_v_self, ((PyObject*)__pyx_t_3), ((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->isProperNoun(__pyx_v_self, __pyx_v_surfaceForm, 0), 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 980, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_v_defaultFsmParse = ((PyObject*)__pyx_t_2);
    __pyx_t_2 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":981
 *                 self.__dictionaryTrie.addWord(self.__toLower(surfaceForm), TxtWord(self.__toLower(surfaceForm), "IS_OA"))
 *             defaultFsmParse = self.__analysis(self.__toLower(surfaceForm), self.isProperNoun(surfaceForm))
 *             if len(defaultFsmParse) > 0:             # <<<<<<<<<<<<<<
 *                 fsmParseList = FsmParseList(defaultFsmParse)
 *                 self.__cache.add(surfaceForm, fsmParseList)
 */
    if (unlikely(__pyx_v_defaultFsmParse == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
      __PYX_ERR(0, 981, __pyx_L1_error)
    }
    __pyx_t_10 = PyList_GET_SIZE(__pyx_v_defaultFsmParse); if (unlikely(__pyx_t_10 == ((Py_ssize_t)-1))) __PYX_ERR(0, 981, __pyx_L1_error)
    __pyx_t_5 = ((__pyx_t_10 > 0) != 0);
    if (__pyx_t_5) {

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":982
 *             defaultFsmParse = self.__analysis(self.__toLower(surfaceForm), self.isProperNoun(surfaceForm))
 *             if len(defaultFsmParse) > 0:
 *                 fsmParseList = FsmParseList(defaultFsmParse)             # <<<<<<<<<<<<<<
 *                 self.__cache.add(surfaceForm, fsmParseList)
 *                 return fsmParseList
 */
      __pyx_t_2 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_12FsmParseList_FsmParseList), __pyx_v_defaultFsmParse); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 982, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_v_fsmParseList = ((struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *)__pyx_t_2);
      __pyx_t_2 = 0;

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":983
 *             if len(defaultFsmParse) > 0:
 *                 fsmParseList = FsmParseList(defaultFsmParse)
 *                 self.__cache.add(surfaceForm, fsmParseList)             # <<<<<<<<<<<<<<
 *                 return fsmParseList
 *             fsmParse = []
 */
      __pyx_t_2 = ((struct __pyx_vtabstruct_13DataStructure_5Cache_8LRUCache_LRUCache *)__pyx_v_self->__pyx___cache->__pyx_vtab)->add(__pyx_v_self->__pyx___cache, __pyx_v_surfaceForm, ((PyObject *)__pyx_v_fsmParseList), 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 983, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":984
 *                 fsmParseList = FsmParseList(defaultFsmParse)
 *                 self.__cache.add(surfaceForm, fsmParseList)
 *                 return fsmParseList             # <<<<<<<<<<<<<<
 *             fsmParse = []
 *             if "'" in surfaceForm:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(((PyObject *)__pyx_v_fsmParseList));
      __pyx_r = ((PyObject *)__pyx_v_fsmParseList);
      goto __pyx_L0;

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":981
 *                 self.__dictionaryTrie.addWord(self.__toLower(surfaceForm), TxtWord(self.__toLower(surfaceForm), "IS_OA"))
 *             defaultFsmParse = self.__analysis(self.__toLower(surfaceForm), self.isProperNoun(surfaceForm))
 *             if len(defaultFsmParse) > 0:             # <<<<<<<<<<<<<<
 *                 fsmParseList = FsmParseList(defaultFsmParse)
 *                 self.__cache.add(surfaceForm, fsmParseList)
 */
    }

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":985
 *                 self.__cache.add(surfaceForm, fsmParseList)
 *                 return fsmParseList
 *             fsmParse = []             # <<<<<<<<<<<<<<
 *             if "'" in surfaceForm:
 *                 possibleRoot = surfaceForm[:surfaceForm.index('\'')]
 */
    __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 985, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_fsmParse = ((PyObject*)__pyx_t_2);
    __pyx_t_2 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":986
 *                 return fsmParseList
 *             fsmParse = []
 *             if "'" in surfaceForm:             # <<<<<<<<<<<<<<
 *                 possibleRoot = surfaceForm[:surfaceForm.index('\'')]
 *                 if len(possibleRoot) > 0:
 */
    if (unlikely(__pyx_v_surfaceForm == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
      __PYX_ERR(0, 986, __pyx_L1_error)
    }
    __pyx_t_5 = (__Pyx_PyUnicode_ContainsTF(__pyx_kp_u__18, __pyx_v_surfaceForm, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 986, __pyx_L1_error)
    __pyx_t_6 = (__pyx_t_5 != 0);
    if (__pyx_t_6) {

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":987
 *             fsmParse = []
 *             if "'" in surfaceForm:
 *                 possibleRoot = surfaceForm[:surfaceForm.index('\'')]             # <<<<<<<<<<<<<<
 *                 if len(possibleRoot) > 0:
 *                     if "/" in possibleRoot or "\\/" in possibleRoot:
 */
      if (unlikely(__pyx_v_surfaceForm == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        __PYX_ERR(0, 987, __pyx_L1_error)
      }
      __pyx_t_2 = __Pyx_CallUnboundCMethod1(&__pyx_umethod_PyUnicode_Type_index, __pyx_v_surfaceForm, __pyx_kp_u__18); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 987, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_6 = (__pyx_t_2 == Py_None);
      if (__pyx_t_6) {
        __pyx_t_10 = PY_SSIZE_T_MAX;
      } else {
        __pyx_t_13 = __Pyx_PyIndex_AsSsize_t(__pyx_t_2); if (unlikely((__pyx_t_13 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 987, __pyx_L1_error)
        __pyx_t_10 = __pyx_t_13;
      }
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = __Pyx_PyUnicode_Substring(__pyx_v_surfaceForm, 0, __pyx_t_10); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 987, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_v_possibleRoot = ((PyObject*)__pyx_t_2);
      __pyx_t_2 = 0;

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":988
 *             if "'" in surfaceForm:
 *                 possibleRoot = surfaceForm[:surfaceForm.index('\'')]
 *                 if len(possibleRoot) > 0:             # <<<<<<<<<<<<<<
 *                     if "/" in possibleRoot or "\\/" in possibleRoot:
 *                         self.__dictionaryTrie.addWord(possibleRoot, TxtWord(possibleRoot, "IS_KESIR"))
 */
      __pyx_t_10 = __Pyx_PyUnicode_GET_LENGTH(__pyx_v_possibleRoot); if (unlikely(__pyx_t_10 == ((Py_ssize_t)-1))) __PYX_ERR(0, 988, __pyx_L1_error)
      __pyx_t_6 = ((__pyx_t_10 > 0) != 0);
      if (__pyx_t_6) {

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":989
 *                 possibleRoot = surfaceForm[:surfaceForm.index('\'')]
 *                 if len(possibleRoot) > 0:
 *                     if "/" in possibleRoot or "\\/" in possibleRoot:             # <<<<<<<<<<<<<<
 *                         self.__dictionaryTrie.addWord(possibleRoot, TxtWord(possibleRoot, "IS_KESIR"))
 *                         fsmParse = self.__analysis(self.__toLower(surfaceForm), self.isProperNoun(surfaceForm))
 */
        __pyx_t_5 = (__Pyx_PyUnicode_ContainsTF(__pyx_kp_u__19, __pyx_v_possibleRoot, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 989, __pyx_L1_error)
        __pyx_t_12 = (__pyx_t_5 != 0);
        if (!__pyx_t_12) {
        } else {
          __pyx_t_6 = __pyx_t_12;
          goto __pyx_L22_bool_binop_done;
        }
        __pyx_t_12 = (__Pyx_PyUnicode_ContainsTF(__pyx_kp_u__20, __pyx_v_possibleRoot, Py_EQ)); if (unlikely(__pyx_t_12 < 0)) __PYX_ERR(0, 989, __pyx_L1_error)
        __pyx_t_5 = (__pyx_t_12 != 0);
        __pyx_t_6 = __pyx_t_5;
        __pyx_L22_bool_binop_done:;
        if (__pyx_t_6) {

          /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":990
 *                 if len(possibleRoot) > 0:
 *                     if "/" in possibleRoot or "\\/" in possibleRoot:
 *                         self.__dictionaryTrie.addWord(possibleRoot, TxtWord(possibleRoot, "IS_KESIR"))             # <<<<<<<<<<<<<<
 *                         fsmParse = self.__analysis(self.__toLower(surfaceForm), self.isProperNoun(surfaceForm))
 *                     elif self.__isDate(possibleRoot):
 */
          __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 990, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_INCREF(__pyx_v_possibleRoot);
          __Pyx_GIVEREF(__pyx_v_possibleRoot);
          PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_possibleRoot);
          __Pyx_INCREF(__pyx_n_u_IS_KESIR);
          __Pyx_GIVEREF(__pyx_n_u_IS_KESIR);
          PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_n_u_IS_KESIR);
          __pyx_t_3 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_10Dictionary_7TxtWord_TxtWord), __pyx_t_2, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 990, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __pyx_t_2 = ((struct __pyx_vtabstruct_10Dictionary_4Trie_4Trie_Trie *)__pyx_v_self->__pyx___dictionaryTrie->__pyx_vtab)->addWord(__pyx_v_self->__pyx___dictionaryTrie, __pyx_v_possibleRoot, ((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_t_3), 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 990, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

          /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":991
 *                     if "/" in possibleRoot or "\\/" in possibleRoot:
 *                         self.__dictionaryTrie.addWord(possibleRoot, TxtWord(possibleRoot, "IS_KESIR"))
 *                         fsmParse = self.__analysis(self.__toLower(surfaceForm), self.isProperNoun(surfaceForm))             # <<<<<<<<<<<<<<
 *                     elif self.__isDate(possibleRoot):
 *                         self.__dictionaryTrie.addWord(possibleRoot, TxtWord(possibleRoot, "IS_DATE"))
 */
          __pyx_t_2 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->__pyx___toLower(__pyx_v_self, __pyx_v_surfaceForm, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 991, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __pyx_t_3 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->__pyx___analysis(__pyx_v_self, ((PyObject*)__pyx_t_2), ((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->isProperNoun(__pyx_v_self, __pyx_v_surfaceForm, 0), 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 991, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_DECREF_SET(__pyx_v_fsmParse, ((PyObject*)__pyx_t_3));
          __pyx_t_3 = 0;

          /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":989
 *                 possibleRoot = surfaceForm[:surfaceForm.index('\'')]
 *                 if len(possibleRoot) > 0:
 *                     if "/" in possibleRoot or "\\/" in possibleRoot:             # <<<<<<<<<<<<<<
 *                         self.__dictionaryTrie.addWord(possibleRoot, TxtWord(possibleRoot, "IS_KESIR"))
 *                         fsmParse = self.__analysis(self.__toLower(surfaceForm), self.isProperNoun(surfaceForm))
 */
          goto __pyx_L21;
        }

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":992
 *                         self.__dictionaryTrie.addWord(possibleRoot, TxtWord(possibleRoot, "IS_KESIR"))
 *                         fsmParse = self.__analysis(self.__toLower(surfaceForm), self.isProperNoun(surfaceForm))
 *                     elif self.__isDate(possibleRoot):             # <<<<<<<<<<<<<<
 *                         self.__dictionaryTrie.addWord(possibleRoot, TxtWord(possibleRoot, "IS_DATE"))
 *                         fsmParse = self.__analysis(self.__toLower(surfaceForm), self.isProperNoun(surfaceForm))
 */
        __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->__pyx___isDate(__pyx_v_self, __pyx_v_possibleRoot, 0) != 0);
        if (__pyx_t_6) {

          /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":993
 *                         fsmParse = self.__analysis(self.__toLower(surfaceForm), self.isProperNoun(surfaceForm))
 *                     elif self.__isDate(possibleRoot):
 *                         self.__dictionaryTrie.addWord(possibleRoot, TxtWord(possibleRoot, "IS_DATE"))             # <<<<<<<<<<<<<<
 *                         fsmParse = self.__analysis(self.__toLower(surfaceForm), self.isProperNoun(surfaceForm))
 *                     elif self.patternMatches("\\d+/\\d+", possibleRoot):
 */
          __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 993, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_INCREF(__pyx_v_possibleRoot);
          __Pyx_GIVEREF(__pyx_v_possibleRoot);
          PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_possibleRoot);
          __Pyx_INCREF(__pyx_n_u_IS_DATE);
          __Pyx_GIVEREF(__pyx_n_u_IS_DATE);
          PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_n_u_IS_DATE);
          __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_10Dictionary_7TxtWord_TxtWord), __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 993, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __pyx_t_3 = ((struct __pyx_vtabstruct_10Dictionary_4Trie_4Trie_Trie *)__pyx_v_self->__pyx___dictionaryTrie->__pyx_vtab)->addWord(__pyx_v_self->__pyx___dictionaryTrie, __pyx_v_possibleRoot, ((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_t_2), 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 993, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

          /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":994
 *                     elif self.__isDate(possibleRoot):
 *                         self.__dictionaryTrie.addWord(possibleRoot, TxtWord(possibleRoot, "IS_DATE"))
 *                         fsmParse = self.__analysis(self.__toLower(surfaceForm), self.isProperNoun(surfaceForm))             # <<<<<<<<<<<<<<
 *                     elif self.patternMatches("\\d+/\\d+", possibleRoot):
 *                         self.__dictionaryTrie.addWord(possibleRoot, TxtWord(possibleRoot, "IS_KESIR"))
 */
          __pyx_t_3 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->__pyx___toLower(__pyx_v_self, __pyx_v_surfaceForm, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 994, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __pyx_t_2 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->__pyx___analysis(__pyx_v_self, ((PyObject*)__pyx_t_3), ((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->isProperNoun(__pyx_v_self, __pyx_v_surfaceForm, 0), 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 994, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF_SET(__pyx_v_fsmParse, ((PyObject*)__pyx_t_2));
          __pyx_t_2 = 0;

          /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":992
 *                         self.__dictionaryTrie.addWord(possibleRoot, TxtWord(possibleRoot, "IS_KESIR"))
 *                         fsmParse = self.__analysis(self.__toLower(surfaceForm), self.isProperNoun(surfaceForm))
 *                     elif self.__isDate(possibleRoot):             # <<<<<<<<<<<<<<
 *                         self.__dictionaryTrie.addWord(possibleRoot, TxtWord(possibleRoot, "IS_DATE"))
 *                         fsmParse = self.__analysis(self.__toLower(surfaceForm), self.isProperNoun(surfaceForm))
 */
          goto __pyx_L21;
        }

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":995
 *                         self.__dictionaryTrie.addWord(possibleRoot, TxtWord(possibleRoot, "IS_DATE"))
 *                         fsmParse = self.__analysis(self.__toLower(surfaceForm), self.isProperNoun(surfaceForm))
 *                     elif self.patternMatches("\\d+/\\d+", possibleRoot):             # <<<<<<<<<<<<<<
 *                         self.__dictionaryTrie.addWord(possibleRoot, TxtWord(possibleRoot, "IS_KESIR"))
 *                         fsmParse = self.__analysis(self.__toLower(surfaceForm), self.isProperNoun(surfaceForm))
 */
        __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->patternMatches(__pyx_v_self, __pyx_kp_u_d_d, __pyx_v_possibleRoot, 0) != 0);
        if (__pyx_t_6) {

          /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":996
 *                         fsmParse = self.__analysis(self.__toLower(surfaceForm), self.isProperNoun(surfaceForm))
 *                     elif self.patternMatches("\\d+/\\d+", possibleRoot):
 *                         self.__dictionaryTrie.addWord(possibleRoot, TxtWord(possibleRoot, "IS_KESIR"))             # <<<<<<<<<<<<<<
 *                         fsmParse = self.__analysis(self.__toLower(surfaceForm), self.isProperNoun(surfaceForm))
 *                     elif self.__isPercent(possibleRoot):
 */
          __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 996, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_INCREF(__pyx_v_possibleRoot);
          __Pyx_GIVEREF(__pyx_v_possibleRoot);
          PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_possibleRoot);
          __Pyx_INCREF(__pyx_n_u_IS_KESIR);
          __Pyx_GIVEREF(__pyx_n_u_IS_KESIR);
          PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_n_u_IS_KESIR);
          __pyx_t_3 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_10Dictionary_7TxtWord_TxtWord), __pyx_t_2, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 996, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __pyx_t_2 = ((struct __pyx_vtabstruct_10Dictionary_4Trie_4Trie_Trie *)__pyx_v_self->__pyx___dictionaryTrie->__pyx_vtab)->addWord(__pyx_v_self->__pyx___dictionaryTrie, __pyx_v_possibleRoot, ((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_t_3), 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 996, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

          /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":997
 *                     elif self.patternMatches("\\d+/\\d+", possibleRoot):
 *                         self.__dictionaryTrie.addWord(possibleRoot, TxtWord(possibleRoot, "IS_KESIR"))
 *                         fsmParse = self.__analysis(self.__toLower(surfaceForm), self.isProperNoun(surfaceForm))             # <<<<<<<<<<<<<<
 *                     elif self.__isPercent(possibleRoot):
 *                         self.__dictionaryTrie.addWord(possibleRoot, TxtWord(possibleRoot, "IS_PERCENT"))
 */
          __pyx_t_2 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->__pyx___toLower(__pyx_v_self, __pyx_v_surfaceForm, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 997, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __pyx_t_3 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->__pyx___analysis(__pyx_v_self, ((PyObject*)__pyx_t_2), ((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->isProperNoun(__pyx_v_self, __pyx_v_surfaceForm, 0), 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 997, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_DECREF_SET(__pyx_v_fsmParse, ((PyObject*)__pyx_t_3));
          __pyx_t_3 = 0;

          /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":995
 *                         self.__dictionaryTrie.addWord(possibleRoot, TxtWord(possibleRoot, "IS_DATE"))
 *                         fsmParse = self.__analysis(self.__toLower(surfaceForm), self.isProperNoun(surfaceForm))
 *                     elif self.patternMatches("\\d+/\\d+", possibleRoot):             # <<<<<<<<<<<<<<
 *                         self.__dictionaryTrie.addWord(possibleRoot, TxtWord(possibleRoot, "IS_KESIR"))
 *                         fsmParse = self.__analysis(self.__toLower(surfaceForm), self.isProperNoun(surfaceForm))
 */
          goto __pyx_L21;
        }

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":998
 *                         self.__dictionaryTrie.addWord(possibleRoot, TxtWord(possibleRoot, "IS_KESIR"))
 *                         fsmParse = self.__analysis(self.__toLower(surfaceForm), self.isProperNoun(surfaceForm))
 *                     elif self.__isPercent(possibleRoot):             # <<<<<<<<<<<<<<
 *                         self.__dictionaryTrie.addWord(possibleRoot, TxtWord(possibleRoot, "IS_PERCENT"))
 *                         fsmParse = self.__analysis(self.__toLower(surfaceForm), self.isProperNoun(surfaceForm))
 */
        __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->__pyx___isPercent(__pyx_v_self, __pyx_v_possibleRoot, 0) != 0);
        if (__pyx_t_6) {

          /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":999
 *                         fsmParse = self.__analysis(self.__toLower(surfaceForm), self.isProperNoun(surfaceForm))
 *                     elif self.__isPercent(possibleRoot):
 *                         self.__dictionaryTrie.addWord(possibleRoot, TxtWord(possibleRoot, "IS_PERCENT"))             # <<<<<<<<<<<<<<
 *                         fsmParse = self.__analysis(self.__toLower(surfaceForm), self.isProperNoun(surfaceForm))
 *                     elif self.__isTime(possibleRoot):
 */
          __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 999, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_INCREF(__pyx_v_possibleRoot);
          __Pyx_GIVEREF(__pyx_v_possibleRoot);
          PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_possibleRoot);
          __Pyx_INCREF(__pyx_n_u_IS_PERCENT);
          __Pyx_GIVEREF(__pyx_n_u_IS_PERCENT);
          PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_n_u_IS_PERCENT);
          __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_10Dictionary_7TxtWord_TxtWord), __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 999, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __pyx_t_3 = ((struct __pyx_vtabstruct_10Dictionary_4Trie_4Trie_Trie *)__pyx_v_self->__pyx___dictionaryTrie->__pyx_vtab)->addWord(__pyx_v_self->__pyx___dictionaryTrie, __pyx_v_possibleRoot, ((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_t_2), 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 999, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

          /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1000
 *                     elif self.__isPercent(possibleRoot):
 *                         self.__dictionaryTrie.addWord(possibleRoot, TxtWord(possibleRoot, "IS_PERCENT"))
 *                         fsmParse = self.__analysis(self.__toLower(surfaceForm), self.isProperNoun(surfaceForm))             # <<<<<<<<<<<<<<
 *                     elif self.__isTime(possibleRoot):
 *                         self.__dictionaryTrie.addWord(possibleRoot, TxtWord(possibleRoot, "IS_ZAMAN"))
 */
          __pyx_t_3 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->__pyx___toLower(__pyx_v_self, __pyx_v_surfaceForm, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1000, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __pyx_t_2 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->__pyx___analysis(__pyx_v_self, ((PyObject*)__pyx_t_3), ((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->isProperNoun(__pyx_v_self, __pyx_v_surfaceForm, 0), 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1000, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF_SET(__pyx_v_fsmParse, ((PyObject*)__pyx_t_2));
          __pyx_t_2 = 0;

          /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":998
 *                         self.__dictionaryTrie.addWord(possibleRoot, TxtWord(possibleRoot, "IS_KESIR"))
 *                         fsmParse = self.__analysis(self.__toLower(surfaceForm), self.isProperNoun(surfaceForm))
 *                     elif self.__isPercent(possibleRoot):             # <<<<<<<<<<<<<<
 *                         self.__dictionaryTrie.addWord(possibleRoot, TxtWord(possibleRoot, "IS_PERCENT"))
 *                         fsmParse = self.__analysis(self.__toLower(surfaceForm), self.isProperNoun(surfaceForm))
 */
          goto __pyx_L21;
        }

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1001
 *                         self.__dictionaryTrie.addWord(possibleRoot, TxtWord(possibleRoot, "IS_PERCENT"))
 *                         fsmParse = self.__analysis(self.__toLower(surfaceForm), self.isProperNoun(surfaceForm))
 *                     elif self.__isTime(possibleRoot):             # <<<<<<<<<<<<<<
 *                         self.__dictionaryTrie.addWord(possibleRoot, TxtWord(possibleRoot, "IS_ZAMAN"))
 *                         fsmParse = self.__analysis(self.__toLower(surfaceForm), self.isProperNoun(surfaceForm))
 */
        __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->__pyx___isTime(__pyx_v_self, __pyx_v_possibleRoot, 0) != 0);
        if (__pyx_t_6) {

          /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1002
 *                         fsmParse = self.__analysis(self.__toLower(surfaceForm), self.isProperNoun(surfaceForm))
 *                     elif self.__isTime(possibleRoot):
 *                         self.__dictionaryTrie.addWord(possibleRoot, TxtWord(possibleRoot, "IS_ZAMAN"))             # <<<<<<<<<<<<<<
 *                         fsmParse = self.__analysis(self.__toLower(surfaceForm), self.isProperNoun(surfaceForm))
 *                     elif self.__isRange(possibleRoot):
 */
          __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1002, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_INCREF(__pyx_v_possibleRoot);
          __Pyx_GIVEREF(__pyx_v_possibleRoot);
          PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_possibleRoot);
          __Pyx_INCREF(__pyx_n_u_IS_ZAMAN);
          __Pyx_GIVEREF(__pyx_n_u_IS_ZAMAN);
          PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_n_u_IS_ZAMAN);
          __pyx_t_3 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_10Dictionary_7TxtWord_TxtWord), __pyx_t_2, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1002, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __pyx_t_2 = ((struct __pyx_vtabstruct_10Dictionary_4Trie_4Trie_Trie *)__pyx_v_self->__pyx___dictionaryTrie->__pyx_vtab)->addWord(__pyx_v_self->__pyx___dictionaryTrie, __pyx_v_possibleRoot, ((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_t_3), 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1002, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

          /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1003
 *                     elif self.__isTime(possibleRoot):
 *                         self.__dictionaryTrie.addWord(possibleRoot, TxtWord(possibleRoot, "IS_ZAMAN"))
 *                         fsmParse = self.__analysis(self.__toLower(surfaceForm), self.isProperNoun(surfaceForm))             # <<<<<<<<<<<<<<
 *                     elif self.__isRange(possibleRoot):
 *                         self.__dictionaryTrie.addWord(possibleRoot, TxtWord(possibleRoot, "IS_RANGE"))
 */
          __pyx_t_2 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->__pyx___toLower(__pyx_v_self, __pyx_v_surfaceForm, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1003, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __pyx_t_3 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->__pyx___analysis(__pyx_v_self, ((PyObject*)__pyx_t_2), ((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->isProperNoun(__pyx_v_self, __pyx_v_surfaceForm, 0), 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1003, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_DECREF_SET(__pyx_v_fsmParse, ((PyObject*)__pyx_t_3));
          __pyx_t_3 = 0;

          /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1001
 *                         self.__dictionaryTrie.addWord(possibleRoot, TxtWord(possibleRoot, "IS_PERCENT"))
 *                         fsmParse = self.__analysis(self.__toLower(surfaceForm), self.isProperNoun(surfaceForm))
 *                     elif self.__isTime(possibleRoot):             # <<<<<<<<<<<<<<
 *                         self.__dictionaryTrie.addWord(possibleRoot, TxtWord(possibleRoot, "IS_ZAMAN"))
 *                         fsmParse = self.__analysis(self.__toLower(surfaceForm), self.isProperNoun(surfaceForm))
 */
          goto __pyx_L21;
        }

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1004
 *                         self.__dictionaryTrie.addWord(possibleRoot, TxtWord(possibleRoot, "IS_ZAMAN"))
 *                         fsmParse = self.__analysis(self.__toLower(surfaceForm), self.isProperNoun(surfaceForm))
 *                     elif self.__isRange(possibleRoot):             # <<<<<<<<<<<<<<
 *                         self.__dictionaryTrie.addWord(possibleRoot, TxtWord(possibleRoot, "IS_RANGE"))
 *                         fsmParse = self.__analysis(self.__toLower(surfaceForm), self.isProperNoun(surfaceForm))
 */
        __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->__pyx___isRange(__pyx_v_self, __pyx_v_possibleRoot, 0) != 0);
        if (__pyx_t_6) {

          /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1005
 *                         fsmParse = self.__analysis(self.__toLower(surfaceForm), self.isProperNoun(surfaceForm))
 *                     elif self.__isRange(possibleRoot):
 *                         self.__dictionaryTrie.addWord(possibleRoot, TxtWord(possibleRoot, "IS_RANGE"))             # <<<<<<<<<<<<<<
 *                         fsmParse = self.__analysis(self.__toLower(surfaceForm), self.isProperNoun(surfaceForm))
 *                     elif self.__isInteger(possibleRoot):
 */
          __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1005, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_INCREF(__pyx_v_possibleRoot);
          __Pyx_GIVEREF(__pyx_v_possibleRoot);
          PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_possibleRoot);
          __Pyx_INCREF(__pyx_n_u_IS_RANGE);
          __Pyx_GIVEREF(__pyx_n_u_IS_RANGE);
          PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_n_u_IS_RANGE);
          __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_10Dictionary_7TxtWord_TxtWord), __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1005, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __pyx_t_3 = ((struct __pyx_vtabstruct_10Dictionary_4Trie_4Trie_Trie *)__pyx_v_self->__pyx___dictionaryTrie->__pyx_vtab)->addWord(__pyx_v_self->__pyx___dictionaryTrie, __pyx_v_possibleRoot, ((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_t_2), 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1005, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

          /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1006
 *                     elif self.__isRange(possibleRoot):
 *                         self.__dictionaryTrie.addWord(possibleRoot, TxtWord(possibleRoot, "IS_RANGE"))
 *                         fsmParse = self.__analysis(self.__toLower(surfaceForm), self.isProperNoun(surfaceForm))             # <<<<<<<<<<<<<<
 *                     elif self.__isInteger(possibleRoot):
 *                         self.__dictionaryTrie.addWord(possibleRoot, TxtWord(possibleRoot, "IS_SAYI"))
 */
          __pyx_t_3 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->__pyx___toLower(__pyx_v_self, __pyx_v_surfaceForm, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1006, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __pyx_t_2 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->__pyx___analysis(__pyx_v_self, ((PyObject*)__pyx_t_3), ((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->isProperNoun(__pyx_v_self, __pyx_v_surfaceForm, 0), 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1006, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF_SET(__pyx_v_fsmParse, ((PyObject*)__pyx_t_2));
          __pyx_t_2 = 0;

          /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1004
 *                         self.__dictionaryTrie.addWord(possibleRoot, TxtWord(possibleRoot, "IS_ZAMAN"))
 *                         fsmParse = self.__analysis(self.__toLower(surfaceForm), self.isProperNoun(surfaceForm))
 *                     elif self.__isRange(possibleRoot):             # <<<<<<<<<<<<<<
 *                         self.__dictionaryTrie.addWord(possibleRoot, TxtWord(possibleRoot, "IS_RANGE"))
 *                         fsmParse = self.__analysis(self.__toLower(surfaceForm), self.isProperNoun(surfaceForm))
 */
          goto __pyx_L21;
        }

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1007
 *                         self.__dictionaryTrie.addWord(possibleRoot, TxtWord(possibleRoot, "IS_RANGE"))
 *                         fsmParse = self.__analysis(self.__toLower(surfaceForm), self.isProperNoun(surfaceForm))
 *                     elif self.__isInteger(possibleRoot):             # <<<<<<<<<<<<<<
 *                         self.__dictionaryTrie.addWord(possibleRoot, TxtWord(possibleRoot, "IS_SAYI"))
 *                         fsmParse = self.__analysis(self.__toLower(surfaceForm), self.isProperNoun(surfaceForm))
 */
        __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->__pyx___isInteger(__pyx_v_self, __pyx_v_possibleRoot, 0) != 0);
        if (__pyx_t_6) {

          /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1008
 *                         fsmParse = self.__analysis(self.__toLower(surfaceForm), self.isProperNoun(surfaceForm))
 *                     elif self.__isInteger(possibleRoot):
 *                         self.__dictionaryTrie.addWord(possibleRoot, TxtWord(possibleRoot, "IS_SAYI"))             # <<<<<<<<<<<<<<
 *                         fsmParse = self.__analysis(self.__toLower(surfaceForm), self.isProperNoun(surfaceForm))
 *                     elif self.__isDouble(possibleRoot):
 */
          __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1008, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_INCREF(__pyx_v_possibleRoot);
          __Pyx_GIVEREF(__pyx_v_possibleRoot);
          PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_possibleRoot);
          __Pyx_INCREF(__pyx_n_u_IS_SAYI);
          __Pyx_GIVEREF(__pyx_n_u_IS_SAYI);
          PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_n_u_IS_SAYI);
          __pyx_t_3 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_10Dictionary_7TxtWord_TxtWord), __pyx_t_2, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1008, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __pyx_t_2 = ((struct __pyx_vtabstruct_10Dictionary_4Trie_4Trie_Trie *)__pyx_v_self->__pyx___dictionaryTrie->__pyx_vtab)->addWord(__pyx_v_self->__pyx___dictionaryTrie, __pyx_v_possibleRoot, ((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_t_3), 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1008, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

          /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1009
 *                     elif self.__isInteger(possibleRoot):
 *                         self.__dictionaryTrie.addWord(possibleRoot, TxtWord(possibleRoot, "IS_SAYI"))
 *                         fsmParse = self.__analysis(self.__toLower(surfaceForm), self.isProperNoun(surfaceForm))             # <<<<<<<<<<<<<<
 *                     elif self.__isDouble(possibleRoot):
 *                         self.__dictionaryTrie.addWord(possibleRoot, TxtWord(possibleRoot, "IS_REELSAYI"))
 */
          __pyx_t_2 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->__pyx___toLower(__pyx_v_self, __pyx_v_surfaceForm, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1009, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __pyx_t_3 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->__pyx___analysis(__pyx_v_self, ((PyObject*)__pyx_t_2), ((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->isProperNoun(__pyx_v_self, __pyx_v_surfaceForm, 0), 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1009, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_DECREF_SET(__pyx_v_fsmParse, ((PyObject*)__pyx_t_3));
          __pyx_t_3 = 0;

          /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1007
 *                         self.__dictionaryTrie.addWord(possibleRoot, TxtWord(possibleRoot, "IS_RANGE"))
 *                         fsmParse = self.__analysis(self.__toLower(surfaceForm), self.isProperNoun(surfaceForm))
 *                     elif self.__isInteger(possibleRoot):             # <<<<<<<<<<<<<<
 *                         self.__dictionaryTrie.addWord(possibleRoot, TxtWord(possibleRoot, "IS_SAYI"))
 *                         fsmParse = self.__analysis(self.__toLower(surfaceForm), self.isProperNoun(surfaceForm))
 */
          goto __pyx_L21;
        }

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1010
 *                         self.__dictionaryTrie.addWord(possibleRoot, TxtWord(possibleRoot, "IS_SAYI"))
 *                         fsmParse = self.__analysis(self.__toLower(surfaceForm), self.isProperNoun(surfaceForm))
 *                     elif self.__isDouble(possibleRoot):             # <<<<<<<<<<<<<<
 *                         self.__dictionaryTrie.addWord(possibleRoot, TxtWord(possibleRoot, "IS_REELSAYI"))
 *                         fsmParse = self.__analysis(self.__toLower(surfaceForm), self.isProperNoun(surfaceForm))
 */
        __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->__pyx___isDouble(__pyx_v_self, __pyx_v_possibleRoot, 0) != 0);
        if (__pyx_t_6) {

          /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1011
 *                         fsmParse = self.__analysis(self.__toLower(surfaceForm), self.isProperNoun(surfaceForm))
 *                     elif self.__isDouble(possibleRoot):
 *                         self.__dictionaryTrie.addWord(possibleRoot, TxtWord(possibleRoot, "IS_REELSAYI"))             # <<<<<<<<<<<<<<
 *                         fsmParse = self.__analysis(self.__toLower(surfaceForm), self.isProperNoun(surfaceForm))
 *                     elif Word.isCapital(possibleRoot):
 */
          __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1011, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_INCREF(__pyx_v_possibleRoot);
          __Pyx_GIVEREF(__pyx_v_possibleRoot);
          PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_possibleRoot);
          __Pyx_INCREF(__pyx_n_u_IS_REELSAYI);
          __Pyx_GIVEREF(__pyx_n_u_IS_REELSAYI);
          PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_n_u_IS_REELSAYI);
          __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_10Dictionary_7TxtWord_TxtWord), __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1011, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __pyx_t_3 = ((struct __pyx_vtabstruct_10Dictionary_4Trie_4Trie_Trie *)__pyx_v_self->__pyx___dictionaryTrie->__pyx_vtab)->addWord(__pyx_v_self->__pyx___dictionaryTrie, __pyx_v_possibleRoot, ((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_t_2), 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1011, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

          /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1012
 *                     elif self.__isDouble(possibleRoot):
 *                         self.__dictionaryTrie.addWord(possibleRoot, TxtWord(possibleRoot, "IS_REELSAYI"))
 *                         fsmParse = self.__analysis(self.__toLower(surfaceForm), self.isProperNoun(surfaceForm))             # <<<<<<<<<<<<<<
 *                     elif Word.isCapital(possibleRoot):
 *                         newWord = None
 */
          __pyx_t_3 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->__pyx___toLower(__pyx_v_self, __pyx_v_surfaceForm, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1012, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __pyx_t_2 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->__pyx___analysis(__pyx_v_self, ((PyObject*)__pyx_t_3), ((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->isProperNoun(__pyx_v_self, __pyx_v_surfaceForm, 0), 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1012, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF_SET(__pyx_v_fsmParse, ((PyObject*)__pyx_t_2));
          __pyx_t_2 = 0;

          /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1010
 *                         self.__dictionaryTrie.addWord(possibleRoot, TxtWord(possibleRoot, "IS_SAYI"))
 *                         fsmParse = self.__analysis(self.__toLower(surfaceForm), self.isProperNoun(surfaceForm))
 *                     elif self.__isDouble(possibleRoot):             # <<<<<<<<<<<<<<
 *                         self.__dictionaryTrie.addWord(possibleRoot, TxtWord(possibleRoot, "IS_REELSAYI"))
 *                         fsmParse = self.__analysis(self.__toLower(surfaceForm), self.isProperNoun(surfaceForm))
 */
          goto __pyx_L21;
        }

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1013
 *                         self.__dictionaryTrie.addWord(possibleRoot, TxtWord(possibleRoot, "IS_REELSAYI"))
 *                         fsmParse = self.__analysis(self.__toLower(surfaceForm), self.isProperNoun(surfaceForm))
 *                     elif Word.isCapital(possibleRoot):             # <<<<<<<<<<<<<<
 *                         newWord = None
 *                         word = self.__dictionary.getWord(self.__toLower(possibleRoot))
 */
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype_10Dictionary_4Word_Word), __pyx_n_s_isCapital); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1013, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_1 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_1)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_1);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_1) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_1, __pyx_v_possibleRoot) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_possibleRoot);
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1013, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 1013, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (__pyx_t_6) {

          /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1014
 *                         fsmParse = self.__analysis(self.__toLower(surfaceForm), self.isProperNoun(surfaceForm))
 *                     elif Word.isCapital(possibleRoot):
 *                         newWord = None             # <<<<<<<<<<<<<<
 *                         word = self.__dictionary.getWord(self.__toLower(possibleRoot))
 *                         if word is not None and isinstance(word, TxtWord):
 */
          __Pyx_INCREF(Py_None);
          __pyx_v_newWord = ((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)Py_None);

          /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1015
 *                     elif Word.isCapital(possibleRoot):
 *                         newWord = None
 *                         word = self.__dictionary.getWord(self.__toLower(possibleRoot))             # <<<<<<<<<<<<<<
 *                         if word is not None and isinstance(word, TxtWord):
 *                             word.addFlag("IS_OA")
 */
          __pyx_t_2 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->__pyx___toLower(__pyx_v_self, __pyx_v_possibleRoot, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1015, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __pyx_t_3 = ((PyObject *)((struct __pyx_vtabstruct_10Dictionary_13TxtDictionary_TxtDictionary *)__pyx_v_self->__pyx___dictionary->__pyx_base.__pyx_vtab)->__pyx_base.getWord(((struct __pyx_obj_10Dictionary_10Dictionary_Dictionary *)__pyx_v_self->__pyx___dictionary), ((PyObject*)__pyx_t_2), 0)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1015, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_ptype_10Dictionary_7TxtWord_TxtWord))))) __PYX_ERR(0, 1015, __pyx_L1_error)
          __pyx_v_word = ((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)__pyx_t_3);
          __pyx_t_3 = 0;

          /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1016
 *                         newWord = None
 *                         word = self.__dictionary.getWord(self.__toLower(possibleRoot))
 *                         if word is not None and isinstance(word, TxtWord):             # <<<<<<<<<<<<<<
 *                             word.addFlag("IS_OA")
 *                         else:
 */
          __pyx_t_5 = (((PyObject *)__pyx_v_word) != Py_None);
          __pyx_t_12 = (__pyx_t_5 != 0);
          if (__pyx_t_12) {
          } else {
            __pyx_t_6 = __pyx_t_12;
            goto __pyx_L25_bool_binop_done;
          }
          __pyx_t_12 = __Pyx_TypeCheck(((PyObject *)__pyx_v_word), __pyx_ptype_10Dictionary_7TxtWord_TxtWord); 
          __pyx_t_5 = (__pyx_t_12 != 0);
          __pyx_t_6 = __pyx_t_5;
          __pyx_L25_bool_binop_done:;
          if (__pyx_t_6) {

            /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1017
 *                         word = self.__dictionary.getWord(self.__toLower(possibleRoot))
 *                         if word is not None and isinstance(word, TxtWord):
 *                             word.addFlag("IS_OA")             # <<<<<<<<<<<<<<
 *                         else:
 *                             newWord = TxtWord(self.__toLower(possibleRoot), "IS_OA")
 */
            __pyx_t_3 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_word->__pyx_base.__pyx_vtab)->addFlag(__pyx_v_word, __pyx_n_u_IS_OA, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1017, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_3);
            __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

            /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1016
 *                         newWord = None
 *                         word = self.__dictionary.getWord(self.__toLower(possibleRoot))
 *                         if word is not None and isinstance(word, TxtWord):             # <<<<<<<<<<<<<<
 *                             word.addFlag("IS_OA")
 *                         else:
 */
            goto __pyx_L24;
          }

          /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1019
 *                             word.addFlag("IS_OA")
 *                         else:
 *                             newWord = TxtWord(self.__toLower(possibleRoot), "IS_OA")             # <<<<<<<<<<<<<<
 *                             self.__dictionaryTrie.addWord(self.__toLower(possibleRoot), newWord)
 *                         fsmParse = self.__analysis(self.__toLower(surfaceForm), self.isProperNoun(surfaceForm))
 */
          /*else*/ {
            __pyx_t_3 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->__pyx___toLower(__pyx_v_self, __pyx_v_possibleRoot, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1019, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_3);
            __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1019, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_2);
            __Pyx_GIVEREF(__pyx_t_3);
            PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_3);
            __Pyx_INCREF(__pyx_n_u_IS_OA);
            __Pyx_GIVEREF(__pyx_n_u_IS_OA);
            PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_n_u_IS_OA);
            __pyx_t_3 = 0;
            __pyx_t_3 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_10Dictionary_7TxtWord_TxtWord), __pyx_t_2, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1019, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_3);
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
            __Pyx_DECREF_SET(__pyx_v_newWord, ((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)__pyx_t_3));
            __pyx_t_3 = 0;

            /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1020
 *                         else:
 *                             newWord = TxtWord(self.__toLower(possibleRoot), "IS_OA")
 *                             self.__dictionaryTrie.addWord(self.__toLower(possibleRoot), newWord)             # <<<<<<<<<<<<<<
 *                         fsmParse = self.__analysis(self.__toLower(surfaceForm), self.isProperNoun(surfaceForm))
 *                         if len(fsmParse) == 0 and newWord is not None:
 */
            __pyx_t_3 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->__pyx___toLower(__pyx_v_self, __pyx_v_possibleRoot, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1020, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_3);
            __pyx_t_2 = ((struct __pyx_vtabstruct_10Dictionary_4Trie_4Trie_Trie *)__pyx_v_self->__pyx___dictionaryTrie->__pyx_vtab)->addWord(__pyx_v_self->__pyx___dictionaryTrie, ((PyObject*)__pyx_t_3), ((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_v_newWord), 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1020, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_2);
            __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          }
          __pyx_L24:;

          /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1021
 *                             newWord = TxtWord(self.__toLower(possibleRoot), "IS_OA")
 *                             self.__dictionaryTrie.addWord(self.__toLower(possibleRoot), newWord)
 *                         fsmParse = self.__analysis(self.__toLower(surfaceForm), self.isProperNoun(surfaceForm))             # <<<<<<<<<<<<<<
 *                         if len(fsmParse) == 0 and newWord is not None:
 *                             newWord.addFlag("IS_KIS")
 */
          __pyx_t_2 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->__pyx___toLower(__pyx_v_self, __pyx_v_surfaceForm, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1021, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __pyx_t_3 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->__pyx___analysis(__pyx_v_self, ((PyObject*)__pyx_t_2), ((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->isProperNoun(__pyx_v_self, __pyx_v_surfaceForm, 0), 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1021, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_DECREF_SET(__pyx_v_fsmParse, ((PyObject*)__pyx_t_3));
          __pyx_t_3 = 0;

          /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1022
 *                             self.__dictionaryTrie.addWord(self.__toLower(possibleRoot), newWord)
 *                         fsmParse = self.__analysis(self.__toLower(surfaceForm), self.isProperNoun(surfaceForm))
 *                         if len(fsmParse) == 0 and newWord is not None:             # <<<<<<<<<<<<<<
 *                             newWord.addFlag("IS_KIS")
 *                             fsmParse = self.__analysis(self.__toLower(surfaceForm), self.isProperNoun(surfaceForm))
 */
          if (unlikely(__pyx_v_fsmParse == Py_None)) {
            PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
            __PYX_ERR(0, 1022, __pyx_L1_error)
          }
          __pyx_t_10 = PyList_GET_SIZE(__pyx_v_fsmParse); if (unlikely(__pyx_t_10 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1022, __pyx_L1_error)
          __pyx_t_5 = ((__pyx_t_10 == 0) != 0);
          if (__pyx_t_5) {
          } else {
            __pyx_t_6 = __pyx_t_5;
            goto __pyx_L28_bool_binop_done;
          }
          __pyx_t_5 = (((PyObject *)__pyx_v_newWord) != Py_None);
          __pyx_t_12 = (__pyx_t_5 != 0);
          __pyx_t_6 = __pyx_t_12;
          __pyx_L28_bool_binop_done:;
          if (__pyx_t_6) {

            /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1023
 *                         fsmParse = self.__analysis(self.__toLower(surfaceForm), self.isProperNoun(surfaceForm))
 *                         if len(fsmParse) == 0 and newWord is not None:
 *                             newWord.addFlag("IS_KIS")             # <<<<<<<<<<<<<<
 *                             fsmParse = self.__analysis(self.__toLower(surfaceForm), self.isProperNoun(surfaceForm))
 *             fsmParseList = FsmParseList(fsmParse)
 */
            __pyx_t_3 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_newWord->__pyx_base.__pyx_vtab)->addFlag(__pyx_v_newWord, __pyx_n_u_IS_KIS, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1023, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_3);
            __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

            /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1024
 *                         if len(fsmParse) == 0 and newWord is not None:
 *                             newWord.addFlag("IS_KIS")
 *                             fsmParse = self.__analysis(self.__toLower(surfaceForm), self.isProperNoun(surfaceForm))             # <<<<<<<<<<<<<<
 *             fsmParseList = FsmParseList(fsmParse)
 *             if fsmParseList.size() > 0:
 */
            __pyx_t_3 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->__pyx___toLower(__pyx_v_self, __pyx_v_surfaceForm, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1024, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_3);
            __pyx_t_2 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->__pyx___analysis(__pyx_v_self, ((PyObject*)__pyx_t_3), ((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->isProperNoun(__pyx_v_self, __pyx_v_surfaceForm, 0), 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1024, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_2);
            __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
            __Pyx_DECREF_SET(__pyx_v_fsmParse, ((PyObject*)__pyx_t_2));
            __pyx_t_2 = 0;

            /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1022
 *                             self.__dictionaryTrie.addWord(self.__toLower(possibleRoot), newWord)
 *                         fsmParse = self.__analysis(self.__toLower(surfaceForm), self.isProperNoun(surfaceForm))
 *                         if len(fsmParse) == 0 and newWord is not None:             # <<<<<<<<<<<<<<
 *                             newWord.addFlag("IS_KIS")
 *                             fsmParse = self.__analysis(self.__toLower(surfaceForm), self.isProperNoun(surfaceForm))
 */
          }

          /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1013
 *                         self.__dictionaryTrie.addWord(possibleRoot, TxtWord(possibleRoot, "IS_REELSAYI"))
 *                         fsmParse = self.__analysis(self.__toLower(surfaceForm), self.isProperNoun(surfaceForm))
 *                     elif Word.isCapital(possibleRoot):             # <<<<<<<<<<<<<<
 *                         newWord = None
 *                         word = self.__dictionary.getWord(self.__toLower(possibleRoot))
 */
        }
        __pyx_L21:;

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":988
 *             if "'" in surfaceForm:
 *                 possibleRoot = surfaceForm[:surfaceForm.index('\'')]
 *                 if len(possibleRoot) > 0:             # <<<<<<<<<<<<<<
 *                     if "/" in possibleRoot or "\\/" in possibleRoot:
 *                         self.__dictionaryTrie.addWord(possibleRoot, TxtWord(possibleRoot, "IS_KESIR"))
 */
      }

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":986
 *                 return fsmParseList
 *             fsmParse = []
 *             if "'" in surfaceForm:             # <<<<<<<<<<<<<<
 *                 possibleRoot = surfaceForm[:surfaceForm.index('\'')]
 *                 if len(possibleRoot) > 0:
 */
    }

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1025
 *                             newWord.addFlag("IS_KIS")
 *                             fsmParse = self.__analysis(self.__toLower(surfaceForm), self.isProperNoun(surfaceForm))
 *             fsmParseList = FsmParseList(fsmParse)             # <<<<<<<<<<<<<<
 *             if fsmParseList.size() > 0:
 *                 self.__cache.add(surfaceForm, fsmParseList)
 */
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_12FsmParseList_FsmParseList), __pyx_v_fsmParse); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1025, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_fsmParseList = ((struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *)__pyx_t_2);
    __pyx_t_2 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1026
 *                             fsmParse = self.__analysis(self.__toLower(surfaceForm), self.isProperNoun(surfaceForm))
 *             fsmParseList = FsmParseList(fsmParse)
 *             if fsmParseList.size() > 0:             # <<<<<<<<<<<<<<
 *                 self.__cache.add(surfaceForm, fsmParseList)
 *             return fsmParseList
 */
    __pyx_t_6 = ((((struct __pyx_vtabstruct_21MorphologicalAnalysis_12FsmParseList_FsmParseList *)__pyx_v_fsmParseList->__pyx_vtab)->size(__pyx_v_fsmParseList, 0) > 0) != 0);
    if (__pyx_t_6) {

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1027
 *             fsmParseList = FsmParseList(fsmParse)
 *             if fsmParseList.size() > 0:
 *                 self.__cache.add(surfaceForm, fsmParseList)             # <<<<<<<<<<<<<<
 *             return fsmParseList
 * 
 */
      __pyx_t_2 = ((struct __pyx_vtabstruct_13DataStructure_5Cache_8LRUCache_LRUCache *)__pyx_v_self->__pyx___cache->__pyx_vtab)->add(__pyx_v_self->__pyx___cache, __pyx_v_surfaceForm, ((PyObject *)__pyx_v_fsmParseList), 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1027, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1026
 *                             fsmParse = self.__analysis(self.__toLower(surfaceForm), self.isProperNoun(surfaceForm))
 *             fsmParseList = FsmParseList(fsmParse)
 *             if fsmParseList.size() > 0:             # <<<<<<<<<<<<<<
 *                 self.__cache.add(surfaceForm, fsmParseList)
 *             return fsmParseList
 */
    }

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1028
 *             if fsmParseList.size() > 0:
 *                 self.__cache.add(surfaceForm, fsmParseList)
 *             return fsmParseList             # <<<<<<<<<<<<<<
 * 
 *     cpdef robustMorphologicalAnalysis(self, sentenceOrSurfaceForm):
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(((PyObject *)__pyx_v_fsmParseList));
    __pyx_r = ((PyObject *)__pyx_v_fsmParseList);
    goto __pyx_L0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":969
 *                 result.append(wordFsmParseList)
 *             return result
 *         elif isinstance(sentenceOrSurfaceForm, str):             # <<<<<<<<<<<<<<
 *             surfaceForm = sentenceOrSurfaceForm
 *             if self.__parsedSurfaceForms is not None and surfaceForm not in self.__parsedSurfaceForms \
 */
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":923
 *                self.patternMatches("(\\d\\d|\\d)\\.(\\d\\d|\\d)\\.\\d+", surfaceForm)
 * 
 *     cpdef morphologicalAnalysis(self, sentenceOrSurfaceForm):             # <<<<<<<<<<<<<<
 *         """
 *         The morphologicalAnalysis method is used to analyse a FsmParseList by comparing with the regex.
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("MorphologicalAnalysis.FsmMorphologicalAnalyzer.FsmMorphologicalAnalyzer.morphologicalAnalysis", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_sentence);
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_fsmParse);
  __Pyx_XDECREF(__pyx_v_originalForm);
  __Pyx_XDECREF(__pyx_v_spellCorrectedForm);
  __Pyx_XDECREF(__pyx_v_surfaceForm);
  __Pyx_XDECREF(__pyx_v_possibleRoot);
  __Pyx_XDECREF((PyObject *)__pyx_v_wordFsmParseList);
  __Pyx_XDECREF((PyObject *)__pyx_v_fsmParseList);
  __Pyx_XDECREF((PyObject *)__pyx_v_newWord);
  __Pyx_XDECREF((PyObject *)__pyx_v_word);
  __Pyx_XDECREF(__pyx_v_defaultFsmParse);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_45morphologicalAnalysis(PyObject *__pyx_v_self, PyObject *__pyx_v_sentenceOrSurfaceForm); /*proto*/
static char __pyx_doc_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_44morphologicalAnalysis[] = "\n        The morphologicalAnalysis method is used to analyse a FsmParseList by comparing with the regex.\n        It creates a list fsmParse to hold the result of the analysis method. For each surfaceForm input,\n        it gets a substring and considers it as a possibleRoot. Then compares with the regex.\n\n        If the surfaceForm input string matches with Turkish chars like \303\207, \305\236, \304\260, \303\234, \303\226, it adds the surfaceForm to Trie\n        with IS_OA tag.\n        If the possibleRoot contains /, then it is added to the Trie with IS_KESIR tag.\n        If the possibleRoot contains \\d\\d|\\d)/(\\d\\d|\\d)/\\d+, then it is added to the Trie with IS_DATE tag.\n        If the possibleRoot contains \\d\\d|\\d, then it is added to the Trie with IS_PERCENT tag.\n        If the possibleRoot contains \\d\\d|\\d):(\\d\\d|\\d):(\\d\\d|\\d), then it is added to the Trie with IS_ZAMAN\n        tag.\n        If the possibleRoot contains \\d+-\\d+, then it is added to the Trie with IS_RANGE tag.\n        If the possibleRoot is an Integer, then it is added to the Trie with IS_SAYI tag.\n        If the possibleRoot is a Double, then it is added to the Trie with IS_REELSAYI tag.\n\n        PARAMETERS\n        ----------\n        sentenceOrSurfaceForm : str\n            String or Sentence to analyse.\n\n        RETURNS\n        -------\n        list\n            list which folds the analysis\n        FsmParseList\n            fsmParseList which holds the analysis.\n        ";
static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_45morphologicalAnalysis(PyObject *__pyx_v_self, PyObject *__pyx_v_sentenceOrSurfaceForm) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("morphologicalAnalysis (wrapper)", 0);
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_44morphologicalAnalysis(((struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self), ((PyObject *)__pyx_v_sentenceOrSurfaceForm));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_44morphologicalAnalysis(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_sentenceOrSurfaceForm) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("morphologicalAnalysis", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_morphologicalAnalysis(__pyx_v_self, __pyx_v_sentenceOrSurfaceForm, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 923, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.FsmMorphologicalAnalyzer.FsmMorphologicalAnalyzer.morphologicalAnalysis", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1030
 *             return fsmParseList
 * 
 *     cpdef robustMorphologicalAnalysis(self, sentenceOrSurfaceForm):             # <<<<<<<<<<<<<<
 *         """
 *         The robustMorphologicalAnalysis is used to analyse surfaceForm String. First it gets the currentParse of the
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_47robustMorphologicalAnalysis(PyObject *__pyx_v_self, PyObject *__pyx_v_sentenceOrSurfaceForm); /*proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_robustMorphologicalAnalysis(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_sentenceOrSurfaceForm, int __pyx_skip_dispatch) {
  struct __pyx_obj_6Corpus_8Sentence_Sentence *__pyx_v_sentence = 0;
  PyObject *__pyx_v_result = 0;
  int __pyx_v_i;
  PyObject *__pyx_v_originalForm = 0;
  PyObject *__pyx_v_spellCorrectedForm = 0;
  PyObject *__pyx_v_surfaceForm = 0;
  struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *__pyx_v_wordFsmParseList = 0;
  struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *__pyx_v_currentParse = 0;
  PyObject *__pyx_v_fsmParse = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_t_9;
  Py_ssize_t __pyx_t_10;
  int __pyx_t_11;
  int __pyx_t_12;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("robustMorphologicalAnalysis", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_robustMorphologicalAnalysis); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1030, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_47robustMorphologicalAnalysis)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_v_sentenceOrSurfaceForm) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_sentenceOrSurfaceForm);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1030, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1058
 *         cdef FsmParseList wordFsmParseList, currentParse
 *         cdef list fsmParse
 *         if isinstance(sentenceOrSurfaceForm, Sentence):             # <<<<<<<<<<<<<<
 *             sentence = sentenceOrSurfaceForm
 *             result = []
 */
  __pyx_t_5 = __Pyx_TypeCheck(__pyx_v_sentenceOrSurfaceForm, __pyx_ptype_6Corpus_8Sentence_Sentence); 
  __pyx_t_6 = (__pyx_t_5 != 0);
  if (__pyx_t_6) {

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1059
 *         cdef list fsmParse
 *         if isinstance(sentenceOrSurfaceForm, Sentence):
 *             sentence = sentenceOrSurfaceForm             # <<<<<<<<<<<<<<
 *             result = []
 *             for i in range(sentence.wordCount()):
 */
    if (!(likely(((__pyx_v_sentenceOrSurfaceForm) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_sentenceOrSurfaceForm, __pyx_ptype_6Corpus_8Sentence_Sentence))))) __PYX_ERR(0, 1059, __pyx_L1_error)
    __pyx_t_1 = __pyx_v_sentenceOrSurfaceForm;
    __Pyx_INCREF(__pyx_t_1);
    __pyx_v_sentence = ((struct __pyx_obj_6Corpus_8Sentence_Sentence *)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1060
 *         if isinstance(sentenceOrSurfaceForm, Sentence):
 *             sentence = sentenceOrSurfaceForm
 *             result = []             # <<<<<<<<<<<<<<
 *             for i in range(sentence.wordCount()):
 *                 originalForm = sentence.getWord(i).getName()
 */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1060, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_result = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1061
 *             sentence = sentenceOrSurfaceForm
 *             result = []
 *             for i in range(sentence.wordCount()):             # <<<<<<<<<<<<<<
 *                 originalForm = sentence.getWord(i).getName()
 *                 spellCorrectedForm = self.__dictionary.getCorrectForm(originalForm)
 */
    __pyx_t_7 = ((struct __pyx_vtabstruct_6Corpus_8Sentence_Sentence *)__pyx_v_sentence->__pyx_vtab)->wordCount(__pyx_v_sentence, 0);
    __pyx_t_8 = __pyx_t_7;
    for (__pyx_t_9 = 0; __pyx_t_9 < __pyx_t_8; __pyx_t_9+=1) {
      __pyx_v_i = __pyx_t_9;

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1062
 *             result = []
 *             for i in range(sentence.wordCount()):
 *                 originalForm = sentence.getWord(i).getName()             # <<<<<<<<<<<<<<
 *                 spellCorrectedForm = self.__dictionary.getCorrectForm(originalForm)
 *                 if len(spellCorrectedForm) == 0:
 */
      __pyx_t_1 = ((PyObject *)((struct __pyx_vtabstruct_6Corpus_8Sentence_Sentence *)__pyx_v_sentence->__pyx_vtab)->getWord(__pyx_v_sentence, __pyx_v_i, 0)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1062, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_2 = ((struct __pyx_vtabstruct_10Dictionary_4Word_Word *)((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_t_1)->__pyx_vtab)->getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_t_1), 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1062, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF_SET(__pyx_v_originalForm, ((PyObject*)__pyx_t_2));
      __pyx_t_2 = 0;

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1063
 *             for i in range(sentence.wordCount()):
 *                 originalForm = sentence.getWord(i).getName()
 *                 spellCorrectedForm = self.__dictionary.getCorrectForm(originalForm)             # <<<<<<<<<<<<<<
 *                 if len(spellCorrectedForm) == 0:
 *                     spellCorrectedForm = originalForm
 */
      __pyx_t_2 = ((struct __pyx_vtabstruct_10Dictionary_13TxtDictionary_TxtDictionary *)__pyx_v_self->__pyx___dictionary->__pyx_base.__pyx_vtab)->getCorrectForm(__pyx_v_self->__pyx___dictionary, __pyx_v_originalForm, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1063, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_XDECREF_SET(__pyx_v_spellCorrectedForm, ((PyObject*)__pyx_t_2));
      __pyx_t_2 = 0;

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1064
 *                 originalForm = sentence.getWord(i).getName()
 *                 spellCorrectedForm = self.__dictionary.getCorrectForm(originalForm)
 *                 if len(spellCorrectedForm) == 0:             # <<<<<<<<<<<<<<
 *                     spellCorrectedForm = originalForm
 *                 wordFsmParseList = self.robustMorphologicalAnalysis(spellCorrectedForm)
 */
      if (unlikely(__pyx_v_spellCorrectedForm == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
        __PYX_ERR(0, 1064, __pyx_L1_error)
      }
      __pyx_t_10 = __Pyx_PyUnicode_GET_LENGTH(__pyx_v_spellCorrectedForm); if (unlikely(__pyx_t_10 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1064, __pyx_L1_error)
      __pyx_t_6 = ((__pyx_t_10 == 0) != 0);
      if (__pyx_t_6) {

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1065
 *                 spellCorrectedForm = self.__dictionary.getCorrectForm(originalForm)
 *                 if len(spellCorrectedForm) == 0:
 *                     spellCorrectedForm = originalForm             # <<<<<<<<<<<<<<
 *                 wordFsmParseList = self.robustMorphologicalAnalysis(spellCorrectedForm)
 *                 result.append(wordFsmParseList)
 */
        __Pyx_INCREF(__pyx_v_originalForm);
        __Pyx_DECREF_SET(__pyx_v_spellCorrectedForm, __pyx_v_originalForm);

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1064
 *                 originalForm = sentence.getWord(i).getName()
 *                 spellCorrectedForm = self.__dictionary.getCorrectForm(originalForm)
 *                 if len(spellCorrectedForm) == 0:             # <<<<<<<<<<<<<<
 *                     spellCorrectedForm = originalForm
 *                 wordFsmParseList = self.robustMorphologicalAnalysis(spellCorrectedForm)
 */
      }

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1066
 *                 if len(spellCorrectedForm) == 0:
 *                     spellCorrectedForm = originalForm
 *                 wordFsmParseList = self.robustMorphologicalAnalysis(spellCorrectedForm)             # <<<<<<<<<<<<<<
 *                 result.append(wordFsmParseList)
 *             return result
 */
      __pyx_t_2 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->robustMorphologicalAnalysis(__pyx_v_self, __pyx_v_spellCorrectedForm, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1066, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_21MorphologicalAnalysis_12FsmParseList_FsmParseList))))) __PYX_ERR(0, 1066, __pyx_L1_error)
      __Pyx_XDECREF_SET(__pyx_v_wordFsmParseList, ((struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *)__pyx_t_2));
      __pyx_t_2 = 0;

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1067
 *                     spellCorrectedForm = originalForm
 *                 wordFsmParseList = self.robustMorphologicalAnalysis(spellCorrectedForm)
 *                 result.append(wordFsmParseList)             # <<<<<<<<<<<<<<
 *             return result
 *         elif isinstance(sentenceOrSurfaceForm, str):
 */
      __pyx_t_11 = __Pyx_PyList_Append(__pyx_v_result, ((PyObject *)__pyx_v_wordFsmParseList)); if (unlikely(__pyx_t_11 == ((int)-1))) __PYX_ERR(0, 1067, __pyx_L1_error)
    }

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1068
 *                 wordFsmParseList = self.robustMorphologicalAnalysis(spellCorrectedForm)
 *                 result.append(wordFsmParseList)
 *             return result             # <<<<<<<<<<<<<<
 *         elif isinstance(sentenceOrSurfaceForm, str):
 *             surfaceForm = sentenceOrSurfaceForm
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_result);
    __pyx_r = __pyx_v_result;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1058
 *         cdef FsmParseList wordFsmParseList, currentParse
 *         cdef list fsmParse
 *         if isinstance(sentenceOrSurfaceForm, Sentence):             # <<<<<<<<<<<<<<
 *             sentence = sentenceOrSurfaceForm
 *             result = []
 */
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1069
 *                 result.append(wordFsmParseList)
 *             return result
 *         elif isinstance(sentenceOrSurfaceForm, str):             # <<<<<<<<<<<<<<
 *             surfaceForm = sentenceOrSurfaceForm
 *             if surfaceForm is None or len(surfaceForm) == 0:
 */
  __pyx_t_6 = PyUnicode_Check(__pyx_v_sentenceOrSurfaceForm); 
  __pyx_t_5 = (__pyx_t_6 != 0);
  if (__pyx_t_5) {

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1070
 *             return result
 *         elif isinstance(sentenceOrSurfaceForm, str):
 *             surfaceForm = sentenceOrSurfaceForm             # <<<<<<<<<<<<<<
 *             if surfaceForm is None or len(surfaceForm) == 0:
 *                 return FsmParseList([])
 */
    if (!(likely(PyUnicode_CheckExact(__pyx_v_sentenceOrSurfaceForm))||((__pyx_v_sentenceOrSurfaceForm) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_v_sentenceOrSurfaceForm)->tp_name), 0))) __PYX_ERR(0, 1070, __pyx_L1_error)
    __pyx_t_2 = __pyx_v_sentenceOrSurfaceForm;
    __Pyx_INCREF(__pyx_t_2);
    __pyx_v_surfaceForm = ((PyObject*)__pyx_t_2);
    __pyx_t_2 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1071
 *         elif isinstance(sentenceOrSurfaceForm, str):
 *             surfaceForm = sentenceOrSurfaceForm
 *             if surfaceForm is None or len(surfaceForm) == 0:             # <<<<<<<<<<<<<<
 *                 return FsmParseList([])
 *             currentParse = self.morphologicalAnalysis(surfaceForm)
 */
    __pyx_t_6 = (__pyx_v_surfaceForm == ((PyObject*)Py_None));
    __pyx_t_12 = (__pyx_t_6 != 0);
    if (!__pyx_t_12) {
    } else {
      __pyx_t_5 = __pyx_t_12;
      goto __pyx_L8_bool_binop_done;
    }
    if (unlikely(__pyx_v_surfaceForm == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
      __PYX_ERR(0, 1071, __pyx_L1_error)
    }
    __pyx_t_10 = __Pyx_PyUnicode_GET_LENGTH(__pyx_v_surfaceForm); if (unlikely(__pyx_t_10 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1071, __pyx_L1_error)
    __pyx_t_12 = ((__pyx_t_10 == 0) != 0);
    __pyx_t_5 = __pyx_t_12;
    __pyx_L8_bool_binop_done:;
    if (__pyx_t_5) {

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1072
 *             surfaceForm = sentenceOrSurfaceForm
 *             if surfaceForm is None or len(surfaceForm) == 0:
 *                 return FsmParseList([])             # <<<<<<<<<<<<<<
 *             currentParse = self.morphologicalAnalysis(surfaceForm)
 *             if currentParse.size() == 0:
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1072, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_12FsmParseList_FsmParseList), __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1072, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_r = __pyx_t_1;
      __pyx_t_1 = 0;
      goto __pyx_L0;

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1071
 *         elif isinstance(sentenceOrSurfaceForm, str):
 *             surfaceForm = sentenceOrSurfaceForm
 *             if surfaceForm is None or len(surfaceForm) == 0:             # <<<<<<<<<<<<<<
 *                 return FsmParseList([])
 *             currentParse = self.morphologicalAnalysis(surfaceForm)
 */
    }

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1073
 *             if surfaceForm is None or len(surfaceForm) == 0:
 *                 return FsmParseList([])
 *             currentParse = self.morphologicalAnalysis(surfaceForm)             # <<<<<<<<<<<<<<
 *             if currentParse.size() == 0:
 *                 fsmParse = []
 */
    __pyx_t_1 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->morphologicalAnalysis(__pyx_v_self, __pyx_v_surfaceForm, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1073, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_21MorphologicalAnalysis_12FsmParseList_FsmParseList))))) __PYX_ERR(0, 1073, __pyx_L1_error)
    __pyx_v_currentParse = ((struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1074
 *                 return FsmParseList([])
 *             currentParse = self.morphologicalAnalysis(surfaceForm)
 *             if currentParse.size() == 0:             # <<<<<<<<<<<<<<
 *                 fsmParse = []
 *                 if self.isProperNoun(surfaceForm):
 */
    __pyx_t_5 = ((((struct __pyx_vtabstruct_21MorphologicalAnalysis_12FsmParseList_FsmParseList *)__pyx_v_currentParse->__pyx_vtab)->size(__pyx_v_currentParse, 0) == 0) != 0);
    if (__pyx_t_5) {

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1075
 *             currentParse = self.morphologicalAnalysis(surfaceForm)
 *             if currentParse.size() == 0:
 *                 fsmParse = []             # <<<<<<<<<<<<<<
 *                 if self.isProperNoun(surfaceForm):
 *                     fsmParse.append(FsmParse(surfaceForm, self.__finiteStateMachine.getState("ProperRoot")))
 */
      __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1075, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_v_fsmParse = ((PyObject*)__pyx_t_1);
      __pyx_t_1 = 0;

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1076
 *             if currentParse.size() == 0:
 *                 fsmParse = []
 *                 if self.isProperNoun(surfaceForm):             # <<<<<<<<<<<<<<
 *                     fsmParse.append(FsmParse(surfaceForm, self.__finiteStateMachine.getState("ProperRoot")))
 *                     return FsmParseList(self.__parseWord(fsmParse, surfaceForm))
 */
      __pyx_t_5 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->isProperNoun(__pyx_v_self, __pyx_v_surfaceForm, 0) != 0);
      if (__pyx_t_5) {

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1077
 *                 fsmParse = []
 *                 if self.isProperNoun(surfaceForm):
 *                     fsmParse.append(FsmParse(surfaceForm, self.__finiteStateMachine.getState("ProperRoot")))             # <<<<<<<<<<<<<<
 *                     return FsmParseList(self.__parseWord(fsmParse, surfaceForm))
 *                 else:
 */
        __pyx_t_1 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine *)__pyx_v_self->__pyx___finiteStateMachine->__pyx_vtab)->getState(__pyx_v_self->__pyx___finiteStateMachine, __pyx_n_u_ProperRoot, 0)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1077, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1077, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_INCREF(__pyx_v_surfaceForm);
        __Pyx_GIVEREF(__pyx_v_surfaceForm);
        PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_surfaceForm);
        __Pyx_GIVEREF(__pyx_t_1);
        PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_1);
        __pyx_t_1 = 0;
        __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse), __pyx_t_2, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1077, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_t_11 = __Pyx_PyList_Append(__pyx_v_fsmParse, __pyx_t_1); if (unlikely(__pyx_t_11 == ((int)-1))) __PYX_ERR(0, 1077, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1078
 *                 if self.isProperNoun(surfaceForm):
 *                     fsmParse.append(FsmParse(surfaceForm, self.__finiteStateMachine.getState("ProperRoot")))
 *                     return FsmParseList(self.__parseWord(fsmParse, surfaceForm))             # <<<<<<<<<<<<<<
 *                 else:
 *                     fsmParse.append(FsmParse(surfaceForm, self.__finiteStateMachine.getState("NominalRoot")))
 */
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_1 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->__pyx___parseWord(__pyx_v_self, __pyx_v_fsmParse, __pyx_v_surfaceForm, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1078, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_2 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_12FsmParseList_FsmParseList), __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1078, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        goto __pyx_L0;

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1076
 *             if currentParse.size() == 0:
 *                 fsmParse = []
 *                 if self.isProperNoun(surfaceForm):             # <<<<<<<<<<<<<<
 *                     fsmParse.append(FsmParse(surfaceForm, self.__finiteStateMachine.getState("ProperRoot")))
 *                     return FsmParseList(self.__parseWord(fsmParse, surfaceForm))
 */
      }

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1080
 *                     return FsmParseList(self.__parseWord(fsmParse, surfaceForm))
 *                 else:
 *                     fsmParse.append(FsmParse(surfaceForm, self.__finiteStateMachine.getState("NominalRoot")))             # <<<<<<<<<<<<<<
 *                     return FsmParseList(self.__parseWord(fsmParse, surfaceForm))
 *             else:
 */
      /*else*/ {
        __pyx_t_2 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine *)__pyx_v_self->__pyx___finiteStateMachine->__pyx_vtab)->getState(__pyx_v_self->__pyx___finiteStateMachine, __pyx_n_u_NominalRoot, 0)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1080, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1080, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_INCREF(__pyx_v_surfaceForm);
        __Pyx_GIVEREF(__pyx_v_surfaceForm);
        PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_surfaceForm);
        __Pyx_GIVEREF(__pyx_t_2);
        PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_2);
        __pyx_t_2 = 0;
        __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse), __pyx_t_1, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1080, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_11 = __Pyx_PyList_Append(__pyx_v_fsmParse, __pyx_t_2); if (unlikely(__pyx_t_11 == ((int)-1))) __PYX_ERR(0, 1080, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1081
 *                 else:
 *                     fsmParse.append(FsmParse(surfaceForm, self.__finiteStateMachine.getState("NominalRoot")))
 *                     return FsmParseList(self.__parseWord(fsmParse, surfaceForm))             # <<<<<<<<<<<<<<
 *             else:
 *                 return currentParse
 */
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_2 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->__pyx___parseWord(__pyx_v_self, __pyx_v_fsmParse, __pyx_v_surfaceForm, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1081, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_1 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_12FsmParseList_FsmParseList), __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1081, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_1;
        __pyx_t_1 = 0;
        goto __pyx_L0;
      }

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1074
 *                 return FsmParseList([])
 *             currentParse = self.morphologicalAnalysis(surfaceForm)
 *             if currentParse.size() == 0:             # <<<<<<<<<<<<<<
 *                 fsmParse = []
 *                 if self.isProperNoun(surfaceForm):
 */
    }

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1083
 *                     return FsmParseList(self.__parseWord(fsmParse, surfaceForm))
 *             else:
 *                 return currentParse             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint __isInteger(self, str surfaceForm):
 */
    /*else*/ {
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(((PyObject *)__pyx_v_currentParse));
      __pyx_r = ((PyObject *)__pyx_v_currentParse);
      goto __pyx_L0;
    }

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1069
 *                 result.append(wordFsmParseList)
 *             return result
 *         elif isinstance(sentenceOrSurfaceForm, str):             # <<<<<<<<<<<<<<
 *             surfaceForm = sentenceOrSurfaceForm
 *             if surfaceForm is None or len(surfaceForm) == 0:
 */
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1030
 *             return fsmParseList
 * 
 *     cpdef robustMorphologicalAnalysis(self, sentenceOrSurfaceForm):             # <<<<<<<<<<<<<<
 *         """
 *         The robustMorphologicalAnalysis is used to analyse surfaceForm String. First it gets the currentParse of the
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("MorphologicalAnalysis.FsmMorphologicalAnalyzer.FsmMorphologicalAnalyzer.robustMorphologicalAnalysis", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_sentence);
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_originalForm);
  __Pyx_XDECREF(__pyx_v_spellCorrectedForm);
  __Pyx_XDECREF(__pyx_v_surfaceForm);
  __Pyx_XDECREF((PyObject *)__pyx_v_wordFsmParseList);
  __Pyx_XDECREF((PyObject *)__pyx_v_currentParse);
  __Pyx_XDECREF(__pyx_v_fsmParse);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_47robustMorphologicalAnalysis(PyObject *__pyx_v_self, PyObject *__pyx_v_sentenceOrSurfaceForm); /*proto*/
static char __pyx_doc_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_46robustMorphologicalAnalysis[] = "\n        The robustMorphologicalAnalysis is used to analyse surfaceForm String. First it gets the currentParse of the\n        surfaceForm then, if the size of the currentParse is 0, and given surfaceForm is a proper noun, it adds the\n        surfaceForm whose state name is ProperRoot to an list, of it is not a proper noon, it adds the surfaceForm\n        whose state name is NominalRoot to the list.\n        The robustMorphologicalAnalysis method takes just one argument as an input. It gets the name of the words from\n        input sentence then calls robustMorphologicalAnalysis with surfaceForm.\n\n        PARAMETERS\n        ----------\n        sentenceOrSurfaceForm\n            Sentence type input used to get surfaceForm.\n            String to analyse.\n\n        RETURNS\n        -------\n        list\n            FsmParseList array which holds the result of the analysis.\n        FsmParseList\n            FsmParseList type currentParse which holds morphological analysis of the surfaceForm.\n        ";
static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_47robustMorphologicalAnalysis(PyObject *__pyx_v_self, PyObject *__pyx_v_sentenceOrSurfaceForm) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("robustMorphologicalAnalysis (wrapper)", 0);
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_46robustMorphologicalAnalysis(((struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self), ((PyObject *)__pyx_v_sentenceOrSurfaceForm));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_46robustMorphologicalAnalysis(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_sentenceOrSurfaceForm) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("robustMorphologicalAnalysis", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_robustMorphologicalAnalysis(__pyx_v_self, __pyx_v_sentenceOrSurfaceForm, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1030, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.FsmMorphologicalAnalyzer.FsmMorphologicalAnalyzer.robustMorphologicalAnalysis", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1085
 *                 return currentParse
 * 
 *     cpdef bint __isInteger(self, str surfaceForm):             # <<<<<<<<<<<<<<
 *         """
 *         The isInteger method compares input surfaceForm with given regex and returns the result.
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_49__isInteger(PyObject *__pyx_v_self, PyObject *__pyx_v_surfaceForm); /*proto*/
static int __pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer___isInteger(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_surfaceForm, int __pyx_skip_dispatch) {
  int __pyx_v_length;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__isInteger", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_isInteger); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1085, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_49__isInteger)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_v_surfaceForm) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_surfaceForm);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1085, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1085, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1101
 *         """
 *         cdef int length
 *         if not self.patternMatches("\\+?\\d+", surfaceForm):             # <<<<<<<<<<<<<<
 *             return False
 *         length = len(surfaceForm)
 */
  __pyx_t_5 = ((!(((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->patternMatches(__pyx_v_self, __pyx_kp_u_d, __pyx_v_surfaceForm, 0) != 0)) != 0);
  if (__pyx_t_5) {

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1102
 *         cdef int length
 *         if not self.patternMatches("\\+?\\d+", surfaceForm):
 *             return False             # <<<<<<<<<<<<<<
 *         length = len(surfaceForm)
 *         if length < 10:
 */
    __pyx_r = 0;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1101
 *         """
 *         cdef int length
 *         if not self.patternMatches("\\+?\\d+", surfaceForm):             # <<<<<<<<<<<<<<
 *             return False
 *         length = len(surfaceForm)
 */
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1103
 *         if not self.patternMatches("\\+?\\d+", surfaceForm):
 *             return False
 *         length = len(surfaceForm)             # <<<<<<<<<<<<<<
 *         if length < 10:
 *             return True
 */
  if (unlikely(__pyx_v_surfaceForm == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(0, 1103, __pyx_L1_error)
  }
  __pyx_t_6 = __Pyx_PyUnicode_GET_LENGTH(__pyx_v_surfaceForm); if (unlikely(__pyx_t_6 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1103, __pyx_L1_error)
  __pyx_v_length = __pyx_t_6;

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1104
 *             return False
 *         length = len(surfaceForm)
 *         if length < 10:             # <<<<<<<<<<<<<<
 *             return True
 *         elif length > 10:
 */
  __pyx_t_5 = ((__pyx_v_length < 10) != 0);
  if (__pyx_t_5) {

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1105
 *         length = len(surfaceForm)
 *         if length < 10:
 *             return True             # <<<<<<<<<<<<<<
 *         elif length > 10:
 *             return False
 */
    __pyx_r = 1;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1104
 *             return False
 *         length = len(surfaceForm)
 *         if length < 10:             # <<<<<<<<<<<<<<
 *             return True
 *         elif length > 10:
 */
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1106
 *         if length < 10:
 *             return True
 *         elif length > 10:             # <<<<<<<<<<<<<<
 *             return False
 *         else:
 */
  __pyx_t_5 = ((__pyx_v_length > 10) != 0);
  if (__pyx_t_5) {

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1107
 *             return True
 *         elif length > 10:
 *             return False             # <<<<<<<<<<<<<<
 *         else:
 *             return surfaceForm <= "2147483647"
 */
    __pyx_r = 0;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1106
 *         if length < 10:
 *             return True
 *         elif length > 10:             # <<<<<<<<<<<<<<
 *             return False
 *         else:
 */
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1109
 *             return False
 *         else:
 *             return surfaceForm <= "2147483647"             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint __isDouble(self, str surfaceForm):
 */
  /*else*/ {
    __pyx_t_1 = PyObject_RichCompare(__pyx_v_surfaceForm, __pyx_kp_u_2147483647, Py_LE); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1109, __pyx_L1_error)
    __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1109, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_r = __pyx_t_5;
    goto __pyx_L0;
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1085
 *                 return currentParse
 * 
 *     cpdef bint __isInteger(self, str surfaceForm):             # <<<<<<<<<<<<<<
 *         """
 *         The isInteger method compares input surfaceForm with given regex and returns the result.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("MorphologicalAnalysis.FsmMorphologicalAnalyzer.FsmMorphologicalAnalyzer.__isInteger", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_49__isInteger(PyObject *__pyx_v_self, PyObject *__pyx_v_surfaceForm); /*proto*/
static char __pyx_doc_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_48__isInteger[] = "\n        The isInteger method compares input surfaceForm with given regex and returns the result.\n        Supports positive integer checks only.\n\n        PARAMETERS\n        ----------\n        surfaceForm : str\n            String to check.\n\n        RETURNS\n        -------\n        bool\n            True if surfaceForm matches with the regex.\n        ";
static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_49__isInteger(PyObject *__pyx_v_self, PyObject *__pyx_v_surfaceForm) {
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__isInteger (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_surfaceForm), (&PyUnicode_Type), 1, "surfaceForm", 1))) __PYX_ERR(0, 1085, __pyx_L1_error)
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_48__isInteger(((struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self), ((PyObject*)__pyx_v_surfaceForm));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_48__isInteger(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_surfaceForm) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__isInteger", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer___isInteger(__pyx_v_self, __pyx_v_surfaceForm, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1085, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.FsmMorphologicalAnalyzer.FsmMorphologicalAnalyzer.__isInteger", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1111
 *             return surfaceForm <= "2147483647"
 * 
 *     cpdef bint __isDouble(self, str surfaceForm):             # <<<<<<<<<<<<<<
 *         """
 *         The isDouble method compares input surfaceForm with given regex and returns the result.
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_51__isDouble(PyObject *__pyx_v_self, PyObject *__pyx_v_surfaceForm); /*proto*/
static int __pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer___isDouble(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_surfaceForm, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__isDouble", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_isDouble); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1111, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_51__isDouble)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_v_surfaceForm) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_surfaceForm);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1111, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1111, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1125
 *             True if surfaceForm matches with the regex.
 *         """
 *         return self.patternMatches("\\+?(\\d+)?\\.\\d*", surfaceForm)             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint __isNumber(self, str surfaceForm):
 */
  __pyx_r = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->patternMatches(__pyx_v_self, __pyx_kp_u_d_d_4, __pyx_v_surfaceForm, 0);
  goto __pyx_L0;

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1111
 *             return surfaceForm <= "2147483647"
 * 
 *     cpdef bint __isDouble(self, str surfaceForm):             # <<<<<<<<<<<<<<
 *         """
 *         The isDouble method compares input surfaceForm with given regex and returns the result.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("MorphologicalAnalysis.FsmMorphologicalAnalyzer.FsmMorphologicalAnalyzer.__isDouble", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_51__isDouble(PyObject *__pyx_v_self, PyObject *__pyx_v_surfaceForm); /*proto*/
static char __pyx_doc_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_50__isDouble[] = "\n        The isDouble method compares input surfaceForm with given regex and returns the result.\n\n        PARAMETERS\n        ----------\n        surfaceForm : str\n            String to check.\n\n        RETURNS\n        -------\n        bool\n            True if surfaceForm matches with the regex.\n        ";
static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_51__isDouble(PyObject *__pyx_v_self, PyObject *__pyx_v_surfaceForm) {
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__isDouble (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_surfaceForm), (&PyUnicode_Type), 1, "surfaceForm", 1))) __PYX_ERR(0, 1111, __pyx_L1_error)
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_50__isDouble(((struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self), ((PyObject*)__pyx_v_surfaceForm));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_50__isDouble(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_surfaceForm) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__isDouble", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer___isDouble(__pyx_v_self, __pyx_v_surfaceForm, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1111, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.FsmMorphologicalAnalyzer.FsmMorphologicalAnalyzer.__isDouble", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1127
 *         return self.patternMatches("\\+?(\\d+)?\\.\\d*", surfaceForm)
 * 
 *     cpdef bint __isNumber(self, str surfaceForm):             # <<<<<<<<<<<<<<
 *         """
 *         The isNumber method compares input surfaceForm with the array of written numbers and returns the result.
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_53__isNumber(PyObject *__pyx_v_self, PyObject *__pyx_v_surfaceForm); /*proto*/
static int __pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer___isNumber(CYTHON_UNUSED struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_surfaceForm, int __pyx_skip_dispatch) {
  PyObject *__pyx_v_word = 0;
  PyObject *__pyx_v_number = 0;
  int __pyx_v_count;
  int __pyx_v_found;
  PyObject *__pyx_v_numbers = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__isNumber", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_isNumber); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1127, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_53__isNumber)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_v_surfaceForm) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_surfaceForm);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1127, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1127, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1144
 *         cdef int count
 *         cdef bint found
 *         numbers = ["bir", "iki", "", "drt", "be", "alt", "yedi", "sekiz", "dokuz",             # <<<<<<<<<<<<<<
 *                    "on", "yirmi", "otuz", "krk", "elli", "altm", "yetmi", "seksen", "doksan",
 *                    "yz", "bin", "milyon", "milyar", "trilyon", "katrilyon"]
 */
  __pyx_t_1 = PyList_New(24); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1144, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_n_u_bir);
  __Pyx_GIVEREF(__pyx_n_u_bir);
  PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_u_bir);
  __Pyx_INCREF(__pyx_n_u_iki);
  __Pyx_GIVEREF(__pyx_n_u_iki);
  PyList_SET_ITEM(__pyx_t_1, 1, __pyx_n_u_iki);
  __Pyx_INCREF(__pyx_n_u__21);
  __Pyx_GIVEREF(__pyx_n_u__21);
  PyList_SET_ITEM(__pyx_t_1, 2, __pyx_n_u__21);
  __Pyx_INCREF(__pyx_n_u_drt);
  __Pyx_GIVEREF(__pyx_n_u_drt);
  PyList_SET_ITEM(__pyx_t_1, 3, __pyx_n_u_drt);
  __Pyx_INCREF(__pyx_n_u_be);
  __Pyx_GIVEREF(__pyx_n_u_be);
  PyList_SET_ITEM(__pyx_t_1, 4, __pyx_n_u_be);
  __Pyx_INCREF(__pyx_n_u_alt);
  __Pyx_GIVEREF(__pyx_n_u_alt);
  PyList_SET_ITEM(__pyx_t_1, 5, __pyx_n_u_alt);
  __Pyx_INCREF(__pyx_n_u_yedi);
  __Pyx_GIVEREF(__pyx_n_u_yedi);
  PyList_SET_ITEM(__pyx_t_1, 6, __pyx_n_u_yedi);
  __Pyx_INCREF(__pyx_n_u_sekiz);
  __Pyx_GIVEREF(__pyx_n_u_sekiz);
  PyList_SET_ITEM(__pyx_t_1, 7, __pyx_n_u_sekiz);
  __Pyx_INCREF(__pyx_n_u_dokuz);
  __Pyx_GIVEREF(__pyx_n_u_dokuz);
  PyList_SET_ITEM(__pyx_t_1, 8, __pyx_n_u_dokuz);
  __Pyx_INCREF(__pyx_n_u_on);
  __Pyx_GIVEREF(__pyx_n_u_on);
  PyList_SET_ITEM(__pyx_t_1, 9, __pyx_n_u_on);
  __Pyx_INCREF(__pyx_n_u_yirmi);
  __Pyx_GIVEREF(__pyx_n_u_yirmi);
  PyList_SET_ITEM(__pyx_t_1, 10, __pyx_n_u_yirmi);
  __Pyx_INCREF(__pyx_n_u_otuz);
  __Pyx_GIVEREF(__pyx_n_u_otuz);
  PyList_SET_ITEM(__pyx_t_1, 11, __pyx_n_u_otuz);
  __Pyx_INCREF(__pyx_n_u_krk);
  __Pyx_GIVEREF(__pyx_n_u_krk);
  PyList_SET_ITEM(__pyx_t_1, 12, __pyx_n_u_krk);
  __Pyx_INCREF(__pyx_n_u_elli);
  __Pyx_GIVEREF(__pyx_n_u_elli);
  PyList_SET_ITEM(__pyx_t_1, 13, __pyx_n_u_elli);
  __Pyx_INCREF(__pyx_n_u_altm);
  __Pyx_GIVEREF(__pyx_n_u_altm);
  PyList_SET_ITEM(__pyx_t_1, 14, __pyx_n_u_altm);
  __Pyx_INCREF(__pyx_n_u_yetmi);
  __Pyx_GIVEREF(__pyx_n_u_yetmi);
  PyList_SET_ITEM(__pyx_t_1, 15, __pyx_n_u_yetmi);
  __Pyx_INCREF(__pyx_n_u_seksen);
  __Pyx_GIVEREF(__pyx_n_u_seksen);
  PyList_SET_ITEM(__pyx_t_1, 16, __pyx_n_u_seksen);
  __Pyx_INCREF(__pyx_n_u_doksan);
  __Pyx_GIVEREF(__pyx_n_u_doksan);
  PyList_SET_ITEM(__pyx_t_1, 17, __pyx_n_u_doksan);
  __Pyx_INCREF(__pyx_n_u_yz);
  __Pyx_GIVEREF(__pyx_n_u_yz);
  PyList_SET_ITEM(__pyx_t_1, 18, __pyx_n_u_yz);
  __Pyx_INCREF(__pyx_n_u_bin);
  __Pyx_GIVEREF(__pyx_n_u_bin);
  PyList_SET_ITEM(__pyx_t_1, 19, __pyx_n_u_bin);
  __Pyx_INCREF(__pyx_n_u_milyon);
  __Pyx_GIVEREF(__pyx_n_u_milyon);
  PyList_SET_ITEM(__pyx_t_1, 20, __pyx_n_u_milyon);
  __Pyx_INCREF(__pyx_n_u_milyar);
  __Pyx_GIVEREF(__pyx_n_u_milyar);
  PyList_SET_ITEM(__pyx_t_1, 21, __pyx_n_u_milyar);
  __Pyx_INCREF(__pyx_n_u_trilyon);
  __Pyx_GIVEREF(__pyx_n_u_trilyon);
  PyList_SET_ITEM(__pyx_t_1, 22, __pyx_n_u_trilyon);
  __Pyx_INCREF(__pyx_n_u_katrilyon);
  __Pyx_GIVEREF(__pyx_n_u_katrilyon);
  PyList_SET_ITEM(__pyx_t_1, 23, __pyx_n_u_katrilyon);
  __pyx_v_numbers = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1147
 *                    "on", "yirmi", "otuz", "krk", "elli", "altm", "yetmi", "seksen", "doksan",
 *                    "yz", "bin", "milyon", "milyar", "trilyon", "katrilyon"]
 *         word = surfaceForm             # <<<<<<<<<<<<<<
 *         count = 0
 *         while len(word) > 0:
 */
  __Pyx_INCREF(__pyx_v_surfaceForm);
  __pyx_v_word = __pyx_v_surfaceForm;

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1148
 *                    "yz", "bin", "milyon", "milyar", "trilyon", "katrilyon"]
 *         word = surfaceForm
 *         count = 0             # <<<<<<<<<<<<<<
 *         while len(word) > 0:
 *             found = False
 */
  __pyx_v_count = 0;

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1149
 *         word = surfaceForm
 *         count = 0
 *         while len(word) > 0:             # <<<<<<<<<<<<<<
 *             found = False
 *             for number in numbers:
 */
  while (1) {
    if (unlikely(__pyx_v_word == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
      __PYX_ERR(0, 1149, __pyx_L1_error)
    }
    __pyx_t_6 = __Pyx_PyUnicode_GET_LENGTH(__pyx_v_word); if (unlikely(__pyx_t_6 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1149, __pyx_L1_error)
    __pyx_t_5 = ((__pyx_t_6 > 0) != 0);
    if (!__pyx_t_5) break;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1150
 *         count = 0
 *         while len(word) > 0:
 *             found = False             # <<<<<<<<<<<<<<
 *             for number in numbers:
 *                 if word.startswith(number):
 */
    __pyx_v_found = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1151
 *         while len(word) > 0:
 *             found = False
 *             for number in numbers:             # <<<<<<<<<<<<<<
 *                 if word.startswith(number):
 *                     found = True
 */
    __pyx_t_1 = __pyx_v_numbers; __Pyx_INCREF(__pyx_t_1); __pyx_t_6 = 0;
    for (;;) {
      if (__pyx_t_6 >= PyList_GET_SIZE(__pyx_t_1)) break;
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      __pyx_t_2 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_6); __Pyx_INCREF(__pyx_t_2); __pyx_t_6++; if (unlikely(0 < 0)) __PYX_ERR(0, 1151, __pyx_L1_error)
      #else
      __pyx_t_2 = PySequence_ITEM(__pyx_t_1, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1151, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      #endif
      if (!(likely(PyUnicode_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_2)->tp_name), 0))) __PYX_ERR(0, 1151, __pyx_L1_error)
      __Pyx_XDECREF_SET(__pyx_v_number, ((PyObject*)__pyx_t_2));
      __pyx_t_2 = 0;

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1152
 *             found = False
 *             for number in numbers:
 *                 if word.startswith(number):             # <<<<<<<<<<<<<<
 *                     found = True
 *                     count = count + 1
 */
      if (unlikely(__pyx_v_word == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "startswith");
        __PYX_ERR(0, 1152, __pyx_L1_error)
      }
      __pyx_t_5 = __Pyx_PyUnicode_Tailmatch(__pyx_v_word, __pyx_v_number, 0, PY_SSIZE_T_MAX, -1); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(0, 1152, __pyx_L1_error)
      if ((__pyx_t_5 != 0)) {

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1153
 *             for number in numbers:
 *                 if word.startswith(number):
 *                     found = True             # <<<<<<<<<<<<<<
 *                     count = count + 1
 *                     word = word[len(number):]
 */
        __pyx_v_found = 1;

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1154
 *                 if word.startswith(number):
 *                     found = True
 *                     count = count + 1             # <<<<<<<<<<<<<<
 *                     word = word[len(number):]
 *                     break
 */
        __pyx_v_count = (__pyx_v_count + 1);

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1155
 *                     found = True
 *                     count = count + 1
 *                     word = word[len(number):]             # <<<<<<<<<<<<<<
 *                     break
 *             if not found:
 */
        if (unlikely(__pyx_v_word == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
          __PYX_ERR(0, 1155, __pyx_L1_error)
        }
        if (unlikely(__pyx_v_number == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
          __PYX_ERR(0, 1155, __pyx_L1_error)
        }
        __pyx_t_7 = __Pyx_PyUnicode_GET_LENGTH(__pyx_v_number); if (unlikely(__pyx_t_7 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1155, __pyx_L1_error)
        __pyx_t_2 = __Pyx_PyUnicode_Substring(__pyx_v_word, __pyx_t_7, PY_SSIZE_T_MAX); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1155, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF_SET(__pyx_v_word, ((PyObject*)__pyx_t_2));
        __pyx_t_2 = 0;

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1156
 *                     count = count + 1
 *                     word = word[len(number):]
 *                     break             # <<<<<<<<<<<<<<
 *             if not found:
 *                 break
 */
        goto __pyx_L6_break;

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1152
 *             found = False
 *             for number in numbers:
 *                 if word.startswith(number):             # <<<<<<<<<<<<<<
 *                     found = True
 *                     count = count + 1
 */
      }

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1151
 *         while len(word) > 0:
 *             found = False
 *             for number in numbers:             # <<<<<<<<<<<<<<
 *                 if word.startswith(number):
 *                     found = True
 */
    }
    __pyx_L6_break:;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1157
 *                     word = word[len(number):]
 *                     break
 *             if not found:             # <<<<<<<<<<<<<<
 *                 break
 *         return len(word) == 0 and count > 1
 */
    __pyx_t_5 = ((!(__pyx_v_found != 0)) != 0);
    if (__pyx_t_5) {

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1158
 *                     break
 *             if not found:
 *                 break             # <<<<<<<<<<<<<<
 *         return len(word) == 0 and count > 1
 * 
 */
      goto __pyx_L4_break;

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1157
 *                     word = word[len(number):]
 *                     break
 *             if not found:             # <<<<<<<<<<<<<<
 *                 break
 *         return len(word) == 0 and count > 1
 */
    }
  }
  __pyx_L4_break:;

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1159
 *             if not found:
 *                 break
 *         return len(word) == 0 and count > 1             # <<<<<<<<<<<<<<
 * 
 *     cpdef str __toLower(self, str surfaceForm):
 */
  if (unlikely(__pyx_v_word == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(0, 1159, __pyx_L1_error)
  }
  __pyx_t_6 = __Pyx_PyUnicode_GET_LENGTH(__pyx_v_word); if (unlikely(__pyx_t_6 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1159, __pyx_L1_error)
  __pyx_t_8 = ((__pyx_t_6 == 0) != 0);
  if (__pyx_t_8) {
  } else {
    __pyx_t_5 = __pyx_t_8;
    goto __pyx_L9_bool_binop_done;
  }
  __pyx_t_8 = ((__pyx_v_count > 1) != 0);
  __pyx_t_5 = __pyx_t_8;
  __pyx_L9_bool_binop_done:;
  __pyx_r = __pyx_t_5;
  goto __pyx_L0;

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1127
 *         return self.patternMatches("\\+?(\\d+)?\\.\\d*", surfaceForm)
 * 
 *     cpdef bint __isNumber(self, str surfaceForm):             # <<<<<<<<<<<<<<
 *         """
 *         The isNumber method compares input surfaceForm with the array of written numbers and returns the result.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("MorphologicalAnalysis.FsmMorphologicalAnalyzer.FsmMorphologicalAnalyzer.__isNumber", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_word);
  __Pyx_XDECREF(__pyx_v_number);
  __Pyx_XDECREF(__pyx_v_numbers);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_53__isNumber(PyObject *__pyx_v_self, PyObject *__pyx_v_surfaceForm); /*proto*/
static char __pyx_doc_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_52__isNumber[] = "\n        The isNumber method compares input surfaceForm with the array of written numbers and returns the result.\n\n        PARAMETERS\n        ----------\n        surfaceForm : str\n            String to check.\n\n        RETURNS\n        -------\n        bool\n            True if surfaceForm matches with the regex.\n        ";
static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_53__isNumber(PyObject *__pyx_v_self, PyObject *__pyx_v_surfaceForm) {
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__isNumber (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_surfaceForm), (&PyUnicode_Type), 1, "surfaceForm", 1))) __PYX_ERR(0, 1127, __pyx_L1_error)
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_52__isNumber(((struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self), ((PyObject*)__pyx_v_surfaceForm));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_52__isNumber(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_surfaceForm) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__isNumber", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer___isNumber(__pyx_v_self, __pyx_v_surfaceForm, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1127, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.FsmMorphologicalAnalyzer.FsmMorphologicalAnalyzer.__isNumber", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1161
 *         return len(word) == 0 and count > 1
 * 
 *     cpdef str __toLower(self, str surfaceForm):             # <<<<<<<<<<<<<<
 *         cdef str result
 *         if "I" in surfaceForm or "" in surfaceForm:
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_55__toLower(PyObject *__pyx_v_self, PyObject *__pyx_v_surfaceForm); /*proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer___toLower(CYTHON_UNUSED struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_surfaceForm, int __pyx_skip_dispatch) {
  PyObject *__pyx_v_result = 0;
  Py_ssize_t __pyx_v_i;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  Py_ssize_t __pyx_t_8;
  Py_ssize_t __pyx_t_9;
  Py_ssize_t __pyx_t_10;
  Py_UCS4 __pyx_t_11;
  Py_UCS4 __pyx_t_12;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__toLower", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_toLower); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1161, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_55__toLower)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_v_surfaceForm) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_surfaceForm);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1161, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (!(likely(PyUnicode_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_2)->tp_name), 0))) __PYX_ERR(0, 1161, __pyx_L1_error)
        __pyx_r = ((PyObject*)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1163
 *     cpdef str __toLower(self, str surfaceForm):
 *         cdef str result
 *         if "I" in surfaceForm or "" in surfaceForm:             # <<<<<<<<<<<<<<
 *             result = ""
 *             for i in range(len(surfaceForm)):
 */
  if (unlikely(__pyx_v_surfaceForm == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(0, 1163, __pyx_L1_error)
  }
  __pyx_t_6 = (__Pyx_PyUnicode_ContainsTF(__pyx_n_u_I, __pyx_v_surfaceForm, Py_EQ)); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 1163, __pyx_L1_error)
  __pyx_t_7 = (__pyx_t_6 != 0);
  if (!__pyx_t_7) {
  } else {
    __pyx_t_5 = __pyx_t_7;
    goto __pyx_L4_bool_binop_done;
  }
  if (unlikely(__pyx_v_surfaceForm == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(0, 1163, __pyx_L1_error)
  }
  __pyx_t_7 = (__Pyx_PyUnicode_ContainsTF(__pyx_n_u__22, __pyx_v_surfaceForm, Py_EQ)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 1163, __pyx_L1_error)
  __pyx_t_6 = (__pyx_t_7 != 0);
  __pyx_t_5 = __pyx_t_6;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_5) {

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1164
 *         cdef str result
 *         if "I" in surfaceForm or "" in surfaceForm:
 *             result = ""             # <<<<<<<<<<<<<<
 *             for i in range(len(surfaceForm)):
 *                 if surfaceForm[i] == "I":
 */
    __Pyx_INCREF(__pyx_kp_u__3);
    __pyx_v_result = __pyx_kp_u__3;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1165
 *         if "I" in surfaceForm or "" in surfaceForm:
 *             result = ""
 *             for i in range(len(surfaceForm)):             # <<<<<<<<<<<<<<
 *                 if surfaceForm[i] == "I":
 *                     result = result + ""
 */
    if (unlikely(__pyx_v_surfaceForm == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
      __PYX_ERR(0, 1165, __pyx_L1_error)
    }
    __pyx_t_8 = __Pyx_PyUnicode_GET_LENGTH(__pyx_v_surfaceForm); if (unlikely(__pyx_t_8 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1165, __pyx_L1_error)
    __pyx_t_9 = __pyx_t_8;
    for (__pyx_t_10 = 0; __pyx_t_10 < __pyx_t_9; __pyx_t_10+=1) {
      __pyx_v_i = __pyx_t_10;

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1166
 *             result = ""
 *             for i in range(len(surfaceForm)):
 *                 if surfaceForm[i] == "I":             # <<<<<<<<<<<<<<
 *                     result = result + ""
 *                 elif surfaceForm[i] == "":
 */
      __pyx_t_11 = __Pyx_GetItemInt_Unicode(__pyx_v_surfaceForm, __pyx_v_i, Py_ssize_t, 1, PyInt_FromSsize_t, 0, 1, 1); if (unlikely(__pyx_t_11 == (Py_UCS4)-1)) __PYX_ERR(0, 1166, __pyx_L1_error)
      __pyx_t_5 = ((__pyx_t_11 == 73) != 0);
      if (__pyx_t_5) {

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1167
 *             for i in range(len(surfaceForm)):
 *                 if surfaceForm[i] == "I":
 *                     result = result + ""             # <<<<<<<<<<<<<<
 *                 elif surfaceForm[i] == "":
 *                     result = result + "i"
 */
        __pyx_t_1 = __Pyx_PyUnicode_Concat(__pyx_v_result, __pyx_n_u__23); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1167, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF_SET(__pyx_v_result, ((PyObject*)__pyx_t_1));
        __pyx_t_1 = 0;

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1166
 *             result = ""
 *             for i in range(len(surfaceForm)):
 *                 if surfaceForm[i] == "I":             # <<<<<<<<<<<<<<
 *                     result = result + ""
 *                 elif surfaceForm[i] == "":
 */
        goto __pyx_L8;
      }

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1168
 *                 if surfaceForm[i] == "I":
 *                     result = result + ""
 *                 elif surfaceForm[i] == "":             # <<<<<<<<<<<<<<
 *                     result = result + "i"
 *                 else:
 */
      __pyx_t_11 = __Pyx_GetItemInt_Unicode(__pyx_v_surfaceForm, __pyx_v_i, Py_ssize_t, 1, PyInt_FromSsize_t, 0, 1, 1); if (unlikely(__pyx_t_11 == (Py_UCS4)-1)) __PYX_ERR(0, 1168, __pyx_L1_error)
      __pyx_t_5 = ((__pyx_t_11 == 0x130) != 0);
      if (__pyx_t_5) {

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1169
 *                     result = result + ""
 *                 elif surfaceForm[i] == "":
 *                     result = result + "i"             # <<<<<<<<<<<<<<
 *                 else:
 *                     result = result + surfaceForm[i].lower()
 */
        __pyx_t_1 = __Pyx_PyUnicode_Concat(__pyx_v_result, __pyx_n_u_i); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1169, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF_SET(__pyx_v_result, ((PyObject*)__pyx_t_1));
        __pyx_t_1 = 0;

        /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1168
 *                 if surfaceForm[i] == "I":
 *                     result = result + ""
 *                 elif surfaceForm[i] == "":             # <<<<<<<<<<<<<<
 *                     result = result + "i"
 *                 else:
 */
        goto __pyx_L8;
      }

      /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1171
 *                     result = result + "i"
 *                 else:
 *                     result = result + surfaceForm[i].lower()             # <<<<<<<<<<<<<<
 *             return result
 *         else:
 */
      /*else*/ {
        __pyx_t_11 = __Pyx_GetItemInt_Unicode(__pyx_v_surfaceForm, __pyx_v_i, Py_ssize_t, 1, PyInt_FromSsize_t, 0, 1, 1); if (unlikely(__pyx_t_11 == (Py_UCS4)-1)) __PYX_ERR(0, 1171, __pyx_L1_error)
        __pyx_t_12 = Py_UNICODE_TOLOWER(__pyx_t_11); 
        __pyx_t_1 = PyUnicode_FromOrdinal(__pyx_t_12); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1171, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_2 = __Pyx_PyUnicode_Concat(__pyx_v_result, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1171, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (!(likely(PyUnicode_CheckExact(__pyx_t_2))||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_2)->tp_name), 0))) __PYX_ERR(0, 1171, __pyx_L1_error)
        __Pyx_DECREF_SET(__pyx_v_result, ((PyObject*)__pyx_t_2));
        __pyx_t_2 = 0;
      }
      __pyx_L8:;
    }

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1172
 *                 else:
 *                     result = result + surfaceForm[i].lower()
 *             return result             # <<<<<<<<<<<<<<
 *         else:
 *             return surfaceForm.lower()
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_result);
    __pyx_r = __pyx_v_result;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1163
 *     cpdef str __toLower(self, str surfaceForm):
 *         cdef str result
 *         if "I" in surfaceForm or "" in surfaceForm:             # <<<<<<<<<<<<<<
 *             result = ""
 *             for i in range(len(surfaceForm)):
 */
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1174
 *             return result
 *         else:
 *             return surfaceForm.lower()             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint morphologicalAnalysisExists(self, TxtWord rootWord, str surfaceForm):
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_surfaceForm, __pyx_n_s_lower); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1174, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
      }
    }
    __pyx_t_2 = (__pyx_t_3) ? __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_3) : __Pyx_PyObject_CallNoArg(__pyx_t_1);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1174, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (!(likely(PyUnicode_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_2)->tp_name), 0))) __PYX_ERR(0, 1174, __pyx_L1_error)
    __pyx_r = ((PyObject*)__pyx_t_2);
    __pyx_t_2 = 0;
    goto __pyx_L0;
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1161
 *         return len(word) == 0 and count > 1
 * 
 *     cpdef str __toLower(self, str surfaceForm):             # <<<<<<<<<<<<<<
 *         cdef str result
 *         if "I" in surfaceForm or "" in surfaceForm:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("MorphologicalAnalysis.FsmMorphologicalAnalyzer.FsmMorphologicalAnalyzer.__toLower", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_55__toLower(PyObject *__pyx_v_self, PyObject *__pyx_v_surfaceForm); /*proto*/
static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_55__toLower(PyObject *__pyx_v_self, PyObject *__pyx_v_surfaceForm) {
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__toLower (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_surfaceForm), (&PyUnicode_Type), 1, "surfaceForm", 1))) __PYX_ERR(0, 1161, __pyx_L1_error)
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_54__toLower(((struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self), ((PyObject*)__pyx_v_surfaceForm));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_54__toLower(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v_surfaceForm) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__toLower", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer___toLower(__pyx_v_self, __pyx_v_surfaceForm, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1161, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.FsmMorphologicalAnalyzer.FsmMorphologicalAnalyzer.__toLower", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1176
 *             return surfaceForm.lower()
 * 
 *     cpdef bint morphologicalAnalysisExists(self, TxtWord rootWord, str surfaceForm):             # <<<<<<<<<<<<<<
 *         """
 *         The morphologicalAnalysisExists method calls analysisExists to check the existence of the analysis with given
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_57morphologicalAnalysisExists(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_morphologicalAnalysisExists(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_rootWord, PyObject *__pyx_v_surfaceForm, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("morphologicalAnalysisExists", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_morphologicalAnalysisExists); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1176, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_57morphologicalAnalysisExists)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        __pyx_t_5 = 0;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_5 = 1;
          }
        }
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_3)) {
          PyObject *__pyx_temp[3] = {__pyx_t_4, ((PyObject *)__pyx_v_rootWord), __pyx_v_surfaceForm};
          __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1176, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_GOTREF(__pyx_t_2);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
          PyObject *__pyx_temp[3] = {__pyx_t_4, ((PyObject *)__pyx_v_rootWord), __pyx_v_surfaceForm};
          __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1176, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_GOTREF(__pyx_t_2);
        } else
        #endif
        {
          __pyx_t_6 = PyTuple_New(2+__pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1176, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          if (__pyx_t_4) {
            __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4); __pyx_t_4 = NULL;
          }
          __Pyx_INCREF(((PyObject *)__pyx_v_rootWord));
          __Pyx_GIVEREF(((PyObject *)__pyx_v_rootWord));
          PyTuple_SET_ITEM(__pyx_t_6, 0+__pyx_t_5, ((PyObject *)__pyx_v_rootWord));
          __Pyx_INCREF(__pyx_v_surfaceForm);
          __Pyx_GIVEREF(__pyx_v_surfaceForm);
          PyTuple_SET_ITEM(__pyx_t_6, 1+__pyx_t_5, __pyx_v_surfaceForm);
          __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_6, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1176, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        }
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_7 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1176, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_7;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1193
 *             True an analysis exists, otherwise return False.
 *         """
 *         return self.__analysisExists(rootWord, self.__toLower(surfaceForm), True)             # <<<<<<<<<<<<<<
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->__pyx___toLower(__pyx_v_self, __pyx_v_surfaceForm, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1193, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self->__pyx_vtab)->__pyx___analysisExists(__pyx_v_self, __pyx_v_rootWord, ((PyObject*)__pyx_t_1), 1, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1176
 *             return surfaceForm.lower()
 * 
 *     cpdef bint morphologicalAnalysisExists(self, TxtWord rootWord, str surfaceForm):             # <<<<<<<<<<<<<<
 *         """
 *         The morphologicalAnalysisExists method calls analysisExists to check the existence of the analysis with given
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_WriteUnraisable("MorphologicalAnalysis.FsmMorphologicalAnalyzer.FsmMorphologicalAnalyzer.morphologicalAnalysisExists", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_57morphologicalAnalysisExists(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_56morphologicalAnalysisExists[] = "\n        The morphologicalAnalysisExists method calls analysisExists to check the existence of the analysis with given\n        root and surfaceForm.\n\n        PARAMETERS\n        ----------\n        surfaceForm : str\n            String to check.\n        rootWord : TxtWord\n            TxtWord input root.\n\n        RETURNS\n        -------\n        bool\n            True an analysis exists, otherwise return False.\n        ";
static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_57morphologicalAnalysisExists(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_rootWord = 0;
  PyObject *__pyx_v_surfaceForm = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("morphologicalAnalysisExists (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_rootWord,&__pyx_n_s_surfaceForm,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_rootWord)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_surfaceForm)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("morphologicalAnalysisExists", 1, 2, 2, 1); __PYX_ERR(0, 1176, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "morphologicalAnalysisExists") < 0)) __PYX_ERR(0, 1176, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_rootWord = ((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)values[0]);
    __pyx_v_surfaceForm = ((PyObject*)values[1]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("morphologicalAnalysisExists", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1176, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("MorphologicalAnalysis.FsmMorphologicalAnalyzer.FsmMorphologicalAnalyzer.morphologicalAnalysisExists", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_rootWord), __pyx_ptype_10Dictionary_7TxtWord_TxtWord, 1, "rootWord", 0))) __PYX_ERR(0, 1176, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_surfaceForm), (&PyUnicode_Type), 1, "surfaceForm", 1))) __PYX_ERR(0, 1176, __pyx_L1_error)
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_56morphologicalAnalysisExists(((struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self), __pyx_v_rootWord, __pyx_v_surfaceForm);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_56morphologicalAnalysisExists(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_rootWord, PyObject *__pyx_v_surfaceForm) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("morphologicalAnalysisExists", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_morphologicalAnalysisExists(__pyx_v_self, __pyx_v_rootWord, __pyx_v_surfaceForm, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1176, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.FsmMorphologicalAnalyzer.FsmMorphologicalAnalyzer.morphologicalAnalysisExists", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_59__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_59__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_58__reduce_cython__(((struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_58__reduce_cython__(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self) {
  PyObject *__pyx_v_state = 0;
  PyObject *__pyx_v__dict = 0;
  int __pyx_v_use_setstate;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":5
 *     cdef object _dict
 *     cdef bint use_setstate
 *     state = (self.__cache, self.__dictionary, self.__dictionaryTrie, self.__finiteStateMachine, self.__mostUsedPatterns, self.__parsedSurfaceForms)             # <<<<<<<<<<<<<<
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 */
  __pyx_t_1 = PyTuple_New(6); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(((PyObject *)__pyx_v_self->__pyx___cache));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_self->__pyx___cache));
  PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self->__pyx___cache));
  __Pyx_INCREF(((PyObject *)__pyx_v_self->__pyx___dictionary));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_self->__pyx___dictionary));
  PyTuple_SET_ITEM(__pyx_t_1, 1, ((PyObject *)__pyx_v_self->__pyx___dictionary));
  __Pyx_INCREF(((PyObject *)__pyx_v_self->__pyx___dictionaryTrie));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_self->__pyx___dictionaryTrie));
  PyTuple_SET_ITEM(__pyx_t_1, 2, ((PyObject *)__pyx_v_self->__pyx___dictionaryTrie));
  __Pyx_INCREF(((PyObject *)__pyx_v_self->__pyx___finiteStateMachine));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_self->__pyx___finiteStateMachine));
  PyTuple_SET_ITEM(__pyx_t_1, 3, ((PyObject *)__pyx_v_self->__pyx___finiteStateMachine));
  __Pyx_INCREF(__pyx_v_self->__pyx___mostUsedPatterns);
  __Pyx_GIVEREF(__pyx_v_self->__pyx___mostUsedPatterns);
  PyTuple_SET_ITEM(__pyx_t_1, 4, __pyx_v_self->__pyx___mostUsedPatterns);
  __Pyx_INCREF(__pyx_v_self->__pyx___parsedSurfaceForms);
  __Pyx_GIVEREF(__pyx_v_self->__pyx___parsedSurfaceForms);
  PyTuple_SET_ITEM(__pyx_t_1, 5, __pyx_v_self->__pyx___parsedSurfaceForms);
  __pyx_v_state = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "(tree fragment)":6
 *     cdef bint use_setstate
 *     state = (self.__cache, self.__dictionary, self.__dictionaryTrie, self.__finiteStateMachine, self.__mostUsedPatterns, self.__parsedSurfaceForms)
 *     _dict = getattr(self, '__dict__', None)             # <<<<<<<<<<<<<<
 *     if _dict is not None:
 *         state += (_dict,)
 */
  __pyx_t_1 = __Pyx_GetAttr3(((PyObject *)__pyx_v_self), __pyx_n_s_dict, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v__dict = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "(tree fragment)":7
 *     state = (self.__cache, self.__dictionary, self.__dictionaryTrie, self.__finiteStateMachine, self.__mostUsedPatterns, self.__parsedSurfaceForms)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
  __pyx_t_2 = (__pyx_v__dict != Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "(tree fragment)":8
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 *         state += (_dict,)             # <<<<<<<<<<<<<<
 *         use_setstate = True
 *     else:
 */
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v__dict);
    __Pyx_GIVEREF(__pyx_v__dict);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v__dict);
    __pyx_t_4 = PyNumber_InPlaceAdd(__pyx_v_state, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF_SET(__pyx_v_state, ((PyObject*)__pyx_t_4));
    __pyx_t_4 = 0;

    /* "(tree fragment)":9
 *     if _dict is not None:
 *         state += (_dict,)
 *         use_setstate = True             # <<<<<<<<<<<<<<
 *     else:
 *         use_setstate = self.__cache is not None or self.__dictionary is not None or self.__dictionaryTrie is not None or self.__finiteStateMachine is not None or self.__mostUsedPatterns is not None or self.__parsedSurfaceForms is not None
 */
    __pyx_v_use_setstate = 1;

    /* "(tree fragment)":7
 *     state = (self.__cache, self.__dictionary, self.__dictionaryTrie, self.__finiteStateMachine, self.__mostUsedPatterns, self.__parsedSurfaceForms)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
    goto __pyx_L3;
  }

  /* "(tree fragment)":11
 *         use_setstate = True
 *     else:
 *         use_setstate = self.__cache is not None or self.__dictionary is not None or self.__dictionaryTrie is not None or self.__finiteStateMachine is not None or self.__mostUsedPatterns is not None or self.__parsedSurfaceForms is not None             # <<<<<<<<<<<<<<
 *     if use_setstate:
 *         return __pyx_unpickle_FsmMorphologicalAnalyzer, (type(self), 0xcbdb4c3, None), state
 */
  /*else*/ {
    __pyx_t_2 = (((PyObject *)__pyx_v_self->__pyx___cache) != Py_None);
    __pyx_t_5 = (__pyx_t_2 != 0);
    if (!__pyx_t_5) {
    } else {
      __pyx_t_3 = __pyx_t_5;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_5 = (((PyObject *)__pyx_v_self->__pyx___dictionary) != Py_None);
    __pyx_t_2 = (__pyx_t_5 != 0);
    if (!__pyx_t_2) {
    } else {
      __pyx_t_3 = __pyx_t_2;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_2 = (((PyObject *)__pyx_v_self->__pyx___dictionaryTrie) != Py_None);
    __pyx_t_5 = (__pyx_t_2 != 0);
    if (!__pyx_t_5) {
    } else {
      __pyx_t_3 = __pyx_t_5;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_5 = (((PyObject *)__pyx_v_self->__pyx___finiteStateMachine) != Py_None);
    __pyx_t_2 = (__pyx_t_5 != 0);
    if (!__pyx_t_2) {
    } else {
      __pyx_t_3 = __pyx_t_2;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_2 = (__pyx_v_self->__pyx___mostUsedPatterns != ((PyObject*)Py_None));
    __pyx_t_5 = (__pyx_t_2 != 0);
    if (!__pyx_t_5) {
    } else {
      __pyx_t_3 = __pyx_t_5;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_5 = (__pyx_v_self->__pyx___parsedSurfaceForms != ((PyObject*)Py_None));
    __pyx_t_2 = (__pyx_t_5 != 0);
    __pyx_t_3 = __pyx_t_2;
    __pyx_L4_bool_binop_done:;
    __pyx_v_use_setstate = __pyx_t_3;
  }
  __pyx_L3:;

  /* "(tree fragment)":12
 *     else:
 *         use_setstate = self.__cache is not None or self.__dictionary is not None or self.__dictionaryTrie is not None or self.__finiteStateMachine is not None or self.__mostUsedPatterns is not None or self.__parsedSurfaceForms is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_FsmMorphologicalAnalyzer, (type(self), 0xcbdb4c3, None), state
 *     else:
 */
  __pyx_t_3 = (__pyx_v_use_setstate != 0);
  if (__pyx_t_3) {

    /* "(tree fragment)":13
 *         use_setstate = self.__cache is not None or self.__dictionary is not None or self.__dictionaryTrie is not None or self.__finiteStateMachine is not None or self.__mostUsedPatterns is not None or self.__parsedSurfaceForms is not None
 *     if use_setstate:
 *         return __pyx_unpickle_FsmMorphologicalAnalyzer, (type(self), 0xcbdb4c3, None), state             # <<<<<<<<<<<<<<
 *     else:
 *         return __pyx_unpickle_FsmMorphologicalAnalyzer, (type(self), 0xcbdb4c3, state)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_pyx_unpickle_FsmMorphologicalA); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_INCREF(__pyx_int_213759171);
    __Pyx_GIVEREF(__pyx_int_213759171);
    PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_int_213759171);
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    PyTuple_SET_ITEM(__pyx_t_1, 2, Py_None);
    __pyx_t_6 = PyTuple_New(3); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_1);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    PyTuple_SET_ITEM(__pyx_t_6, 2, __pyx_v_state);
    __pyx_t_4 = 0;
    __pyx_t_1 = 0;
    __pyx_r = __pyx_t_6;
    __pyx_t_6 = 0;
    goto __pyx_L0;

    /* "(tree fragment)":12
 *     else:
 *         use_setstate = self.__cache is not None or self.__dictionary is not None or self.__dictionaryTrie is not None or self.__finiteStateMachine is not None or self.__mostUsedPatterns is not None or self.__parsedSurfaceForms is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_FsmMorphologicalAnalyzer, (type(self), 0xcbdb4c3, None), state
 *     else:
 */
  }

  /* "(tree fragment)":15
 *         return __pyx_unpickle_FsmMorphologicalAnalyzer, (type(self), 0xcbdb4c3, None), state
 *     else:
 *         return __pyx_unpickle_FsmMorphologicalAnalyzer, (type(self), 0xcbdb4c3, state)             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_FsmMorphologicalAnalyzer__set_state(self, __pyx_state)
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_pyx_unpickle_FsmMorphologicalA); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_INCREF(__pyx_int_213759171);
    __Pyx_GIVEREF(__pyx_int_213759171);
    PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_int_213759171);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_state);
    __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_6);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_1);
    __pyx_t_6 = 0;
    __pyx_t_1 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;
  }

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("MorphologicalAnalysis.FsmMorphologicalAnalyzer.FsmMorphologicalAnalyzer.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_state);
  __Pyx_XDECREF(__pyx_v__dict);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_FsmMorphologicalAnalyzer, (type(self), 0xcbdb4c3, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_FsmMorphologicalAnalyzer__set_state(self, __pyx_state)
 */

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_61__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_61__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_60__setstate_cython__(((struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_60__setstate_cython__(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":17
 *         return __pyx_unpickle_FsmMorphologicalAnalyzer, (type(self), 0xcbdb4c3, state)
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_FsmMorphologicalAnalyzer__set_state(self, __pyx_state)             # <<<<<<<<<<<<<<
 */
  if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "tuple", Py_TYPE(__pyx_v___pyx_state)->tp_name), 0))) __PYX_ERR(1, 17, __pyx_L1_error)
  __pyx_t_1 = __pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer___pyx_unpickle_FsmMorphologicalAnalyzer__set_state(__pyx_v_self, ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_FsmMorphologicalAnalyzer, (type(self), 0xcbdb4c3, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_FsmMorphologicalAnalyzer__set_state(self, __pyx_state)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.FsmMorphologicalAnalyzer.FsmMorphologicalAnalyzer.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __pyx_unpickle_FsmMorphologicalAnalyzer(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_1__pyx_unpickle_FsmMorphologicalAnalyzer(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_1__pyx_unpickle_FsmMorphologicalAnalyzer = {"__pyx_unpickle_FsmMorphologicalAnalyzer", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_1__pyx_unpickle_FsmMorphologicalAnalyzer, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_1__pyx_unpickle_FsmMorphologicalAnalyzer(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v___pyx_type = 0;
  long __pyx_v___pyx_checksum;
  PyObject *__pyx_v___pyx_state = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_unpickle_FsmMorphologicalAnalyzer (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_type,&__pyx_n_s_pyx_checksum,&__pyx_n_s_pyx_state,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pyx_type)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pyx_checksum)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_FsmMorphologicalAnalyzer", 1, 3, 3, 1); __PYX_ERR(1, 1, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pyx_state)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_FsmMorphologicalAnalyzer", 1, 3, 3, 2); __PYX_ERR(1, 1, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__pyx_unpickle_FsmMorphologicalAnalyzer") < 0)) __PYX_ERR(1, 1, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v___pyx_type = values[0];
    __pyx_v___pyx_checksum = __Pyx_PyInt_As_long(values[1]); if (unlikely((__pyx_v___pyx_checksum == (long)-1) && PyErr_Occurred())) __PYX_ERR(1, 1, __pyx_L3_error)
    __pyx_v___pyx_state = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_FsmMorphologicalAnalyzer", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(1, 1, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("MorphologicalAnalysis.FsmMorphologicalAnalyzer.__pyx_unpickle_FsmMorphologicalAnalyzer", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer___pyx_unpickle_FsmMorphologicalAnalyzer(__pyx_self, __pyx_v___pyx_type, __pyx_v___pyx_checksum, __pyx_v___pyx_state);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer___pyx_unpickle_FsmMorphologicalAnalyzer(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_v___pyx_PickleError = 0;
  PyObject *__pyx_v___pyx_result = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_FsmMorphologicalAnalyzer", 0);

  /* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum != 0xcbdb4c3:             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0xcbdb4c3 = (__cache, __dictionary, __dictionaryTrie, __finiteStateMachine, __mostUsedPatterns, __parsedSurfaceForms))" % __pyx_checksum)
 */
  __pyx_t_1 = ((__pyx_v___pyx_checksum != 0xcbdb4c3) != 0);
  if (__pyx_t_1) {

    /* "(tree fragment)":5
 *     cdef object __pyx_result
 *     if __pyx_checksum != 0xcbdb4c3:
 *         from pickle import PickleError as __pyx_PickleError             # <<<<<<<<<<<<<<
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0xcbdb4c3 = (__cache, __dictionary, __dictionaryTrie, __finiteStateMachine, __mostUsedPatterns, __parsedSurfaceForms))" % __pyx_checksum)
 *     __pyx_result = FsmMorphologicalAnalyzer.__new__(__pyx_type)
 */
    __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_n_s_PickleError);
    __Pyx_GIVEREF(__pyx_n_s_PickleError);
    PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_PickleError);
    __pyx_t_3 = __Pyx_Import(__pyx_n_s_pickle, __pyx_t_2, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_PickleError); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_v___pyx_PickleError = __pyx_t_2;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "(tree fragment)":6
 *     if __pyx_checksum != 0xcbdb4c3:
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0xcbdb4c3 = (__cache, __dictionary, __dictionaryTrie, __finiteStateMachine, __mostUsedPatterns, __parsedSurfaceForms))" % __pyx_checksum)             # <<<<<<<<<<<<<<
 *     __pyx_result = FsmMorphologicalAnalyzer.__new__(__pyx_type)
 *     if __pyx_state is not None:
 */
    __pyx_t_2 = __Pyx_PyInt_From_long(__pyx_v___pyx_checksum); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyString_Format(__pyx_kp_s_Incompatible_checksums_s_vs_0xcb, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_INCREF(__pyx_v___pyx_PickleError);
    __pyx_t_2 = __pyx_v___pyx_PickleError; __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
      }
    }
    __pyx_t_3 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_5, __pyx_t_4) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_4);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(1, 6, __pyx_L1_error)

    /* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum != 0xcbdb4c3:             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0xcbdb4c3 = (__cache, __dictionary, __dictionaryTrie, __finiteStateMachine, __mostUsedPatterns, __parsedSurfaceForms))" % __pyx_checksum)
 */
  }

  /* "(tree fragment)":7
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0xcbdb4c3 = (__cache, __dictionary, __dictionaryTrie, __finiteStateMachine, __mostUsedPatterns, __parsedSurfaceForms))" % __pyx_checksum)
 *     __pyx_result = FsmMorphologicalAnalyzer.__new__(__pyx_type)             # <<<<<<<<<<<<<<
 *     if __pyx_state is not None:
 *         __pyx_unpickle_FsmMorphologicalAnalyzer__set_state(<FsmMorphologicalAnalyzer> __pyx_result, __pyx_state)
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer), __pyx_n_s_new); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_3 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_4, __pyx_v___pyx_type) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v___pyx_type);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v___pyx_result = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "(tree fragment)":8
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0xcbdb4c3 = (__cache, __dictionary, __dictionaryTrie, __finiteStateMachine, __mostUsedPatterns, __parsedSurfaceForms))" % __pyx_checksum)
 *     __pyx_result = FsmMorphologicalAnalyzer.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_FsmMorphologicalAnalyzer__set_state(<FsmMorphologicalAnalyzer> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
  __pyx_t_1 = (__pyx_v___pyx_state != Py_None);
  __pyx_t_6 = (__pyx_t_1 != 0);
  if (__pyx_t_6) {

    /* "(tree fragment)":9
 *     __pyx_result = FsmMorphologicalAnalyzer.__new__(__pyx_type)
 *     if __pyx_state is not None:
 *         __pyx_unpickle_FsmMorphologicalAnalyzer__set_state(<FsmMorphologicalAnalyzer> __pyx_result, __pyx_state)             # <<<<<<<<<<<<<<
 *     return __pyx_result
 * cdef __pyx_unpickle_FsmMorphologicalAnalyzer__set_state(FsmMorphologicalAnalyzer __pyx_result, tuple __pyx_state):
 */
    if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "tuple", Py_TYPE(__pyx_v___pyx_state)->tp_name), 0))) __PYX_ERR(1, 9, __pyx_L1_error)
    __pyx_t_3 = __pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer___pyx_unpickle_FsmMorphologicalAnalyzer__set_state(((struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)__pyx_v___pyx_result), ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 9, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "(tree fragment)":8
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0xcbdb4c3 = (__cache, __dictionary, __dictionaryTrie, __finiteStateMachine, __mostUsedPatterns, __parsedSurfaceForms))" % __pyx_checksum)
 *     __pyx_result = FsmMorphologicalAnalyzer.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_FsmMorphologicalAnalyzer__set_state(<FsmMorphologicalAnalyzer> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
  }

  /* "(tree fragment)":10
 *     if __pyx_state is not None:
 *         __pyx_unpickle_FsmMorphologicalAnalyzer__set_state(<FsmMorphologicalAnalyzer> __pyx_result, __pyx_state)
 *     return __pyx_result             # <<<<<<<<<<<<<<
 * cdef __pyx_unpickle_FsmMorphologicalAnalyzer__set_state(FsmMorphologicalAnalyzer __pyx_result, tuple __pyx_state):
 *     __pyx_result.__cache = __pyx_state[0]; __pyx_result.__dictionary = __pyx_state[1]; __pyx_result.__dictionaryTrie = __pyx_state[2]; __pyx_result.__finiteStateMachine = __pyx_state[3]; __pyx_result.__mostUsedPatterns = __pyx_state[4]; __pyx_result.__parsedSurfaceForms = __pyx_state[5]
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v___pyx_result);
  __pyx_r = __pyx_v___pyx_result;
  goto __pyx_L0;

  /* "(tree fragment)":1
 * def __pyx_unpickle_FsmMorphologicalAnalyzer(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("MorphologicalAnalysis.FsmMorphologicalAnalyzer.__pyx_unpickle_FsmMorphologicalAnalyzer", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v___pyx_PickleError);
  __Pyx_XDECREF(__pyx_v___pyx_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":11
 *         __pyx_unpickle_FsmMorphologicalAnalyzer__set_state(<FsmMorphologicalAnalyzer> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_FsmMorphologicalAnalyzer__set_state(FsmMorphologicalAnalyzer __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_result.__cache = __pyx_state[0]; __pyx_result.__dictionary = __pyx_state[1]; __pyx_result.__dictionaryTrie = __pyx_state[2]; __pyx_result.__finiteStateMachine = __pyx_state[3]; __pyx_result.__mostUsedPatterns = __pyx_state[4]; __pyx_result.__parsedSurfaceForms = __pyx_state[5]
 *     if len(__pyx_state) > 6 and hasattr(__pyx_result, '__dict__'):
 */

static PyObject *__pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer___pyx_unpickle_FsmMorphologicalAnalyzer__set_state(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *__pyx_v___pyx_result, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_FsmMorphologicalAnalyzer__set_state", 0);

  /* "(tree fragment)":12
 *     return __pyx_result
 * cdef __pyx_unpickle_FsmMorphologicalAnalyzer__set_state(FsmMorphologicalAnalyzer __pyx_result, tuple __pyx_state):
 *     __pyx_result.__cache = __pyx_state[0]; __pyx_result.__dictionary = __pyx_state[1]; __pyx_result.__dictionaryTrie = __pyx_state[2]; __pyx_result.__finiteStateMachine = __pyx_state[3]; __pyx_result.__mostUsedPatterns = __pyx_state[4]; __pyx_result.__parsedSurfaceForms = __pyx_state[5]             # <<<<<<<<<<<<<<
 *     if len(__pyx_state) > 6 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[6])
 */
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_13DataStructure_5Cache_8LRUCache_LRUCache))))) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->__pyx___cache);
  __Pyx_DECREF(((PyObject *)__pyx_v___pyx_result->__pyx___cache));
  __pyx_v___pyx_result->__pyx___cache = ((struct __pyx_obj_13DataStructure_5Cache_8LRUCache_LRUCache *)__pyx_t_1);
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_10Dictionary_13TxtDictionary_TxtDictionary))))) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->__pyx___dictionary);
  __Pyx_DECREF(((PyObject *)__pyx_v___pyx_result->__pyx___dictionary));
  __pyx_v___pyx_result->__pyx___dictionary = ((struct __pyx_obj_10Dictionary_13TxtDictionary_TxtDictionary *)__pyx_t_1);
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 2, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_10Dictionary_4Trie_4Trie_Trie))))) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->__pyx___dictionaryTrie);
  __Pyx_DECREF(((PyObject *)__pyx_v___pyx_result->__pyx___dictionaryTrie));
  __pyx_v___pyx_result->__pyx___dictionaryTrie = ((struct __pyx_obj_10Dictionary_4Trie_4Trie_Trie *)__pyx_t_1);
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 3, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine))))) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->__pyx___finiteStateMachine);
  __Pyx_DECREF(((PyObject *)__pyx_v___pyx_result->__pyx___finiteStateMachine));
  __pyx_v___pyx_result->__pyx___finiteStateMachine = ((struct __pyx_obj_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine *)__pyx_t_1);
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 4, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PyDict_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "dict", Py_TYPE(__pyx_t_1)->tp_name), 0))) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->__pyx___mostUsedPatterns);
  __Pyx_DECREF(__pyx_v___pyx_result->__pyx___mostUsedPatterns);
  __pyx_v___pyx_result->__pyx___mostUsedPatterns = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 5, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PySet_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "set", Py_TYPE(__pyx_t_1)->tp_name), 0))) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->__pyx___parsedSurfaceForms);
  __Pyx_DECREF(__pyx_v___pyx_result->__pyx___parsedSurfaceForms);
  __pyx_v___pyx_result->__pyx___parsedSurfaceForms = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "(tree fragment)":13
 * cdef __pyx_unpickle_FsmMorphologicalAnalyzer__set_state(FsmMorphologicalAnalyzer __pyx_result, tuple __pyx_state):
 *     __pyx_result.__cache = __pyx_state[0]; __pyx_result.__dictionary = __pyx_state[1]; __pyx_result.__dictionaryTrie = __pyx_state[2]; __pyx_result.__finiteStateMachine = __pyx_state[3]; __pyx_result.__mostUsedPatterns = __pyx_state[4]; __pyx_result.__parsedSurfaceForms = __pyx_state[5]
 *     if len(__pyx_state) > 6 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[6])
 */
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(1, 13, __pyx_L1_error)
  }
  __pyx_t_3 = PyTuple_GET_SIZE(__pyx_v___pyx_state); if (unlikely(__pyx_t_3 == ((Py_ssize_t)-1))) __PYX_ERR(1, 13, __pyx_L1_error)
  __pyx_t_4 = ((__pyx_t_3 > 6) != 0);
  if (__pyx_t_4) {
  } else {
    __pyx_t_2 = __pyx_t_4;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_4 = __Pyx_HasAttr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(1, 13, __pyx_L1_error)
  __pyx_t_5 = (__pyx_t_4 != 0);
  __pyx_t_2 = __pyx_t_5;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_2) {

    /* "(tree fragment)":14
 *     __pyx_result.__cache = __pyx_state[0]; __pyx_result.__dictionary = __pyx_state[1]; __pyx_result.__dictionaryTrie = __pyx_state[2]; __pyx_result.__finiteStateMachine = __pyx_state[3]; __pyx_result.__mostUsedPatterns = __pyx_state[4]; __pyx_result.__parsedSurfaceForms = __pyx_state[5]
 *     if len(__pyx_state) > 6 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[6])             # <<<<<<<<<<<<<<
 */
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_update); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(__pyx_v___pyx_state == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 14, __pyx_L1_error)
    }
    __pyx_t_6 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 6, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_8 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_7, function);
      }
    }
    __pyx_t_1 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_8, __pyx_t_6) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_6);
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "(tree fragment)":13
 * cdef __pyx_unpickle_FsmMorphologicalAnalyzer__set_state(FsmMorphologicalAnalyzer __pyx_result, tuple __pyx_state):
 *     __pyx_result.__cache = __pyx_state[0]; __pyx_result.__dictionary = __pyx_state[1]; __pyx_result.__dictionaryTrie = __pyx_state[2]; __pyx_result.__finiteStateMachine = __pyx_state[3]; __pyx_result.__mostUsedPatterns = __pyx_state[4]; __pyx_result.__parsedSurfaceForms = __pyx_state[5]
 *     if len(__pyx_state) > 6 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[6])
 */
  }

  /* "(tree fragment)":11
 *         __pyx_unpickle_FsmMorphologicalAnalyzer__set_state(<FsmMorphologicalAnalyzer> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_FsmMorphologicalAnalyzer__set_state(FsmMorphologicalAnalyzer __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_result.__cache = __pyx_state[0]; __pyx_result.__dictionary = __pyx_state[1]; __pyx_result.__dictionaryTrie = __pyx_state[2]; __pyx_result.__finiteStateMachine = __pyx_state[3]; __pyx_result.__mostUsedPatterns = __pyx_state[4]; __pyx_result.__parsedSurfaceForms = __pyx_state[5]
 *     if len(__pyx_state) > 6 and hasattr(__pyx_result, '__dict__'):
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("MorphologicalAnalysis.FsmMorphologicalAnalyzer.__pyx_unpickle_FsmMorphologicalAnalyzer__set_state", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static struct __pyx_vtabstruct_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer __pyx_vtable_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer;

static PyObject *__pyx_tp_new_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *p;
  PyObject *o;
  if (likely((t->tp_flags & Py_TPFLAGS_IS_ABSTRACT) == 0)) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)o);
  p->__pyx_vtab = __pyx_vtabptr_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer;
  p->__pyx___dictionaryTrie = ((struct __pyx_obj_10Dictionary_4Trie_4Trie_Trie *)Py_None); Py_INCREF(Py_None);
  p->__pyx___finiteStateMachine = ((struct __pyx_obj_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine *)Py_None); Py_INCREF(Py_None);
  p->__pyx___dictionary = ((struct __pyx_obj_10Dictionary_13TxtDictionary_TxtDictionary *)Py_None); Py_INCREF(Py_None);
  p->__pyx___cache = ((struct __pyx_obj_13DataStructure_5Cache_8LRUCache_LRUCache *)Py_None); Py_INCREF(Py_None);
  p->__pyx___mostUsedPatterns = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->__pyx___parsedSurfaceForms = ((PyObject*)Py_None); Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer(PyObject *o) {
  struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *p = (struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE) && Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx___dictionaryTrie);
  Py_CLEAR(p->__pyx___finiteStateMachine);
  Py_CLEAR(p->__pyx___dictionary);
  Py_CLEAR(p->__pyx___cache);
  Py_CLEAR(p->__pyx___mostUsedPatterns);
  Py_CLEAR(p->__pyx___parsedSurfaceForms);
  (*Py_TYPE(o)->tp_free)(o);
}

static int __pyx_tp_traverse_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *p = (struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)o;
  if (p->__pyx___dictionaryTrie) {
    e = (*v)(((PyObject *)p->__pyx___dictionaryTrie), a); if (e) return e;
  }
  if (p->__pyx___finiteStateMachine) {
    e = (*v)(((PyObject *)p->__pyx___finiteStateMachine), a); if (e) return e;
  }
  if (p->__pyx___dictionary) {
    e = (*v)(((PyObject *)p->__pyx___dictionary), a); if (e) return e;
  }
  if (p->__pyx___cache) {
    e = (*v)(((PyObject *)p->__pyx___cache), a); if (e) return e;
  }
  if (p->__pyx___mostUsedPatterns) {
    e = (*v)(p->__pyx___mostUsedPatterns, a); if (e) return e;
  }
  if (p->__pyx___parsedSurfaceForms) {
    e = (*v)(p->__pyx___parsedSurfaceForms, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *p = (struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *)o;
  tmp = ((PyObject*)p->__pyx___dictionaryTrie);
  p->__pyx___dictionaryTrie = ((struct __pyx_obj_10Dictionary_4Trie_4Trie_Trie *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx___finiteStateMachine);
  p->__pyx___finiteStateMachine = ((struct __pyx_obj_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx___dictionary);
  p->__pyx___dictionary = ((struct __pyx_obj_10Dictionary_13TxtDictionary_TxtDictionary *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx___cache);
  p->__pyx___cache = ((struct __pyx_obj_13DataStructure_5Cache_8LRUCache_LRUCache *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx___mostUsedPatterns);
  p->__pyx___mostUsedPatterns = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx___parsedSurfaceForms);
  p->__pyx___parsedSurfaceForms = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer[] = {
  {"addParsedSurfaceForms", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_3addParsedSurfaceForms, METH_O, 0},
  {"getPossibleWords", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_5getPossibleWords, METH_VARARGS|METH_KEYWORDS, __pyx_doc_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_4getPossibleWords},
  {"getDictionary", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_7getDictionary, METH_NOARGS, __pyx_doc_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_6getDictionary},
  {"getFiniteStateMachine", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_9getFiniteStateMachine, METH_NOARGS, __pyx_doc_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_8getFiniteStateMachine},
  {"__isPossibleSubstring", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_11__isPossibleSubstring, METH_VARARGS|METH_KEYWORDS, __pyx_doc_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_10__isPossibleSubstring},
  {"__initializeParseList", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_13__initializeParseList, METH_VARARGS|METH_KEYWORDS, __pyx_doc_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_12__initializeParseList},
  {"__initializeParseListFromRoot", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_15__initializeParseListFromRoot, METH_VARARGS|METH_KEYWORDS, __pyx_doc_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_14__initializeParseListFromRoot},
  {"__initializeParseListFromSurfaceForm", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_17__initializeParseListFromSurfaceForm, METH_VARARGS|METH_KEYWORDS, __pyx_doc_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_16__initializeParseListFromSurfaceForm},
  {"__addNewParsesFromCurrentParse", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_19__addNewParsesFromCurrentParse, METH_VARARGS|METH_KEYWORDS, __pyx_doc_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_18__addNewParsesFromCurrentParse},
  {"__parseExists", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_21__parseExists, METH_VARARGS|METH_KEYWORDS, __pyx_doc_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_20__parseExists},
  {"__parseWord", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_23__parseWord, METH_VARARGS|METH_KEYWORDS, __pyx_doc_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_22__parseWord},
  {"morphologicalAnalysisRoot", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_25morphologicalAnalysisRoot, METH_VARARGS|METH_KEYWORDS, __pyx_doc_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_24morphologicalAnalysisRoot},
  {"generateAllParses", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_27generateAllParses, METH_VARARGS|METH_KEYWORDS, __pyx_doc_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_26generateAllParses},
  {"__analysisExists", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_29__analysisExists, METH_VARARGS|METH_KEYWORDS, __pyx_doc_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_28__analysisExists},
  {"__analysis", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_31__analysis, METH_VARARGS|METH_KEYWORDS, __pyx_doc_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_30__analysis},
  {"patternMatches", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_33patternMatches, METH_VARARGS|METH_KEYWORDS, 0},
  {"isProperNoun", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_35isProperNoun, METH_O, __pyx_doc_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_34isProperNoun},
  {"__isPercent", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_37__isPercent, METH_O, 0},
  {"__isTime", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_39__isTime, METH_O, 0},
  {"__isRange", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_41__isRange, METH_O, 0},
  {"__isDate", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_43__isDate, METH_O, 0},
  {"morphologicalAnalysis", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_45morphologicalAnalysis, METH_O, __pyx_doc_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_44morphologicalAnalysis},
  {"robustMorphologicalAnalysis", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_47robustMorphologicalAnalysis, METH_O, __pyx_doc_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_46robustMorphologicalAnalysis},
  {"__isInteger", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_49__isInteger, METH_O, __pyx_doc_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_48__isInteger},
  {"__isDouble", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_51__isDouble, METH_O, __pyx_doc_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_50__isDouble},
  {"__isNumber", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_53__isNumber, METH_O, __pyx_doc_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_52__isNumber},
  {"__toLower", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_55__toLower, METH_O, 0},
  {"morphologicalAnalysisExists", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_57morphologicalAnalysisExists, METH_VARARGS|METH_KEYWORDS, __pyx_doc_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_56morphologicalAnalysisExists},
  {"__reduce_cython__", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_59__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_61__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};

static PyTypeObject __pyx_type_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer = {
  PyVarObject_HEAD_INIT(0, 0)
  "MorphologicalAnalysis.FsmMorphologicalAnalyzer.FsmMorphologicalAnalyzer", /*tp_name*/
  sizeof(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer, /*tp_traverse*/
  __pyx_tp_clear_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  __pyx_pw_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
};

static PyMethodDef __pyx_methods[] = {
  {0, 0, 0, 0}
};

#if PY_MAJOR_VERSION >= 3
#if CYTHON_PEP489_MULTI_PHASE_INIT
static PyObject* __pyx_pymod_create(PyObject *spec, PyModuleDef *def); /*proto*/
static int __pyx_pymod_exec_FsmMorphologicalAnalyzer(PyObject* module); /*proto*/
static PyModuleDef_Slot __pyx_moduledef_slots[] = {
  {Py_mod_create, (void*)__pyx_pymod_create},
  {Py_mod_exec, (void*)__pyx_pymod_exec_FsmMorphologicalAnalyzer},
  {0, NULL}
};
#endif

static struct PyModuleDef __pyx_moduledef = {
    PyModuleDef_HEAD_INIT,
    "FsmMorphologicalAnalyzer",
    0, /* m_doc */
  #if CYTHON_PEP489_MULTI_PHASE_INIT
    0, /* m_size */
  #else
    -1, /* m_size */
  #endif
    __pyx_methods /* m_methods */,
  #if CYTHON_PEP489_MULTI_PHASE_INIT
    __pyx_moduledef_slots, /* m_slots */
  #else
    NULL, /* m_reload */
  #endif
    NULL, /* m_traverse */
    NULL, /* m_clear */
    NULL /* m_free */
};
#endif
#ifndef CYTHON_SMALL_CODE
#if defined(__clang__)
    #define CYTHON_SMALL_CODE
#elif defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 3))
    #define CYTHON_SMALL_CODE __attribute__((cold))
#else
    #define CYTHON_SMALL_CODE
#endif
#endif

static __Pyx_StringTabEntry __pyx_string_tab[] = {
  {&__pyx_kp_u_2147483647, __pyx_k_2147483647, sizeof(__pyx_k_2147483647), 0, 1, 0, 0},
  {&__pyx_n_u_Adjective, __pyx_k_Adjective, sizeof(__pyx_k_Adjective), 0, 1, 0, 1},
  {&__pyx_n_u_AdjectiveRoot, __pyx_k_AdjectiveRoot, sizeof(__pyx_k_AdjectiveRoot), 0, 1, 0, 1},
  {&__pyx_n_u_AdverbRoot, __pyx_k_AdverbRoot, sizeof(__pyx_k_AdverbRoot), 0, 1, 0, 1},
  {&__pyx_n_u_CardinalRoot, __pyx_k_CardinalRoot, sizeof(__pyx_k_CardinalRoot), 0, 1, 0, 1},
  {&__pyx_n_u_CompoundNounRoot, __pyx_k_CompoundNounRoot, sizeof(__pyx_k_CompoundNounRoot), 0, 1, 0, 1},
  {&__pyx_n_u_ConjunctionRoot, __pyx_k_ConjunctionRoot, sizeof(__pyx_k_ConjunctionRoot), 0, 1, 0, 1},
  {&__pyx_n_u_DateRoot, __pyx_k_DateRoot, sizeof(__pyx_k_DateRoot), 0, 1, 0, 1},
  {&__pyx_n_u_DeterminerRoot, __pyx_k_DeterminerRoot, sizeof(__pyx_k_DeterminerRoot), 0, 1, 0, 1},
  {&__pyx_n_u_DuplicateRoot, __pyx_k_DuplicateRoot, sizeof(__pyx_k_DuplicateRoot), 0, 1, 0, 1},
  {&__pyx_n_u_Email, __pyx_k_Email, sizeof(__pyx_k_Email), 0, 1, 0, 1},
  {&__pyx_n_u_FractionRoot, __pyx_k_FractionRoot, sizeof(__pyx_k_FractionRoot), 0, 1, 0, 1},
  {&__pyx_n_s_FsmMorphologicalAnalyzer, __pyx_k_FsmMorphologicalAnalyzer, sizeof(__pyx_k_FsmMorphologicalAnalyzer), 0, 0, 1, 1},
  {&__pyx_n_u_Hashtag, __pyx_k_Hashtag, sizeof(__pyx_k_Hashtag), 0, 1, 0, 1},
  {&__pyx_n_u_HeaderRoot, __pyx_k_HeaderRoot, sizeof(__pyx_k_HeaderRoot), 0, 1, 0, 1},
  {&__pyx_n_u_I, __pyx_k_I, sizeof(__pyx_k_I), 0, 1, 0, 1},
  {&__pyx_n_u_IS_DATE, __pyx_k_IS_DATE, sizeof(__pyx_k_IS_DATE), 0, 1, 0, 1},
  {&__pyx_n_u_IS_KESIR, __pyx_k_IS_KESIR, sizeof(__pyx_k_IS_KESIR), 0, 1, 0, 1},
  {&__pyx_n_u_IS_KIS, __pyx_k_IS_KIS, sizeof(__pyx_k_IS_KIS), 0, 1, 0, 1},
  {&__pyx_n_u_IS_OA, __pyx_k_IS_OA, sizeof(__pyx_k_IS_OA), 0, 1, 0, 1},
  {&__pyx_n_u_IS_PERCENT, __pyx_k_IS_PERCENT, sizeof(__pyx_k_IS_PERCENT), 0, 1, 0, 1},
  {&__pyx_n_u_IS_RANGE, __pyx_k_IS_RANGE, sizeof(__pyx_k_IS_RANGE), 0, 1, 0, 1},
  {&__pyx_n_u_IS_REELSAYI, __pyx_k_IS_REELSAYI, sizeof(__pyx_k_IS_REELSAYI), 0, 1, 0, 1},
  {&__pyx_n_u_IS_SAYI, __pyx_k_IS_SAYI, sizeof(__pyx_k_IS_SAYI), 0, 1, 0, 1},
  {&__pyx_n_u_IS_SD, __pyx_k_IS_SD, sizeof(__pyx_k_IS_SD), 0, 1, 0, 1},
  {&__pyx_n_u_IS_SDD, __pyx_k_IS_SDD, sizeof(__pyx_k_IS_SDD), 0, 1, 0, 1},
  {&__pyx_n_u_IS_ST, __pyx_k_IS_ST, sizeof(__pyx_k_IS_ST), 0, 1, 0, 1},
  {&__pyx_n_u_IS_STT, __pyx_k_IS_STT, sizeof(__pyx_k_IS_STT), 0, 1, 0, 1},
  {&__pyx_n_u_IS_UD, __pyx_k_IS_UD, sizeof(__pyx_k_IS_UD), 0, 1, 0, 1},
  {&__pyx_n_u_IS_UDD, __pyx_k_IS_UDD, sizeof(__pyx_k_IS_UDD), 0, 1, 0, 1},
  {&__pyx_n_u_IS_UU, __pyx_k_IS_UU, sizeof(__pyx_k_IS_UU), 0, 1, 0, 1},
  {&__pyx_n_u_IS_UUU, __pyx_k_IS_UUU, sizeof(__pyx_k_IS_UUU), 0, 1, 0, 1},
  {&__pyx_n_u_IS_ZAMAN, __pyx_k_IS_ZAMAN, sizeof(__pyx_k_IS_ZAMAN), 0, 1, 0, 1},
  {&__pyx_kp_s_Incompatible_checksums_s_vs_0xcb, __pyx_k_Incompatible_checksums_s_vs_0xcb, sizeof(__pyx_k_Incompatible_checksums_s_vs_0xcb), 0, 0, 1, 0},
  {&__pyx_n_u_InterjectionRoot, __pyx_k_InterjectionRoot, sizeof(__pyx_k_InterjectionRoot), 0, 1, 0, 1},
  {&__pyx_n_s_MAX_DISTANCE, __pyx_k_MAX_DISTANCE, sizeof(__pyx_k_MAX_DISTANCE), 0, 0, 1, 1},
  {&__pyx_n_s_MorphologicalAnalysis_FsmMorphol, __pyx_k_MorphologicalAnalysis_FsmMorphol, sizeof(__pyx_k_MorphologicalAnalysis_FsmMorphol), 0, 0, 1, 1},
  {&__pyx_n_s_MorphologicalAnalysis_Morphologi, __pyx_k_MorphologicalAnalysis_Morphologi, sizeof(__pyx_k_MorphologicalAnalysis_Morphologi), 0, 0, 1, 1},
  {&__pyx_n_s_MorphologicalTag, __pyx_k_MorphologicalTag, sizeof(__pyx_k_MorphologicalTag), 0, 0, 1, 1},
  {&__pyx_n_u_NominalRoot, __pyx_k_NominalRoot, sizeof(__pyx_k_NominalRoot), 0, 1, 0, 1},
  {&__pyx_n_u_NominalRootNoPossesive, __pyx_k_NominalRootNoPossesive, sizeof(__pyx_k_NominalRootNoPossesive), 0, 1, 0, 1},
  {&__pyx_n_u_NominalRootPlural, __pyx_k_NominalRootPlural, sizeof(__pyx_k_NominalRootPlural), 0, 1, 0, 1},
  {&__pyx_n_u_OrdinalRoot, __pyx_k_OrdinalRoot, sizeof(__pyx_k_OrdinalRoot), 0, 1, 0, 1},
  {&__pyx_n_u_PassiveHn, __pyx_k_PassiveHn, sizeof(__pyx_k_PassiveHn), 0, 1, 0, 1},
  {&__pyx_n_u_PercentRoot, __pyx_k_PercentRoot, sizeof(__pyx_k_PercentRoot), 0, 1, 0, 1},
  {&__pyx_n_s_PickleError, __pyx_k_PickleError, sizeof(__pyx_k_PickleError), 0, 0, 1, 1},
  {&__pyx_n_u_PostP, __pyx_k_PostP, sizeof(__pyx_k_PostP), 0, 1, 0, 1},
  {&__pyx_kp_u_PronounRoot_DEMONS, __pyx_k_PronounRoot_DEMONS, sizeof(__pyx_k_PronounRoot_DEMONS), 0, 1, 0, 0},
  {&__pyx_kp_u_PronounRoot_PERS, __pyx_k_PronounRoot_PERS, sizeof(__pyx_k_PronounRoot_PERS), 0, 1, 0, 0},
  {&__pyx_kp_u_PronounRoot_QUANT, __pyx_k_PronounRoot_QUANT, sizeof(__pyx_k_PronounRoot_QUANT), 0, 1, 0, 0},
  {&__pyx_kp_u_PronounRoot_QUANTPLURAL, __pyx_k_PronounRoot_QUANTPLURAL, sizeof(__pyx_k_PronounRoot_QUANTPLURAL), 0, 1, 0, 0},
  {&__pyx_kp_u_PronounRoot_QUES, __pyx_k_PronounRoot_QUES, sizeof(__pyx_k_PronounRoot_QUES), 0, 1, 0, 0},
  {&__pyx_kp_u_PronounRoot_REFLEX, __pyx_k_PronounRoot_REFLEX, sizeof(__pyx_k_PronounRoot_REFLEX), 0, 1, 0, 0},
  {&__pyx_n_u_ProperRoot, __pyx_k_ProperRoot, sizeof(__pyx_k_ProperRoot), 0, 1, 0, 1},
  {&__pyx_n_u_Punctuation, __pyx_k_Punctuation, sizeof(__pyx_k_Punctuation), 0, 1, 0, 1},
  {&__pyx_n_u_QuestionRoot, __pyx_k_QuestionRoot, sizeof(__pyx_k_QuestionRoot), 0, 1, 0, 1},
  {&__pyx_n_u_RangeRoot, __pyx_k_RangeRoot, sizeof(__pyx_k_RangeRoot), 0, 1, 0, 1},
  {&__pyx_n_u_RealRoot, __pyx_k_RealRoot, sizeof(__pyx_k_RealRoot), 0, 1, 0, 1},
  {&__pyx_n_u_TimeRoot, __pyx_k_TimeRoot, sizeof(__pyx_k_TimeRoot), 0, 1, 0, 1},
  {&__pyx_n_s_VERB, __pyx_k_VERB, sizeof(__pyx_k_VERB), 0, 0, 1, 1},
  {&__pyx_n_u_VERB, __pyx_k_VERB, sizeof(__pyx_k_VERB), 0, 1, 0, 1},
  {&__pyx_kp_u_VerbalRoot, __pyx_k_VerbalRoot, sizeof(__pyx_k_VerbalRoot), 0, 1, 0, 0},
  {&__pyx_n_u_VerbalRoot_2, __pyx_k_VerbalRoot_2, sizeof(__pyx_k_VerbalRoot_2), 0, 1, 0, 1},
  {&__pyx_kp_u__13, __pyx_k__13, sizeof(__pyx_k__13), 0, 1, 0, 0},
  {&__pyx_kp_u__15, __pyx_k__15, sizeof(__pyx_k__15), 0, 1, 0, 0},
  {&__pyx_kp_u__17, __pyx_k__17, sizeof(__pyx_k__17), 0, 1, 0, 0},
  {&__pyx_kp_u__18, __pyx_k__18, sizeof(__pyx_k__18), 0, 1, 0, 0},
  {&__pyx_kp_u__19, __pyx_k__19, sizeof(__pyx_k__19), 0, 1, 0, 0},
  {&__pyx_n_u__2, __pyx_k__2, sizeof(__pyx_k__2), 0, 1, 0, 1},
  {&__pyx_kp_u__20, __pyx_k__20, sizeof(__pyx_k__20), 0, 1, 0, 0},
  {&__pyx_n_u__21, __pyx_k__21, sizeof(__pyx_k__21), 0, 1, 0, 1},
  {&__pyx_n_u__22, __pyx_k__22, sizeof(__pyx_k__22), 0, 1, 0, 1},
  {&__pyx_n_u__23, __pyx_k__23, sizeof(__pyx_k__23), 0, 1, 0, 1},
  {&__pyx_kp_u__3, __pyx_k__3, sizeof(__pyx_k__3), 0, 1, 0, 0},
  {&__pyx_kp_u__4, __pyx_k__4, sizeof(__pyx_k__4), 0, 1, 0, 0},
  {&__pyx_kp_u__5, __pyx_k__5, sizeof(__pyx_k__5), 0, 1, 0, 0},
  {&__pyx_n_u_a, __pyx_k_a, sizeof(__pyx_k_a), 0, 1, 0, 1},
  {&__pyx_n_s_addNewParsesFromCurrentParse, __pyx_k_addNewParsesFromCurrentParse, sizeof(__pyx_k_addNewParsesFromCurrentParse), 0, 0, 1, 1},
  {&__pyx_n_s_addParsedSurfaceForms, __pyx_k_addParsedSurfaceForms, sizeof(__pyx_k_addParsedSurfaceForms), 0, 0, 1, 1},
  {&__pyx_n_u_alt, __pyx_k_alt, sizeof(__pyx_k_alt), 0, 1, 0, 1},
  {&__pyx_n_u_altm, __pyx_k_altm, sizeof(__pyx_k_altm), 0, 1, 0, 1},
  {&__pyx_n_s_analysis, __pyx_k_analysis, sizeof(__pyx_k_analysis), 0, 0, 1, 1},
  {&__pyx_n_s_analysisExists, __pyx_k_analysisExists, sizeof(__pyx_k_analysisExists), 0, 0, 1, 1},
  {&__pyx_n_u_bakas, __pyx_k_bakas, sizeof(__pyx_k_bakas), 0, 1, 0, 1},
  {&__pyx_n_u_baz, __pyx_k_baz, sizeof(__pyx_k_baz), 0, 1, 0, 1},
  {&__pyx_n_u_be, __pyx_k_be, sizeof(__pyx_k_be), 0, 1, 0, 1},
  {&__pyx_n_u_ben, __pyx_k_ben, sizeof(__pyx_k_ben), 0, 1, 0, 1},
  {&__pyx_n_u_bin, __pyx_k_bin, sizeof(__pyx_k_bin), 0, 1, 0, 1},
  {&__pyx_n_u_bir, __pyx_k_bir, sizeof(__pyx_k_bir), 0, 1, 0, 1},
  {&__pyx_n_u_birbiri, __pyx_k_birbiri, sizeof(__pyx_k_birbiri), 0, 1, 0, 1},
  {&__pyx_n_u_birbirleri, __pyx_k_birbirleri, sizeof(__pyx_k_birbirleri), 0, 1, 0, 1},
  {&__pyx_n_u_biri, __pyx_k_biri, sizeof(__pyx_k_biri), 0, 1, 0, 1},
  {&__pyx_n_u_birka, __pyx_k_birka, sizeof(__pyx_k_birka), 0, 1, 0, 1},
  {&__pyx_n_u_biroklar, __pyx_k_biroklar, sizeof(__pyx_k_biroklar), 0, 1, 0, 1},
  {&__pyx_n_u_birou, __pyx_k_birou, sizeof(__pyx_k_birou), 0, 1, 0, 1},
  {&__pyx_n_u_biz, __pyx_k_biz, sizeof(__pyx_k_biz), 0, 1, 0, 1},
  {&__pyx_n_u_br, __pyx_k_br, sizeof(__pyx_k_br), 0, 1, 0, 1},
  {&__pyx_n_u_bu, __pyx_k_bu, sizeof(__pyx_k_bu), 0, 1, 0, 1},
  {&__pyx_n_u_bylesi, __pyx_k_bylesi, sizeof(__pyx_k_bylesi), 0, 1, 0, 1},
  {&__pyx_n_s_cacheSize, __pyx_k_cacheSize, sizeof(__pyx_k_cacheSize), 0, 0, 1, 1},
  {&__pyx_n_s_cline_in_traceback, __pyx_k_cline_in_traceback, sizeof(__pyx_k_cline_in_traceback), 0, 0, 1, 1},
  {&__pyx_n_u_cmlesi, __pyx_k_cmlesi, sizeof(__pyx_k_cmlesi), 0, 1, 0, 1},
  {&__pyx_n_s_compile, __pyx_k_compile, sizeof(__pyx_k_compile), 0, 0, 1, 1},
  {&__pyx_n_s_copy, __pyx_k_copy, sizeof(__pyx_k_copy), 0, 0, 1, 1},
  {&__pyx_n_s_currentFsmParse, __pyx_k_currentFsmParse, sizeof(__pyx_k_currentFsmParse), 0, 0, 1, 1},
  {&__pyx_kp_u_d, __pyx_k_d, sizeof(__pyx_k_d), 0, 1, 0, 0},
  {&__pyx_kp_u_d_d, __pyx_k_d_d, sizeof(__pyx_k_d_d), 0, 1, 0, 0},
  {&__pyx_kp_u_d_d_2, __pyx_k_d_d_2, sizeof(__pyx_k_d_d_2), 0, 1, 0, 0},
  {&__pyx_kp_u_d_d_3, __pyx_k_d_d_3, sizeof(__pyx_k_d_d_3), 0, 1, 0, 0},
  {&__pyx_kp_u_d_d_4, __pyx_k_d_d_4, sizeof(__pyx_k_d_d_4), 0, 1, 0, 0},
  {&__pyx_kp_u_d_d_d, __pyx_k_d_d_d, sizeof(__pyx_k_d_d_d), 0, 1, 0, 0},
  {&__pyx_kp_u_d_d_d_d, __pyx_k_d_d_d_d, sizeof(__pyx_k_d_d_d_d), 0, 1, 0, 0},
  {&__pyx_kp_u_d_d_d_d_d_d, __pyx_k_d_d_d_d_d_d, sizeof(__pyx_k_d_d_d_d_d_d), 0, 1, 0, 0},
  {&__pyx_kp_u_d_d_d_d_d_d_d, __pyx_k_d_d_d_d_d_d_d, sizeof(__pyx_k_d_d_d_d_d_d_d), 0, 1, 0, 0},
  {&__pyx_kp_u_d_d_d_d_d_d_d_2, __pyx_k_d_d_d_d_d_d_d_2, sizeof(__pyx_k_d_d_d_d_d_d_d_2), 0, 1, 0, 0},
  {&__pyx_kp_u_d_d_d_d_d_d_d_d_d, __pyx_k_d_d_d_d_d_d_d_d_d, sizeof(__pyx_k_d_d_d_d_d_d_d_d_d), 0, 1, 0, 0},
  {&__pyx_kp_u_d_d_d_d_d_d_d_d_d_d_d_d, __pyx_k_d_d_d_d_d_d_d_d_d_d_d_d, sizeof(__pyx_k_d_d_d_d_d_d_d_d_d_d_d_d), 0, 1, 0, 0},
  {&__pyx_kp_u_d_d_d_d_d_d_d_d_d_d_d_d_2, __pyx_k_d_d_d_d_d_d_d_d_d_d_d_d_2, sizeof(__pyx_k_d_d_d_d_d_d_d_d_d_d_d_d_2), 0, 1, 0, 0},
  {&__pyx_n_s_deepcopy, __pyx_k_deepcopy, sizeof(__pyx_k_deepcopy), 0, 0, 1, 1},
  {&__pyx_n_s_dict, __pyx_k_dict, sizeof(__pyx_k_dict), 0, 0, 1, 1},
  {&__pyx_n_s_dictionaryFileName, __pyx_k_dictionaryFileName, sizeof(__pyx_k_dictionaryFileName), 0, 0, 1, 1},
  {&__pyx_n_u_dieri, __pyx_k_dieri, sizeof(__pyx_k_dieri), 0, 1, 0, 1},
  {&__pyx_n_u_doksan, __pyx_k_doksan, sizeof(__pyx_k_doksan), 0, 1, 0, 1},
  {&__pyx_n_u_dokuz, __pyx_k_dokuz, sizeof(__pyx_k_dokuz), 0, 1, 0, 1},
  {&__pyx_n_u_drt, __pyx_k_drt, sizeof(__pyx_k_drt), 0, 1, 0, 1},
  {&__pyx_n_u_e, __pyx_k_e, sizeof(__pyx_k_e), 0, 1, 0, 1},
  {&__pyx_n_u_elli, __pyx_k_elli, sizeof(__pyx_k_elli), 0, 1, 0, 1},
  {&__pyx_n_s_expr, __pyx_k_expr, sizeof(__pyx_k_expr), 0, 0, 1, 1},
  {&__pyx_n_s_fileName, __pyx_k_fileName, sizeof(__pyx_k_fileName), 0, 0, 1, 1},
  {&__pyx_n_s_fsmParse, __pyx_k_fsmParse, sizeof(__pyx_k_fsmParse), 0, 0, 1, 1},
  {&__pyx_n_s_fullmatch, __pyx_k_fullmatch, sizeof(__pyx_k_fullmatch), 0, 0, 1, 1},
  {&__pyx_n_s_generateAllParses, __pyx_k_generateAllParses, sizeof(__pyx_k_generateAllParses), 0, 0, 1, 1},
  {&__pyx_n_s_getDictionary, __pyx_k_getDictionary, sizeof(__pyx_k_getDictionary), 0, 0, 1, 1},
  {&__pyx_n_s_getFiniteStateMachine, __pyx_k_getFiniteStateMachine, sizeof(__pyx_k_getFiniteStateMachine), 0, 0, 1, 1},
  {&__pyx_n_s_getPossibleWords, __pyx_k_getPossibleWords, sizeof(__pyx_k_getPossibleWords), 0, 0, 1, 1},
  {&__pyx_n_s_getstate, __pyx_k_getstate, sizeof(__pyx_k_getstate), 0, 0, 1, 1},
  {&__pyx_n_u_hangi, __pyx_k_hangi, sizeof(__pyx_k_hangi), 0, 1, 0, 1},
  {&__pyx_n_u_hep, __pyx_k_hep, sizeof(__pyx_k_hep), 0, 1, 0, 1},
  {&__pyx_n_u_hepsi, __pyx_k_hepsi, sizeof(__pyx_k_hepsi), 0, 1, 0, 1},
  {&__pyx_n_u_herkes, __pyx_k_herkes, sizeof(__pyx_k_herkes), 0, 1, 0, 1},
  {&__pyx_n_u_hibiri, __pyx_k_hibiri, sizeof(__pyx_k_hibiri), 0, 1, 0, 1},
  {&__pyx_n_u_i, __pyx_k_i, sizeof(__pyx_k_i), 0, 1, 0, 1},
  {&__pyx_n_u_iki, __pyx_k_iki, sizeof(__pyx_k_iki), 0, 1, 0, 1},
  {&__pyx_n_s_import, __pyx_k_import, sizeof(__pyx_k_import), 0, 0, 1, 1},
  {&__pyx_n_s_index, __pyx_k_index, sizeof(__pyx_k_index), 0, 0, 1, 1},
  {&__pyx_n_s_initializeParseList, __pyx_k_initializeParseList, sizeof(__pyx_k_initializeParseList), 0, 0, 1, 1},
  {&__pyx_n_s_initializeParseListFromRoot, __pyx_k_initializeParseListFromRoot, sizeof(__pyx_k_initializeParseListFromRoot), 0, 0, 1, 1},
  {&__pyx_n_s_initializeParseListFromSurface, __pyx_k_initializeParseListFromSurface, sizeof(__pyx_k_initializeParseListFromSurface), 0, 0, 1, 1},
  {&__pyx_n_s_isCapital, __pyx_k_isCapital, sizeof(__pyx_k_isCapital), 0, 0, 1, 1},
  {&__pyx_n_s_isDate, __pyx_k_isDate, sizeof(__pyx_k_isDate), 0, 0, 1, 1},
  {&__pyx_n_s_isDouble, __pyx_k_isDouble, sizeof(__pyx_k_isDouble), 0, 0, 1, 1},
  {&__pyx_n_s_isInteger, __pyx_k_isInteger, sizeof(__pyx_k_isInteger), 0, 0, 1, 1},
  {&__pyx_n_s_isNumber, __pyx_k_isNumber, sizeof(__pyx_k_isNumber), 0, 0, 1, 1},
  {&__pyx_n_s_isPercent, __pyx_k_isPercent, sizeof(__pyx_k_isPercent), 0, 0, 1, 1},
  {&__pyx_n_s_isPossibleSubstring, __pyx_k_isPossibleSubstring, sizeof(__pyx_k_isPossibleSubstring), 0, 0, 1, 1},
  {&__pyx_n_s_isProper, __pyx_k_isProper, sizeof(__pyx_k_isProper), 0, 0, 1, 1},
  {&__pyx_n_s_isProperNoun, __pyx_k_isProperNoun, sizeof(__pyx_k_isProperNoun), 0, 0, 1, 1},
  {&__pyx_n_s_isPunctuationSymbol, __pyx_k_isPunctuationSymbol, sizeof(__pyx_k_isPunctuationSymbol), 0, 0, 1, 1},
  {&__pyx_n_s_isRange, __pyx_k_isRange, sizeof(__pyx_k_isRange), 0, 0, 1, 1},
  {&__pyx_n_s_isTime, __pyx_k_isTime, sizeof(__pyx_k_isTime), 0, 0, 1, 1},
  {&__pyx_n_u_k, __pyx_k_k, sizeof(__pyx_k_k), 0, 1, 0, 1},
  {&__pyx_n_u_ka, __pyx_k_ka, sizeof(__pyx_k_ka), 0, 1, 0, 1},
  {&__pyx_n_u_katrilyon, __pyx_k_katrilyon, sizeof(__pyx_k_katrilyon), 0, 1, 0, 1},
  {&__pyx_n_u_kendi, __pyx_k_kendi, sizeof(__pyx_k_kendi), 0, 1, 0, 1},
  {&__pyx_n_u_kim, __pyx_k_kim, sizeof(__pyx_k_kim), 0, 1, 0, 1},
  {&__pyx_n_u_kimi, __pyx_k_kimi, sizeof(__pyx_k_kimi), 0, 1, 0, 1},
  {&__pyx_n_u_kimse, __pyx_k_kimse, sizeof(__pyx_k_kimse), 0, 1, 0, 1},
  {&__pyx_n_u_krk, __pyx_k_krk, sizeof(__pyx_k_krk), 0, 1, 0, 1},
  {&__pyx_n_u_lAr, __pyx_k_lAr, sizeof(__pyx_k_lAr), 0, 1, 0, 1},
  {&__pyx_n_s_longString, __pyx_k_longString, sizeof(__pyx_k_longString), 0, 0, 1, 1},
  {&__pyx_n_s_lower, __pyx_k_lower, sizeof(__pyx_k_lower), 0, 0, 1, 1},
  {&__pyx_n_u_mAk, __pyx_k_mAk, sizeof(__pyx_k_mAk), 0, 1, 0, 1},
  {&__pyx_n_s_main, __pyx_k_main, sizeof(__pyx_k_main), 0, 0, 1, 1},
  {&__pyx_n_s_maxLength, __pyx_k_maxLength, sizeof(__pyx_k_maxLength), 0, 0, 1, 1},
  {&__pyx_n_s_maxLengthOrSurfaceForm, __pyx_k_maxLengthOrSurfaceForm, sizeof(__pyx_k_maxLengthOrSurfaceForm), 0, 0, 1, 1},
  {&__pyx_n_s_metamorphicParse, __pyx_k_metamorphicParse, sizeof(__pyx_k_metamorphicParse), 0, 0, 1, 1},
  {&__pyx_n_u_milyar, __pyx_k_milyar, sizeof(__pyx_k_milyar), 0, 1, 0, 1},
  {&__pyx_n_u_milyon, __pyx_k_milyon, sizeof(__pyx_k_milyon), 0, 1, 0, 1},
  {&__pyx_n_s_misspelledFileName, __pyx_k_misspelledFileName, sizeof(__pyx_k_misspelledFileName), 0, 0, 1, 1},
  {&__pyx_n_s_morphologicalAnalysis, __pyx_k_morphologicalAnalysis, sizeof(__pyx_k_morphologicalAnalysis), 0, 0, 1, 1},
  {&__pyx_n_s_morphologicalAnalysisExists, __pyx_k_morphologicalAnalysisExists, sizeof(__pyx_k_morphologicalAnalysisExists), 0, 0, 1, 1},
  {&__pyx_n_s_morphologicalAnalysisRoot, __pyx_k_morphologicalAnalysisRoot, sizeof(__pyx_k_morphologicalAnalysisRoot), 0, 0, 1, 1},
  {&__pyx_n_s_morphologicalParse, __pyx_k_morphologicalParse, sizeof(__pyx_k_morphologicalParse), 0, 0, 1, 1},
  {&__pyx_n_s_name, __pyx_k_name, sizeof(__pyx_k_name), 0, 0, 1, 1},
  {&__pyx_n_u_ne, __pyx_k_ne, sizeof(__pyx_k_ne), 0, 1, 0, 1},
  {&__pyx_n_u_nere, __pyx_k_nere, sizeof(__pyx_k_nere), 0, 1, 0, 1},
  {&__pyx_n_s_new, __pyx_k_new, sizeof(__pyx_k_new), 0, 0, 1, 1},
  {&__pyx_n_u_o, __pyx_k_o, sizeof(__pyx_k_o), 0, 1, 0, 1},
  {&__pyx_n_u_on, __pyx_k_on, sizeof(__pyx_k_on), 0, 1, 0, 1},
  {&__pyx_n_u_onlar, __pyx_k_onlar, sizeof(__pyx_k_onlar), 0, 1, 0, 1},
  {&__pyx_n_s_open, __pyx_k_open, sizeof(__pyx_k_open), 0, 0, 1, 1},
  {&__pyx_n_u_otuz, __pyx_k_otuz, sizeof(__pyx_k_otuz), 0, 1, 0, 1},
  {&__pyx_n_u_ou, __pyx_k_ou, sizeof(__pyx_k_ou), 0, 1, 0, 1},
  {&__pyx_n_u_p, __pyx_k_p, sizeof(__pyx_k_p), 0, 1, 0, 1},
  {&__pyx_n_s_parseExists, __pyx_k_parseExists, sizeof(__pyx_k_parseExists), 0, 0, 1, 1},
  {&__pyx_n_s_parseList, __pyx_k_parseList, sizeof(__pyx_k_parseList), 0, 0, 1, 1},
  {&__pyx_n_s_parseWord, __pyx_k_parseWord, sizeof(__pyx_k_parseWord), 0, 0, 1, 1},
  {&__pyx_n_s_patternMatches, __pyx_k_patternMatches, sizeof(__pyx_k_patternMatches), 0, 0, 1, 1},
  {&__pyx_n_s_pickle, __pyx_k_pickle, sizeof(__pyx_k_pickle), 0, 0, 1, 1},
  {&__pyx_n_s_pop, __pyx_k_pop, sizeof(__pyx_k_pop), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_PickleError, __pyx_k_pyx_PickleError, sizeof(__pyx_k_pyx_PickleError), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_checksum, __pyx_k_pyx_checksum, sizeof(__pyx_k_pyx_checksum), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_result, __pyx_k_pyx_result, sizeof(__pyx_k_pyx_result), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_state, __pyx_k_pyx_state, sizeof(__pyx_k_pyx_state), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_type, __pyx_k_pyx_type, sizeof(__pyx_k_pyx_type), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_unpickle_FsmMorphologicalA, __pyx_k_pyx_unpickle_FsmMorphologicalA, sizeof(__pyx_k_pyx_unpickle_FsmMorphologicalA), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_vtable, __pyx_k_pyx_vtable, sizeof(__pyx_k_pyx_vtable), 0, 0, 1, 1},
  {&__pyx_n_u_r, __pyx_k_r, sizeof(__pyx_k_r), 0, 1, 0, 1},
  {&__pyx_n_s_range, __pyx_k_range, sizeof(__pyx_k_range), 0, 0, 1, 1},
  {&__pyx_n_s_re, __pyx_k_re, sizeof(__pyx_k_re), 0, 0, 1, 1},
  {&__pyx_n_s_readlines, __pyx_k_readlines, sizeof(__pyx_k_readlines), 0, 0, 1, 1},
  {&__pyx_n_s_reduce, __pyx_k_reduce, sizeof(__pyx_k_reduce), 0, 0, 1, 1},
  {&__pyx_n_s_reduce_cython, __pyx_k_reduce_cython, sizeof(__pyx_k_reduce_cython), 0, 0, 1, 1},
  {&__pyx_n_s_reduce_ex, __pyx_k_reduce_ex, sizeof(__pyx_k_reduce_ex), 0, 0, 1, 1},
  {&__pyx_n_s_robustMorphologicalAnalysis, __pyx_k_robustMorphologicalAnalysis, sizeof(__pyx_k_robustMorphologicalAnalysis), 0, 0, 1, 1},
  {&__pyx_n_s_root, __pyx_k_root, sizeof(__pyx_k_root), 0, 0, 1, 1},
  {&__pyx_n_s_rootWord, __pyx_k_rootWord, sizeof(__pyx_k_rootWord), 0, 0, 1, 1},
  {&__pyx_n_u_sekiz, __pyx_k_sekiz, sizeof(__pyx_k_sekiz), 0, 1, 0, 1},
  {&__pyx_n_u_seksen, __pyx_k_seksen, sizeof(__pyx_k_seksen), 0, 1, 0, 1},
  {&__pyx_n_u_sen, __pyx_k_sen, sizeof(__pyx_k_sen), 0, 1, 0, 1},
  {&__pyx_n_s_setstate, __pyx_k_setstate, sizeof(__pyx_k_setstate), 0, 0, 1, 1},
  {&__pyx_n_s_setstate_cython, __pyx_k_setstate_cython, sizeof(__pyx_k_setstate_cython), 0, 0, 1, 1},
  {&__pyx_n_s_shortString, __pyx_k_shortString, sizeof(__pyx_k_shortString), 0, 0, 1, 1},
  {&__pyx_n_u_siz, __pyx_k_siz, sizeof(__pyx_k_siz), 0, 1, 0, 1},
  {&__pyx_n_s_state, __pyx_k_state, sizeof(__pyx_k_state), 0, 0, 1, 1},
  {&__pyx_n_s_str, __pyx_k_str, sizeof(__pyx_k_str), 0, 0, 1, 1},
  {&__pyx_kp_s_stringsource, __pyx_k_stringsource, sizeof(__pyx_k_stringsource), 0, 0, 1, 0},
  {&__pyx_n_s_strip, __pyx_k_strip, sizeof(__pyx_k_strip), 0, 0, 1, 1},
  {&__pyx_n_s_suffixList, __pyx_k_suffixList, sizeof(__pyx_k_suffixList), 0, 0, 1, 1},
  {&__pyx_n_s_surfaceForm, __pyx_k_surfaceForm, sizeof(__pyx_k_surfaceForm), 0, 0, 1, 1},
  {&__pyx_n_u_t, __pyx_k_t, sizeof(__pyx_k_t), 0, 1, 0, 1},
  {&__pyx_n_u_teki, __pyx_k_teki, sizeof(__pyx_k_teki), 0, 1, 0, 1},
  {&__pyx_n_s_test, __pyx_k_test, sizeof(__pyx_k_test), 0, 0, 1, 1},
  {&__pyx_n_u_tm, __pyx_k_tm, sizeof(__pyx_k_tm), 0, 1, 0, 1},
  {&__pyx_n_s_toLower, __pyx_k_toLower, sizeof(__pyx_k_toLower), 0, 0, 1, 1},
  {&__pyx_n_u_topu, __pyx_k_topu, sizeof(__pyx_k_topu), 0, 1, 0, 1},
  {&__pyx_n_s_transitionPossibleWord, __pyx_k_transitionPossibleWord, sizeof(__pyx_k_transitionPossibleWord), 0, 0, 1, 1},
  {&__pyx_n_u_trilyon, __pyx_k_trilyon, sizeof(__pyx_k_trilyon), 0, 1, 0, 1},
  {&__pyx_kp_u_turkish_finite_state_machine_xml, __pyx_k_turkish_finite_state_machine_xml, sizeof(__pyx_k_turkish_finite_state_machine_xml), 0, 1, 0, 0},
  {&__pyx_n_u_u, __pyx_k_u, sizeof(__pyx_k_u), 0, 1, 0, 1},
  {&__pyx_n_s_update, __pyx_k_update, sizeof(__pyx_k_update), 0, 0, 1, 1},
  {&__pyx_n_s_value, __pyx_k_value, sizeof(__pyx_k_value), 0, 0, 1, 1},
  {&__pyx_kp_u_w, __pyx_k_w, sizeof(__pyx_k_w), 0, 1, 0, 0},
  {&__pyx_n_u_yedi, __pyx_k_yedi, sizeof(__pyx_k_yedi), 0, 1, 0, 1},
  {&__pyx_n_u_yetmi, __pyx_k_yetmi, sizeof(__pyx_k_yetmi), 0, 1, 0, 1},
  {&__pyx_n_u_yirmi, __pyx_k_yirmi, sizeof(__pyx_k_yirmi), 0, 1, 0, 1},
  {&__pyx_n_u_yz, __pyx_k_yz, sizeof(__pyx_k_yz), 0, 1, 0, 1},
  {0, 0, 0, 0, 0, 0, 0}
};
static CYTHON_SMALL_CODE int __Pyx_InitCachedBuiltins(void) {
  __pyx_builtin_open = __Pyx_GetBuiltinName(__pyx_n_s_open); if (!__pyx_builtin_open) __PYX_ERR(0, 48, __pyx_L1_error)
  __pyx_builtin_range = __Pyx_GetBuiltinName(__pyx_n_s_range); if (!__pyx_builtin_range) __PYX_ERR(0, 107, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}

static CYTHON_SMALL_CODE int __Pyx_InitCachedConstants(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_InitCachedConstants", 0);

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":88
 *         isRootVerb = morphologicalParse.getRootPos() == "VERB"
 *         containsVerb = morphologicalParse.containsTag(MorphologicalTag.VERB)
 *         verbTransition = Transition("mAk")             # <<<<<<<<<<<<<<
 *         result = set()
 *         if metamorphicParse is None or metamorphicParse.getWord() is None:
 */
  __pyx_tuple_ = PyTuple_Pack(1, __pyx_n_u_mAk); if (unlikely(!__pyx_tuple_)) __PYX_ERR(0, 88, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple_);
  __Pyx_GIVEREF(__pyx_tuple_);

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":794
 *         if Word.isPunctuationSymbol(surfaceForm) and surfaceForm != "%":
 *             initialFsmParse = []
 *             fsmParse = FsmParse(surfaceForm, State("Punctuation", True, True))             # <<<<<<<<<<<<<<
 *             fsmParse.constructInflectionalGroups()
 *             initialFsmParse.append(fsmParse)
 */
  __pyx_tuple__6 = PyTuple_Pack(3, __pyx_n_u_Punctuation, Py_True, Py_True); if (unlikely(!__pyx_tuple__6)) __PYX_ERR(0, 794, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__6);
  __Pyx_GIVEREF(__pyx_tuple__6);

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":800
 *         if self.__isNumber(surfaceForm):
 *             initialFsmParse = []
 *             fsmParse = FsmParse(surfaceForm, State("CardinalRoot", True, True))             # <<<<<<<<<<<<<<
 *             fsmParse.constructInflectionalGroups()
 *             initialFsmParse.append(fsmParse)
 */
  __pyx_tuple__7 = PyTuple_Pack(3, __pyx_n_u_CardinalRoot, Py_True, Py_True); if (unlikely(!__pyx_tuple__7)) __PYX_ERR(0, 800, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__7);
  __Pyx_GIVEREF(__pyx_tuple__7);

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":806
 *         if self.patternMatches("\\d+/\\d+", surfaceForm):
 *             initialFsmParse = []
 *             fsmParse = FsmParse(surfaceForm, State("FractionRoot", True, True))             # <<<<<<<<<<<<<<
 *             fsmParse.constructInflectionalGroups()
 *             initialFsmParse.append(fsmParse)
 */
  __pyx_tuple__8 = PyTuple_Pack(3, __pyx_n_u_FractionRoot, Py_True, Py_True); if (unlikely(!__pyx_tuple__8)) __PYX_ERR(0, 806, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__8);
  __Pyx_GIVEREF(__pyx_tuple__8);

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":809
 *             fsmParse.constructInflectionalGroups()
 *             initialFsmParse.append(fsmParse)
 *             fsmParse = FsmParse(surfaceForm, State("DateRoot", True, True))             # <<<<<<<<<<<<<<
 *             fsmParse.constructInflectionalGroups()
 *             initialFsmParse.append(fsmParse)
 */
  __pyx_tuple__9 = PyTuple_Pack(3, __pyx_n_u_DateRoot, Py_True, Py_True); if (unlikely(!__pyx_tuple__9)) __PYX_ERR(0, 809, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__9);
  __Pyx_GIVEREF(__pyx_tuple__9);

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":827
 *         if surfaceForm == "%" or self.__isPercent(surfaceForm):
 *             initialFsmParse = []
 *             fsmParse = FsmParse(surfaceForm, State("PercentRoot", True, True))             # <<<<<<<<<<<<<<
 *             fsmParse.constructInflectionalGroups()
 *             initialFsmParse.append(fsmParse)
 */
  __pyx_tuple__10 = PyTuple_Pack(3, __pyx_n_u_PercentRoot, Py_True, Py_True); if (unlikely(!__pyx_tuple__10)) __PYX_ERR(0, 827, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__10);
  __Pyx_GIVEREF(__pyx_tuple__10);

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":833
 *         if self.__isTime(surfaceForm):
 *             initialFsmParse = []
 *             fsmParse = FsmParse(surfaceForm, State("TimeRoot", True, True))             # <<<<<<<<<<<<<<
 *             fsmParse.constructInflectionalGroups()
 *             initialFsmParse.append(fsmParse)
 */
  __pyx_tuple__11 = PyTuple_Pack(3, __pyx_n_u_TimeRoot, Py_True, Py_True); if (unlikely(!__pyx_tuple__11)) __PYX_ERR(0, 833, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__11);
  __Pyx_GIVEREF(__pyx_tuple__11);

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":839
 *         if self.__isRange(surfaceForm):
 *             initialFsmParse = []
 *             fsmParse = FsmParse(surfaceForm, State("RangeRoot", True, True))             # <<<<<<<<<<<<<<
 *             fsmParse.constructInflectionalGroups()
 *             initialFsmParse.append(fsmParse)
 */
  __pyx_tuple__12 = PyTuple_Pack(3, __pyx_n_u_RangeRoot, Py_True, Py_True); if (unlikely(!__pyx_tuple__12)) __PYX_ERR(0, 839, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__12);
  __Pyx_GIVEREF(__pyx_tuple__12);

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":845
 *         if surfaceForm.startswith("#"):
 *             initialFsmParse = []
 *             fsmParse = FsmParse(surfaceForm, State("Hashtag", True, True))             # <<<<<<<<<<<<<<
 *             fsmParse.constructInflectionalGroups()
 *             initialFsmParse.append(fsmParse)
 */
  __pyx_tuple__14 = PyTuple_Pack(3, __pyx_n_u_Hashtag, Py_True, Py_True); if (unlikely(!__pyx_tuple__14)) __PYX_ERR(0, 845, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__14);
  __Pyx_GIVEREF(__pyx_tuple__14);

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":851
 *         if "@" in surfaceForm:
 *             initialFsmParse = []
 *             fsmParse = FsmParse(surfaceForm, State("Email", True, True))             # <<<<<<<<<<<<<<
 *             fsmParse.constructInflectionalGroups()
 *             initialFsmParse.append(fsmParse)
 */
  __pyx_tuple__16 = PyTuple_Pack(3, __pyx_n_u_Email, Py_True, Py_True); if (unlikely(!__pyx_tuple__16)) __PYX_ERR(0, 851, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__16);
  __Pyx_GIVEREF(__pyx_tuple__16);

  /* "(tree fragment)":1
 * def __pyx_unpickle_FsmMorphologicalAnalyzer(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */
  __pyx_tuple__24 = PyTuple_Pack(5, __pyx_n_s_pyx_type, __pyx_n_s_pyx_checksum, __pyx_n_s_pyx_state, __pyx_n_s_pyx_PickleError, __pyx_n_s_pyx_result); if (unlikely(!__pyx_tuple__24)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__24);
  __Pyx_GIVEREF(__pyx_tuple__24);
  __pyx_codeobj__25 = (PyObject*)__Pyx_PyCode_New(3, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_pyx_unpickle_FsmMorphologicalA, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__25)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}

static CYTHON_SMALL_CODE int __Pyx_InitGlobals(void) {
  __pyx_umethod_PyUnicode_Type_index.type = (PyObject*)&PyUnicode_Type;
  __pyx_umethod_PyUnicode_Type_strip.type = (PyObject*)&PyUnicode_Type;
  if (__Pyx_InitStrings(__pyx_string_tab) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  __pyx_int_0 = PyInt_FromLong(0); if (unlikely(!__pyx_int_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_1 = PyInt_FromLong(1); if (unlikely(!__pyx_int_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_2 = PyInt_FromLong(2); if (unlikely(!__pyx_int_2)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_10000000 = PyInt_FromLong(10000000L); if (unlikely(!__pyx_int_10000000)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_213759171 = PyInt_FromLong(213759171L); if (unlikely(!__pyx_int_213759171)) __PYX_ERR(0, 1, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}

static CYTHON_SMALL_CODE int __Pyx_modinit_global_init_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_export_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_export_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_init_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_import_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_import_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_import_code(void); /*proto*/

static int __Pyx_modinit_global_init_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_global_init_code", 0);
  /*--- Global init code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_variable_export_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_export_code", 0);
  /*--- Variable export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_export_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_export_code", 0);
  /*--- Function export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_type_init_code(void) {
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_init_code", 0);
  /*--- Type init code ---*/
  __pyx_vtabptr_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer = &__pyx_vtable_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer;
  __pyx_vtable_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer.addParsedSurfaceForms = (PyObject *(*)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, PyObject *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_addParsedSurfaceForms;
  __pyx_vtable_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer.getPossibleWords = (PyObject *(*)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, struct __pyx_obj_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_getPossibleWords;
  __pyx_vtable_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer.getDictionary = (struct __pyx_obj_10Dictionary_13TxtDictionary_TxtDictionary *(*)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_getDictionary;
  __pyx_vtable_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer.getFiniteStateMachine = (struct __pyx_obj_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine *(*)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_getFiniteStateMachine;
  __pyx_vtable_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer.__pyx___isPossibleSubstring = (int (*)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, PyObject *, PyObject *, struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer___isPossibleSubstring;
  __pyx_vtable_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer.__pyx___initializeParseList = (PyObject *(*)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, PyObject *, struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer___initializeParseList;
  __pyx_vtable_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer.__pyx___initializeParseListFromRoot = (PyObject *(*)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, PyObject *, struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer___initializeParseListFromRoot;
  __pyx_vtable_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer.__pyx___initializeParseListFromSurfaceForm = (PyObject *(*)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, PyObject *, int, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer___initializeParseListFromSurfaceForm;
  __pyx_vtable_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer.__pyx___addNewParsesFromCurrentParse = (PyObject *(*)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, PyObject *, PyObject *, struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer___addNewParsesFromCurrentParse;
  __pyx_vtable_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer.__pyx___parseExists = (int (*)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, PyObject *, PyObject *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer___parseExists;
  __pyx_vtable_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer.__pyx___parseWord = (PyObject *(*)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, PyObject *, PyObject *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer___parseWord;
  __pyx_vtable_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer.morphologicalAnalysisRoot = (PyObject *(*)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, PyObject *, struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch, struct __pyx_opt_args_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_morphologicalAnalysisRoot *__pyx_optional_args))__pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_morphologicalAnalysisRoot;
  __pyx_vtable_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer.generateAllParses = (PyObject *(*)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_generateAllParses;
  __pyx_vtable_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer.__pyx___analysisExists = (int (*)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, PyObject *, int, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer___analysisExists;
  __pyx_vtable_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer.__pyx___analysis = (PyObject *(*)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, PyObject *, int, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer___analysis;
  __pyx_vtable_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer.patternMatches = (int (*)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, PyObject *, PyObject *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_patternMatches;
  __pyx_vtable_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer.isProperNoun = (int (*)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, PyObject *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_isProperNoun;
  __pyx_vtable_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer.morphologicalAnalysis = (PyObject *(*)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, PyObject *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_morphologicalAnalysis;
  __pyx_vtable_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer.robustMorphologicalAnalysis = (PyObject *(*)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, PyObject *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_robustMorphologicalAnalysis;
  __pyx_vtable_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer.__pyx___isInteger = (int (*)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, PyObject *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer___isInteger;
  __pyx_vtable_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer.__pyx___isDouble = (int (*)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, PyObject *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer___isDouble;
  __pyx_vtable_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer.__pyx___isNumber = (int (*)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, PyObject *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer___isNumber;
  __pyx_vtable_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer.__pyx___isPercent = (int (*)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, PyObject *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer___isPercent;
  __pyx_vtable_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer.__pyx___isTime = (int (*)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, PyObject *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer___isTime;
  __pyx_vtable_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer.__pyx___isRange = (int (*)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, PyObject *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer___isRange;
  __pyx_vtable_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer.__pyx___isDate = (int (*)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, PyObject *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer___isDate;
  __pyx_vtable_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer.__pyx___toLower = (PyObject *(*)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, PyObject *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer___toLower;
  __pyx_vtable_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer.morphologicalAnalysisExists = (int (*)(struct __pyx_obj_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer *, struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, PyObject *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer_morphologicalAnalysisExists;
  if (PyType_Ready(&__pyx_type_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer) < 0) __PYX_ERR(0, 13, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer.tp_dictoffset && __pyx_type_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #if CYTHON_COMPILING_IN_CPYTHON
  {
    PyObject *wrapper = PyObject_GetAttrString((PyObject *)&__pyx_type_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer, "__init__"); if (unlikely(!wrapper)) __PYX_ERR(0, 13, __pyx_L1_error)
    if (Py_TYPE(wrapper) == &PyWrapperDescr_Type) {
      __pyx_wrapperbase_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer___init__ = *((PyWrapperDescrObject *)wrapper)->d_base;
      __pyx_wrapperbase_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer___init__.doc = __pyx_doc_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer___init__;
      ((PyWrapperDescrObject *)wrapper)->d_base = &__pyx_wrapperbase_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_24FsmMorphologicalAnalyzer___init__;
    }
  }
  #endif
  if (__Pyx_SetVtable(__pyx_type_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer.tp_dict, __pyx_vtabptr_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer) < 0) __PYX_ERR(0, 13, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_FsmMorphologicalAnalyzer, (PyObject *)&__pyx_type_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer) < 0) __PYX_ERR(0, 13, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject*)&__pyx_type_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer) < 0) __PYX_ERR(0, 13, __pyx_L1_error)
  __pyx_ptype_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer = &__pyx_type_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer;
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_type_import_code(void) {
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_import_code", 0);
  /*--- Type import code ---*/
  __pyx_t_1 = PyImport_ImportModule("Dictionary.Word"); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_10Dictionary_4Word_Word = __Pyx_ImportType(__pyx_t_1, "Dictionary.Word", "Word", sizeof(struct __pyx_obj_10Dictionary_4Word_Word), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_10Dictionary_4Word_Word) __PYX_ERR(2, 1, __pyx_L1_error)
  __pyx_vtabptr_10Dictionary_4Word_Word = (struct __pyx_vtabstruct_10Dictionary_4Word_Word*)__Pyx_GetVtable(__pyx_ptype_10Dictionary_4Word_Word->tp_dict); if (unlikely(!__pyx_vtabptr_10Dictionary_4Word_Word)) __PYX_ERR(2, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("Dictionary.Trie.TrieNode"); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_10Dictionary_4Trie_8TrieNode_TrieNode = __Pyx_ImportType(__pyx_t_1, "Dictionary.Trie.TrieNode", "TrieNode", sizeof(struct __pyx_obj_10Dictionary_4Trie_8TrieNode_TrieNode), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_10Dictionary_4Trie_8TrieNode_TrieNode) __PYX_ERR(3, 4, __pyx_L1_error)
  __pyx_vtabptr_10Dictionary_4Trie_8TrieNode_TrieNode = (struct __pyx_vtabstruct_10Dictionary_4Trie_8TrieNode_TrieNode*)__Pyx_GetVtable(__pyx_ptype_10Dictionary_4Trie_8TrieNode_TrieNode->tp_dict); if (unlikely(!__pyx_vtabptr_10Dictionary_4Trie_8TrieNode_TrieNode)) __PYX_ERR(3, 4, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("Dictionary.TxtWord"); if (unlikely(!__pyx_t_1)) __PYX_ERR(4, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_10Dictionary_7TxtWord_TxtWord = __Pyx_ImportType(__pyx_t_1, "Dictionary.TxtWord", "TxtWord", sizeof(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_10Dictionary_7TxtWord_TxtWord) __PYX_ERR(4, 4, __pyx_L1_error)
  __pyx_vtabptr_10Dictionary_7TxtWord_TxtWord = (struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord*)__Pyx_GetVtable(__pyx_ptype_10Dictionary_7TxtWord_TxtWord->tp_dict); if (unlikely(!__pyx_vtabptr_10Dictionary_7TxtWord_TxtWord)) __PYX_ERR(4, 4, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("Dictionary.Trie.Trie"); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_10Dictionary_4Trie_4Trie_Trie = __Pyx_ImportType(__pyx_t_1, "Dictionary.Trie.Trie", "Trie", sizeof(struct __pyx_obj_10Dictionary_4Trie_4Trie_Trie), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_10Dictionary_4Trie_4Trie_Trie) __PYX_ERR(5, 6, __pyx_L1_error)
  __pyx_vtabptr_10Dictionary_4Trie_4Trie_Trie = (struct __pyx_vtabstruct_10Dictionary_4Trie_4Trie_Trie*)__Pyx_GetVtable(__pyx_ptype_10Dictionary_4Trie_4Trie_Trie->tp_dict); if (unlikely(!__pyx_vtabptr_10Dictionary_4Trie_4Trie_Trie)) __PYX_ERR(5, 6, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("Dictionary.Dictionary"); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_10Dictionary_10Dictionary_Dictionary = __Pyx_ImportType(__pyx_t_1, "Dictionary.Dictionary", "Dictionary", sizeof(struct __pyx_obj_10Dictionary_10Dictionary_Dictionary), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_10Dictionary_10Dictionary_Dictionary) __PYX_ERR(6, 4, __pyx_L1_error)
  __pyx_vtabptr_10Dictionary_10Dictionary_Dictionary = (struct __pyx_vtabstruct_10Dictionary_10Dictionary_Dictionary*)__Pyx_GetVtable(__pyx_ptype_10Dictionary_10Dictionary_Dictionary->tp_dict); if (unlikely(!__pyx_vtabptr_10Dictionary_10Dictionary_Dictionary)) __PYX_ERR(6, 4, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("Dictionary.TxtDictionary"); if (unlikely(!__pyx_t_1)) __PYX_ERR(7, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_10Dictionary_13TxtDictionary_TxtDictionary = __Pyx_ImportType(__pyx_t_1, "Dictionary.TxtDictionary", "TxtDictionary", sizeof(struct __pyx_obj_10Dictionary_13TxtDictionary_TxtDictionary), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_10Dictionary_13TxtDictionary_TxtDictionary) __PYX_ERR(7, 7, __pyx_L1_error)
  __pyx_vtabptr_10Dictionary_13TxtDictionary_TxtDictionary = (struct __pyx_vtabstruct_10Dictionary_13TxtDictionary_TxtDictionary*)__Pyx_GetVtable(__pyx_ptype_10Dictionary_13TxtDictionary_TxtDictionary->tp_dict); if (unlikely(!__pyx_vtabptr_10Dictionary_13TxtDictionary_TxtDictionary)) __PYX_ERR(7, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("DataStructure.Cache.LRUCache"); if (unlikely(!__pyx_t_1)) __PYX_ERR(8, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_13DataStructure_5Cache_8LRUCache_LRUCache = __Pyx_ImportType(__pyx_t_1, "DataStructure.Cache.LRUCache", "LRUCache", sizeof(struct __pyx_obj_13DataStructure_5Cache_8LRUCache_LRUCache), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_13DataStructure_5Cache_8LRUCache_LRUCache) __PYX_ERR(8, 1, __pyx_L1_error)
  __pyx_vtabptr_13DataStructure_5Cache_8LRUCache_LRUCache = (struct __pyx_vtabstruct_13DataStructure_5Cache_8LRUCache_LRUCache*)__Pyx_GetVtable(__pyx_ptype_13DataStructure_5Cache_8LRUCache_LRUCache->tp_dict); if (unlikely(!__pyx_vtabptr_13DataStructure_5Cache_8LRUCache_LRUCache)) __PYX_ERR(8, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("MorphologicalAnalysis.InflectionalGroup"); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup = __Pyx_ImportType(__pyx_t_1, "MorphologicalAnalysis.InflectionalGroup", "InflectionalGroup", sizeof(struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup) __PYX_ERR(9, 1, __pyx_L1_error)
  __pyx_vtabptr_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup = (struct __pyx_vtabstruct_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup*)__Pyx_GetVtable(__pyx_ptype_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup->tp_dict); if (unlikely(!__pyx_vtabptr_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup)) __PYX_ERR(9, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("MorphologicalAnalysis.MorphologicalParse"); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse = __Pyx_ImportType(__pyx_t_1, "MorphologicalAnalysis.MorphologicalParse", "MorphologicalParse", sizeof(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse) __PYX_ERR(10, 7, __pyx_L1_error)
  __pyx_vtabptr_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse = (struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse*)__Pyx_GetVtable(__pyx_ptype_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse->tp_dict); if (unlikely(!__pyx_vtabptr_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse)) __PYX_ERR(10, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("MorphologicalAnalysis.State"); if (unlikely(!__pyx_t_1)) __PYX_ERR(11, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_21MorphologicalAnalysis_5State_State = __Pyx_ImportType(__pyx_t_1, "MorphologicalAnalysis.State", "State", sizeof(struct __pyx_obj_21MorphologicalAnalysis_5State_State), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_21MorphologicalAnalysis_5State_State) __PYX_ERR(11, 1, __pyx_L1_error)
  __pyx_vtabptr_21MorphologicalAnalysis_5State_State = (struct __pyx_vtabstruct_21MorphologicalAnalysis_5State_State*)__Pyx_GetVtable(__pyx_ptype_21MorphologicalAnalysis_5State_State->tp_dict); if (unlikely(!__pyx_vtabptr_21MorphologicalAnalysis_5State_State)) __PYX_ERR(11, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("MorphologicalAnalysis.FsmParse"); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse = __Pyx_ImportType(__pyx_t_1, "MorphologicalAnalysis.FsmParse", "FsmParse", sizeof(struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse) __PYX_ERR(12, 5, __pyx_L1_error)
  __pyx_vtabptr_21MorphologicalAnalysis_8FsmParse_FsmParse = (struct __pyx_vtabstruct_21MorphologicalAnalysis_8FsmParse_FsmParse*)__Pyx_GetVtable(__pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse->tp_dict); if (unlikely(!__pyx_vtabptr_21MorphologicalAnalysis_8FsmParse_FsmParse)) __PYX_ERR(12, 5, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("MorphologicalAnalysis.FiniteStateMachine"); if (unlikely(!__pyx_t_1)) __PYX_ERR(13, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine = __Pyx_ImportType(__pyx_t_1, "MorphologicalAnalysis.FiniteStateMachine", "FiniteStateMachine", sizeof(struct __pyx_obj_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine) __PYX_ERR(13, 4, __pyx_L1_error)
  __pyx_vtabptr_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine = (struct __pyx_vtabstruct_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine*)__Pyx_GetVtable(__pyx_ptype_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine->tp_dict); if (unlikely(!__pyx_vtabptr_21MorphologicalAnalysis_18FiniteStateMachine_FiniteStateMachine)) __PYX_ERR(13, 4, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("MorphologicalAnalysis.MetamorphicParse"); if (unlikely(!__pyx_t_1)) __PYX_ERR(14, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse = __Pyx_ImportType(__pyx_t_1, "MorphologicalAnalysis.MetamorphicParse", "MetamorphicParse", sizeof(struct __pyx_obj_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse) __PYX_ERR(14, 6, __pyx_L1_error)
  __pyx_vtabptr_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse = (struct __pyx_vtabstruct_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse*)__Pyx_GetVtable(__pyx_ptype_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse->tp_dict); if (unlikely(!__pyx_vtabptr_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse)) __PYX_ERR(14, 6, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("Corpus.Sentence"); if (unlikely(!__pyx_t_1)) __PYX_ERR(15, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6Corpus_8Sentence_Sentence = __Pyx_ImportType(__pyx_t_1, "Corpus.Sentence", "Sentence", sizeof(struct __pyx_obj_6Corpus_8Sentence_Sentence), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_6Corpus_8Sentence_Sentence) __PYX_ERR(15, 4, __pyx_L1_error)
  __pyx_vtabptr_6Corpus_8Sentence_Sentence = (struct __pyx_vtabstruct_6Corpus_8Sentence_Sentence*)__Pyx_GetVtable(__pyx_ptype_6Corpus_8Sentence_Sentence->tp_dict); if (unlikely(!__pyx_vtabptr_6Corpus_8Sentence_Sentence)) __PYX_ERR(15, 4, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("MorphologicalAnalysis.FsmParseList"); if (unlikely(!__pyx_t_1)) __PYX_ERR(16, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_21MorphologicalAnalysis_12FsmParseList_FsmParseList = __Pyx_ImportType(__pyx_t_1, "MorphologicalAnalysis.FsmParseList", "FsmParseList", sizeof(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_21MorphologicalAnalysis_12FsmParseList_FsmParseList) __PYX_ERR(16, 4, __pyx_L1_error)
  __pyx_vtabptr_21MorphologicalAnalysis_12FsmParseList_FsmParseList = (struct __pyx_vtabstruct_21MorphologicalAnalysis_12FsmParseList_FsmParseList*)__Pyx_GetVtable(__pyx_ptype_21MorphologicalAnalysis_12FsmParseList_FsmParseList->tp_dict); if (unlikely(!__pyx_vtabptr_21MorphologicalAnalysis_12FsmParseList_FsmParseList)) __PYX_ERR(16, 4, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("MorphologicalAnalysis.Transition"); if (unlikely(!__pyx_t_1)) __PYX_ERR(17, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_21MorphologicalAnalysis_10Transition_Transition = __Pyx_ImportType(__pyx_t_1, "MorphologicalAnalysis.Transition", "Transition", sizeof(struct __pyx_obj_21MorphologicalAnalysis_10Transition_Transition), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_21MorphologicalAnalysis_10Transition_Transition) __PYX_ERR(17, 6, __pyx_L1_error)
  __pyx_vtabptr_21MorphologicalAnalysis_10Transition_Transition = (struct __pyx_vtabstruct_21MorphologicalAnalysis_10Transition_Transition*)__Pyx_GetVtable(__pyx_ptype_21MorphologicalAnalysis_10Transition_Transition->tp_dict); if (unlikely(!__pyx_vtabptr_21MorphologicalAnalysis_10Transition_Transition)) __PYX_ERR(17, 6, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_variable_import_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_import_code", 0);
  /*--- Variable import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_import_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_import_code", 0);
  /*--- Function import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}


#ifndef CYTHON_NO_PYINIT_EXPORT
#define __Pyx_PyMODINIT_FUNC PyMODINIT_FUNC
#elif PY_MAJOR_VERSION < 3
#ifdef __cplusplus
#define __Pyx_PyMODINIT_FUNC extern "C" void
#else
#define __Pyx_PyMODINIT_FUNC void
#endif
#else
#ifdef __cplusplus
#define __Pyx_PyMODINIT_FUNC extern "C" PyObject *
#else
#define __Pyx_PyMODINIT_FUNC PyObject *
#endif
#endif


#if PY_MAJOR_VERSION < 3
__Pyx_PyMODINIT_FUNC initFsmMorphologicalAnalyzer(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC initFsmMorphologicalAnalyzer(void)
#else
__Pyx_PyMODINIT_FUNC PyInit_FsmMorphologicalAnalyzer(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC PyInit_FsmMorphologicalAnalyzer(void)
#if CYTHON_PEP489_MULTI_PHASE_INIT
{
  return PyModuleDef_Init(&__pyx_moduledef);
}
static CYTHON_SMALL_CODE int __Pyx_check_single_interpreter(void) {
    #if PY_VERSION_HEX >= 0x030700A1
    static PY_INT64_T main_interpreter_id = -1;
    PY_INT64_T current_id = PyInterpreterState_GetID(PyThreadState_Get()->interp);
    if (main_interpreter_id == -1) {
        main_interpreter_id = current_id;
        return (unlikely(current_id == -1)) ? -1 : 0;
    } else if (unlikely(main_interpreter_id != current_id))
    #else
    static PyInterpreterState *main_interpreter = NULL;
    PyInterpreterState *current_interpreter = PyThreadState_Get()->interp;
    if (!main_interpreter) {
        main_interpreter = current_interpreter;
    } else if (unlikely(main_interpreter != current_interpreter))
    #endif
    {
        PyErr_SetString(
            PyExc_ImportError,
            "Interpreter change detected - this module can only be loaded into one interpreter per process.");
        return -1;
    }
    return 0;
}
static CYTHON_SMALL_CODE int __Pyx_copy_spec_to_module(PyObject *spec, PyObject *moddict, const char* from_name, const char* to_name, int allow_none) {
    PyObject *value = PyObject_GetAttrString(spec, from_name);
    int result = 0;
    if (likely(value)) {
        if (allow_none || value != Py_None) {
            result = PyDict_SetItemString(moddict, to_name, value);
        }
        Py_DECREF(value);
    } else if (PyErr_ExceptionMatches(PyExc_AttributeError)) {
        PyErr_Clear();
    } else {
        result = -1;
    }
    return result;
}
static CYTHON_SMALL_CODE PyObject* __pyx_pymod_create(PyObject *spec, CYTHON_UNUSED PyModuleDef *def) {
    PyObject *module = NULL, *moddict, *modname;
    if (__Pyx_check_single_interpreter())
        return NULL;
    if (__pyx_m)
        return __Pyx_NewRef(__pyx_m);
    modname = PyObject_GetAttrString(spec, "name");
    if (unlikely(!modname)) goto bad;
    module = PyModule_NewObject(modname);
    Py_DECREF(modname);
    if (unlikely(!module)) goto bad;
    moddict = PyModule_GetDict(module);
    if (unlikely(!moddict)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "loader", "__loader__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "origin", "__file__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "parent", "__package__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "submodule_search_locations", "__path__", 0) < 0)) goto bad;
    return module;
bad:
    Py_XDECREF(module);
    return NULL;
}


static CYTHON_SMALL_CODE int __pyx_pymod_exec_FsmMorphologicalAnalyzer(PyObject *__pyx_pyinit_module)
#endif
#endif
{
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  if (__pyx_m) {
    if (__pyx_m == __pyx_pyinit_module) return 0;
    PyErr_SetString(PyExc_RuntimeError, "Module 'FsmMorphologicalAnalyzer' has already been imported. Re-initialisation is not supported.");
    return -1;
  }
  #elif PY_MAJOR_VERSION >= 3
  if (__pyx_m) return __Pyx_NewRef(__pyx_m);
  #endif
  #if CYTHON_REFNANNY
__Pyx_RefNanny = __Pyx_RefNannyImportAPI("refnanny");
if (!__Pyx_RefNanny) {
  PyErr_Clear();
  __Pyx_RefNanny = __Pyx_RefNannyImportAPI("Cython.Runtime.refnanny");
  if (!__Pyx_RefNanny)
      Py_FatalError("failed to import 'refnanny' module");
}
#endif
  __Pyx_RefNannySetupContext("__Pyx_PyMODINIT_FUNC PyInit_FsmMorphologicalAnalyzer(void)", 0);
  if (__Pyx_check_binary_version() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #ifdef __Pxy_PyFrame_Initialize_Offsets
  __Pxy_PyFrame_Initialize_Offsets();
  #endif
  __pyx_empty_tuple = PyTuple_New(0); if (unlikely(!__pyx_empty_tuple)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_bytes = PyBytes_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_bytes)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_unicode = PyUnicode_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_unicode)) __PYX_ERR(0, 1, __pyx_L1_error)
  #ifdef __Pyx_CyFunction_USED
  if (__pyx_CyFunction_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_FusedFunction_USED
  if (__pyx_FusedFunction_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Coroutine_USED
  if (__pyx_Coroutine_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Generator_USED
  if (__pyx_Generator_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_AsyncGen_USED
  if (__pyx_AsyncGen_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_StopAsyncIteration_USED
  if (__pyx_StopAsyncIteration_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  /*--- Library function declarations ---*/
  /*--- Threads initialization code ---*/
  #if defined(__PYX_FORCE_INIT_THREADS) && __PYX_FORCE_INIT_THREADS
  #ifdef WITH_THREAD /* Python build with threading support? */
  PyEval_InitThreads();
  #endif
  #endif
  /*--- Module creation code ---*/
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  __pyx_m = __pyx_pyinit_module;
  Py_INCREF(__pyx_m);
  #else
  #if PY_MAJOR_VERSION < 3
  __pyx_m = Py_InitModule4("FsmMorphologicalAnalyzer", __pyx_methods, 0, 0, PYTHON_API_VERSION); Py_XINCREF(__pyx_m);
  #else
  __pyx_m = PyModule_Create(&__pyx_moduledef);
  #endif
  if (unlikely(!__pyx_m)) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  __pyx_d = PyModule_GetDict(__pyx_m); if (unlikely(!__pyx_d)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_d);
  __pyx_b = PyImport_AddModule(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_b)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_b);
  __pyx_cython_runtime = PyImport_AddModule((char *) "cython_runtime"); if (unlikely(!__pyx_cython_runtime)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_cython_runtime);
  if (PyObject_SetAttrString(__pyx_m, "__builtins__", __pyx_b) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  /*--- Initialize various global constants etc. ---*/
  if (__Pyx_InitGlobals() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #if PY_MAJOR_VERSION < 3 && (__PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT)
  if (__Pyx_init_sys_getdefaultencoding_params() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  if (__pyx_module_is_main_MorphologicalAnalysis__FsmMorphologicalAnalyzer) {
    if (PyObject_SetAttr(__pyx_m, __pyx_n_s_name, __pyx_n_s_main) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  }
  #if PY_MAJOR_VERSION >= 3
  {
    PyObject *modules = PyImport_GetModuleDict(); if (unlikely(!modules)) __PYX_ERR(0, 1, __pyx_L1_error)
    if (!PyDict_GetItemString(modules, "MorphologicalAnalysis.FsmMorphologicalAnalyzer")) {
      if (unlikely(PyDict_SetItemString(modules, "MorphologicalAnalysis.FsmMorphologicalAnalyzer", __pyx_m) < 0)) __PYX_ERR(0, 1, __pyx_L1_error)
    }
  }
  #endif
  /*--- Builtin init code ---*/
  if (__Pyx_InitCachedBuiltins() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Constants init code ---*/
  if (__Pyx_InitCachedConstants() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Global type/function init code ---*/
  (void)__Pyx_modinit_global_init_code();
  (void)__Pyx_modinit_variable_export_code();
  (void)__Pyx_modinit_function_export_code();
  if (unlikely(__Pyx_modinit_type_init_code() < 0)) __PYX_ERR(0, 1, __pyx_L1_error)
  if (unlikely(__Pyx_modinit_type_import_code() < 0)) __PYX_ERR(0, 1, __pyx_L1_error)
  (void)__Pyx_modinit_variable_import_code();
  (void)__Pyx_modinit_function_import_code();
  /*--- Execution code ---*/
  #if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
  if (__Pyx_patch_abc() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1
 * import copy             # <<<<<<<<<<<<<<
 * import re
 * 
 */
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_copy, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_copy, __pyx_t_1) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":2
 * import copy
 * import re             # <<<<<<<<<<<<<<
 * 
 * from Corpus.Sentence cimport Sentence
 */
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_re, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_re, __pyx_t_1) < 0) __PYX_ERR(0, 2, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":8
 * 
 * from MorphologicalAnalysis.FsmParseList cimport FsmParseList
 * from MorphologicalAnalysis.MorphologicalTag import MorphologicalTag             # <<<<<<<<<<<<<<
 * from MorphologicalAnalysis.State cimport State
 * from MorphologicalAnalysis.Transition cimport Transition
 */
  __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 8, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_n_s_MorphologicalTag);
  __Pyx_GIVEREF(__pyx_n_s_MorphologicalTag);
  PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_s_MorphologicalTag);
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_MorphologicalAnalysis_Morphologi, __pyx_t_1, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 8, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 8, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_MorphologicalTag, __pyx_t_1) < 0) __PYX_ERR(0, 8, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":15
 * cdef class FsmMorphologicalAnalyzer:
 * 
 *     MAX_DISTANCE = 2             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self, dictionaryFileName=None, misspelledFileName=None, fileName="turkish_finite_state_machine.xml",
 */
  if (PyDict_SetItem((PyObject *)__pyx_ptype_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer->tp_dict, __pyx_n_s_MAX_DISTANCE, __pyx_int_2) < 0) __PYX_ERR(0, 15, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_FsmMorphologicalAnalyzer);

  /* "(tree fragment)":1
 * def __pyx_unpickle_FsmMorphologicalAnalyzer(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */
  __pyx_t_2 = PyCFunction_NewEx(&__pyx_mdef_21MorphologicalAnalysis_24FsmMorphologicalAnalyzer_1__pyx_unpickle_FsmMorphologicalAnalyzer, NULL, __pyx_n_s_MorphologicalAnalysis_FsmMorphol); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_pyx_unpickle_FsmMorphologicalA, __pyx_t_2) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "MorphologicalAnalysis/FsmMorphologicalAnalyzer.pyx":1
 * import copy             # <<<<<<<<<<<<<<
 * import re
 * 
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test, __pyx_t_2) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /*--- Wrapped vars code ---*/

  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  if (__pyx_m) {
    if (__pyx_d) {
      __Pyx_AddTraceback("init MorphologicalAnalysis.FsmMorphologicalAnalyzer", __pyx_clineno, __pyx_lineno, __pyx_filename);
    }
    Py_CLEAR(__pyx_m);
  } else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_ImportError, "init MorphologicalAnalysis.FsmMorphologicalAnalyzer");
  }
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  return (__pyx_m != NULL) ? 0 : -1;
  #elif PY_MAJOR_VERSION >= 3
  return __pyx_m;
  #else
  return;
  #endif
}

/* --- Runtime support code --- */
/* Refnanny */
#if CYTHON_REFNANNY
static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname) {
    PyObject *m = NULL, *p = NULL;
    void *r = NULL;
    m = PyImport_ImportModule(modname);
    if (!m) goto end;
    p = PyObject_GetAttrString(m, "RefNannyAPI");
    if (!p) goto end;
    r = PyLong_AsVoidPtr(p);
end:
    Py_XDECREF(p);
    Py_XDECREF(m);
    return (__Pyx_RefNannyAPIStruct *)r;
}
#endif

/* PyObjectGetAttrStr */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro))
        return tp->tp_getattro(obj, attr_name);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_getattr))
        return tp->tp_getattr(obj, PyString_AS_STRING(attr_name));
#endif
    return PyObject_GetAttr(obj, attr_name);
}
#endif

/* GetBuiltinName */
static PyObject *__Pyx_GetBuiltinName(PyObject *name) {
    PyObject* result = __Pyx_PyObject_GetAttrStr(__pyx_b, name);
    if (unlikely(!result)) {
        PyErr_Format(PyExc_NameError,
#if PY_MAJOR_VERSION >= 3
            "name '%U' is not defined", name);
#else
            "name '%.200s' is not defined", PyString_AS_STRING(name));
#endif
    }
    return result;
}

/* RaiseDoubleKeywords */
static void __Pyx_RaiseDoubleKeywordsError(
    const char* func_name,
    PyObject* kw_name)
{
    PyErr_Format(PyExc_TypeError,
        #if PY_MAJOR_VERSION >= 3
        "%s() got multiple values for keyword argument '%U'", func_name, kw_name);
        #else
        "%s() got multiple values for keyword argument '%s'", func_name,
        PyString_AsString(kw_name));
        #endif
}

/* ParseKeywords */
static int __Pyx_ParseOptionalKeywords(
    PyObject *kwds,
    PyObject **argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name)
{
    PyObject *key = 0, *value = 0;
    Py_ssize_t pos = 0;
    PyObject*** name;
    PyObject*** first_kw_arg = argnames + num_pos_args;
    while (PyDict_Next(kwds, &pos, &key, &value)) {
        name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (*name) {
            values[name-argnames] = value;
            continue;
        }
        name = first_kw_arg;
        #if PY_MAJOR_VERSION < 3
        if (likely(PyString_Check(key))) {
            while (*name) {
                if ((CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**name) == PyString_GET_SIZE(key))
                        && _PyString_Eq(**name, key)) {
                    values[name-argnames] = value;
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    if ((**argname == key) || (
                            (CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**argname) == PyString_GET_SIZE(key))
                             && _PyString_Eq(**argname, key))) {
                        goto arg_passed_twice;
                    }
                    argname++;
                }
            }
        } else
        #endif
        if (likely(PyUnicode_Check(key))) {
            while (*name) {
                int cmp = (**name == key) ? 0 :
                #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                    (__Pyx_PyUnicode_GET_LENGTH(**name) != __Pyx_PyUnicode_GET_LENGTH(key)) ? 1 :
                #endif
                    PyUnicode_Compare(**name, key);
                if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                if (cmp == 0) {
                    values[name-argnames] = value;
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    int cmp = (**argname == key) ? 0 :
                    #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                        (__Pyx_PyUnicode_GET_LENGTH(**argname) != __Pyx_PyUnicode_GET_LENGTH(key)) ? 1 :
                    #endif
                        PyUnicode_Compare(**argname, key);
                    if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                    if (cmp == 0) goto arg_passed_twice;
                    argname++;
                }
            }
        } else
            goto invalid_keyword_type;
        if (kwds2) {
            if (unlikely(PyDict_SetItem(kwds2, key, value))) goto bad;
        } else {
            goto invalid_keyword;
        }
    }
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, key);
    goto bad;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    goto bad;
invalid_keyword:
    PyErr_Format(PyExc_TypeError,
    #if PY_MAJOR_VERSION < 3
        "%.200s() got an unexpected keyword argument '%.200s'",
        function_name, PyString_AsString(key));
    #else
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
bad:
    return -1;
}

/* RaiseArgTupleInvalid */
static void __Pyx_RaiseArgtupleInvalid(
    const char* func_name,
    int exact,
    Py_ssize_t num_min,
    Py_ssize_t num_max,
    Py_ssize_t num_found)
{
    Py_ssize_t num_expected;
    const char *more_or_less;
    if (num_found < num_min) {
        num_expected = num_min;
        more_or_less = "at least";
    } else {
        num_expected = num_max;
        more_or_less = "at most";
    }
    if (exact) {
        more_or_less = "exactly";
    }
    PyErr_Format(PyExc_TypeError,
                 "%.200s() takes %.8s %" CYTHON_FORMAT_SSIZE_T "d positional argument%.1s (%" CYTHON_FORMAT_SSIZE_T "d given)",
                 func_name, more_or_less, num_expected,
                 (num_expected == 1) ? "" : "s", num_found);
}

/* PyFunctionFastCall */
#if CYTHON_FAST_PYCALL
static PyObject* __Pyx_PyFunction_FastCallNoKw(PyCodeObject *co, PyObject **args, Py_ssize_t na,
                                               PyObject *globals) {
    PyFrameObject *f;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    PyObject **fastlocals;
    Py_ssize_t i;
    PyObject *result;
    assert(globals != NULL);
    /* XXX Perhaps we should create a specialized
       PyFrame_New() that doesn't take locals, but does
       take builtins without sanity checking them.
       */
    assert(tstate != NULL);
    f = PyFrame_New(tstate, co, globals, NULL);
    if (f == NULL) {
        return NULL;
    }
    fastlocals = __Pyx_PyFrame_GetLocalsplus(f);
    for (i = 0; i < na; i++) {
        Py_INCREF(*args);
        fastlocals[i] = *args++;
    }
    result = PyEval_EvalFrameEx(f,0);
    ++tstate->recursion_depth;
    Py_DECREF(f);
    --tstate->recursion_depth;
    return result;
}
#if 1 || PY_VERSION_HEX < 0x030600B1
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, Py_ssize_t nargs, PyObject *kwargs) {
    PyCodeObject *co = (PyCodeObject *)PyFunction_GET_CODE(func);
    PyObject *globals = PyFunction_GET_GLOBALS(func);
    PyObject *argdefs = PyFunction_GET_DEFAULTS(func);
    PyObject *closure;
#if PY_MAJOR_VERSION >= 3
    PyObject *kwdefs;
#endif
    PyObject *kwtuple, **k;
    PyObject **d;
    Py_ssize_t nd;
    Py_ssize_t nk;
    PyObject *result;
    assert(kwargs == NULL || PyDict_Check(kwargs));
    nk = kwargs ? PyDict_Size(kwargs) : 0;
    if (Py_EnterRecursiveCall((char*)" while calling a Python object")) {
        return NULL;
    }
    if (
#if PY_MAJOR_VERSION >= 3
            co->co_kwonlyargcount == 0 &&
#endif
            likely(kwargs == NULL || nk == 0) &&
            co->co_flags == (CO_OPTIMIZED | CO_NEWLOCALS | CO_NOFREE)) {
        if (argdefs == NULL && co->co_argcount == nargs) {
            result = __Pyx_PyFunction_FastCallNoKw(co, args, nargs, globals);
            goto done;
        }
        else if (nargs == 0 && argdefs != NULL
                 && co->co_argcount == Py_SIZE(argdefs)) {
            /* function called with no arguments, but all parameters have
               a default value: use default values as arguments .*/
            args = &PyTuple_GET_ITEM(argdefs, 0);
            result =__Pyx_PyFunction_FastCallNoKw(co, args, Py_SIZE(argdefs), globals);
            goto done;
        }
    }
    if (kwargs != NULL) {
        Py_ssize_t pos, i;
        kwtuple = PyTuple_New(2 * nk);
        if (kwtuple == NULL) {
            result = NULL;
            goto done;
        }
        k = &PyTuple_GET_ITEM(kwtuple, 0);
        pos = i = 0;
        while (PyDict_Next(kwargs, &pos, &k[i], &k[i+1])) {
            Py_INCREF(k[i]);
            Py_INCREF(k[i+1]);
            i += 2;
        }
        nk = i / 2;
    }
    else {
        kwtuple = NULL;
        k = NULL;
    }
    closure = PyFunction_GET_CLOSURE(func);
#if PY_MAJOR_VERSION >= 3
    kwdefs = PyFunction_GET_KW_DEFAULTS(func);
#endif
    if (argdefs != NULL) {
        d = &PyTuple_GET_ITEM(argdefs, 0);
        nd = Py_SIZE(argdefs);
    }
    else {
        d = NULL;
        nd = 0;
    }
#if PY_MAJOR_VERSION >= 3
    result = PyEval_EvalCodeEx((PyObject*)co, globals, (PyObject *)NULL,
                               args, (int)nargs,
                               k, (int)nk,
                               d, (int)nd, kwdefs, closure);
#else
    result = PyEval_EvalCodeEx(co, globals, (PyObject *)NULL,
                               args, (int)nargs,
                               k, (int)nk,
                               d, (int)nd, closure);
#endif
    Py_XDECREF(kwtuple);
done:
    Py_LeaveRecursiveCall();
    return result;
}
#endif
#endif

/* PyObjectCall */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *result;
    ternaryfunc call = func->ob_type->tp_call;
    if (unlikely(!call))
        return PyObject_Call(func, arg, kw);
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    result = (*call)(func, arg, kw);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectCallMethO */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg) {
    PyObject *self, *result;
    PyCFunction cfunc;
    cfunc = PyCFunction_GET_FUNCTION(func);
    self = PyCFunction_GET_SELF(func);
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    result = cfunc(self, arg);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectCallNoArg */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func) {
#if CYTHON_FAST_PYCALL
    if (PyFunction_Check(func)) {
        return __Pyx_PyFunction_FastCall(func, NULL, 0);
    }
#endif
#ifdef __Pyx_CyFunction_USED
    if (likely(PyCFunction_Check(func) || __Pyx_CyFunction_Check(func)))
#else
    if (likely(PyCFunction_Check(func)))
#endif
    {
        if (likely(PyCFunction_GET_FLAGS(func) & METH_NOARGS)) {
            return __Pyx_PyObject_CallMethO(func, NULL);
        }
    }
    return __Pyx_PyObject_Call(func, __pyx_empty_tuple, NULL);
}
#endif

/* PyCFunctionFastCall */
#if CYTHON_FAST_PYCCALL
static CYTHON_INLINE PyObject * __Pyx_PyCFunction_FastCall(PyObject *func_obj, PyObject **args, Py_ssize_t nargs) {
    PyCFunctionObject *func = (PyCFunctionObject*)func_obj;
    PyCFunction meth = PyCFunction_GET_FUNCTION(func);
    PyObject *self = PyCFunction_GET_SELF(func);
    int flags = PyCFunction_GET_FLAGS(func);
    assert(PyCFunction_Check(func));
    assert(METH_FASTCALL == (flags & ~(METH_CLASS | METH_STATIC | METH_COEXIST | METH_KEYWORDS | METH_STACKLESS)));
    assert(nargs >= 0);
    assert(nargs == 0 || args != NULL);
    /* _PyCFunction_FastCallDict() must not be called with an exception set,
       because it may clear it (directly or indirectly) and so the
       caller loses its exception */
    assert(!PyErr_Occurred());
    if ((PY_VERSION_HEX < 0x030700A0) || unlikely(flags & METH_KEYWORDS)) {
        return (*((__Pyx_PyCFunctionFastWithKeywords)(void*)meth)) (self, args, nargs, NULL);
    } else {
        return (*((__Pyx_PyCFunctionFast)(void*)meth)) (self, args, nargs);
    }
}
#endif

/* PyObjectCallOneArg */
#if CYTHON_COMPILING_IN_CPYTHON
static PyObject* __Pyx__PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *result;
    PyObject *args = PyTuple_New(1);
    if (unlikely(!args)) return NULL;
    Py_INCREF(arg);
    PyTuple_SET_ITEM(args, 0, arg);
    result = __Pyx_PyObject_Call(func, args, NULL);
    Py_DECREF(args);
    return result;
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
#if CYTHON_FAST_PYCALL
    if (PyFunction_Check(func)) {
        return __Pyx_PyFunction_FastCall(func, &arg, 1);
    }
#endif
    if (likely(PyCFunction_Check(func))) {
        if (likely(PyCFunction_GET_FLAGS(func) & METH_O)) {
            return __Pyx_PyObject_CallMethO(func, arg);
#if CYTHON_FAST_PYCCALL
        } else if (PyCFunction_GET_FLAGS(func) & METH_FASTCALL) {
            return __Pyx_PyCFunction_FastCall(func, &arg, 1);
#endif
        }
    }
    return __Pyx__PyObject_CallOneArg(func, arg);
}
#else
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *result;
    PyObject *args = PyTuple_Pack(1, arg);
    if (unlikely(!args)) return NULL;
    result = __Pyx_PyObject_Call(func, args, NULL);
    Py_DECREF(args);
    return result;
}
#endif

/* PyDictVersioning */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    return likely(dict) ? __PYX_GET_DICT_VERSION(dict) : 0;
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj) {
    PyObject **dictptr = NULL;
    Py_ssize_t offset = Py_TYPE(obj)->tp_dictoffset;
    if (offset) {
#if CYTHON_COMPILING_IN_CPYTHON
        dictptr = (likely(offset > 0)) ? (PyObject **) ((char *)obj + offset) : _PyObject_GetDictPtr(obj);
#else
        dictptr = _PyObject_GetDictPtr(obj);
#endif
    }
    return (dictptr && *dictptr) ? __PYX_GET_DICT_VERSION(*dictptr) : 0;
}
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    if (unlikely(!dict) || unlikely(tp_dict_version != __PYX_GET_DICT_VERSION(dict)))
        return 0;
    return obj_dict_version == __Pyx_get_object_dict_version(obj);
}
#endif

/* PyObjectCall2Args */
static CYTHON_UNUSED PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2) {
    PyObject *args, *result = NULL;
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(function)) {
        PyObject *args[2] = {arg1, arg2};
        return __Pyx_PyFunction_FastCall(function, args, 2);
    }
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(function)) {
        PyObject *args[2] = {arg1, arg2};
        return __Pyx_PyCFunction_FastCall(function, args, 2);
    }
    #endif
    args = PyTuple_New(2);
    if (unlikely(!args)) goto done;
    Py_INCREF(arg1);
    PyTuple_SET_ITEM(args, 0, arg1);
    Py_INCREF(arg2);
    PyTuple_SET_ITEM(args, 1, arg2);
    Py_INCREF(function);
    result = __Pyx_PyObject_Call(function, args, NULL);
    Py_DECREF(args);
    Py_DECREF(function);
done:
    return result;
}

/* UnpackUnboundCMethod */
static int __Pyx_TryUnpackUnboundCMethod(__Pyx_CachedCFunction* target) {
    PyObject *method;
    method = __Pyx_PyObject_GetAttrStr(target->type, *target->method_name);
    if (unlikely(!method))
        return -1;
    target->method = method;
#if CYTHON_COMPILING_IN_CPYTHON
    #if PY_MAJOR_VERSION >= 3
    if (likely(__Pyx_TypeCheck(method, &PyMethodDescr_Type)))
    #endif
    {
        PyMethodDescrObject *descr = (PyMethodDescrObject*) method;
        target->func = descr->d_method->ml_meth;
        target->flag = descr->d_method->ml_flags & ~(METH_CLASS | METH_STATIC | METH_COEXIST | METH_STACKLESS);
    }
#endif
    return 0;
}

/* CallUnboundCMethod0 */
static PyObject* __Pyx__CallUnboundCMethod0(__Pyx_CachedCFunction* cfunc, PyObject* self) {
    PyObject *args, *result = NULL;
    if (unlikely(!cfunc->method) && unlikely(__Pyx_TryUnpackUnboundCMethod(cfunc) < 0)) return NULL;
#if CYTHON_ASSUME_SAFE_MACROS
    args = PyTuple_New(1);
    if (unlikely(!args)) goto bad;
    Py_INCREF(self);
    PyTuple_SET_ITEM(args, 0, self);
#else
    args = PyTuple_Pack(1, self);
    if (unlikely(!args)) goto bad;
#endif
    result = __Pyx_PyObject_Call(cfunc->method, args, NULL);
    Py_DECREF(args);
bad:
    return result;
}

/* ArgTypeTest */
static int __Pyx__ArgTypeTest(PyObject *obj, PyTypeObject *type, const char *name, int exact)
{
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    else if (exact) {
        #if PY_MAJOR_VERSION == 2
        if ((type == &PyBaseString_Type) && likely(__Pyx_PyBaseString_CheckExact(obj))) return 1;
        #endif
    }
    else {
        if (likely(__Pyx_TypeCheck(obj, type))) return 1;
    }
    PyErr_Format(PyExc_TypeError,
        "Argument '%.200s' has incorrect type (expected %.200s, got %.200s)",
        name, type->tp_name, Py_TYPE(obj)->tp_name);
    return 0;
}

/* BytesEquals */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY
    return PyObject_RichCompareBool(s1, s2, equals);
#else
    if (s1 == s2) {
        return (equals == Py_EQ);
    } else if (PyBytes_CheckExact(s1) & PyBytes_CheckExact(s2)) {
        const char *ps1, *ps2;
        Py_ssize_t length = PyBytes_GET_SIZE(s1);
        if (length != PyBytes_GET_SIZE(s2))
            return (equals == Py_NE);
        ps1 = PyBytes_AS_STRING(s1);
        ps2 = PyBytes_AS_STRING(s2);
        if (ps1[0] != ps2[0]) {
            return (equals == Py_NE);
        } else if (length == 1) {
            return (equals == Py_EQ);
        } else {
            int result;
#if CYTHON_USE_UNICODE_INTERNALS
            Py_hash_t hash1, hash2;
            hash1 = ((PyBytesObject*)s1)->ob_shash;
            hash2 = ((PyBytesObject*)s2)->ob_shash;
            if (hash1 != hash2 && hash1 != -1 && hash2 != -1) {
                return (equals == Py_NE);
            }
#endif
            result = memcmp(ps1, ps2, (size_t)length);
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & PyBytes_CheckExact(s2)) {
        return (equals == Py_NE);
    } else if ((s2 == Py_None) & PyBytes_CheckExact(s1)) {
        return (equals == Py_NE);
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
#endif
}

/* UnicodeEquals */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY
    return PyObject_RichCompareBool(s1, s2, equals);
#else
#if PY_MAJOR_VERSION < 3
    PyObject* owned_ref = NULL;
#endif
    int s1_is_unicode, s2_is_unicode;
    if (s1 == s2) {
        goto return_eq;
    }
    s1_is_unicode = PyUnicode_CheckExact(s1);
    s2_is_unicode = PyUnicode_CheckExact(s2);
#if PY_MAJOR_VERSION < 3
    if ((s1_is_unicode & (!s2_is_unicode)) && PyString_CheckExact(s2)) {
        owned_ref = PyUnicode_FromObject(s2);
        if (unlikely(!owned_ref))
            return -1;
        s2 = owned_ref;
        s2_is_unicode = 1;
    } else if ((s2_is_unicode & (!s1_is_unicode)) && PyString_CheckExact(s1)) {
        owned_ref = PyUnicode_FromObject(s1);
        if (unlikely(!owned_ref))
            return -1;
        s1 = owned_ref;
        s1_is_unicode = 1;
    } else if (((!s2_is_unicode) & (!s1_is_unicode))) {
        return __Pyx_PyBytes_Equals(s1, s2, equals);
    }
#endif
    if (s1_is_unicode & s2_is_unicode) {
        Py_ssize_t length;
        int kind;
        void *data1, *data2;
        if (unlikely(__Pyx_PyUnicode_READY(s1) < 0) || unlikely(__Pyx_PyUnicode_READY(s2) < 0))
            return -1;
        length = __Pyx_PyUnicode_GET_LENGTH(s1);
        if (length != __Pyx_PyUnicode_GET_LENGTH(s2)) {
            goto return_ne;
        }
#if CYTHON_USE_UNICODE_INTERNALS
        {
            Py_hash_t hash1, hash2;
        #if CYTHON_PEP393_ENABLED
            hash1 = ((PyASCIIObject*)s1)->hash;
            hash2 = ((PyASCIIObject*)s2)->hash;
        #else
            hash1 = ((PyUnicodeObject*)s1)->hash;
            hash2 = ((PyUnicodeObject*)s2)->hash;
        #endif
            if (hash1 != hash2 && hash1 != -1 && hash2 != -1) {
                goto return_ne;
            }
        }
#endif
        kind = __Pyx_PyUnicode_KIND(s1);
        if (kind != __Pyx_PyUnicode_KIND(s2)) {
            goto return_ne;
        }
        data1 = __Pyx_PyUnicode_DATA(s1);
        data2 = __Pyx_PyUnicode_DATA(s2);
        if (__Pyx_PyUnicode_READ(kind, data1, 0) != __Pyx_PyUnicode_READ(kind, data2, 0)) {
            goto return_ne;
        } else if (length == 1) {
            goto return_eq;
        } else {
            int result = memcmp(data1, data2, (size_t)(length * kind));
            #if PY_MAJOR_VERSION < 3
            Py_XDECREF(owned_ref);
            #endif
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & s2_is_unicode) {
        goto return_ne;
    } else if ((s2 == Py_None) & s1_is_unicode) {
        goto return_ne;
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        #if PY_MAJOR_VERSION < 3
        Py_XDECREF(owned_ref);
        #endif
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
return_eq:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(owned_ref);
    #endif
    return (equals == Py_EQ);
return_ne:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(owned_ref);
    #endif
    return (equals == Py_NE);
#endif
}

/* GetModuleGlobalName */
#if CYTHON_USE_DICT_VERSIONS
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value)
#else
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name)
#endif
{
    PyObject *result;
#if !CYTHON_AVOID_BORROWED_REFS
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030500A1
    result = _PyDict_GetItem_KnownHash(__pyx_d, name, ((PyASCIIObject *) name)->hash);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    } else if (unlikely(PyErr_Occurred())) {
        return NULL;
    }
#else
    result = PyDict_GetItem(__pyx_d, name);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    }
#endif
#else
    result = PyObject_GetItem(__pyx_d, name);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    }
    PyErr_Clear();
#endif
    return __Pyx_GetBuiltinName(name);
}

/* ExtTypeTest */
static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type) {
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    if (likely(__Pyx_TypeCheck(obj, type)))
        return 1;
    PyErr_Format(PyExc_TypeError, "Cannot convert %.200s to %.200s",
                 Py_TYPE(obj)->tp_name, type->tp_name);
    return 0;
}

/* GetItemIntUnicode */
static CYTHON_INLINE Py_UCS4 __Pyx_GetItemInt_Unicode_Fast(PyObject* ustring, Py_ssize_t i,
                                                           int wraparound, int boundscheck) {
    Py_ssize_t length;
    if (unlikely(__Pyx_PyUnicode_READY(ustring) < 0)) return (Py_UCS4)-1;
    if (wraparound | boundscheck) {
        length = __Pyx_PyUnicode_GET_LENGTH(ustring);
        if (wraparound & unlikely(i < 0)) i += length;
        if ((!boundscheck) || likely(__Pyx_is_valid_index(i, length))) {
            return __Pyx_PyUnicode_READ_CHAR(ustring, i);
        } else {
            PyErr_SetString(PyExc_IndexError, "string index out of range");
            return (Py_UCS4)-1;
        }
    } else {
        return __Pyx_PyUnicode_READ_CHAR(ustring, i);
    }
}

/* unicode_tailmatch */
static int __Pyx_PyUnicode_TailmatchTuple(PyObject* s, PyObject* substrings,
                                          Py_ssize_t start, Py_ssize_t end, int direction) {
    Py_ssize_t i, count = PyTuple_GET_SIZE(substrings);
    for (i = 0; i < count; i++) {
        Py_ssize_t result;
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        result = PyUnicode_Tailmatch(s, PyTuple_GET_ITEM(substrings, i),
                                     start, end, direction);
#else
        PyObject* sub = PySequence_ITEM(substrings, i);
        if (unlikely(!sub)) return -1;
        result = PyUnicode_Tailmatch(s, sub, start, end, direction);
        Py_DECREF(sub);
#endif
        if (result) {
            return (int) result;
        }
    }
    return 0;
}
static int __Pyx_PyUnicode_Tailmatch(PyObject* s, PyObject* substr,
                                     Py_ssize_t start, Py_ssize_t end, int direction) {
    if (unlikely(PyTuple_Check(substr))) {
        return __Pyx_PyUnicode_TailmatchTuple(s, substr, start, end, direction);
    }
    return (int) PyUnicode_Tailmatch(s, substr, start, end, direction);
}

/* PyIntBinop */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_SubtractObjC(PyObject *op1, PyObject *op2, CYTHON_UNUSED long intval, int inplace, int zerodivision_check) {
    (void)inplace;
    (void)zerodivision_check;
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long x;
        long a = PyInt_AS_LONG(op1);
            x = (long)((unsigned long)a - b);
            if (likely((x^a) >= 0 || (x^~b) >= 0))
                return PyInt_FromLong(x);
            return PyLong_Type.tp_as_number->nb_subtract(op1, op2);
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        const long b = intval;
        long a, x;
#ifdef HAVE_LONG_LONG
        const PY_LONG_LONG llb = intval;
        PY_LONG_LONG lla, llx;
#endif
        const digit* digits = ((PyLongObject*)op1)->ob_digit;
        const Py_ssize_t size = Py_SIZE(op1);
        if (likely(__Pyx_sst_abs(size) <= 1)) {
            a = likely(size) ? digits[0] : 0;
            if (size == -1) a = -a;
        } else {
            switch (size) {
                case -2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = (long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case -3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = (long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case -4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = (long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                default: return PyLong_Type.tp_as_number->nb_subtract(op1, op2);
            }
        }
                x = a - b;
            return PyLong_FromLong(x);
#ifdef HAVE_LONG_LONG
        long_long:
                llx = lla - llb;
            return PyLong_FromLongLong(llx);
#endif
        
        
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        const long b = intval;
        double a = PyFloat_AS_DOUBLE(op1);
            double result;
            PyFPE_START_PROTECT("subtract", return NULL)
            result = ((double)a) - (double)b;
            PyFPE_END_PROTECT(result)
            return PyFloat_FromDouble(result);
    }
    return (inplace ? PyNumber_InPlaceSubtract : PyNumber_Subtract)(op1, op2);
}
#endif

/* PyErrFetchRestore */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    tmp_type = tstate->curexc_type;
    tmp_value = tstate->curexc_value;
    tmp_tb = tstate->curexc_traceback;
    tstate->curexc_type = type;
    tstate->curexc_value = value;
    tstate->curexc_traceback = tb;
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
}
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
    *type = tstate->curexc_type;
    *value = tstate->curexc_value;
    *tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
}
#endif

/* WriteUnraisableException */
static void __Pyx_WriteUnraisable(const char *name, CYTHON_UNUSED int clineno,
                                  CYTHON_UNUSED int lineno, CYTHON_UNUSED const char *filename,
                                  int full_traceback, CYTHON_UNUSED int nogil) {
    PyObject *old_exc, *old_val, *old_tb;
    PyObject *ctx;
    __Pyx_PyThreadState_declare
#ifdef WITH_THREAD
    PyGILState_STATE state;
    if (nogil)
        state = PyGILState_Ensure();
#ifdef _MSC_VER
    else state = (PyGILState_STATE)-1;
#endif
#endif
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&old_exc, &old_val, &old_tb);
    if (full_traceback) {
        Py_XINCREF(old_exc);
        Py_XINCREF(old_val);
        Py_XINCREF(old_tb);
        __Pyx_ErrRestore(old_exc, old_val, old_tb);
        PyErr_PrintEx(1);
    }
    #if PY_MAJOR_VERSION < 3
    ctx = PyString_FromString(name);
    #else
    ctx = PyUnicode_FromString(name);
    #endif
    __Pyx_ErrRestore(old_exc, old_val, old_tb);
    if (!ctx) {
        PyErr_WriteUnraisable(Py_None);
    } else {
        PyErr_WriteUnraisable(ctx);
        Py_DECREF(ctx);
    }
#ifdef WITH_THREAD
    if (nogil)
        PyGILState_Release(state);
#endif
}

/* PyUnicode_Substring */
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_Substring(
            PyObject* text, Py_ssize_t start, Py_ssize_t stop) {
    Py_ssize_t length;
    if (unlikely(__Pyx_PyUnicode_READY(text) == -1)) return NULL;
    length = __Pyx_PyUnicode_GET_LENGTH(text);
    if (start < 0) {
        start += length;
        if (start < 0)
            start = 0;
    }
    if (stop < 0)
        stop += length;
    else if (stop > length)
        stop = length;
    if (stop <= start)
        return __Pyx_NewRef(__pyx_empty_unicode);
#if CYTHON_PEP393_ENABLED
    return PyUnicode_FromKindAndData(PyUnicode_KIND(text),
        PyUnicode_1BYTE_DATA(text) + start*PyUnicode_KIND(text), stop-start);
#else
    return PyUnicode_FromUnicode(PyUnicode_AS_UNICODE(text)+start, stop-start);
#endif
}

/* IterFinish */
static CYTHON_INLINE int __Pyx_IterFinish(void) {
#if CYTHON_FAST_THREAD_STATE
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    PyObject* exc_type = tstate->curexc_type;
    if (unlikely(exc_type)) {
        if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) {
            PyObject *exc_value, *exc_tb;
            exc_value = tstate->curexc_value;
            exc_tb = tstate->curexc_traceback;
            tstate->curexc_type = 0;
            tstate->curexc_value = 0;
            tstate->curexc_traceback = 0;
            Py_DECREF(exc_type);
            Py_XDECREF(exc_value);
            Py_XDECREF(exc_tb);
            return 0;
        } else {
            return -1;
        }
    }
    return 0;
#else
    if (unlikely(PyErr_Occurred())) {
        if (likely(PyErr_ExceptionMatches(PyExc_StopIteration))) {
            PyErr_Clear();
            return 0;
        } else {
            return -1;
        }
    }
    return 0;
#endif
}

/* set_iter */
static CYTHON_INLINE PyObject* __Pyx_set_iterator(PyObject* iterable, int is_set,
                                                  Py_ssize_t* p_orig_length, int* p_source_is_set) {
#if CYTHON_COMPILING_IN_CPYTHON
    is_set = is_set || likely(PySet_CheckExact(iterable) || PyFrozenSet_CheckExact(iterable));
    *p_source_is_set = is_set;
    if (likely(is_set)) {
        *p_orig_length = PySet_Size(iterable);
        Py_INCREF(iterable);
        return iterable;
    }
#else
    (void)is_set;
    *p_source_is_set = 0;
#endif
    *p_orig_length = 0;
    return PyObject_GetIter(iterable);
}
static CYTHON_INLINE int __Pyx_set_iter_next(
        PyObject* iter_obj, Py_ssize_t orig_length,
        Py_ssize_t* ppos, PyObject **value,
        int source_is_set) {
    if (!CYTHON_COMPILING_IN_CPYTHON || unlikely(!source_is_set)) {
        *value = PyIter_Next(iter_obj);
        if (unlikely(!*value)) {
            return __Pyx_IterFinish();
        }
        (void)orig_length;
        (void)ppos;
        return 1;
    }
#if CYTHON_COMPILING_IN_CPYTHON
    if (unlikely(PySet_GET_SIZE(iter_obj) != orig_length)) {
        PyErr_SetString(
            PyExc_RuntimeError,
            "set changed size during iteration");
        return -1;
    }
    {
        Py_hash_t hash;
        int ret = _PySet_NextEntry(iter_obj, ppos, value, &hash);
        assert (ret != -1);
        if (likely(ret)) {
            Py_INCREF(*value);
            return 1;
        }
    }
#endif
    return 0;
}

/* PyObjectGetMethod */
static int __Pyx_PyObject_GetMethod(PyObject *obj, PyObject *name, PyObject **method) {
    PyObject *attr;
#if CYTHON_UNPACK_METHODS && CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_PYTYPE_LOOKUP
    PyTypeObject *tp = Py_TYPE(obj);
    PyObject *descr;
    descrgetfunc f = NULL;
    PyObject **dictptr, *dict;
    int meth_found = 0;
    assert (*method == NULL);
    if (unlikely(tp->tp_getattro != PyObject_GenericGetAttr)) {
        attr = __Pyx_PyObject_GetAttrStr(obj, name);
        goto try_unpack;
    }
    if (unlikely(tp->tp_dict == NULL) && unlikely(PyType_Ready(tp) < 0)) {
        return 0;
    }
    descr = _PyType_Lookup(tp, name);
    if (likely(descr != NULL)) {
        Py_INCREF(descr);
#if PY_MAJOR_VERSION >= 3
        #ifdef __Pyx_CyFunction_USED
        if (likely(PyFunction_Check(descr) || (Py_TYPE(descr) == &PyMethodDescr_Type) || __Pyx_CyFunction_Check(descr)))
        #else
        if (likely(PyFunction_Check(descr) || (Py_TYPE(descr) == &PyMethodDescr_Type)))
        #endif
#else
        #ifdef __Pyx_CyFunction_USED
        if (likely(PyFunction_Check(descr) || __Pyx_CyFunction_Check(descr)))
        #else
        if (likely(PyFunction_Check(descr)))
        #endif
#endif
        {
            meth_found = 1;
        } else {
            f = Py_TYPE(descr)->tp_descr_get;
            if (f != NULL && PyDescr_IsData(descr)) {
                attr = f(descr, obj, (PyObject *)Py_TYPE(obj));
                Py_DECREF(descr);
                goto try_unpack;
            }
        }
    }
    dictptr = _PyObject_GetDictPtr(obj);
    if (dictptr != NULL && (dict = *dictptr) != NULL) {
        Py_INCREF(dict);
        attr = __Pyx_PyDict_GetItemStr(dict, name);
        if (attr != NULL) {
            Py_INCREF(attr);
            Py_DECREF(dict);
            Py_XDECREF(descr);
            goto try_unpack;
        }
        Py_DECREF(dict);
    }
    if (meth_found) {
        *method = descr;
        return 1;
    }
    if (f != NULL) {
        attr = f(descr, obj, (PyObject *)Py_TYPE(obj));
        Py_DECREF(descr);
        goto try_unpack;
    }
    if (descr != NULL) {
        *method = descr;
        return 0;
    }
    PyErr_Format(PyExc_AttributeError,
#if PY_MAJOR_VERSION >= 3
                 "'%.50s' object has no attribute '%U'",
                 tp->tp_name, name);
#else
                 "'%.50s' object has no attribute '%.400s'",
                 tp->tp_name, PyString_AS_STRING(name));
#endif
    return 0;
#else
    attr = __Pyx_PyObject_GetAttrStr(obj, name);
    goto try_unpack;
#endif
try_unpack:
#if CYTHON_UNPACK_METHODS
    if (likely(attr) && PyMethod_Check(attr) && likely(PyMethod_GET_SELF(attr) == obj)) {
        PyObject *function = PyMethod_GET_FUNCTION(attr);
        Py_INCREF(function);
        Py_DECREF(attr);
        *method = function;
        return 1;
    }
#endif
    *method = attr;
    return 0;
}

/* PyObjectCallMethod1 */
static PyObject* __Pyx__PyObject_CallMethod1(PyObject* method, PyObject* arg) {
    PyObject *result = __Pyx_PyObject_CallOneArg(method, arg);
    Py_DECREF(method);
    return result;
}
static PyObject* __Pyx_PyObject_CallMethod1(PyObject* obj, PyObject* method_name, PyObject* arg) {
    PyObject *method = NULL, *result;
    int is_method = __Pyx_PyObject_GetMethod(obj, method_name, &method);
    if (likely(is_method)) {
        result = __Pyx_PyObject_Call2Args(method, obj, arg);
        Py_DECREF(method);
        return result;
    }
    if (unlikely(!method)) return NULL;
    return __Pyx__PyObject_CallMethod1(method, arg);
}

/* pop_index */
static PyObject* __Pyx__PyObject_PopNewIndex(PyObject* L, PyObject* py_ix) {
    PyObject *r;
    if (unlikely(!py_ix)) return NULL;
    r = __Pyx__PyObject_PopIndex(L, py_ix);
    Py_DECREF(py_ix);
    return r;
}
static PyObject* __Pyx__PyObject_PopIndex(PyObject* L, PyObject* py_ix) {
    return __Pyx_PyObject_CallMethod1(L, __pyx_n_s_pop, py_ix);
}
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static PyObject* __Pyx__PyList_PopIndex(PyObject* L, PyObject* py_ix, Py_ssize_t ix) {
    Py_ssize_t size = PyList_GET_SIZE(L);
    if (likely(size > (((PyListObject*)L)->allocated >> 1))) {
        Py_ssize_t cix = ix;
        if (cix < 0) {
            cix += size;
        }
        if (likely(__Pyx_is_valid_index(cix, size))) {
            PyObject* v = PyList_GET_ITEM(L, cix);
            __Pyx_SET_SIZE(L, Py_SIZE(L) - 1);
            size -= 1;
            memmove(&PyList_GET_ITEM(L, cix), &PyList_GET_ITEM(L, cix+1), (size_t)(size-cix)*sizeof(PyObject*));
            return v;
        }
    }
    if (py_ix == Py_None) {
        return __Pyx__PyObject_PopNewIndex(L, PyInt_FromSsize_t(ix));
    } else {
        return __Pyx__PyObject_PopIndex(L, py_ix);
    }
}
#endif

/* GetItemInt */
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j) {
    PyObject *r;
    if (!j) return NULL;
    r = PyObject_GetItem(o, j);
    Py_DECREF(j);
    return r;
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              CYTHON_NCP_UNUSED int wraparound,
                                                              CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyList_GET_SIZE(o);
    }
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyList_GET_SIZE(o)))) {
        PyObject *r = PyList_GET_ITEM(o, wrapped_i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              CYTHON_NCP_UNUSED int wraparound,
                                                              CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyTuple_GET_SIZE(o);
    }
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyTuple_GET_SIZE(o)))) {
        PyObject *r = PyTuple_GET_ITEM(o, wrapped_i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i, int is_list,
                                                     CYTHON_NCP_UNUSED int wraparound,
                                                     CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS && CYTHON_USE_TYPE_SLOTS
    if (is_list || PyList_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyList_GET_SIZE(o);
        if ((!boundscheck) || (likely(__Pyx_is_valid_index(n, PyList_GET_SIZE(o))))) {
            PyObject *r = PyList_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    }
    else if (PyTuple_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyTuple_GET_SIZE(o);
        if ((!boundscheck) || likely(__Pyx_is_valid_index(n, PyTuple_GET_SIZE(o)))) {
            PyObject *r = PyTuple_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    } else {
        PySequenceMethods *m = Py_TYPE(o)->tp_as_sequence;
        if (likely(m && m->sq_item)) {
            if (wraparound && unlikely(i < 0) && likely(m->sq_length)) {
                Py_ssize_t l = m->sq_length(o);
                if (likely(l >= 0)) {
                    i += l;
                } else {
                    if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                        return NULL;
                    PyErr_Clear();
                }
            }
            return m->sq_item(o, i);
        }
    }
#else
    if (is_list || PySequence_Check(o)) {
        return PySequence_GetItem(o, i);
    }
#endif
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
}

/* DictGetItem */
#if PY_MAJOR_VERSION >= 3 && !CYTHON_COMPILING_IN_PYPY
static PyObject *__Pyx_PyDict_GetItem(PyObject *d, PyObject* key) {
    PyObject *value;
    value = PyDict_GetItemWithError(d, key);
    if (unlikely(!value)) {
        if (!PyErr_Occurred()) {
            if (unlikely(PyTuple_Check(key))) {
                PyObject* args = PyTuple_Pack(1, key);
                if (likely(args)) {
                    PyErr_SetObject(PyExc_KeyError, args);
                    Py_DECREF(args);
                }
            } else {
                PyErr_SetObject(PyExc_KeyError, key);
            }
        }
        return NULL;
    }
    Py_INCREF(value);
    return value;
}
#endif

/* pyfrozenset_new */
static CYTHON_INLINE PyObject* __Pyx_PyFrozenSet_New(PyObject* it) {
    if (it) {
        PyObject* result;
#if CYTHON_COMPILING_IN_PYPY
        PyObject* args;
        args = PyTuple_Pack(1, it);
        if (unlikely(!args))
            return NULL;
        result = PyObject_Call((PyObject*)&PyFrozenSet_Type, args, NULL);
        Py_DECREF(args);
        return result;
#else
        if (PyFrozenSet_CheckExact(it)) {
            Py_INCREF(it);
            return it;
        }
        result = PyFrozenSet_New(it);
        if (unlikely(!result))
            return NULL;
        if (likely(PySet_GET_SIZE(result)))
            return result;
        Py_DECREF(result);
#endif
    }
#if CYTHON_USE_TYPE_SLOTS
    return PyFrozenSet_Type.tp_new(&PyFrozenSet_Type, __pyx_empty_tuple, NULL);
#else
    return PyObject_Call((PyObject*)&PyFrozenSet_Type, __pyx_empty_tuple, NULL);
#endif
}

/* PySetContains */
static int __Pyx_PySet_ContainsUnhashable(PyObject *set, PyObject *key) {
    int result = -1;
    if (PySet_Check(key) && PyErr_ExceptionMatches(PyExc_TypeError)) {
        PyObject *tmpkey;
        PyErr_Clear();
        tmpkey = __Pyx_PyFrozenSet_New(key);
        if (tmpkey != NULL) {
            result = PySet_Contains(set, tmpkey);
            Py_DECREF(tmpkey);
        }
    }
    return result;
}
static CYTHON_INLINE int __Pyx_PySet_ContainsTF(PyObject* key, PyObject* set, int eq) {
    int result = PySet_Contains(set, key);
    if (unlikely(result < 0)) {
        result = __Pyx_PySet_ContainsUnhashable(set, key);
    }
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

/* CallUnboundCMethod1 */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg) {
    if (likely(cfunc->func)) {
        int flag = cfunc->flag;
        if (flag == METH_O) {
            return (*(cfunc->func))(self, arg);
        } else if (PY_VERSION_HEX >= 0x030600B1 && flag == METH_FASTCALL) {
            if (PY_VERSION_HEX >= 0x030700A0) {
                return (*(__Pyx_PyCFunctionFast)(void*)(PyCFunction)cfunc->func)(self, &arg, 1);
            } else {
                return (*(__Pyx_PyCFunctionFastWithKeywords)(void*)(PyCFunction)cfunc->func)(self, &arg, 1, NULL);
            }
        } else if (PY_VERSION_HEX >= 0x030700A0 && flag == (METH_FASTCALL | METH_KEYWORDS)) {
            return (*(__Pyx_PyCFunctionFastWithKeywords)(void*)(PyCFunction)cfunc->func)(self, &arg, 1, NULL);
        }
    }
    return __Pyx__CallUnboundCMethod1(cfunc, self, arg);
}
#endif
static PyObject* __Pyx__CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg){
    PyObject *args, *result = NULL;
    if (unlikely(!cfunc->func && !cfunc->method) && unlikely(__Pyx_TryUnpackUnboundCMethod(cfunc) < 0)) return NULL;
#if CYTHON_COMPILING_IN_CPYTHON
    if (cfunc->func && (cfunc->flag & METH_VARARGS)) {
        args = PyTuple_New(1);
        if (unlikely(!args)) goto bad;
        Py_INCREF(arg);
        PyTuple_SET_ITEM(args, 0, arg);
        if (cfunc->flag & METH_KEYWORDS)
            result = (*(PyCFunctionWithKeywords)(void*)(PyCFunction)cfunc->func)(self, args, NULL);
        else
            result = (*cfunc->func)(self, args);
    } else {
        args = PyTuple_New(2);
        if (unlikely(!args)) goto bad;
        Py_INCREF(self);
        PyTuple_SET_ITEM(args, 0, self);
        Py_INCREF(arg);
        PyTuple_SET_ITEM(args, 1, arg);
        result = __Pyx_PyObject_Call(cfunc->method, args, NULL);
    }
#else
    args = PyTuple_Pack(2, self, arg);
    if (unlikely(!args)) goto bad;
    result = __Pyx_PyObject_Call(cfunc->method, args, NULL);
#endif
bad:
    Py_XDECREF(args);
    return result;
}

/* PyErrExceptionMatches */
#if CYTHON_FAST_THREAD_STATE
static int __Pyx_PyErr_ExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    n = PyTuple_GET_SIZE(tuple);
#if PY_MAJOR_VERSION >= 3
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
#endif
    for (i=0; i<n; i++) {
        if (__Pyx_PyErr_GivenExceptionMatches(exc_type, PyTuple_GET_ITEM(tuple, i))) return 1;
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err) {
    PyObject *exc_type = tstate->curexc_type;
    if (exc_type == err) return 1;
    if (unlikely(!exc_type)) return 0;
    if (unlikely(PyTuple_Check(err)))
        return __Pyx_PyErr_ExceptionMatchesTuple(exc_type, err);
    return __Pyx_PyErr_GivenExceptionMatches(exc_type, err);
}
#endif

/* GetAttr */
static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *o, PyObject *n) {
#if CYTHON_USE_TYPE_SLOTS
#if PY_MAJOR_VERSION >= 3
    if (likely(PyUnicode_Check(n)))
#else
    if (likely(PyString_Check(n)))
#endif
        return __Pyx_PyObject_GetAttrStr(o, n);
#endif
    return PyObject_GetAttr(o, n);
}

/* GetAttr3 */
static PyObject *__Pyx_GetAttr3Default(PyObject *d) {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    if (unlikely(!__Pyx_PyErr_ExceptionMatches(PyExc_AttributeError)))
        return NULL;
    __Pyx_PyErr_Clear();
    Py_INCREF(d);
    return d;
}
static CYTHON_INLINE PyObject *__Pyx_GetAttr3(PyObject *o, PyObject *n, PyObject *d) {
    PyObject *r = __Pyx_GetAttr(o, n);
    return (likely(r)) ? r : __Pyx_GetAttr3Default(d);
}

/* Import */
static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level) {
    PyObject *empty_list = 0;
    PyObject *module = 0;
    PyObject *global_dict = 0;
    PyObject *empty_dict = 0;
    PyObject *list;
    #if PY_MAJOR_VERSION < 3
    PyObject *py_import;
    py_import = __Pyx_PyObject_GetAttrStr(__pyx_b, __pyx_n_s_import);
    if (!py_import)
        goto bad;
    #endif
    if (from_list)
        list = from_list;
    else {
        empty_list = PyList_New(0);
        if (!empty_list)
            goto bad;
        list = empty_list;
    }
    global_dict = PyModule_GetDict(__pyx_m);
    if (!global_dict)
        goto bad;
    empty_dict = PyDict_New();
    if (!empty_dict)
        goto bad;
    {
        #if PY_MAJOR_VERSION >= 3
        if (level == -1) {
            if ((1) && (strchr(__Pyx_MODULE_NAME, '.'))) {
                module = PyImport_ImportModuleLevelObject(
                    name, global_dict, empty_dict, list, 1);
                if (!module) {
                    if (!PyErr_ExceptionMatches(PyExc_ImportError))
                        goto bad;
                    PyErr_Clear();
                }
            }
            level = 0;
        }
        #endif
        if (!module) {
            #if PY_MAJOR_VERSION < 3
            PyObject *py_level = PyInt_FromLong(level);
            if (!py_level)
                goto bad;
            module = PyObject_CallFunctionObjArgs(py_import,
                name, global_dict, empty_dict, list, py_level, (PyObject *)NULL);
            Py_DECREF(py_level);
            #else
            module = PyImport_ImportModuleLevelObject(
                name, global_dict, empty_dict, list, level);
            #endif
        }
    }
bad:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(py_import);
    #endif
    Py_XDECREF(empty_list);
    Py_XDECREF(empty_dict);
    return module;
}

/* ImportFrom */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name) {
    PyObject* value = __Pyx_PyObject_GetAttrStr(module, name);
    if (unlikely(!value) && PyErr_ExceptionMatches(PyExc_AttributeError)) {
        PyErr_Format(PyExc_ImportError,
        #if PY_MAJOR_VERSION < 3
            "cannot import name %.230s", PyString_AS_STRING(name));
        #else
            "cannot import name %S", name);
        #endif
    }
    return value;
}

/* RaiseException */
#if PY_MAJOR_VERSION < 3
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb,
                        CYTHON_UNUSED PyObject *cause) {
    __Pyx_PyThreadState_declare
    Py_XINCREF(type);
    if (!value || value == Py_None)
        value = NULL;
    else
        Py_INCREF(value);
    if (!tb || tb == Py_None)
        tb = NULL;
    else {
        Py_INCREF(tb);
        if (!PyTraceBack_Check(tb)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: arg 3 must be a traceback or None");
            goto raise_error;
        }
    }
    if (PyType_Check(type)) {
#if CYTHON_COMPILING_IN_PYPY
        if (!value) {
            Py_INCREF(Py_None);
            value = Py_None;
        }
#endif
        PyErr_NormalizeException(&type, &value, &tb);
    } else {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto raise_error;
        }
        value = type;
        type = (PyObject*) Py_TYPE(type);
        Py_INCREF(type);
        if (!PyType_IsSubtype((PyTypeObject *)type, (PyTypeObject *)PyExc_BaseException)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: exception class must be a subclass of BaseException");
            goto raise_error;
        }
    }
    __Pyx_PyThreadState_assign
    __Pyx_ErrRestore(type, value, tb);
    return;
raise_error:
    Py_XDECREF(value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
    return;
}
#else
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause) {
    PyObject* owned_instance = NULL;
    if (tb == Py_None) {
        tb = 0;
    } else if (tb && !PyTraceBack_Check(tb)) {
        PyErr_SetString(PyExc_TypeError,
            "raise: arg 3 must be a traceback or None");
        goto bad;
    }
    if (value == Py_None)
        value = 0;
    if (PyExceptionInstance_Check(type)) {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto bad;
        }
        value = type;
        type = (PyObject*) Py_TYPE(value);
    } else if (PyExceptionClass_Check(type)) {
        PyObject *instance_class = NULL;
        if (value && PyExceptionInstance_Check(value)) {
            instance_class = (PyObject*) Py_TYPE(value);
            if (instance_class != type) {
                int is_subclass = PyObject_IsSubclass(instance_class, type);
                if (!is_subclass) {
                    instance_class = NULL;
                } else if (unlikely(is_subclass == -1)) {
                    goto bad;
                } else {
                    type = instance_class;
                }
            }
        }
        if (!instance_class) {
            PyObject *args;
            if (!value)
                args = PyTuple_New(0);
            else if (PyTuple_Check(value)) {
                Py_INCREF(value);
                args = value;
            } else
                args = PyTuple_Pack(1, value);
            if (!args)
                goto bad;
            owned_instance = PyObject_Call(type, args, NULL);
            Py_DECREF(args);
            if (!owned_instance)
                goto bad;
            value = owned_instance;
            if (!PyExceptionInstance_Check(value)) {
                PyErr_Format(PyExc_TypeError,
                             "calling %R should have returned an instance of "
                             "BaseException, not %R",
                             type, Py_TYPE(value));
                goto bad;
            }
        }
    } else {
        PyErr_SetString(PyExc_TypeError,
            "raise: exception class must be a subclass of BaseException");
        goto bad;
    }
    if (cause) {
        PyObject *fixed_cause;
        if (cause == Py_None) {
            fixed_cause = NULL;
        } else if (PyExceptionClass_Check(cause)) {
            fixed_cause = PyObject_CallObject(cause, NULL);
            if (fixed_cause == NULL)
                goto bad;
        } else if (PyExceptionInstance_Check(cause)) {
            fixed_cause = cause;
            Py_INCREF(fixed_cause);
        } else {
            PyErr_SetString(PyExc_TypeError,
                            "exception causes must derive from "
                            "BaseException");
            goto bad;
        }
        PyException_SetCause(value, fixed_cause);
    }
    PyErr_SetObject(type, value);
    if (tb) {
#if CYTHON_COMPILING_IN_PYPY
        PyObject *tmp_type, *tmp_value, *tmp_tb;
        PyErr_Fetch(&tmp_type, &tmp_value, &tmp_tb);
        Py_INCREF(tb);
        PyErr_Restore(tmp_type, tmp_value, tb);
        Py_XDECREF(tmp_tb);
#else
        PyThreadState *tstate = __Pyx_PyThreadState_Current;
        PyObject* tmp_tb = tstate->curexc_traceback;
        if (tb != tmp_tb) {
            Py_INCREF(tb);
            tstate->curexc_traceback = tb;
            Py_XDECREF(tmp_tb);
        }
#endif
    }
bad:
    Py_XDECREF(owned_instance);
    return;
}
#endif

/* HasAttr */
static CYTHON_INLINE int __Pyx_HasAttr(PyObject *o, PyObject *n) {
    PyObject *r;
    if (unlikely(!__Pyx_PyBaseString_Check(n))) {
        PyErr_SetString(PyExc_TypeError,
                        "hasattr(): attribute name must be string");
        return -1;
    }
    r = __Pyx_GetAttr(o, n);
    if (unlikely(!r)) {
        PyErr_Clear();
        return 0;
    } else {
        Py_DECREF(r);
        return 1;
    }
}

/* PyObject_GenericGetAttrNoDict */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static PyObject *__Pyx_RaiseGenericGetAttributeError(PyTypeObject *tp, PyObject *attr_name) {
    PyErr_Format(PyExc_AttributeError,
#if PY_MAJOR_VERSION >= 3
                 "'%.50s' object has no attribute '%U'",
                 tp->tp_name, attr_name);
#else
                 "'%.50s' object has no attribute '%.400s'",
                 tp->tp_name, PyString_AS_STRING(attr_name));
#endif
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_GenericGetAttrNoDict(PyObject* obj, PyObject* attr_name) {
    PyObject *descr;
    PyTypeObject *tp = Py_TYPE(obj);
    if (unlikely(!PyString_Check(attr_name))) {
        return PyObject_GenericGetAttr(obj, attr_name);
    }
    assert(!tp->tp_dictoffset);
    descr = _PyType_Lookup(tp, attr_name);
    if (unlikely(!descr)) {
        return __Pyx_RaiseGenericGetAttributeError(tp, attr_name);
    }
    Py_INCREF(descr);
    #if PY_MAJOR_VERSION < 3
    if (likely(PyType_HasFeature(Py_TYPE(descr), Py_TPFLAGS_HAVE_CLASS)))
    #endif
    {
        descrgetfunc f = Py_TYPE(descr)->tp_descr_get;
        if (unlikely(f)) {
            PyObject *res = f(descr, obj, (PyObject *)tp);
            Py_DECREF(descr);
            return res;
        }
    }
    return descr;
}
#endif

/* PyObject_GenericGetAttr */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static PyObject* __Pyx_PyObject_GenericGetAttr(PyObject* obj, PyObject* attr_name) {
    if (unlikely(Py_TYPE(obj)->tp_dictoffset)) {
        return PyObject_GenericGetAttr(obj, attr_name);
    }
    return __Pyx_PyObject_GenericGetAttrNoDict(obj, attr_name);
}
#endif

/* SetVTable */
static int __Pyx_SetVtable(PyObject *dict, void *vtable) {
#if PY_VERSION_HEX >= 0x02070000
    PyObject *ob = PyCapsule_New(vtable, 0, 0);
#else
    PyObject *ob = PyCObject_FromVoidPtr(vtable, 0);
#endif
    if (!ob)
        goto bad;
    if (PyDict_SetItem(dict, __pyx_n_s_pyx_vtable, ob) < 0)
        goto bad;
    Py_DECREF(ob);
    return 0;
bad:
    Py_XDECREF(ob);
    return -1;
}

/* PyObjectGetAttrStrNoError */
static void __Pyx_PyObject_GetAttrStr_ClearAttributeError(void) {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    if (likely(__Pyx_PyErr_ExceptionMatches(PyExc_AttributeError)))
        __Pyx_PyErr_Clear();
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStrNoError(PyObject* obj, PyObject* attr_name) {
    PyObject *result;
#if CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_TYPE_SLOTS && PY_VERSION_HEX >= 0x030700B1
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro == PyObject_GenericGetAttr)) {
        return _PyObject_GenericGetAttrWithDict(obj, attr_name, NULL, 1);
    }
#endif
    result = __Pyx_PyObject_GetAttrStr(obj, attr_name);
    if (unlikely(!result)) {
        __Pyx_PyObject_GetAttrStr_ClearAttributeError();
    }
    return result;
}

/* SetupReduce */
static int __Pyx_setup_reduce_is_named(PyObject* meth, PyObject* name) {
  int ret;
  PyObject *name_attr;
  name_attr = __Pyx_PyObject_GetAttrStr(meth, __pyx_n_s_name);
  if (likely(name_attr)) {
      ret = PyObject_RichCompareBool(name_attr, name, Py_EQ);
  } else {
      ret = -1;
  }
  if (unlikely(ret < 0)) {
      PyErr_Clear();
      ret = 0;
  }
  Py_XDECREF(name_attr);
  return ret;
}
static int __Pyx_setup_reduce(PyObject* type_obj) {
    int ret = 0;
    PyObject *object_reduce = NULL;
    PyObject *object_reduce_ex = NULL;
    PyObject *reduce = NULL;
    PyObject *reduce_ex = NULL;
    PyObject *reduce_cython = NULL;
    PyObject *setstate = NULL;
    PyObject *setstate_cython = NULL;
#if CYTHON_USE_PYTYPE_LOOKUP
    if (_PyType_Lookup((PyTypeObject*)type_obj, __pyx_n_s_getstate)) goto __PYX_GOOD;
#else
    if (PyObject_HasAttr(type_obj, __pyx_n_s_getstate)) goto __PYX_GOOD;
#endif
#if CYTHON_USE_PYTYPE_LOOKUP
    object_reduce_ex = _PyType_Lookup(&PyBaseObject_Type, __pyx_n_s_reduce_ex); if (!object_reduce_ex) goto __PYX_BAD;
#else
    object_reduce_ex = __Pyx_PyObject_GetAttrStr((PyObject*)&PyBaseObject_Type, __pyx_n_s_reduce_ex); if (!object_reduce_ex) goto __PYX_BAD;
#endif
    reduce_ex = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_n_s_reduce_ex); if (unlikely(!reduce_ex)) goto __PYX_BAD;
    if (reduce_ex == object_reduce_ex) {
#if CYTHON_USE_PYTYPE_LOOKUP
        object_reduce = _PyType_Lookup(&PyBaseObject_Type, __pyx_n_s_reduce); if (!object_reduce) goto __PYX_BAD;
#else
        object_reduce = __Pyx_PyObject_GetAttrStr((PyObject*)&PyBaseObject_Type, __pyx_n_s_reduce); if (!object_reduce) goto __PYX_BAD;
#endif
        reduce = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_n_s_reduce); if (unlikely(!reduce)) goto __PYX_BAD;
        if (reduce == object_reduce || __Pyx_setup_reduce_is_named(reduce, __pyx_n_s_reduce_cython)) {
            reduce_cython = __Pyx_PyObject_GetAttrStrNoError(type_obj, __pyx_n_s_reduce_cython);
            if (likely(reduce_cython)) {
                ret = PyDict_SetItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_reduce, reduce_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
                ret = PyDict_DelItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_reduce_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
            } else if (reduce == object_reduce || PyErr_Occurred()) {
                goto __PYX_BAD;
            }
            setstate = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_n_s_setstate);
            if (!setstate) PyErr_Clear();
            if (!setstate || __Pyx_setup_reduce_is_named(setstate, __pyx_n_s_setstate_cython)) {
                setstate_cython = __Pyx_PyObject_GetAttrStrNoError(type_obj, __pyx_n_s_setstate_cython);
                if (likely(setstate_cython)) {
                    ret = PyDict_SetItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_setstate, setstate_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
                    ret = PyDict_DelItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_setstate_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
                } else if (!setstate || PyErr_Occurred()) {
                    goto __PYX_BAD;
                }
            }
            PyType_Modified((PyTypeObject*)type_obj);
        }
    }
    goto __PYX_GOOD;
__PYX_BAD:
    if (!PyErr_Occurred())
        PyErr_Format(PyExc_RuntimeError, "Unable to initialize pickling for %s", ((PyTypeObject*)type_obj)->tp_name);
    ret = -1;
__PYX_GOOD:
#if !CYTHON_USE_PYTYPE_LOOKUP
    Py_XDECREF(object_reduce);
    Py_XDECREF(object_reduce_ex);
#endif
    Py_XDECREF(reduce);
    Py_XDECREF(reduce_ex);
    Py_XDECREF(reduce_cython);
    Py_XDECREF(setstate);
    Py_XDECREF(setstate_cython);
    return ret;
}

/* TypeImport */
#ifndef __PYX_HAVE_RT_ImportType
#define __PYX_HAVE_RT_ImportType
static PyTypeObject *__Pyx_ImportType(PyObject *module, const char *module_name, const char *class_name,
    size_t size, enum __Pyx_ImportType_CheckSize check_size)
{
    PyObject *result = 0;
    char warning[200];
    Py_ssize_t basicsize;
#ifdef Py_LIMITED_API
    PyObject *py_basicsize;
#endif
    result = PyObject_GetAttrString(module, class_name);
    if (!result)
        goto bad;
    if (!PyType_Check(result)) {
        PyErr_Format(PyExc_TypeError,
            "%.200s.%.200s is not a type object",
            module_name, class_name);
        goto bad;
    }
#ifndef Py_LIMITED_API
    basicsize = ((PyTypeObject *)result)->tp_basicsize;
#else
    py_basicsize = PyObject_GetAttrString(result, "__basicsize__");
    if (!py_basicsize)
        goto bad;
    basicsize = PyLong_AsSsize_t(py_basicsize);
    Py_DECREF(py_basicsize);
    py_basicsize = 0;
    if (basicsize == (Py_ssize_t)-1 && PyErr_Occurred())
        goto bad;
#endif
    if ((size_t)basicsize < size) {
        PyErr_Format(PyExc_ValueError,
            "%.200s.%.200s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd from PyObject",
            module_name, class_name, size, basicsize);
        goto bad;
    }
    if (check_size == __Pyx_ImportType_CheckSize_Error && (size_t)basicsize != size) {
        PyErr_Format(PyExc_ValueError,
            "%.200s.%.200s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd from PyObject",
            module_name, class_name, size, basicsize);
        goto bad;
    }
    else if (check_size == __Pyx_ImportType_CheckSize_Warn && (size_t)basicsize > size) {
        PyOS_snprintf(warning, sizeof(warning),
            "%s.%s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd from PyObject",
            module_name, class_name, size, basicsize);
        if (PyErr_WarnEx(NULL, warning, 0) < 0) goto bad;
    }
    return (PyTypeObject *)result;
bad:
    Py_XDECREF(result);
    return NULL;
}
#endif

/* GetVTable */
static void* __Pyx_GetVtable(PyObject *dict) {
    void* ptr;
    PyObject *ob = PyObject_GetItem(dict, __pyx_n_s_pyx_vtable);
    if (!ob)
        goto bad;
#if PY_VERSION_HEX >= 0x02070000
    ptr = PyCapsule_GetPointer(ob, 0);
#else
    ptr = PyCObject_AsVoidPtr(ob);
#endif
    if (!ptr && !PyErr_Occurred())
        PyErr_SetString(PyExc_RuntimeError, "invalid vtable found for imported type");
    Py_DECREF(ob);
    return ptr;
bad:
    Py_XDECREF(ob);
    return NULL;
}

/* CLineInTraceback */
#ifndef CYTHON_CLINE_IN_TRACEBACK
static int __Pyx_CLineForTraceback(CYTHON_NCP_UNUSED PyThreadState *tstate, int c_line) {
    PyObject *use_cline;
    PyObject *ptype, *pvalue, *ptraceback;
#if CYTHON_COMPILING_IN_CPYTHON
    PyObject **cython_runtime_dict;
#endif
    if (unlikely(!__pyx_cython_runtime)) {
        return c_line;
    }
    __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
#if CYTHON_COMPILING_IN_CPYTHON
    cython_runtime_dict = _PyObject_GetDictPtr(__pyx_cython_runtime);
    if (likely(cython_runtime_dict)) {
        __PYX_PY_DICT_LOOKUP_IF_MODIFIED(
            use_cline, *cython_runtime_dict,
            __Pyx_PyDict_GetItemStr(*cython_runtime_dict, __pyx_n_s_cline_in_traceback))
    } else
#endif
    {
      PyObject *use_cline_obj = __Pyx_PyObject_GetAttrStr(__pyx_cython_runtime, __pyx_n_s_cline_in_traceback);
      if (use_cline_obj) {
        use_cline = PyObject_Not(use_cline_obj) ? Py_False : Py_True;
        Py_DECREF(use_cline_obj);
      } else {
        PyErr_Clear();
        use_cline = NULL;
      }
    }
    if (!use_cline) {
        c_line = 0;
        PyObject_SetAttr(__pyx_cython_runtime, __pyx_n_s_cline_in_traceback, Py_False);
    }
    else if (use_cline == Py_False || (use_cline != Py_True && PyObject_Not(use_cline) != 0)) {
        c_line = 0;
    }
    __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
    return c_line;
}
#endif

/* CodeObjectCache */
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line) {
    int start = 0, mid = 0, end = count - 1;
    if (end >= 0 && code_line > entries[end].code_line) {
        return count;
    }
    while (start < end) {
        mid = start + (end - start) / 2;
        if (code_line < entries[mid].code_line) {
            end = mid;
        } else if (code_line > entries[mid].code_line) {
             start = mid + 1;
        } else {
            return mid;
        }
    }
    if (code_line <= entries[mid].code_line) {
        return mid;
    } else {
        return mid + 1;
    }
}
static PyCodeObject *__pyx_find_code_object(int code_line) {
    PyCodeObject* code_object;
    int pos;
    if (unlikely(!code_line) || unlikely(!__pyx_code_cache.entries)) {
        return NULL;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if (unlikely(pos >= __pyx_code_cache.count) || unlikely(__pyx_code_cache.entries[pos].code_line != code_line)) {
        return NULL;
    }
    code_object = __pyx_code_cache.entries[pos].code_object;
    Py_INCREF(code_object);
    return code_object;
}
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object) {
    int pos, i;
    __Pyx_CodeObjectCacheEntry* entries = __pyx_code_cache.entries;
    if (unlikely(!code_line)) {
        return;
    }
    if (unlikely(!entries)) {
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Malloc(64*sizeof(__Pyx_CodeObjectCacheEntry));
        if (likely(entries)) {
            __pyx_code_cache.entries = entries;
            __pyx_code_cache.max_count = 64;
            __pyx_code_cache.count = 1;
            entries[0].code_line = code_line;
            entries[0].code_object = code_object;
            Py_INCREF(code_object);
        }
        return;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if ((pos < __pyx_code_cache.count) && unlikely(__pyx_code_cache.entries[pos].code_line == code_line)) {
        PyCodeObject* tmp = entries[pos].code_object;
        entries[pos].code_object = code_object;
        Py_DECREF(tmp);
        return;
    }
    if (__pyx_code_cache.count == __pyx_code_cache.max_count) {
        int new_max = __pyx_code_cache.max_count + 64;
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Realloc(
            __pyx_code_cache.entries, ((size_t)new_max) * sizeof(__Pyx_CodeObjectCacheEntry));
        if (unlikely(!entries)) {
            return;
        }
        __pyx_code_cache.entries = entries;
        __pyx_code_cache.max_count = new_max;
    }
    for (i=__pyx_code_cache.count; i>pos; i--) {
        entries[i] = entries[i-1];
    }
    entries[pos].code_line = code_line;
    entries[pos].code_object = code_object;
    __pyx_code_cache.count++;
    Py_INCREF(code_object);
}

/* AddTraceback */
#include "compile.h"
#include "frameobject.h"
#include "traceback.h"
static PyCodeObject* __Pyx_CreateCodeObjectForTraceback(
            const char *funcname, int c_line,
            int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyObject *py_srcfile = 0;
    PyObject *py_funcname = 0;
    #if PY_MAJOR_VERSION < 3
    py_srcfile = PyString_FromString(filename);
    #else
    py_srcfile = PyUnicode_FromString(filename);
    #endif
    if (!py_srcfile) goto bad;
    if (c_line) {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        #else
        py_funcname = PyUnicode_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        #endif
    }
    else {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromString(funcname);
        #else
        py_funcname = PyUnicode_FromString(funcname);
        #endif
    }
    if (!py_funcname) goto bad;
    py_code = __Pyx_PyCode_New(
        0,
        0,
        0,
        0,
        0,
        __pyx_empty_bytes, /*PyObject *code,*/
        __pyx_empty_tuple, /*PyObject *consts,*/
        __pyx_empty_tuple, /*PyObject *names,*/
        __pyx_empty_tuple, /*PyObject *varnames,*/
        __pyx_empty_tuple, /*PyObject *freevars,*/
        __pyx_empty_tuple, /*PyObject *cellvars,*/
        py_srcfile,   /*PyObject *filename,*/
        py_funcname,  /*PyObject *name,*/
        py_line,
        __pyx_empty_bytes  /*PyObject *lnotab*/
    );
    Py_DECREF(py_srcfile);
    Py_DECREF(py_funcname);
    return py_code;
bad:
    Py_XDECREF(py_srcfile);
    Py_XDECREF(py_funcname);
    return NULL;
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyFrameObject *py_frame = 0;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    if (c_line) {
        c_line = __Pyx_CLineForTraceback(tstate, c_line);
    }
    py_code = __pyx_find_code_object(c_line ? -c_line : py_line);
    if (!py_code) {
        py_code = __Pyx_CreateCodeObjectForTraceback(
            funcname, c_line, py_line, filename);
        if (!py_code) goto bad;
        __pyx_insert_code_object(c_line ? -c_line : py_line, py_code);
    }
    py_frame = PyFrame_New(
        tstate,            /*PyThreadState *tstate,*/
        py_code,           /*PyCodeObject *code,*/
        __pyx_d,    /*PyObject *globals,*/
        0                  /*PyObject *locals*/
    );
    if (!py_frame) goto bad;
    __Pyx_PyFrame_SetLineNumber(py_frame, py_line);
    PyTraceBack_Here(py_frame);
bad:
    Py_XDECREF(py_code);
    Py_XDECREF(py_frame);
}

/* CIntFromPyVerify */
#define __PYX_VERIFY_RETURN_INT(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 0)
#define __PYX_VERIFY_RETURN_INT_EXC(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 1)
#define __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, exc)\
    {\
        func_type value = func_value;\
        if (sizeof(target_type) < sizeof(func_type)) {\
            if (unlikely(value != (func_type) (target_type) value)) {\
                func_type zero = 0;\
                if (exc && unlikely(value == (func_type)-1 && PyErr_Occurred()))\
                    return (target_type) -1;\
                if (is_unsigned && unlikely(value < zero))\
                    goto raise_neg_overflow;\
                else\
                    goto raise_overflow;\
            }\
        }\
        return (target_type) value;\
    }

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_int(int value) {
    const int neg_one = (int) ((int) 0 - (int) 1), const_zero = (int) 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(int) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(int) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(int) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(int) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(int) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(int),
                                     little, !is_unsigned);
    }
}

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value) {
    const long neg_one = (long) ((long) 0 - (long) 1), const_zero = (long) 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(long) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(long) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(long) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(long),
                                     little, !is_unsigned);
    }
}

/* CIntFromPy */
static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *x) {
    const int neg_one = (int) ((int) 0 - (int) 1), const_zero = (int) 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(int) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(int, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (int) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (int) 0;
                case  1: __PYX_VERIFY_RETURN_INT(int, digit, digits[0])
                case 2:
                    if (8 * sizeof(int) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 2 * PyLong_SHIFT) {
                            return (int) (((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(int) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 3 * PyLong_SHIFT) {
                            return (int) (((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(int) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 4 * PyLong_SHIFT) {
                            return (int) (((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (int) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(int) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(int) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (int) 0;
                case -1: __PYX_VERIFY_RETURN_INT(int, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(int,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(int) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(int) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                            return (int) ((((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(int) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                            return (int) ((((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 4 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(int) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 4 * PyLong_SHIFT) {
                            return (int) ((((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(int) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(int) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            int val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (int) -1;
        }
    } else {
        int val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (int) -1;
        val = __Pyx_PyInt_As_int(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to int");
    return (int) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to int");
    return (int) -1;
}

/* CIntFromPy */
static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *x) {
    const long neg_one = (long) ((long) 0 - (long) 1), const_zero = (long) 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(long) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(long, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (long) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (long) 0;
                case  1: __PYX_VERIFY_RETURN_INT(long, digit, digits[0])
                case 2:
                    if (8 * sizeof(long) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 2 * PyLong_SHIFT) {
                            return (long) (((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(long) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 3 * PyLong_SHIFT) {
                            return (long) (((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(long) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 4 * PyLong_SHIFT) {
                            return (long) (((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (long) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(long) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (long) 0;
                case -1: __PYX_VERIFY_RETURN_INT(long, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(long,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(long) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(long) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                            return (long) ((((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(long) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                            return (long) ((((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(long) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                            return (long) ((((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(long) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            long val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (long) -1;
        }
    } else {
        long val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (long) -1;
        val = __Pyx_PyInt_As_long(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to long");
    return (long) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to long");
    return (long) -1;
}

/* FastTypeChecks */
#if CYTHON_COMPILING_IN_CPYTHON
static int __Pyx_InBases(PyTypeObject *a, PyTypeObject *b) {
    while (a) {
        a = a->tp_base;
        if (a == b)
            return 1;
    }
    return b == &PyBaseObject_Type;
}
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b) {
    PyObject *mro;
    if (a == b) return 1;
    mro = a->tp_mro;
    if (likely(mro)) {
        Py_ssize_t i, n;
        n = PyTuple_GET_SIZE(mro);
        for (i = 0; i < n; i++) {
            if (PyTuple_GET_ITEM(mro, i) == (PyObject *)b)
                return 1;
        }
        return 0;
    }
    return __Pyx_InBases(a, b);
}
#if PY_MAJOR_VERSION == 2
static int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject* exc_type2) {
    PyObject *exception, *value, *tb;
    int res;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&exception, &value, &tb);
    res = exc_type1 ? PyObject_IsSubclass(err, exc_type1) : 0;
    if (unlikely(res == -1)) {
        PyErr_WriteUnraisable(err);
        res = 0;
    }
    if (!res) {
        res = PyObject_IsSubclass(err, exc_type2);
        if (unlikely(res == -1)) {
            PyErr_WriteUnraisable(err);
            res = 0;
        }
    }
    __Pyx_ErrRestore(exception, value, tb);
    return res;
}
#else
static CYTHON_INLINE int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject *exc_type2) {
    int res = exc_type1 ? __Pyx_IsSubtype((PyTypeObject*)err, (PyTypeObject*)exc_type1) : 0;
    if (!res) {
        res = __Pyx_IsSubtype((PyTypeObject*)err, (PyTypeObject*)exc_type2);
    }
    return res;
}
#endif
static int __Pyx_PyErr_GivenExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    assert(PyExceptionClass_Check(exc_type));
    n = PyTuple_GET_SIZE(tuple);
#if PY_MAJOR_VERSION >= 3
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
#endif
    for (i=0; i<n; i++) {
        PyObject *t = PyTuple_GET_ITEM(tuple, i);
        #if PY_MAJOR_VERSION < 3
        if (likely(exc_type == t)) return 1;
        #endif
        if (likely(PyExceptionClass_Check(t))) {
            if (__Pyx_inner_PyErr_GivenExceptionMatches2(exc_type, NULL, t)) return 1;
        } else {
        }
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject* exc_type) {
    if (likely(err == exc_type)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        if (likely(PyExceptionClass_Check(exc_type))) {
            return __Pyx_inner_PyErr_GivenExceptionMatches2(err, NULL, exc_type);
        } else if (likely(PyTuple_Check(exc_type))) {
            return __Pyx_PyErr_GivenExceptionMatchesTuple(err, exc_type);
        } else {
        }
    }
    return PyErr_GivenExceptionMatches(err, exc_type);
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *exc_type1, PyObject *exc_type2) {
    assert(PyExceptionClass_Check(exc_type1));
    assert(PyExceptionClass_Check(exc_type2));
    if (likely(err == exc_type1 || err == exc_type2)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        return __Pyx_inner_PyErr_GivenExceptionMatches2(err, exc_type1, exc_type2);
    }
    return (PyErr_GivenExceptionMatches(err, exc_type1) || PyErr_GivenExceptionMatches(err, exc_type2));
}
#endif

/* CheckBinaryVersion */
static int __Pyx_check_binary_version(void) {
    char ctversion[4], rtversion[4];
    PyOS_snprintf(ctversion, 4, "%d.%d", PY_MAJOR_VERSION, PY_MINOR_VERSION);
    PyOS_snprintf(rtversion, 4, "%s", Py_GetVersion());
    if (ctversion[0] != rtversion[0] || ctversion[2] != rtversion[2]) {
        char message[200];
        PyOS_snprintf(message, sizeof(message),
                      "compiletime version %s of module '%.100s' "
                      "does not match runtime version %s",
                      ctversion, __Pyx_MODULE_NAME, rtversion);
        return PyErr_WarnEx(NULL, message, 1);
    }
    return 0;
}

/* InitStrings */
static int __Pyx_InitStrings(__Pyx_StringTabEntry *t) {
    while (t->p) {
        #if PY_MAJOR_VERSION < 3
        if (t->is_unicode) {
            *t->p = PyUnicode_DecodeUTF8(t->s, t->n - 1, NULL);
        } else if (t->intern) {
            *t->p = PyString_InternFromString(t->s);
        } else {
            *t->p = PyString_FromStringAndSize(t->s, t->n - 1);
        }
        #else
        if (t->is_unicode | t->is_str) {
            if (t->intern) {
                *t->p = PyUnicode_InternFromString(t->s);
            } else if (t->encoding) {
                *t->p = PyUnicode_Decode(t->s, t->n - 1, t->encoding, NULL);
            } else {
                *t->p = PyUnicode_FromStringAndSize(t->s, t->n - 1);
            }
        } else {
            *t->p = PyBytes_FromStringAndSize(t->s, t->n - 1);
        }
        #endif
        if (!*t->p)
            return -1;
        if (PyObject_Hash(*t->p) == -1)
            return -1;
        ++t;
    }
    return 0;
}

static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char* c_str) {
    return __Pyx_PyUnicode_FromStringAndSize(c_str, (Py_ssize_t)strlen(c_str));
}
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject* o) {
    Py_ssize_t ignore;
    return __Pyx_PyObject_AsStringAndSize(o, &ignore);
}
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
#if !CYTHON_PEP393_ENABLED
static const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    char* defenc_c;
    PyObject* defenc = _PyUnicode_AsDefaultEncodedString(o, NULL);
    if (!defenc) return NULL;
    defenc_c = PyBytes_AS_STRING(defenc);
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    {
        char* end = defenc_c + PyBytes_GET_SIZE(defenc);
        char* c;
        for (c = defenc_c; c < end; c++) {
            if ((unsigned char) (*c) >= 128) {
                PyUnicode_AsASCIIString(o);
                return NULL;
            }
        }
    }
#endif
    *length = PyBytes_GET_SIZE(defenc);
    return defenc_c;
}
#else
static CYTHON_INLINE const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    if (unlikely(__Pyx_PyUnicode_READY(o) == -1)) return NULL;
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    if (likely(PyUnicode_IS_ASCII(o))) {
        *length = PyUnicode_GET_LENGTH(o);
        return PyUnicode_AsUTF8(o);
    } else {
        PyUnicode_AsASCIIString(o);
        return NULL;
    }
#else
    return PyUnicode_AsUTF8AndSize(o, length);
#endif
}
#endif
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
    if (
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
            __Pyx_sys_getdefaultencoding_not_ascii &&
#endif
            PyUnicode_Check(o)) {
        return __Pyx_PyUnicode_AsStringAndSize(o, length);
    } else
#endif
#if (!CYTHON_COMPILING_IN_PYPY) || (defined(PyByteArray_AS_STRING) && defined(PyByteArray_GET_SIZE))
    if (PyByteArray_Check(o)) {
        *length = PyByteArray_GET_SIZE(o);
        return PyByteArray_AS_STRING(o);
    } else
#endif
    {
        char* result;
        int r = PyBytes_AsStringAndSize(o, &result, length);
        if (unlikely(r < 0)) {
            return NULL;
        } else {
            return result;
        }
    }
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject* x) {
   int is_true = x == Py_True;
   if (is_true | (x == Py_False) | (x == Py_None)) return is_true;
   else return PyObject_IsTrue(x);
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject* x) {
    int retval;
    if (unlikely(!x)) return -1;
    retval = __Pyx_PyObject_IsTrue(x);
    Py_DECREF(x);
    return retval;
}
static PyObject* __Pyx_PyNumber_IntOrLongWrongResultType(PyObject* result, const char* type_name) {
#if PY_MAJOR_VERSION >= 3
    if (PyLong_Check(result)) {
        if (PyErr_WarnFormat(PyExc_DeprecationWarning, 1,
                "__int__ returned non-int (type %.200s).  "
                "The ability to return an instance of a strict subclass of int "
                "is deprecated, and may be removed in a future version of Python.",
                Py_TYPE(result)->tp_name)) {
            Py_DECREF(result);
            return NULL;
        }
        return result;
    }
#endif
    PyErr_Format(PyExc_TypeError,
                 "__%.4s__ returned non-%.4s (type %.200s)",
                 type_name, type_name, Py_TYPE(result)->tp_name);
    Py_DECREF(result);
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x) {
#if CYTHON_USE_TYPE_SLOTS
  PyNumberMethods *m;
#endif
  const char *name = NULL;
  PyObject *res = NULL;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_Check(x) || PyLong_Check(x)))
#else
  if (likely(PyLong_Check(x)))
#endif
    return __Pyx_NewRef(x);
#if CYTHON_USE_TYPE_SLOTS
  m = Py_TYPE(x)->tp_as_number;
  #if PY_MAJOR_VERSION < 3
  if (m && m->nb_int) {
    name = "int";
    res = m->nb_int(x);
  }
  else if (m && m->nb_long) {
    name = "long";
    res = m->nb_long(x);
  }
  #else
  if (likely(m && m->nb_int)) {
    name = "int";
    res = m->nb_int(x);
  }
  #endif
#else
  if (!PyBytes_CheckExact(x) && !PyUnicode_CheckExact(x)) {
    res = PyNumber_Int(x);
  }
#endif
  if (likely(res)) {
#if PY_MAJOR_VERSION < 3
    if (unlikely(!PyInt_Check(res) && !PyLong_Check(res))) {
#else
    if (unlikely(!PyLong_CheckExact(res))) {
#endif
        return __Pyx_PyNumber_IntOrLongWrongResultType(res, name);
    }
  }
  else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_TypeError,
                    "an integer is required");
  }
  return res;
}
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject* b) {
  Py_ssize_t ival;
  PyObject *x;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_CheckExact(b))) {
    if (sizeof(Py_ssize_t) >= sizeof(long))
        return PyInt_AS_LONG(b);
    else
        return PyInt_AsSsize_t(b);
  }
#endif
  if (likely(PyLong_CheckExact(b))) {
    #if CYTHON_USE_PYLONG_INTERNALS
    const digit* digits = ((PyLongObject*)b)->ob_digit;
    const Py_ssize_t size = Py_SIZE(b);
    if (likely(__Pyx_sst_abs(size) <= 1)) {
        ival = likely(size) ? digits[0] : 0;
        if (size == -1) ival = -ival;
        return ival;
    } else {
      switch (size) {
         case 2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
      }
    }
    #endif
    return PyLong_AsSsize_t(b);
  }
  x = PyNumber_Index(b);
  if (!x) return -1;
  ival = PyInt_AsSsize_t(x);
  Py_DECREF(x);
  return ival;
}
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b) {
  return b ? __Pyx_NewRef(Py_True) : __Pyx_NewRef(Py_False);
}
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t ival) {
    return PyInt_FromSize_t(ival);
}


#endif /* Py_PYTHON_H */
